commit 2295ad5898aabc652b247446be5769e4a43184f1
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Wed Apr 26 10:19:06 2023

    Bump BASE-VER
    
    2023-04-26  Jakub Jelinek  <jakub@redhat.com>
    
            * BASE-VER: Set to 13.1.1.

diff --git a/gcc/BASE-VER b/gcc/BASE-VER
index e6ba351366d..21b80e995f7 100644
--- a/gcc/BASE-VER
+++ b/gcc/BASE-VER
@@ -1 +1 @@
-13.1.0
+13.1.1

commit f8646b8dcb18721e776c39117f62aee7ee571f21
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Apr 20 19:26:17 2023

    c: Avoid -Wenum-int-mismatch warning for redeclaration of builtin acc_on_device [PR107041]
    
    The new -Wenum-int-mismatch warning triggers with -Wsystem-headers in
    <openacc.h>, for obvious reasons the builtin acc_on_device uses int
    type argument rather than enum which isn't defined yet when the builtin
    is created, while the OpenACC spec requires it to have acc_device_t
    enum argument.  The header makes sure it has int underlying type by using
    negative and __INT_MAX__ enumerators.
    
    I've tried to make the builtin typegeneric or just varargs, but that
    changes behavior e.g. when one calls it with some C++ class which has
    cast operator to acc_device_t, so the following patch instead disables
    the warning for this builtin.
    
    2023-04-20  Jakub Jelinek  <jakub@redhat.com>
    
            PR c/107041
            * c-decl.cc (diagnose_mismatched_decls): Avoid -Wenum-int-mismatch
            warning on acc_on_device declaration.
    
            * gcc.dg/goacc/pr107041.c: New test.
    
    (cherry picked from commit 3d7ab53d6c59499624aa41c8dea0664976820b3b)

diff --git a/gcc/c/c-decl.cc b/gcc/c/c-decl.cc
index e537d33f398..1b53f2d0785 100644
--- a/gcc/c/c-decl.cc
+++ b/gcc/c/c-decl.cc
@@ -2219,7 +2219,14 @@ diagnose_mismatched_decls (tree newdecl, tree olddecl,
     }
   /* Warn about enum/integer type mismatches.  They are compatible types
      (C2X 6.7.2.2/5), but may pose portability problems.  */
-  else if (enum_and_int_p && TREE_CODE (newdecl) != TYPE_DECL)
+  else if (enum_and_int_p
+	   && TREE_CODE (newdecl) != TYPE_DECL
+	   /* Don't warn about about acc_on_device built-in redeclaration,
+	      the built-in is declared with int rather than enum because
+	      the enum isn't intrinsic.  */
+	   && !(TREE_CODE (olddecl) == FUNCTION_DECL
+		&& fndecl_built_in_p (olddecl, BUILT_IN_ACC_ON_DEVICE)
+		&& !C_DECL_DECLARED_BUILTIN (olddecl)))
     warned = warning_at (DECL_SOURCE_LOCATION (newdecl),
 			 OPT_Wenum_int_mismatch,
 			 "conflicting types for %q+D due to enum/integer "
diff --git a/gcc/testsuite/gcc.dg/goacc/pr107041.c b/gcc/testsuite/gcc.dg/goacc/pr107041.c
new file mode 100644
index 00000000000..ed7fb5a5b5d
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/goacc/pr107041.c
@@ -0,0 +1,23 @@
+/* PR c/107041 */
+/* { dg-do compile } */
+/* { dg-additional-options "-Wenum-int-mismatch" } */
+
+typedef enum acc_device_t {
+  acc_device_current = -1,
+  acc_device_none = 0,
+  acc_device_default = 1,
+  acc_device_host = 2,
+  acc_device_not_host = 4,
+  acc_device_nvidia = 5,
+  acc_device_radeon = 8,
+  _ACC_highest = __INT_MAX__
+} acc_device_t;
+
+int acc_on_device (acc_device_t);		/* { dg-bogus "conflicting types for 'acc_on_device' due to enum/integer mismatch; have 'int\\\(acc_device_t\\\)'" } */
+int acc_on_device (acc_device_t);
+
+int
+foo (void)
+{
+  return acc_on_device (acc_device_host);
+}

commit 4aeefba6cd657010a395dd187f9136cd152aac95
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Tue Apr 25 14:38:01 2023

    testsuite: Fix up ext-floating15.C tests on powerpc64-linux [PR109278]
    
    I've noticed this test FAILs on powerpc64-linux, with
    FAIL: g++.dg/cpp23/ext-floating15.C  -std=gnu++98 (test for excess errors)
    Excess errors:
    /home/jakub/gcc/gcc/testsuite/g++.dg/cpp23/ext-floating15.C:8:5: error: '_Float128' is not supported on this target
    /home/jakub/gcc/gcc/testsuite/g++.dg/cpp23/ext-floating15.C:8:5: error: '_Float128' is not supported on this target
    /home/jakub/gcc/gcc/testsuite/g++.dg/cpp23/ext-floating15.C:8:1: error: variable or field 'bar' declared void
    /home/jakub/gcc/gcc/testsuite/g++.dg/cpp23/ext-floating15.C:8:5: error: '_Float128' is not supported on this target
    /home/jakub/gcc/gcc/testsuite/g++.dg/cpp23/ext-floating15.C:8:6: error: expected primary-expression before '_Float128'
    and similarly other std versions.
    powerpc64-linux is float128 target, but needs to add some options for it.
    
    Fixed by adding them.
    
    2023-04-25  Jakub Jelinek  <jakub@redhat.com>
    
            PR c++/109278
            * g++.dg/cpp23/ext-floating15.C: Add dg-add-options float128.
    
    (cherry picked from commit 784e03f378bb2c330b96459928d0472d38748970)

diff --git a/gcc/testsuite/g++.dg/cpp23/ext-floating15.C b/gcc/testsuite/g++.dg/cpp23/ext-floating15.C
index 316dd5abacd..6d7dc6ad682 100644
--- a/gcc/testsuite/g++.dg/cpp23/ext-floating15.C
+++ b/gcc/testsuite/g++.dg/cpp23/ext-floating15.C
@@ -1,6 +1,7 @@
 // PR c++/109278
 // { dg-do compile { target float128 } }
 // { dg-options "-w" }
+// { dg-add-options float128 }
 
 void foo (long double);	// { dg-bogus "initializing argument 1 of" }
 

commit 60e0164a371de9129ec0bfdc49a93381cf79c965
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Tue Apr 25 16:00:48 2023

    testsuite: Fix up ext-floating2.C on powerpc64-linux
    
    Another testcase that is failing on powerpc64-linux.  The test expects
    a diagnostics when float64 && float128 or in another spot when
    float32 && float128.  Now, float128 effective target is satisfied on
    powerpc64-linux, despite __CPP_FLOAT128_T__ not being defined, because
    one needs to add some extra options for it.  I think 32-bit arm has
    similar case for float16.
    
    2023-04-25  Jakub Jelinek  <jakub@redhat.com>
    
            * g++.dg/cpp23/ext-floating2.C: Add dg-add-options for
            float16, float32, float64 and float128.
    
    (cherry picked from commit 78aaaf862e70cea45f3a2be7cb855cfe1a4ead21)

diff --git a/gcc/testsuite/g++.dg/cpp23/ext-floating2.C b/gcc/testsuite/g++.dg/cpp23/ext-floating2.C
index 41e9a54ada5..6ae5c6cd247 100644
--- a/gcc/testsuite/g++.dg/cpp23/ext-floating2.C
+++ b/gcc/testsuite/g++.dg/cpp23/ext-floating2.C
@@ -1,6 +1,10 @@
 // P1467R9 - Extended floating-point types and standard names.
 // { dg-do compile { target c++23 } }
 // { dg-options "" }
+// { dg-add-options float16 }
+// { dg-add-options float32 }
+// { dg-add-options float64 }
+// { dg-add-options float128 }
 
 #include "ext-floating.h"
 

commit d2e0b6a3c4965635d8ba8e217ef2272e7be66a5c
Author: Eric Botcazou <ebotcazou@adacore.com>
Date:   Tue Apr 25 10:46:16 2023

    Remove obsolete configure code in gnattools
    
    It was recently pointed out that we generate symbolic links to ghost files
    when building the GNAT tools, as the mlib-tgt-specific-*.adb files are gone.
    
    gnattools/
            * configure.ac (TOOLS_TARGET_PAIRS): Remove obsolete settings.
            (EXTRA_GNATTOOLS): Likewise.
            * configure: Regenerate.

diff --git a/gnattools/configure b/gnattools/configure
index 423527da1b6..6cdfbe67af2 100755
--- a/gnattools/configure
+++ b/gnattools/configure
@@ -2052,74 +2052,38 @@ fi
 
 # Target-specific stuff (defaults)
 TOOLS_TARGET_PAIRS=
-
 EXTRA_GNATTOOLS=
 
-
 # Per-target case statement
 # -------------------------
 case "${target}" in
   *-*-aix*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-aix.adb \
-    indepsw.adb<indepsw-aix.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-aix.adb"
     ;;
   *-*-darwin*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-darwin.adb \
-    indepsw.adb<indepsw-darwin.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-darwin.adb"
     ;;
   *-*-dragonfly*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-linux.adb \
-    indepsw.adb<indepsw-gnu.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-freebsd*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-linux.adb \
-    indepsw.adb<indepsw-gnu.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-linux*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-linux.adb \
-    indepsw.adb<indepsw-gnu.adb"
-    ;;
-  *-*-solaris*)
-    TOOLS_TARGET_PAIRS="mlib-tgt-specific.adb<mlib-tgt-specific-solaris.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-vxworks*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-vxworks.adb \
-    indepsw.adb<indepsw-gnu.adb"
-    ;;
-  hppa*-hp-hpux11*)
-    TOOLS_TARGET_PAIRS="mlib-tgt-specific.adb<mlib-tgt-specific-hpux.adb"
-    ;;
-  ia64-hp-hpux11*)
-    TOOLS_TARGET_PAIRS="mlib-tgt-specific.adb<mlib-tgt-specific-ia64-hpux.adb"
-    ;;
-  alpha*-*-vms* | alpha*-*-openvms*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-vms-alpha.adb \
-    symbols.adb<symbols-vms.adb \
-    symbols-processing.adb<symbols-processing-vms-alpha.adb"
-    EXTRA_GNATTOOLS='../../gnatlbr$(exeext) ../../gnatsym$(exeext)'
-    ;;
-  ia64-*-vms* | ia64-*-openvms*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-vms-ia64.adb \
-    symbols.adb<symbols-vms.adb \
-    symbols-processing.adb<symbols-processing-vms-ia64.adb"
-    EXTRA_GNATTOOLS='../../gnatlbr$(exeext) ../../gnatsym$(exeext)'
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-cygwin32* | *-*-mingw32* | *-*-pe)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-mingw.adb \
-    indepsw.adb<indepsw-mingw.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     EXTRA_GNATTOOLS='../../gnatdll$(exeext)'
     ;;
 esac
 
+
+
+
 # From user or toplevel makefile.
 
 
diff --git a/gnattools/configure.ac b/gnattools/configure.ac
index 5b6f34ed9f4..38a28b6ee62 100644
--- a/gnattools/configure.ac
+++ b/gnattools/configure.ac
@@ -53,74 +53,38 @@ AC_PROG_LN_S
 
 # Target-specific stuff (defaults)
 TOOLS_TARGET_PAIRS=
-AC_SUBST(TOOLS_TARGET_PAIRS)
 EXTRA_GNATTOOLS=
-AC_SUBST(EXTRA_GNATTOOLS)
 
 # Per-target case statement
 # -------------------------
 case "${target}" in
   *-*-aix*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-aix.adb \
-    indepsw.adb<indepsw-aix.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-aix.adb"
     ;;
   *-*-darwin*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-darwin.adb \
-    indepsw.adb<indepsw-darwin.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-darwin.adb"
     ;;
   *-*-dragonfly*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-linux.adb \
-    indepsw.adb<indepsw-gnu.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-freebsd*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-linux.adb \
-    indepsw.adb<indepsw-gnu.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-linux*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-linux.adb \
-    indepsw.adb<indepsw-gnu.adb"
-    ;;
-  *-*-solaris*)
-    TOOLS_TARGET_PAIRS="mlib-tgt-specific.adb<mlib-tgt-specific-solaris.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-vxworks*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-vxworks.adb \
-    indepsw.adb<indepsw-gnu.adb"
-    ;;
-  hppa*-hp-hpux11*)
-    TOOLS_TARGET_PAIRS="mlib-tgt-specific.adb<mlib-tgt-specific-hpux.adb"
-    ;;
-  ia64-hp-hpux11*)
-    TOOLS_TARGET_PAIRS="mlib-tgt-specific.adb<mlib-tgt-specific-ia64-hpux.adb"
-    ;;
-  alpha*-*-vms* | alpha*-*-openvms*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-vms-alpha.adb \
-    symbols.adb<symbols-vms.adb \
-    symbols-processing.adb<symbols-processing-vms-alpha.adb"
-    EXTRA_GNATTOOLS='../../gnatlbr$(exeext) ../../gnatsym$(exeext)'
-    ;;
-  ia64-*-vms* | ia64-*-openvms*)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-vms-ia64.adb \
-    symbols.adb<symbols-vms.adb \
-    symbols-processing.adb<symbols-processing-vms-ia64.adb"
-    EXTRA_GNATTOOLS='../../gnatlbr$(exeext) ../../gnatsym$(exeext)'
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     ;;
   *-*-cygwin32* | *-*-mingw32* | *-*-pe)
-    TOOLS_TARGET_PAIRS="\
-    mlib-tgt-specific.adb<mlib-tgt-specific-mingw.adb \
-    indepsw.adb<indepsw-mingw.adb"
+    TOOLS_TARGET_PAIRS="indepsw.adb<indepsw-gnu.adb"
     EXTRA_GNATTOOLS='../../gnatdll$(exeext)'
     ;;
 esac
 
+AC_SUBST(TOOLS_TARGET_PAIRS)
+AC_SUBST(EXTRA_GNATTOOLS)
+
 # From user or toplevel makefile.
 AC_SUBST(ADA_CFLAGS)
 

commit 263d1ed0484fc81d3f93e39cdd2f9eb0ce4d3e88
Author: Richard Biener <rguenther@suse.de>
Date:   Fri Apr 21 12:57:17 2023

    tree-optimization/109573 - avoid ICEing on unexpected live def
    
    The following relaxes the assert in vectorizable_live_operation
    where we catch currently unhandled cases to also allow an
    intermediate copy as it happens here but also relax the assert
    to checking only.
    
            PR tree-optimization/109573
            * tree-vect-loop.cc (vectorizable_live_operation): Allow
            unhandled SSA copy as well.  Demote assert to checking only.
    
            * g++.dg/vect/pr109573.cc: New testcase.
    
    (cherry picked from commit cddfe6bc40b3dc0806e260bbfb4cac82d609a258)

diff --git a/gcc/testsuite/g++.dg/vect/pr109573.cc b/gcc/testsuite/g++.dg/vect/pr109573.cc
new file mode 100644
index 00000000000..d96f86f9579
--- /dev/null
+++ b/gcc/testsuite/g++.dg/vect/pr109573.cc
@@ -0,0 +1,91 @@
+// { dg-do compile }
+// { dg-require-effective-target c++20 }
+
+void *operator new(__SIZE_TYPE__, void *__p) { return __p; }
+template <typename _Head> struct _Head_base {
+  _Head _M_head_impl;
+};
+template <unsigned long, typename...> struct _Tuple_impl;
+template <unsigned long _Idx, typename _Head, typename... _Tail>
+struct _Tuple_impl<_Idx, _Head, _Tail...> : _Tuple_impl<_Idx + 1, _Tail...>,
+                                            _Head_base<_Head> {
+  template <typename _UHead, typename... _UTail>
+  _Tuple_impl(_UHead __head, _UTail... __tail)
+      : _Tuple_impl<_Idx + 1, _Tail...>(__tail...), _Head_base<_Head>(__head) {}
+};
+template <unsigned long _Idx, typename _Head> struct _Tuple_impl<_Idx, _Head> {
+  template <typename _UHead> _Tuple_impl(_UHead);
+};
+template <typename... _Elements> struct tuple : _Tuple_impl<0, _Elements...> {
+  template <typename... _UElements>
+  tuple(_UElements... __elements)
+      : _Tuple_impl<0, _Elements...>(__elements...) {}
+};
+unsigned long position_;
+struct Zone {
+  template <typename T, typename... Args> T *New(Args... args) {
+    return new (reinterpret_cast<void *>(position_)) T(args...);
+  }
+};
+struct Label {
+  int pos_;
+  int near_link_pos_;
+};
+enum Condition { below_equal };
+void bind(Label *);
+Zone *zone();
+unsigned long deopt_info_address();
+int MakeDeferredCode___trans_tmp_2, MakeDeferredCode___trans_tmp_3,
+    Prologue___trans_tmp_6, MakeDeferredCode___trans_tmp_1;
+struct MaglevAssembler {
+  template <typename Function, typename... Args>
+  void MakeDeferredCode(Function &&, Args &&...);
+  template <typename Function, typename... Args>
+  void JumpToDeferredIf(Condition, Function, Args... args) {
+    MakeDeferredCode(Function(), args...);
+  }
+  void Prologue();
+};
+struct ZoneLabelRef {
+  ZoneLabelRef(Zone *zone) : label_(zone->New<Label>()) {}
+  ZoneLabelRef(MaglevAssembler *) : ZoneLabelRef(zone()) {}
+  Label *operator*() { return label_; }
+  Label *label_;
+};
+template <typename Function>
+struct FunctionArgumentsTupleHelper
+    : FunctionArgumentsTupleHelper<decltype(&Function::operator())> {};
+template <typename C, typename R, typename... A>
+struct FunctionArgumentsTupleHelper<R (C::*)(A...) const> {
+  using Tuple = tuple<A...>;
+};
+template <typename> struct StripFirstTupleArg;
+template <typename T1, typename... T>
+struct StripFirstTupleArg<tuple<T1, T...>> {
+  using Stripped = tuple<T...>;
+};
+template <typename Function> struct DeferredCodeInfoImpl {
+  template <typename... InArgs>
+  DeferredCodeInfoImpl(int *, int, int, Function, InArgs... args)
+      : args(args...) {}
+  StripFirstTupleArg<
+      typename FunctionArgumentsTupleHelper<Function>::Tuple>::Stripped args;
+};
+template <typename Function, typename... Args>
+void MaglevAssembler::MakeDeferredCode(Function &&deferred_code_gen,
+                                       Args &&...args) {
+  zone()->New<DeferredCodeInfoImpl<Function>>(
+      &MakeDeferredCode___trans_tmp_1, MakeDeferredCode___trans_tmp_2,
+      MakeDeferredCode___trans_tmp_3, deferred_code_gen, args...);
+}
+void MaglevAssembler::Prologue() {
+  int *__trans_tmp_9;
+  ZoneLabelRef deferred_call_stack_guard_return(this);
+  __trans_tmp_9 = reinterpret_cast<int *>(deopt_info_address());
+  JumpToDeferredIf(
+      below_equal, [](MaglevAssembler, int *, ZoneLabelRef, int, int) {},
+      __trans_tmp_9, deferred_call_stack_guard_return, Prologue___trans_tmp_6,
+      0);
+  Label __trans_tmp_7 = **deferred_call_stack_guard_return;
+  bind(&__trans_tmp_7);
+}
diff --git a/gcc/tree-vect-loop.cc b/gcc/tree-vect-loop.cc
index ba28214f09a..6ea0f21fd13 100644
--- a/gcc/tree-vect-loop.cc
+++ b/gcc/tree-vect-loop.cc
@@ -10114,9 +10114,10 @@ vectorizable_live_operation (vec_info *vinfo,
 						use_stmt))
 	      {
 		enum tree_code code = gimple_assign_rhs_code (use_stmt);
-		gcc_assert (code == CONSTRUCTOR
-			    || code == VIEW_CONVERT_EXPR
-			    || CONVERT_EXPR_CODE_P (code));
+		gcc_checking_assert (code == SSA_NAME
+				     || code == CONSTRUCTOR
+				     || code == VIEW_CONVERT_EXPR
+				     || CONVERT_EXPR_CODE_P (code));
 		if (dump_enabled_p ())
 		  dump_printf_loc (MSG_MISSED_OPTIMIZATION, vect_location,
 				   "Using original scalar computation for "

commit bb406a6aea336966681927a27f54ee89c4fd4ea1
Author: Richard Biener <rguenther@suse.de>
Date:   Mon Apr 24 13:31:07 2023

    rtl-optimization/109585 - alias analysis typo
    
    When r10-514-gc6b84edb6110dd2b4fb improved access path analysis
    it introduced a typo that triggers when there's an access to a
    trailing array in the first access path leading to false
    disambiguation.
    
            PR rtl-optimization/109585
            * tree-ssa-alias.cc (aliasing_component_refs_p): Fix typo.
    
            * gcc.dg/torture/pr109585.c: New testcase.
    
    (cherry picked from commit 6d4bd27a60447c7505cb4783e675e98a191a8904)

diff --git a/gcc/testsuite/gcc.dg/torture/pr109585.c b/gcc/testsuite/gcc.dg/torture/pr109585.c
new file mode 100644
index 00000000000..f92de7c1f2e
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/torture/pr109585.c
@@ -0,0 +1,33 @@
+/* { dg-do run } */
+
+#include <stdlib.h>
+
+struct P {
+    long v;
+    struct P *n;
+};
+
+struct F {
+    long x;
+    struct P fam[];
+};
+
+int __attribute__((noipa))
+f(struct F *f, int i)
+{
+  struct P *p = f->fam;
+  asm("" : "+r"(f): "r"(p));
+  p->v = 0;
+  p->n = 0;
+  return f->fam->n != 0;
+}
+
+int
+main()
+{
+  struct F *m = malloc (sizeof (long) + 2 * sizeof (struct P));
+  m->fam[0].n = &m->fam[1];
+  if (f (m, 0))
+    abort ();
+  return 0;
+}
diff --git a/gcc/tree-ssa-alias.cc b/gcc/tree-ssa-alias.cc
index 81bc51ed4ad..8a1ec9091fa 100644
--- a/gcc/tree-ssa-alias.cc
+++ b/gcc/tree-ssa-alias.cc
@@ -1330,7 +1330,7 @@ aliasing_component_refs_p (tree ref1,
   /* If we didn't find a common base, try the other way around.  */
   if (cmp_outer <= 0 
       || (end_struct_ref1
-	  && compare_type_sizes (TREE_TYPE (end_struct_ref1), type1) <= 0))
+	  && compare_type_sizes (TREE_TYPE (end_struct_ref1), type2) <= 0))
     {
       int res = aliasing_component_refs_walk (ref2, type2, base2,
 					      offset2, max_size2,

commit df49e4602882eabe0642699fb71a70f6e120e263
Author: Richard Biener <rguenther@suse.de>
Date:   Tue Apr 25 14:56:44 2023

    tree-optimization/109609 - correctly interpret arg size in fnspec
    
    By majority vote and a hint from the API name which is
    arg_max_access_size_given_by_arg_p this interprets a memory access
    size specified as given as other argument such as for strncpy
    in the testcase which has "1cO313" as specifying the _maximum_
    size read/written rather than the exact size.  There are two
    uses interpreting it that way already and one differing.  The
    following adjusts the differing and clarifies the documentation.
    
            PR tree-optimization/109609
            * attr-fnspec.h (arg_max_access_size_given_by_arg_p):
            Clarify semantics.
            * tree-ssa-alias.cc (check_fnspec): Correctly interpret
            the size given by arg_max_access_size_given_by_arg_p as
            maximum, not exact, size.
    
            * gcc.dg/torture/pr109609.c: New testcase.
    
    (cherry picked from commit e8d00353017f895d03a9eabae3506fd126ce1a2d)

diff --git a/gcc/attr-fnspec.h b/gcc/attr-fnspec.h
index acf1c5f6be7..99d5f896e8b 100644
--- a/gcc/attr-fnspec.h
+++ b/gcc/attr-fnspec.h
@@ -54,7 +54,7 @@
      ' '        nothing is known
      't'	the size of value written/read corresponds to the size of
 		of the pointed-to type of the argument type
-     '1'...'9'  specifies the size of value written/read is given by the
+     '1'...'9'  specifies the size of value written/read is bound by the
 		specified argument
  */
 
@@ -169,7 +169,7 @@ public:
 	   && str[idx] != 'x' && str[idx] != 'X';
   }
 
-  /* Return true if load of memory pointed to by argument I is specified
+  /* Return true if load of memory pointed to by argument I is bound
      by another argument.  In this case set ARG.  */
   bool
   arg_max_access_size_given_by_arg_p (unsigned int i, unsigned int *arg)
diff --git a/gcc/testsuite/gcc.dg/torture/pr109609.c b/gcc/testsuite/gcc.dg/torture/pr109609.c
new file mode 100644
index 00000000000..0e191cd1ee8
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/torture/pr109609.c
@@ -0,0 +1,26 @@
+/* { dg-do run } */
+
+#define N 23
+#define MAX_LEN 13
+char dst[N + 1];
+
+void __attribute__((noipa))
+invert(const char *id)
+{
+  char buf[MAX_LEN];
+  char *ptr = buf + sizeof(buf);  // start from the end of buf
+  *(--ptr) = '\0';                // terminate string
+  while (*id && ptr > buf) {
+    *(--ptr) = *(id++);           // copy id backwards
+  }
+  __builtin_strncpy(dst, ptr, N);           // copy ptr/buf to dst
+}
+
+
+int main()
+{
+  invert("abcde");
+  if (__builtin_strcmp(dst, "edcba"))
+    __builtin_abort();
+  return 0;
+}
diff --git a/gcc/tree-ssa-alias.cc b/gcc/tree-ssa-alias.cc
index 8a1ec9091fa..e0693e146bf 100644
--- a/gcc/tree-ssa-alias.cc
+++ b/gcc/tree-ssa-alias.cc
@@ -2726,9 +2726,21 @@ check_fnspec (gcall *call, ao_ref *ref, bool clobber)
 		      t = TREE_CHAIN (t);
 		    size = TYPE_SIZE_UNIT (TREE_TYPE (TREE_VALUE (t)));
 		  }
-		ao_ref_init_from_ptr_and_size (&dref,
-					       gimple_call_arg (call, i),
-					       size);
+		poly_int64 size_hwi;
+		if (size
+		    && poly_int_tree_p (size, &size_hwi)
+		    && coeffs_in_range_p (size_hwi, 0,
+					  HOST_WIDE_INT_MAX / BITS_PER_UNIT))
+		  {
+		    size_hwi = size_hwi * BITS_PER_UNIT;
+		    ao_ref_init_from_ptr_and_range (&dref,
+						    gimple_call_arg (call, i),
+						    true, 0, -1, size_hwi);
+		  }
+		else
+		  ao_ref_init_from_ptr_and_range (&dref,
+						  gimple_call_arg (call, i),
+						  false, 0, -1, -1);
 		if (refs_may_alias_p_1 (&dref, ref, false))
 		  return 1;
 	      }

commit 3411f75ea1cd3d98f77367fc4b0a54871978645d
Author: Andrew Stubbs <ams@codesourcery.com>
Date:   Fri Apr 14 18:05:15 2023

    amdgcn: HardFP divide
    
    Implement FP division using hardware instructions. This replaces both the
    softfp library calls, and the --fast-math inaccurate divsion we had previously.
    
    The GCN architecture does not have a single divide instruction, but it does
    have a number of support instructions designed to make multiply-by-reciprocal
    sufficiently accurate for non-fast-math usage.
    
    gcc/ChangeLog:
    
            * config/gcn/gcn-valu.md (SV_SFDF): New iterator.
            (SV_FP): New iterator.
            (scalar_mode, SCALAR_MODE): Add identity mappings for scalar modes.
            (recip<mode>2): Unify the two patterns using SV_FP.
            (div_scale<mode><exec_vcc>): New insn.
            (div_fmas<mode><exec>): New insn.
            (div_fixup<mode><exec>): New insn.
            (div<mode>3): Unify the two expanders and rewrite using hardfp.
            * config/gcn/gcn.cc (gcn_md_reorg): Support "vccwait" attribute.
            * config/gcn/gcn.md (unspec): Add UNSPEC_DIV_SCALE, UNSPEC_DIV_FMAS,
            and UNSPEC_DIV_FIXUP.
            (vccwait): New attribute.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/gcn/fpdiv.c: Remove the -ffast-math requirement.
    
    (cherry picked from commit cfdc45f73c56ad051a53576a4e88675ced2660d4)

diff --git a/gcc/config/gcn/gcn-valu.md b/gcc/config/gcn/gcn-valu.md
index e3d6d65e9a9..4a40a9d8d4c 100644
--- a/gcc/config/gcn/gcn-valu.md
+++ b/gcc/config/gcn/gcn-valu.md
@@ -15,6 +15,7 @@
 ;; <http://www.gnu.org/licenses/>.
 
 ;; {{{ Vector iterators
+; SV iterators include both scalar and vector modes.
 
 ; Vector modes for specific types
 (define_mode_iterator V_QI
@@ -126,6 +127,15 @@
 		       V32SI V32DI
 		       V64SI V64DI])
 
+(define_mode_iterator SV_SFDF
+		      [SF DF
+		       V2SF V2DF
+		       V4SF V4DF
+		       V8SF V8DF
+		       V16SF V16DF
+		       V32SF V32DF
+		       V64SF V64DF])
+
 ; All of above
 (define_mode_iterator V_ALL
 		      [V2QI V2HI V2HF V2SI V2SF V2DI V2DF
@@ -156,9 +166,19 @@
 		       V16HF V16SF V16DF
 		       V32HF V32SF V32DF
 		       V64HF V64SF V64DF])
+(define_mode_iterator SV_FP
+		      [HF SF DF
+		       V2HF V2SF V2DF
+		       V4HF V4SF V4DF
+		       V8HF V8SF V8DF
+		       V16HF V16SF V16DF
+		       V32HF V32SF V32DF
+		       V64HF V64SF V64DF])
 
 (define_mode_attr scalar_mode
-  [(V2QI "qi") (V2HI "hi") (V2SI "si")
+  [(QI "qi") (HI "hi") (SI "si")
+   (HF "hf") (SF "sf") (DI "di") (DF "df")
+   (V2QI "qi") (V2HI "hi") (V2SI "si")
    (V2HF "hf") (V2SF "sf") (V2DI "di") (V2DF "df")
    (V4QI "qi") (V4HI "hi") (V4SI "si")
    (V4HF "hf") (V4SF "sf") (V4DI "di") (V4DF "df")
@@ -172,7 +192,9 @@
    (V64HF "hf") (V64SF "sf") (V64DI "di") (V64DF "df")])
 
 (define_mode_attr SCALAR_MODE
-  [(V2QI "QI") (V2HI "HI") (V2SI "SI")
+  [(QI "QI") (HI "HI") (SI "SI")
+   (HF "HF") (SF "SF") (DI "DI") (DF "DF")
+   (V2QI "QI") (V2HI "HI") (V2SI "SI")
    (V2HF "HF") (V2SF "SF") (V2DI "DI") (V2DF "DF")
    (V4QI "QI") (V4HI "HI") (V4SI "SI")
    (V4HF "HF") (V4SF "SF") (V4DI "DI") (V4DF "DF")
@@ -3188,113 +3210,124 @@
 ;; {{{ FP division
 
 (define_insn "recip<mode>2<exec>"
-  [(set (match_operand:V_FP 0 "register_operand"  "=  v")
-	(unspec:V_FP
-	  [(match_operand:V_FP 1 "gcn_alu_operand" "vSvB")]
+  [(set (match_operand:SV_FP 0 "register_operand"  "=  v")
+	(unspec:SV_FP
+	  [(match_operand:SV_FP 1 "gcn_alu_operand" "vSvB")]
 	  UNSPEC_RCP))]
   ""
   "v_rcp%i0\t%0, %1"
   [(set_attr "type" "vop1")
    (set_attr "length" "8")])
 
-(define_insn "recip<mode>2"
-  [(set (match_operand:FP 0 "register_operand"	 "=  v")
-	(unspec:FP
-	  [(match_operand:FP 1 "gcn_alu_operand" "vSvB")]
-	  UNSPEC_RCP))]
-  ""
-  "v_rcp%i0\t%0, %1"
-  [(set_attr "type" "vop1")
+;; v_div_scale takes a numerator (op2) and denominator (op1) and returns the
+;; one that matches op3 adjusted for best results in reciprocal division.
+;; It also emits a VCC mask that is intended for input to v_div_fmas.
+;; The caller is expected to call this twice, once for each input.  The output
+;; VCC is the same in both cases, so the caller may discard one.
+(define_insn "div_scale<mode><exec_vcc>"
+  [(set (match_operand:SV_SFDF 0 "register_operand"   "=v")
+	(unspec:SV_SFDF
+	  [(match_operand:SV_SFDF 1 "gcn_alu_operand" "v")
+	   (match_operand:SV_SFDF 2 "gcn_alu_operand" "v")
+	   (match_operand:SV_SFDF 3 "gcn_alu_operand" "v")]
+	  UNSPEC_DIV_SCALE))
+   (set (match_operand:DI 4 "register_operand"        "=SvcV")
+	(unspec:DI
+	  [(match_dup 1) (match_dup 2) (match_dup 3)]
+	  UNSPEC_DIV_SCALE))]
+  ""
+  "v_div_scale%i0\t%0, %4, %3, %1, %2"
+  [(set_attr "type" "vop3b")
    (set_attr "length" "8")])
 
-;; Do division via a = b * 1/c
-;; The v_rcp_* instructions are not sufficiently accurate on their own,
-;; so we use 2 v_fma_* instructions to do one round of Newton-Raphson
-;; which the ISA manual says is enough to improve the reciprocal accuracy.
-;;
-;; FIXME: This does not handle denormals, NaNs, division-by-zero etc.
+;; v_div_fmas is "FMA and Scale" that uses the VCC output from v_div_scale
+;; to conditionally scale the output of the whole division operation.
+;; This is necessary to counter the adjustments made by v_div_scale and
+;; replaces the last FMA instruction of the Newton Raphson algorithm.
+(define_insn "div_fmas<mode><exec>"
+  [(set (match_operand:SV_SFDF 0 "register_operand"       "=v")
+	(unspec:SV_SFDF
+	  [(plus:SV_SFDF
+	     (mult:SV_SFDF
+	       (match_operand:SV_SFDF 1 "gcn_alu_operand" "v")
+	       (match_operand:SV_SFDF 2 "gcn_alu_operand" "v"))
+	     (match_operand:SV_SFDF 3 "gcn_alu_operand"   "v"))
+	   (match_operand:DI 4 "register_operand"         "cV")]
+	  UNSPEC_DIV_FMAS))]
+  ""
+  "v_div_fmas%i0\t%0, %1, %2, %3; %4"
+  [(set_attr "type" "vop3a")
+   (set_attr "length" "8")
+   (set_attr "vccwait" "5")])
+
+;; v_div_fixup takes the inputs and outputs of a division operation already
+;; completed and cleans up the floating-point sign bit, infinity, underflow,
+;; overflow, and NaN status.  It will also emit any FP exceptions.
+;; op1: quotient,  op2: denominator,  op3: numerator
+(define_insn "div_fixup<mode><exec>"
+  [(set (match_operand:SV_FP 0 "register_operand"    "=v")
+	(unspec:SV_FP
+	  [(match_operand:SV_FP 1 "register_operand" "v")
+	   (match_operand:SV_FP 2 "gcn_alu_operand"  "v")
+	   (match_operand:SV_FP 3 "gcn_alu_operand"  "v")]
+	  UNSPEC_DIV_FIXUP))]
+  ""
+  "v_div_fixup%i0\t%0, %1, %2, %3"
+  [(set_attr "type" "vop3a")
+   (set_attr "length" "8")])
 
 (define_expand "div<mode>3"
-  [(match_operand:V_FP 0 "gcn_valu_dst_operand")
-   (match_operand:V_FP 1 "gcn_valu_src0_operand")
-   (match_operand:V_FP 2 "gcn_valu_src0_operand")]
-  "flag_reciprocal_math"
+  [(match_operand:SV_SFDF 0 "register_operand")
+   (match_operand:SV_SFDF 1 "gcn_alu_operand")
+   (match_operand:SV_SFDF 2 "gcn_alu_operand")]
+  ""
   {
+    rtx numerator = operands[1];
+    rtx denominator = operands[2];
+
+    /* Scale the inputs if they are close to the FP limits.
+       This will be reversed later.  */
+    rtx vcc = gen_reg_rtx (DImode);
+    rtx discardedvcc = gen_reg_rtx (DImode);
+    rtx scaled_numerator = gen_reg_rtx (<MODE>mode);
+    rtx scaled_denominator = gen_reg_rtx (<MODE>mode);
+    emit_insn (gen_div_scale<mode> (scaled_denominator,
+				    denominator, numerator,
+				    denominator, discardedvcc));
+    emit_insn (gen_div_scale<mode> (scaled_numerator,
+				    denominator, numerator,
+				    numerator, vcc));
+
+    /* Find the reciprocal of the denominator, and use Newton-Raphson to
+       improve the accuracy over the basic hardware instruction.  */
     rtx one = gcn_vec_constant (<MODE>mode,
 		  const_double_from_real_value (dconst1, <SCALAR_MODE>mode));
     rtx initrcp = gen_reg_rtx (<MODE>mode);
-    rtx fma = gen_reg_rtx (<MODE>mode);
-    rtx rcp;
-    rtx num = operands[1], denom = operands[2];
-
-    bool is_rcp = (GET_CODE (num) == CONST_VECTOR
-		   && real_identical
-		        (CONST_DOUBLE_REAL_VALUE
-			  (CONST_VECTOR_ELT (num, 0)), &dconstm1));
-
-    if (is_rcp)
-      rcp = operands[0];
-    else
-      rcp = gen_reg_rtx (<MODE>mode);
-
-    emit_insn (gen_recip<mode>2 (initrcp, denom));
-    emit_insn (gen_fma<mode>4_negop2 (fma, initrcp, denom, one));
-    emit_insn (gen_fma<mode>4 (rcp, fma, initrcp, initrcp));
-
-    if (!is_rcp)
-      {
-	rtx div_est = gen_reg_rtx (<MODE>mode);
-	rtx fma2 = gen_reg_rtx (<MODE>mode);
-	rtx fma3 = gen_reg_rtx (<MODE>mode);
-	rtx fma4 = gen_reg_rtx (<MODE>mode);
-	emit_insn (gen_mul<mode>3 (div_est, num, rcp));
-	emit_insn (gen_fma<mode>4_negop2 (fma2, div_est, denom, num));
-	emit_insn (gen_fma<mode>4 (fma3, fma2, rcp, div_est));
-	emit_insn (gen_fma<mode>4_negop2 (fma4, fma3, denom, num));
-	emit_insn (gen_fma<mode>4 (operands[0], fma4, rcp, fma3));
-      }
-
-    DONE;
-  })
-
-(define_expand "div<mode>3"
-  [(match_operand:FP 0 "gcn_valu_dst_operand")
-   (match_operand:FP 1 "gcn_valu_src0_operand")
-   (match_operand:FP 2 "gcn_valu_src0_operand")]
-  "flag_reciprocal_math"
-  {
-    rtx one = const_double_from_real_value (dconst1, <MODE>mode);
-    rtx initrcp = gen_reg_rtx (<MODE>mode);
-    rtx fma = gen_reg_rtx (<MODE>mode);
-    rtx rcp;
-    rtx num = operands[1], denom = operands[2];
-
-    bool is_rcp = (GET_CODE (operands[1]) == CONST_DOUBLE
-		   && real_identical (CONST_DOUBLE_REAL_VALUE (operands[1]),
-				      &dconstm1));
-
-    if (is_rcp)
-      rcp = operands[0];
-    else
-      rcp = gen_reg_rtx (<MODE>mode);
-
-    emit_insn (gen_recip<mode>2 (initrcp, denom));
-    emit_insn (gen_fma<mode>4_negop2 (fma, initrcp, denom, one));
-    emit_insn (gen_fma<mode>4 (rcp, fma, initrcp, initrcp));
-
-    if (!is_rcp)
-      {
-	rtx div_est = gen_reg_rtx (<MODE>mode);
-	rtx fma2 = gen_reg_rtx (<MODE>mode);
-	rtx fma3 = gen_reg_rtx (<MODE>mode);
-	rtx fma4 = gen_reg_rtx (<MODE>mode);
-	emit_insn (gen_mul<mode>3 (div_est, num, rcp));
-	emit_insn (gen_fma<mode>4_negop2 (fma2, div_est, denom, num));
-	emit_insn (gen_fma<mode>4 (fma3, fma2, rcp, div_est));
-	emit_insn (gen_fma<mode>4_negop2 (fma4, fma3, denom, num));
-	emit_insn (gen_fma<mode>4 (operands[0], fma4, rcp, fma3));
-      }
-
+    rtx fma1 = gen_reg_rtx (<MODE>mode);
+    rtx rcp = gen_reg_rtx (<MODE>mode);
+    emit_insn (gen_recip<mode>2 (initrcp, scaled_denominator));
+    emit_insn (gen_fma<mode>4_negop2 (fma1, initrcp, scaled_denominator, one));
+    emit_insn (gen_fma<mode>4 (rcp, fma1, initrcp, initrcp));
+
+    /* Do the division "a/b" via "a*1/b" and use Newton-Raphson to improve
+       the accuracy.  The "div_fmas" instruction reverses any scaling
+       performed by "div_scale", above.  */
+    rtx div_est = gen_reg_rtx (<MODE>mode);
+    rtx fma2 = gen_reg_rtx (<MODE>mode);
+    rtx fma3 = gen_reg_rtx (<MODE>mode);
+    rtx fma4 = gen_reg_rtx (<MODE>mode);
+    rtx fmas = gen_reg_rtx (<MODE>mode);
+    emit_insn (gen_mul<mode>3 (div_est, scaled_numerator, rcp));
+    emit_insn (gen_fma<mode>4_negop2 (fma2, div_est, scaled_denominator,
+				      scaled_numerator));
+    emit_insn (gen_fma<mode>4 (fma3, fma2, rcp, div_est));
+    emit_insn (gen_fma<mode>4_negop2 (fma4, fma3, scaled_denominator,
+				      scaled_numerator));
+    emit_insn (gen_div_fmas<mode> (fmas, fma4, rcp, fma3, vcc));
+
+    /* Finally, use "div_fixup" to get the details right and find errors.  */
+    emit_insn (gen_div_fixup<mode> (operands[0], fmas, denominator,
+				    numerator));
     DONE;
   })
 
diff --git a/gcc/config/gcn/gcn.cc b/gcc/config/gcn/gcn.cc
index a7d278cd2f8..5608d85a1a0 100644
--- a/gcc/config/gcn/gcn.cc
+++ b/gcc/config/gcn/gcn.cc
@@ -5840,6 +5840,7 @@ gcn_md_reorg (void)
       attr_type itype = get_attr_type (insn);
       attr_unit iunit = get_attr_unit (insn);
       attr_delayeduse idelayeduse = get_attr_delayeduse (insn);
+      int ivccwait = get_attr_vccwait (insn);
       HARD_REG_SET ireads, iwrites;
       CLEAR_HARD_REG_SET (ireads);
       CLEAR_HARD_REG_SET (iwrites);
@@ -5917,6 +5918,14 @@ gcn_md_reorg (void)
 	      && ((hard_reg_set_intersect_p
 		   (prev_insn->reads, iwrites))))
 	    nops_rqd = 1 - prev_insn->age;
+
+	  /* Instruction that requires VCC is not written too close before
+	     using it.  */
+	  if (prev_insn->age < ivccwait
+	      && (hard_reg_set_intersect_p
+		  (prev_insn->writes,
+		   reg_class_contents[(int)VCC_CONDITIONAL_REG])))
+	    nops_rqd = ivccwait - prev_insn->age;
 	}
 
       /* Insert the required number of NOPs.  */
diff --git a/gcc/config/gcn/gcn.md b/gcc/config/gcn/gcn.md
index c90303c54b5..7065acf402b 100644
--- a/gcc/config/gcn/gcn.md
+++ b/gcc/config/gcn/gcn.md
@@ -90,7 +90,8 @@
   UNSPEC_RCP
   UNSPEC_FLBIT_INT
   UNSPEC_FLOOR UNSPEC_CEIL UNSPEC_SIN UNSPEC_COS UNSPEC_EXP2 UNSPEC_LOG2
-  UNSPEC_LDEXP UNSPEC_FREXP_EXP UNSPEC_FREXP_MANT])
+  UNSPEC_LDEXP UNSPEC_FREXP_EXP UNSPEC_FREXP_MANT
+  UNSPEC_DIV_SCALE UNSPEC_DIV_FMAS UNSPEC_DIV_FIXUP])
 
 ;; }}}
 ;; {{{ Attributes
@@ -302,6 +303,11 @@
 
 (define_attr "delayeduse" "yes,no" (const_string "no"))
 
+; Identify instructions that require "Manually Inserted Wait State" if
+; a previous instruction writes to VCC.  The number gives the number of NOPs.
+
+(define_attr "vccwait" "" (const_int 0))
+
 ;; }}}
 ;; {{{ Iterators useful across the wole machine description
 
diff --git a/gcc/testsuite/gcc.target/gcn/fpdiv.c b/gcc/testsuite/gcc.target/gcn/fpdiv.c
index 7125b6f6ba0..936d39cf98e 100644
--- a/gcc/testsuite/gcc.target/gcn/fpdiv.c
+++ b/gcc/testsuite/gcc.target/gcn/fpdiv.c
@@ -1,5 +1,4 @@
 /* { dg-do run } */
-/* { dg-options "-ffast-math" } */
 
 #include <stdio.h>
 #include <stdlib.h>

commit 26f58fff56d55cd6bf8860a556c9dcde9544fdc9
Author: Andrew Stubbs <ams@codesourcery.com>
Date:   Tue Apr 18 13:03:43 2023

    amdgcn: update target-supports.exp
    
    The backend can now vectorize more things.
    
    gcc/testsuite/ChangeLog:
    
            * lib/target-supports.exp
            (check_effective_target_vect_call_copysignf): Add amdgcn.
            (check_effective_target_vect_call_sqrtf): Add amdgcn.
            (check_effective_target_vect_call_ceilf): Add amdgcn.
            (check_effective_target_vect_call_floor): Add amdgcn.
            (check_effective_target_vect_logical_reduc): Add amdgcn.
    
    (cherry picked from commit 09751f52bfa6757405c85faede627129fdd0884f)

diff --git a/gcc/testsuite/lib/target-supports.exp b/gcc/testsuite/lib/target-supports.exp
index ad68af51f91..868e2c4f092 100644
--- a/gcc/testsuite/lib/target-supports.exp
+++ b/gcc/testsuite/lib/target-supports.exp
@@ -8555,7 +8555,8 @@ proc check_effective_target_vect_call_copysignf { } {
     return [check_cached_effective_target_indexed vect_call_copysignf {
       expr { [istarget i?86-*-*] || [istarget x86_64-*-*]
 	     || [istarget powerpc*-*-*]
-	     || [istarget aarch64*-*-*] }}]
+	     || [istarget aarch64*-*-*]
+             || [istarget amdgcn-*-*] }}]
 }
 
 # Return 1 if the target supports hardware square root instructions.
@@ -8591,7 +8592,8 @@ proc check_effective_target_vect_call_sqrtf { } {
 	     || [istarget i?86-*-*] || [istarget x86_64-*-*]
 	     || ([istarget powerpc*-*-*] && [check_vsx_hw_available])
 	     || ([istarget s390*-*-*]
-		 && [check_effective_target_s390_vx]) }}]
+		 && [check_effective_target_s390_vx])
+             || [istarget amdgcn-*-*] }}]
 }
 
 # Return 1 if the target supports vector lrint calls.
@@ -8636,14 +8638,16 @@ proc check_effective_target_vect_call_ceil { } {
 
 proc check_effective_target_vect_call_ceilf { } {
     return [check_cached_effective_target_indexed vect_call_ceilf {
-      expr { [istarget aarch64*-*-*] }}]
+      expr { [istarget aarch64*-*-*]
+	     || [istarget amdgcn-*-*] }}]
 }
 
 # Return 1 if the target supports vector floor calls.
 
 proc check_effective_target_vect_call_floor { } {
     return [check_cached_effective_target_indexed vect_call_floor {
-      expr { [istarget aarch64*-*-*] }}]
+      expr { [istarget aarch64*-*-*]
+	     || [istarget amdgcn-*-*] }}]
 }
 
 # Return 1 if the target supports vector floorf calls.
@@ -8699,7 +8703,8 @@ proc check_effective_target_vect_call_roundf { } {
 # Return 1 if the target supports AND, OR and XOR reduction.
 
 proc check_effective_target_vect_logical_reduc { } {
-    return [check_effective_target_aarch64_sve]
+    return [expr { [check_effective_target_aarch64_sve]
+	           || [istarget amdgcn-*-*] }]
 }
 
 # Return 1 if the target supports the fold_extract_last optab.

commit 76f6a10e41b01d69e2e8b4a21baf877ecb3a6552
Author: Andrew Stubbs <ams@codesourcery.com>
Date:   Thu Apr 20 12:11:13 2023

    amdgcn: bug fix ldexp insn
    
    The vop3 instructions don't support B constraint immediates.
    Also, take the use the SV_FP iterator to delete a redundant pattern.
    
    gcc/ChangeLog:
    
            * config/gcn/gcn-valu.md (vnsi, VnSI): Add scalar modes.
            (ldexp<mode>3): Delete.
            (ldexp<mode>3<exec>): Change "B" to "A".
    
    (cherry picked from commit 0be4fbeaa6a7a2db466a6fd2efad2afdb642bac0)

diff --git a/gcc/config/gcn/gcn-valu.md b/gcc/config/gcn/gcn-valu.md
index 4a40a9d8d4c..44c48468dd6 100644
--- a/gcc/config/gcn/gcn-valu.md
+++ b/gcc/config/gcn/gcn-valu.md
@@ -208,7 +208,9 @@
    (V64HF "HF") (V64SF "SF") (V64DI "DI") (V64DF "DF")])
 
 (define_mode_attr vnsi
-  [(V2QI "v2si") (V2HI "v2si") (V2HF "v2si") (V2SI "v2si")
+  [(QI "si") (HI "si") (SI "si")
+   (HF "si") (SF "si") (DI "si") (DF "si")
+   (V2QI "v2si") (V2HI "v2si") (V2HF "v2si") (V2SI "v2si")
    (V2SF "v2si") (V2DI "v2si") (V2DF "v2si")
    (V4QI "v4si") (V4HI "v4si") (V4HF "v4si") (V4SI "v4si")
    (V4SF "v4si") (V4DI "v4si") (V4DF "v4si")
@@ -222,7 +224,9 @@
    (V64SF "v64si") (V64DI "v64si") (V64DF "v64si")])
 
 (define_mode_attr VnSI
-  [(V2QI "V2SI") (V2HI "V2SI") (V2HF "V2SI") (V2SI "V2SI")
+  [(QI "SI") (HI "SI") (SI "SI")
+   (HF "SI") (SF "SI") (DI "SI") (DF "SI")
+   (V2QI "V2SI") (V2HI "V2SI") (V2HF "V2SI") (V2SI "V2SI")
    (V2SF "V2SI") (V2DI "V2SI") (V2DF "V2SI")
    (V4QI "V4SI") (V4HI "V4SI") (V4HF "V4SI") (V4SI "V4SI")
    (V4SF "V4SI") (V4DI "V4SI") (V4DF "V4SI")
@@ -3043,21 +3047,10 @@
 
 ; Implement ldexp pattern
 
-(define_insn "ldexp<mode>3"
-  [(set (match_operand:FP 0 "register_operand"  "=v")
-	(unspec:FP
-	  [(match_operand:FP 1 "gcn_alu_operand" "vB")
-	   (match_operand:SI 2 "gcn_alu_operand" "vSvA")]
-	  UNSPEC_LDEXP))]
-  ""
-  "v_ldexp%i0\t%0, %1, %2"
-  [(set_attr "type" "vop3a")
-   (set_attr "length" "8")])
-
 (define_insn "ldexp<mode>3<exec>"
-  [(set (match_operand:V_FP 0 "register_operand"     "=  v")
-	(unspec:V_FP
-	  [(match_operand:V_FP 1 "gcn_alu_operand"   "  vB")
+  [(set (match_operand:SV_FP 0 "register_operand"     "=  v")
+	(unspec:SV_FP
+	  [(match_operand:SV_FP 1 "gcn_alu_operand"   "  vA")
 	   (match_operand:<VnSI> 2 "gcn_alu_operand" "vSvA")]
 	  UNSPEC_LDEXP))]
   ""

commit 910735c5d7ce7607384fc1eec4189e90c8ae5c84
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Apr 27 02:21:18 2023

    Daily bump.

diff --git a/contrib/ChangeLog b/contrib/ChangeLog
index e9362593c88..ca754d92152 100644
--- a/contrib/ChangeLog
+++ b/contrib/ChangeLog
@@ -1,3 +1,10 @@
+2023-04-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-26  Jakub Jelinek  <jakub@redhat.com>
+
+	* gennews (files): Add files for GCC 13.
+
 2023-04-26  Release Manager
 
 	* GCC 13.1.0 released.
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index be07b08a516..4151c5366fa 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,59 @@
+2023-04-26  Andrew Stubbs  <ams@codesourcery.com>
+
+	Backported from master:
+	2023-04-20  Andrew Stubbs  <ams@codesourcery.com>
+
+	* config/gcn/gcn-valu.md (vnsi, VnSI): Add scalar modes.
+	(ldexp<mode>3): Delete.
+	(ldexp<mode>3<exec>): Change "B" to "A".
+
+2023-04-26  Andrew Stubbs  <ams@codesourcery.com>
+
+	Backported from master:
+	2023-04-18  Andrew Stubbs  <ams@codesourcery.com>
+
+	* config/gcn/gcn-valu.md (SV_SFDF): New iterator.
+	(SV_FP): New iterator.
+	(scalar_mode, SCALAR_MODE): Add identity mappings for scalar modes.
+	(recip<mode>2): Unify the two patterns using SV_FP.
+	(div_scale<mode><exec_vcc>): New insn.
+	(div_fmas<mode><exec>): New insn.
+	(div_fixup<mode><exec>): New insn.
+	(div<mode>3): Unify the two expanders and rewrite using hardfp.
+	* config/gcn/gcn.cc (gcn_md_reorg): Support "vccwait" attribute.
+	* config/gcn/gcn.md (unspec): Add UNSPEC_DIV_SCALE, UNSPEC_DIV_FMAS,
+	and UNSPEC_DIV_FIXUP.
+	(vccwait): New attribute.
+
+2023-04-26  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2023-04-25  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/109609
+	* attr-fnspec.h (arg_max_access_size_given_by_arg_p):
+	Clarify semantics.
+	* tree-ssa-alias.cc (check_fnspec): Correctly interpret
+	the size given by arg_max_access_size_given_by_arg_p as
+	maximum, not exact, size.
+
+2023-04-26  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2023-04-25  Richard Biener  <rguenther@suse.de>
+
+	PR rtl-optimization/109585
+	* tree-ssa-alias.cc (aliasing_component_refs_p): Fix typo.
+
+2023-04-26  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2023-04-21  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/109573
+	* tree-vect-loop.cc (vectorizable_live_operation): Allow
+	unhandled SSA copy as well.  Demote assert to checking only.
+
 2023-04-26  Release Manager
 
 	* GCC 13.1.0 released.
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 927b96ecaa8..faac45ae8d2 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20230426
+20230427
diff --git a/gcc/c/ChangeLog b/gcc/c/ChangeLog
index 7e98008a65d..2f8b8d7b0e8 100644
--- a/gcc/c/ChangeLog
+++ b/gcc/c/ChangeLog
@@ -1,3 +1,12 @@
+2023-04-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-20  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/107041
+	* c-decl.cc (diagnose_mismatched_decls): Avoid -Wenum-int-mismatch
+	warning on acc_on_device declaration.
+
 2023-04-26  Release Manager
 
 	* GCC 13.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 4badb39132c..4f603cb8f3f 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,70 @@
+2023-04-26  Andrew Stubbs  <ams@codesourcery.com>
+
+	Backported from master:
+	2023-04-20  Andrew Stubbs  <ams@codesourcery.com>
+
+	* lib/target-supports.exp
+	(check_effective_target_vect_call_copysignf): Add amdgcn.
+	(check_effective_target_vect_call_sqrtf): Add amdgcn.
+	(check_effective_target_vect_call_ceilf): Add amdgcn.
+	(check_effective_target_vect_call_floor): Add amdgcn.
+	(check_effective_target_vect_logical_reduc): Add amdgcn.
+
+2023-04-26  Andrew Stubbs  <ams@codesourcery.com>
+
+	Backported from master:
+	2023-04-18  Andrew Stubbs  <ams@codesourcery.com>
+
+	* gcc.target/gcn/fpdiv.c: Remove the -ffast-math requirement.
+
+2023-04-26  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2023-04-25  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/109609
+	* gcc.dg/torture/pr109609.c: New testcase.
+
+2023-04-26  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2023-04-25  Richard Biener  <rguenther@suse.de>
+
+	PR rtl-optimization/109585
+	* gcc.dg/torture/pr109585.c: New testcase.
+
+2023-04-26  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2023-04-21  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/109573
+	* g++.dg/vect/pr109573.cc: New testcase.
+
+2023-04-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-25  Jakub Jelinek  <jakub@redhat.com>
+
+	* g++.dg/cpp23/ext-floating2.C: Add dg-add-options for
+	float16, float32, float64 and float128.
+
+2023-04-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-25  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/109278
+	* g++.dg/cpp23/ext-floating15.C: Add dg-add-options float128.
+
+2023-04-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-20  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/107041
+	* gcc.dg/goacc/pr107041.c: New test.
+
 2023-04-26  Release Manager
 
 	* GCC 13.1.0 released.
diff --git a/gnattools/ChangeLog b/gnattools/ChangeLog
index 97676c998c1..529ecd9b163 100644
--- a/gnattools/ChangeLog
+++ b/gnattools/ChangeLog
@@ -1,3 +1,9 @@
+2023-04-26  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* configure.ac (TOOLS_TARGET_PAIRS): Remove obsolete settings.
+	(EXTRA_GNATTOOLS): Likewise.
+	* configure: Regenerate.
+
 2023-04-26  Release Manager
 
 	* GCC 13.1.0 released.

commit 7e312adcb70ca7d67f0c2cf238cddec9b3243ff9
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Apr 27 11:35:55 2023

    c: Fix up error-recovery on functions initialized as variables [PR109412]
    
    The change to allow empty initializers in C broke error-recovery on the
    following testcase.  We are emitting function %qD is initialized like a
    variable error early; if the initializer is non-empty, we just emit
    another error that the initializer is invalid.  Previously if it was empty,
    we'd emit another error that scalar is being initialized by empty
    initializer (not really correct), but now we instead just try to
    build_zero_cst for the FUNCTION_TYPE and ICE on it.
    
    The following patch just emits the same diagnostics for the empty
    initializers as we emit for the non-empty ones.
    
    2023-04-27  Jakub Jelinek  <jakub@redhat.com>
    
            PR c/107682
            PR c/109412
            * c-typeck.cc (pop_init_level): If constructor_type is FUNCTION_TYPE,
            reject empty initializer as invalid.
    
            * gcc.dg/pr109412.c: New test.
    
    (cherry picked from commit a1030fbf70eef5b635e4fbb904ec7209ebd137ca)

diff --git a/gcc/c/c-typeck.cc b/gcc/c/c-typeck.cc
index 7079d4ee145..a17879698ec 100644
--- a/gcc/c/c-typeck.cc
+++ b/gcc/c/c-typeck.cc
@@ -9374,6 +9374,11 @@ pop_init_level (location_t loc, int implicit,
 	{
 	  if (constructor_erroneous || constructor_type == error_mark_node)
 	    ret.value = error_mark_node;
+	  else if (TREE_CODE (constructor_type) == FUNCTION_TYPE)
+	    {
+	      error_init (loc, "invalid initializer");
+	      ret.value = error_mark_node;
+	    }
 	  else if (TREE_CODE (constructor_type) == POINTER_TYPE)
 	    /* Ensure this is a null pointer constant in the case of a
 	       'constexpr' object initialized with {}.  */
diff --git a/gcc/testsuite/gcc.dg/pr109412.c b/gcc/testsuite/gcc.dg/pr109412.c
new file mode 100644
index 00000000000..11adce52509
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr109412.c
@@ -0,0 +1,20 @@
+/* PR c/107682 */
+/* PR c/109412 */
+/* { dg-do compile } */
+/* { dg-options "" } */
+
+char bar () = {};	/* { dg-error "function 'bar' is initialized like a variable" } */
+			/* { dg-error "invalid initializer" "" { target *-*-* } .-1 } */
+			/* { dg-message "near initialization for 'bar'" "" { target *-*-* } .-2 } */
+char baz () = { 1 };	/* { dg-error "function 'baz' is initialized like a variable" } */
+			/* { dg-error "invalid initializer" "" { target *-*-* } .-1 } */
+			/* { dg-message "near initialization for 'baz'" "" { target *-*-* } .-2 } */
+void
+foo ()
+{
+  int qux () = {};	/* { dg-error "function 'qux' is initialized like a variable" } */
+			/* { dg-error "invalid initializer" "" { target *-*-* } .-1 } */
+			/* { dg-message "near initialization for 'qux'" "" { target *-*-* } .-2 } */
+  int corge () = { 1 };	/* { dg-error "function 'corge' is initialized like a variable" } */
+			/* { dg-error "invalid initializer" "" { target *-*-* } .-1 } */
+}			/* { dg-message "near initialization for 'corge'" "" { target *-*-* } .-2 } */

commit 297d0efc13d73d36371583c2d6d6e7a47f88cd02
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Apr 27 11:36:54 2023

    c: Fix up error-recovery on non-empty VLA initializers [PR109409]
    
    On the following testcase we ICE, because after we emit the
    variable-sized object may not be initialized except with an empty initializer
    error we don't really reset the initializer to error_mark_node and then at
    -Wformat checking time we ICE on seeing STRING_CST initializer for a VLA.
    
    The following patch just arranges for error_mark_node to be returned after
    the error diagnostics.
    
    2023-04-27  Jakub Jelinek  <jakub@redhat.com>
    
            PR c/109409
            * c-parser.cc (c_parser_initializer): Move diagnostics about
            initialization of variable sized object with non-empty initializer
            after c_parser_expr_no_commas call and ret.set_error (); after it.
    
            * gcc.dg/pr109409.c: New test.
    
    (cherry picked from commit d8842271ebf9a81128df9ae80e1d3b688749eac8)

diff --git a/gcc/c/c-parser.cc b/gcc/c/c-parser.cc
index 21bc3167ce2..3627a3fbdc7 100644
--- a/gcc/c/c-parser.cc
+++ b/gcc/c/c-parser.cc
@@ -5677,11 +5677,14 @@ c_parser_initializer (c_parser *parser, tree decl)
     {
       struct c_expr ret;
       location_t loc = c_parser_peek_token (parser)->location;
-      if (decl != error_mark_node && C_DECL_VARIABLE_SIZE (decl))
-	error_at (loc,
-		  "variable-sized object may not be initialized except "
-		  "with an empty initializer");
       ret = c_parser_expr_no_commas (parser, NULL);
+      if (decl != error_mark_node && C_DECL_VARIABLE_SIZE (decl))
+	{
+	  error_at (loc,
+		    "variable-sized object may not be initialized except "
+		    "with an empty initializer");
+	  ret.set_error ();
+	}
       /* This is handled mostly by gimplify.cc, but we have to deal with
 	 not warning about int x = x; as it is a GCC extension to turn off
 	 this warning but only if warn_init_self is zero.  */
diff --git a/gcc/testsuite/gcc.dg/pr109409.c b/gcc/testsuite/gcc.dg/pr109409.c
new file mode 100644
index 00000000000..097a511c07e
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr109409.c
@@ -0,0 +1,10 @@
+/* PR c/109409 */
+/* { dg-do compile } */
+/* { dg-options "-Wall" } */
+
+void
+foo (int n)
+{
+  const char c[n] = "1";	/* { dg-error "variable-sized object may not be initialized except with an empty initializer" } */
+  __builtin_printf (c);
+}

commit a682ab46d8b73feb19729619225183f56f26d7e6
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Wed Apr 26 13:27:59 2023

    libstdc++: Reduce Doxygen output for PDF
    
    Including the header source code in the doxygen-generated PDF file makes
    it too large, and causes pdflatex to run out of memory. If we only set
    SOURCE_BROWSER=YES for the HTML docs then we won't include the sources
    in the PDF file.
    
    There are several macros defined for std::valarray that are only used to
    generate repetitive code and then #undef'd. Those aren't useful in the
    doxygen docs, especially the ones that reuse the same name in different
    files. Omitting them avoids warnings about duplicate labels in the
    refman.tex file.
    
    libstdc++-v3/ChangeLog:
    
            * doc/doxygen/user.cfg.in (SOURCE_BROWSER): Only set to YES for
            HTML docs.
            * include/bits/gslice_array.h (_DEFINE_VALARRAY_OPERATOR): Omit
            from doxygen docs.
            * include/bits/indirect_array.h (_DEFINE_VALARRAY_OPERATOR):
            Likewise.
            * include/bits/mask_array.h (_DEFINE_VALARRAY_OPERATOR):
            Likewise.
            * include/bits/slice_array.h (_DEFINE_VALARRAY_OPERATOR):
            Likewise.
            * include/std/valarray (_DEFINE_VALARRAY_UNARY_OPERATOR)
            (_DEFINE_VALARRAY_AUGMENTED_ASSIGNMENT)
            (_DEFINE_VALARRAY_EXPR_AUGMENTED_ASSIGNMENT)
            (_DEFINE_BINARY_OPERATOR): Likewise.
    
    (cherry picked from commit afa69618d1627435841c9164b019ef98000e0365)

diff --git a/libstdc++-v3/doc/doxygen/user.cfg.in b/libstdc++-v3/doc/doxygen/user.cfg.in
index 31613f51517..9d814af8614 100644
--- a/libstdc++-v3/doc/doxygen/user.cfg.in
+++ b/libstdc++-v3/doc/doxygen/user.cfg.in
@@ -1217,7 +1217,7 @@ USE_MDFILE_AS_MAINPAGE =
 # also VERBATIM_HEADERS is set to NO.
 # The default value is: NO.
 
-SOURCE_BROWSER         = YES
+SOURCE_BROWSER         = @do_html@
 
 # Setting the INLINE_SOURCES tag to YES will include the body of functions,
 # classes and enums directly into the documentation.
diff --git a/libstdc++-v3/include/bits/gslice_array.h b/libstdc++-v3/include/bits/gslice_array.h
index f117a172678..6a48d418477 100644
--- a/libstdc++-v3/include/bits/gslice_array.h
+++ b/libstdc++-v3/include/bits/gslice_array.h
@@ -183,6 +183,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 			      _Array<size_t>(_M_index));
       }
 
+  /// @cond undocumented
 #undef _DEFINE_VALARRAY_OPERATOR
 #define _DEFINE_VALARRAY_OPERATOR(_Op, _Name)				\
   template<typename _Tp>						\
@@ -214,6 +215,7 @@ _DEFINE_VALARRAY_OPERATOR(<<, __shift_left)
 _DEFINE_VALARRAY_OPERATOR(>>, __shift_right)
 
 #undef _DEFINE_VALARRAY_OPERATOR
+  /// @endcond
 
   /// @} group numeric_arrays
 
diff --git a/libstdc++-v3/include/bits/indirect_array.h b/libstdc++-v3/include/bits/indirect_array.h
index deeed99893c..8d34a365799 100644
--- a/libstdc++-v3/include/bits/indirect_array.h
+++ b/libstdc++-v3/include/bits/indirect_array.h
@@ -174,6 +174,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       indirect_array<_Tp>::operator=(const _Expr<_Dom, _Tp>& __e) const
       { std::__valarray_copy(__e, _M_sz, _M_array, _M_index); }
 
+  /// @cond undocumented
 #undef _DEFINE_VALARRAY_OPERATOR
 #define _DEFINE_VALARRAY_OPERATOR(_Op, _Name)				\
   template<typename _Tp>						\
@@ -203,6 +204,7 @@ _DEFINE_VALARRAY_OPERATOR(<<, __shift_left)
 _DEFINE_VALARRAY_OPERATOR(>>, __shift_right)
 
 #undef _DEFINE_VALARRAY_OPERATOR
+  /// @endcond
 
   /// @} group numeric_arrays
 
diff --git a/libstdc++-v3/include/bits/mask_array.h b/libstdc++-v3/include/bits/mask_array.h
index d4112a9d0a3..a3174dd7074 100644
--- a/libstdc++-v3/include/bits/mask_array.h
+++ b/libstdc++-v3/include/bits/mask_array.h
@@ -181,6 +181,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	std::__valarray_copy(__e, __e.size(), _M_array, _M_mask);
       }
 
+  /// @cond undocumented
 #undef _DEFINE_VALARRAY_OPERATOR
 #define _DEFINE_VALARRAY_OPERATOR(_Op, _Name)				\
   template<typename _Tp>						\
@@ -213,6 +214,7 @@ _DEFINE_VALARRAY_OPERATOR(<<, __shift_left)
 _DEFINE_VALARRAY_OPERATOR(>>, __shift_right)
 
 #undef _DEFINE_VALARRAY_OPERATOR
+  /// @endcond
 
   /// @} group numeric_arrays
 
diff --git a/libstdc++-v3/include/bits/slice_array.h b/libstdc++-v3/include/bits/slice_array.h
index 571e372c292..42b136d7dce 100644
--- a/libstdc++-v3/include/bits/slice_array.h
+++ b/libstdc++-v3/include/bits/slice_array.h
@@ -245,6 +245,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     slice_array<_Tp>::operator=(const _Expr<_Dom,_Tp>& __e) const
     { std::__valarray_copy(__e, _M_sz, _M_array, _M_stride); }
 
+  /// @cond undocumented
 #undef _DEFINE_VALARRAY_OPERATOR
 #define _DEFINE_VALARRAY_OPERATOR(_Op,_Name)				\
   template<typename _Tp>						\
@@ -275,6 +276,7 @@ _DEFINE_VALARRAY_OPERATOR(<<, __shift_left)
 _DEFINE_VALARRAY_OPERATOR(>>, __shift_right)
 
 #undef _DEFINE_VALARRAY_OPERATOR
+  /// @endcond
 
   /// @} group numeric_arrays
 
diff --git a/libstdc++-v3/include/std/valarray b/libstdc++-v3/include/std/valarray
index 504d02b7359..6bd23e0914b 100644
--- a/libstdc++-v3/include/std/valarray
+++ b/libstdc++-v3/include/std/valarray
@@ -1080,6 +1080,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       return _Expr<_Closure, _Tp>(_Closure(*this, __func));
     }
 
+  /// @cond undocumented
 #define _DEFINE_VALARRAY_UNARY_OPERATOR(_Op, _Name)                     \
   template<typename _Tp>						\
     inline typename valarray<_Tp>::template _UnaryOp<_Name>::_Rt	\
@@ -1206,6 +1207,7 @@ _DEFINE_BINARY_OPERATOR(<=, __less_equal)
 _DEFINE_BINARY_OPERATOR(>=, __greater_equal)
 
 #undef _DEFINE_BINARY_OPERATOR
+  /// @endcond
 
 #if __cplusplus >= 201103L
   /**

commit 6778b885e8973d80d897eccbe669d94a29abf22f
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Thu Apr 27 00:38:43 2023

    libstdc++: Fix typos in doxygen comments
    
    libstdc++-v3/ChangeLog:
    
            * include/bits/mofunc_impl.h: Fix typo in doxygen comment.
            * include/std/format: Likewise.
    
    (cherry picked from commit 481281ccf41aa2bc596e548edaad4e57833f3340)

diff --git a/libstdc++-v3/include/bits/mofunc_impl.h b/libstdc++-v3/include/bits/mofunc_impl.h
index 47e1e506306..318a55e618f 100644
--- a/libstdc++-v3/include/bits/mofunc_impl.h
+++ b/libstdc++-v3/include/bits/mofunc_impl.h
@@ -51,14 +51,13 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
    *  @headerfile functional
    *
    *  The `std::move_only_function` class template is a call wrapper similar
-   *  to *  `std::function`, but does not require the stored target function
+   *  to `std::function`, but does not require the stored target function
    *  to be copyable.
    *
    *  It also supports const-qualification, ref-qualification, and
    *  no-throw guarantees. The qualifications and exception-specification
    *  of the `move_only_function::operator()` member function are respected
    *  when invoking the target function.
-   *
    */
   template<typename _Res, typename... _ArgTypes, bool _Noex>
     class move_only_function<_Res(_ArgTypes...) _GLIBCXX_MOF_CV
diff --git a/libstdc++-v3/include/std/format b/libstdc++-v3/include/std/format
index e4ef4f9b6d9..6edc3208afa 100644
--- a/libstdc++-v3/include/std/format
+++ b/libstdc++-v3/include/std/format
@@ -185,7 +185,7 @@ namespace __format
   __failed_to_parse_format_spec()
   { __throw_format_error("format error: failed to parse format-spec"); }
 } // namespace __format
-/// @endcond
+  /// @endcond
 
   // [format.parse.ctx], class template basic_format_parse_context
   template<typename _CharT> class basic_format_parse_context;
@@ -3870,7 +3870,7 @@ namespace __format
     };
 #endif
 } // namespace __format
-/// @@endcond
+/// @endcond
 
   template<typename... _Args>
     [[nodiscard]]

commit 08ea480cce1580823461c1ebbedf409acce48156
Author: Joseph Myers <joseph@codesourcery.com>
Date:   Thu Apr 27 21:50:55 2023

    Update gcc .po files
    
            * be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
            ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
            zh_TW.po: Update.

diff --git a/gcc/po/be.po b/gcc/po/be.po
index fad46be32f1..18388ee2845 100644
--- a/gcc/po/be.po
+++ b/gcc/po/be.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -4049,7 +4049,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7756,6 +7756,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr ""
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17430,12 +17435,12 @@ msgstr ""
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18499,110 +18504,110 @@ msgstr ""
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr ""
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr ""
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr ""
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr ""
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
 "   "
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr ""
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr ""
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr ""
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr ""
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr ""
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr ""
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr ""
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr ""
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr ""
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr ""
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr ""
 
@@ -19028,76 +19033,76 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 #| msgid "invalid string constant `%E'"
 msgid "invalid vector constant"
 msgstr "`%E' - нерэчаісная нязьменная тыпу string"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "invalid register name for `%s'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "прапушчан ініцыялізатар"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "нерэчаісны %%d аперанд"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "нерэчаісны адрас"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -19114,18 +19119,18 @@ msgid "invalid %%r value"
 msgstr "нерэчаіснае значэньне %%r"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "нерэчаіснае значэньне %%R"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
@@ -19155,7 +19160,7 @@ msgstr "нерэчаіснае значэньне %%M"
 msgid "invalid %%U value"
 msgstr "нерэчаіснае значэньне %%U"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
@@ -19165,7 +19170,7 @@ msgstr "нерэчаіснае значэньне %%v"
 msgid "invalid %%C value"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
@@ -19178,7 +19183,7 @@ msgstr ""
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "нерэчаіснае значэньне %%xn"
@@ -19263,36 +19268,36 @@ msgstr "нерэчаісны %%-код"
 msgid "unrecognized supposed constant"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19301,26 +19306,26 @@ msgstr "Нерэчаісны выбар \"%s\""
 msgid "invalid operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr ""
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr ""
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19699,100 +19704,100 @@ msgstr "`%E' - нерэчаісная нязьменная тыпу string"
 msgid "Expected register or constant integer."
 msgstr ""
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of register '%s'"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of asm flag output"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
-msgid "invalid operand type used with operand code 'Z'"
-msgstr "нерэчаісны %%-код"
+msgid "invalid operand type used with operand code '%c'"
+msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "нерэчаісны %%-код"
+msgid "invalid operand size for operand code '%c'"
+msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid constraints for operand"
 msgstr "нерэчаісны %%c аперанд"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "невядомы рэжым машыны \"%s\""
@@ -19829,7 +19834,7 @@ msgstr "нерэчаісны %%-код"
 msgid "invalid %%P operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -19876,8 +19881,8 @@ msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, fuzzy, c-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of '%%%c'"
@@ -19910,7 +19915,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -20081,7 +20086,7 @@ msgstr "нераспазнаны адрас"
 msgid "unsupported memory expression:"
 msgstr "непадтрымліваемая версія"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid vector operand"
@@ -20136,150 +20141,150 @@ msgstr ""
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%A value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%t value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "нерэчаіснае значэньне %%V"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr ""
 
@@ -20742,7 +20747,7 @@ msgstr ""
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -21240,7 +21245,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "увага:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -21406,11 +21411,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr ""
 
@@ -21418,219 +21423,219 @@ msgstr ""
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 #| msgid "no arguments"
 msgid "value argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr ""
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -21643,27 +21648,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22574,7 +22579,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -22970,7 +22975,7 @@ msgstr ""
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -23069,10 +23074,10 @@ msgstr ""
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -23211,7 +23216,7 @@ msgstr "немагчыма знайсьці файл для кляса %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -25099,7 +25104,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25892,7 +25897,7 @@ msgstr ""
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -27016,14 +27021,14 @@ msgstr ""
 msgid "using a dangling pointer to %qD"
 msgstr ""
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -27069,7 +27074,7 @@ msgstr ""
 msgid "call to %qD"
 msgstr ""
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr ""
@@ -28138,7 +28143,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr ""
@@ -29107,7 +29112,7 @@ msgstr ""
 msgid "command-line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -29149,12 +29154,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -29313,7 +29318,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -29354,186 +29359,186 @@ msgstr ""
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr ""
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr ""
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qs attribute directive ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr ""
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr ""
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr ""
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr ""
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr ""
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter `%s'"
 msgid "unknown stack check parameter %qs"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, fuzzy, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr ""
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -30217,190 +30222,190 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function symbol is not function"
 msgstr "функцыя не вяртае тып string"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "node has invalid order %i"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "node is alias but not definition"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr ""
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -32083,27 +32088,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -32927,7 +32932,7 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr ""
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -35050,7 +35055,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36747,7 +36752,7 @@ msgstr "вельмі шмат уваходзячых файлаў"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -36779,15 +36784,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -36876,48 +36881,48 @@ msgstr ""
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -37403,13 +37408,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -37649,7 +37654,7 @@ msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
@@ -37691,7 +37696,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -37778,326 +37783,326 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%Q value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Нераспазнаны выбар \"%s\""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s не падтрымлівае %s"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %wd"
 msgstr "непадтрымліваемая версія"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -38284,13 +38289,13 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -38433,17 +38438,17 @@ msgstr "памер \"%s\" больш чам %d байт"
 msgid "%qE attribute only applies to variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
@@ -38654,7 +38659,7 @@ msgstr "ISO C не падтрымлівае комлексныя цэлалік
 msgid "target CPU does not support unaligned accesses"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
@@ -38709,7 +38714,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
@@ -38815,7 +38820,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -38865,32 +38870,32 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -38898,23 +38903,23 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "-pipe не падтрымліваецца"
@@ -38992,18 +38997,18 @@ msgstr "-pipe не падтрымліваецца"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "%qs function cannot have arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "%qs function cannot return a value"
@@ -39327,7 +39332,7 @@ msgstr "не хапае аргументаў у функцыі"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "invalid argument to built-in function"
@@ -39933,753 +39938,753 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s does not support %s"
 msgid "code model %s does not support PIC mode"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr ""
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr ""
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -41028,7 +41033,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -42162,52 +42167,52 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -42227,67 +42232,72 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "%qs is not a valid base register in %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, gcc-internal-format
@@ -42764,99 +42774,99 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 #| msgid "%s=%s is too large"
 msgid "%s%qs%s is not allowed"
 msgstr "%s=%s вельмі вялікі"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -44279,7 +44289,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -44469,7 +44479,7 @@ msgstr ""
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -44646,7 +44656,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -44775,7 +44785,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "тып параметра \"%s\" не аб'яўлены"
@@ -44979,7 +44989,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr ""
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -45031,7 +45041,7 @@ msgstr ""
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -45078,7 +45088,7 @@ msgstr "абвяшчэньне `%#D'"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -45123,7 +45133,7 @@ msgstr ""
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr ""
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
@@ -45155,7 +45165,7 @@ msgstr "няма папярэдняга прататыпа для \"%s\""
 msgid "%qD was used with no prototype before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %qD"
@@ -45275,12 +45285,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -47345,7 +47355,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
@@ -47476,12 +47486,12 @@ msgstr ""
 msgid "variant %qD is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47743,7 +47753,7 @@ msgstr ""
 msgid "invalid use of flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr ""
@@ -48699,12 +48709,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -48745,7 +48755,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -48760,8 +48770,8 @@ msgstr ""
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -48851,7 +48861,7 @@ msgstr ""
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -50206,7 +50216,7 @@ msgstr "немагчымы апэратар '%s'"
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -50216,7 +50226,7 @@ msgstr "\"%s\" не абвешчан (першае выкарыстанне ў 
 msgid "%q#D is protected within this context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared protected here"
@@ -50232,7 +50242,7 @@ msgstr ""
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
@@ -50564,7 +50574,7 @@ msgstr ""
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -51138,7 +51148,7 @@ msgstr ""
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
@@ -51261,7 +51271,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -51330,7 +51340,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
@@ -51379,7 +51389,7 @@ msgstr ""
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -51503,7 +51513,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -51602,7 +51612,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -51681,7 +51691,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -51748,190 +51758,190 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr ""
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -52516,7 +52526,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr ""
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr ""
@@ -52608,7 +52618,7 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 msgid "no suspend point info for %qD"
 msgstr ""
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -52629,23 +52639,23 @@ msgstr ""
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -53131,7 +53141,7 @@ msgstr "папярэдняе абвяшчэньне `%D'"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -53542,2305 +53552,2305 @@ msgstr "\"%s\" звычайна функцыя"
 msgid "%q#T is not a class"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr ""
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr ""
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Не магу знайсці дэкларацыю інтэрфейса для \"%s\""
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' павінна вяртаць `int'"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a variable concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "size of array %qD has non-integral type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as array of void"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr ""
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qE as non-member"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr ""
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr ""
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr ""
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qs declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "%<explicit%> outside class declaration"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "Не магу знайсці дэкларацыю пратакола для \"%s\""
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "нерэчаіснае выкарыстаньне `::'"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %qD as member of %qT"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "%qD cannot be %qs"
 msgstr "[нельга знайсці %s]"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr ""
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "%qD must have no arguments"
 msgstr "няма аргументаў"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qD has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qT has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -55852,111 +55862,111 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr ""
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of %qT as a non-template"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr ""
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "паўтарэнне \"restrict\""
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -55965,83 +55975,83 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "не знойдзен клас \"%s\""
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, gcc-internal-format
 msgid "using %qs"
 msgstr ""
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -56896,7 +56906,7 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -57955,7 +57965,7 @@ msgstr ""
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr ""
@@ -58707,7 +58717,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -59430,12 +59440,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -60041,7 +60051,7 @@ msgstr "невыкарыстаемы параметр \"%s\""
 msgid "%qT not permitted in template argument"
 msgstr ""
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
@@ -60912,7 +60922,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
@@ -61930,7 +61940,7 @@ msgstr ""
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
@@ -62026,279 +62036,279 @@ msgstr "функцыя не вяртае тып string"
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -62310,164 +62320,164 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr ""
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr ""
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -62781,7 +62791,7 @@ msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -63189,27 +63199,27 @@ msgstr ""
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -63217,22 +63227,22 @@ msgstr ""
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -64481,223 +64491,223 @@ msgstr "няма папярэдняга аб'яўлення для \"%s\""
 msgid "declaration of %q#T"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of pack expansion %qT"
 msgstr "нерэчаіснае выкарыстаньне `%T'"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr ""
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr ""
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
@@ -65637,7 +65647,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -66734,12 +66744,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -66921,7 +66931,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -68938,7 +68948,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -69209,7 +69219,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -69327,7 +69337,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
@@ -69337,7 +69347,7 @@ msgstr ""
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
@@ -69468,7 +69478,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -69685,12 +69695,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -69800,563 +69810,563 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "не знойдзен клас \"%s\""
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -70541,7 +70551,7 @@ msgstr "пераўтварэньне з `%T' у `%T'"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
@@ -71094,7 +71104,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -71665,7 +71675,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -73527,8 +73537,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -75497,710 +75507,720 @@ msgstr ""
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr ""
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr ""
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr ""
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr ""
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr ""
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "метка \"%s\" вызначана, але не выкарыстоўваецца"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "Substring end index at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -76209,12 +76229,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -76223,293 +76243,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -76518,284 +76538,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -76803,207 +76823,207 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -77011,987 +77031,987 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "String length at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr ""
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -78892,7 +78912,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -78904,12 +78924,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -79002,82 +79022,87 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr ""
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "unused variable `%s'"
 msgid "Unused variable %qs declared at %L"
 msgstr "невыкарыстоўваемая пераменная \"%s\""
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -79092,28 +79117,28 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
diff --git a/gcc/po/da.po b/gcc/po/da.po
index 51771709780..1e91ff4fc8b 100644
--- a/gcc/po/da.po
+++ b/gcc/po/da.po
@@ -137,7 +137,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc-9.1-b20190203\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2019-02-14 11:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
@@ -4341,7 +4341,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -8303,6 +8303,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Understøt indbyggede MMX- og SSE-funktioner og kodegenerering"
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -18683,12 +18689,12 @@ msgstr "»%%l«-operand er ikke en etiket"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "kommatalskonstant misbrugt"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -19777,65 +19783,65 @@ msgstr "Dette tilvalg mangler dokumentation."
 msgid "Uses of this option are diagnosed."
 msgstr "Brug af dette tilvalg diagnosticeres."
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s%s."
 msgstr "%s Samme som %s."
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s."
 msgstr "%s Samme som %s."
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s Samme som %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[standard]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[aktiveret]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[deaktiveret]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Ingen tilvalg med de ønskede karakteristika blev fundet\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Ingen fundet. Brug --help=%s for at vise *alle* tilvalgene understøttet af brugerfladen %s.\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Alle tilvalg med de ønskede karakteristika er allerede blevet vist\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "invalid type argument"
 msgid ""
@@ -19843,49 +19849,49 @@ msgid ""
 "   "
 msgstr "ugyldig typeparameter"
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "De følgende tilvalg er målspecifikke"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "De følgende tilvalg kontrollerer advarselsbeskeder for oversætteren"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "De følgende tilvalg kontrollerer optimeringer"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "De følgende tilvalg er sproguafhængige"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options control optimizations"
 msgid "The following options control parameters"
 msgstr "De følgende tilvalg kontrollerer optimeringer"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "De følgende tilvalg er specifikke kun for sproget "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "De følgende tilvalg er understøttet af sproget "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "De følgende tilvalg er ikke dokumenterede"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "De følgende tilvalg anvender forskellige parametre"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "De følgende tilvalg anvender fælles parametre"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "De følgende tilvalg er sprogrelaterede"
 
@@ -20275,78 +20281,78 @@ msgstr "længdemodifikation i strfmon-formatering"
 msgid "<command-line>"
 msgstr "<kommandolinje>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "invalid operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "manglende operand"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "ugyldig operand"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ugyldig operandpræfiks »%%%c«"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ugyldig adresseringstilstand"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands to binary %s"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ugyldige operander til binær %s"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« brugt uden nogle lokale dynamiske TLS-referencer"
@@ -20363,18 +20369,18 @@ msgid "invalid %%r value"
 msgstr "ugyldig %%r-værdi"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "ugyldig %%R-værdi"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
@@ -20404,7 +20410,7 @@ msgstr "ugyldig %%M-værdi"
 msgid "invalid %%U value"
 msgstr "ugyldig %%U-værdi"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
@@ -20414,7 +20420,7 @@ msgstr "ugyldig %%s-værdi"
 msgid "invalid %%C value"
 msgstr "ugyldig %%C-værdi"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
@@ -20427,7 +20433,7 @@ msgstr "ukendt relokaliserings-unspec"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ugyldig %%xn-kode"
@@ -20511,37 +20517,37 @@ msgstr "ugyldig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "ukendt formodet konstant"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "ugyldig skift-operand"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, fuzzy, c-format
 #| msgid "Generate char instructions"
 msgid "predicated Thumb instruction"
 msgstr "Generér char-instruktioner"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, fuzzy, c-format
 #| msgid "ret instruction not implemented"
 msgid "predicated instruction in conditional sequence"
 msgstr "ret-instruktion ikke implementeret"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -20550,30 +20556,30 @@ msgstr "Ikke understøttet operand for koden »%c«"
 msgid "invalid operand for code '%c'"
 msgstr "ugyldig operand for koden »%c«"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktion aldrig udført"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "forældet Maverick-formatkode »%c«"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -20954,100 +20960,102 @@ msgstr "ugyldig konstant:"
 msgid "Expected register or constant integer."
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ugyldig UNSPEC som operand"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of register '%s'"
 msgstr "ugyldig brug af 'restrict'"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ugyldig brug af asm-flaguddata"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ugyldig operandstørrelse for operandkoden »O«"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ugyldig operandstørrelse for operandkoden »z«"
 
-#: config/i386/i386.cc:13283
-#, c-format
-msgid "invalid operand type used with operand code 'Z'"
+#: config/i386/i386.cc:13290
+#, fuzzy, c-format
+#| msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "ugyldig operandtype brugt med operandkoden »Z«"
 
-#: config/i386/i386.cc:13288
-#, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "ugyldig operandstørrelse for operandkoden »Z«"
+#: config/i386/i386.cc:13295
+#, fuzzy, c-format
+#| msgid "invalid operand size for operand code 'O'"
+msgid "invalid operand size for operand code '%c'"
+msgstr "ugyldig operandstørrelse for operandkoden »O«"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »Y«"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »D«"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »%c«"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand er ikke en offsettable-hukommelsesreference, ugyldig operandkode »H«"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »K«"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »R«"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 #| msgid "operand is not a specific integer, invalid operand code 'r'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ugyldig operandkode »%c«"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ugyldige begrænsninger for operand"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector immediate"
 msgstr "ugyldig konstant:"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "ukendt instruktionstilstand"
 
@@ -21078,7 +21086,7 @@ msgstr "ugyldig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ugyldig %%P-operand"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -21123,8 +21131,8 @@ msgstr "»%%%c« er ikke et gyldigt operandpræfiks"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ugyldig brug af »%%%c«"
@@ -21156,7 +21164,7 @@ msgid "post-increment address is not a register"
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -21325,7 +21333,7 @@ msgstr "ikke-understøttet kombination: %s"
 msgid "unsupported memory expression:"
 msgstr "fast-punkt-konvertering er ikke understøttet"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -21394,154 +21402,154 @@ msgstr "-mquad-memory er ikke tilgængelig i lilleendet tilstand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "ugyldig %%D-værdi"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "ugyldig %%e-værdi"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "ugyldig %%z-værdi"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr "Kunne ikke generere addis-værdi for fusion"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kunne ikke generere indlæsning/lagring af forskydning for fusion"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "Ugyldig GPR-fusion"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -22008,7 +22016,7 @@ msgstr "kandidat 1:"
 msgid "  after user-defined conversion:"
 msgstr "Aktivér brug af DB-instruktioner"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -22545,7 +22553,7 @@ msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 msgid "Driving:"
 msgstr "advarsel: "
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -22735,11 +22743,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "tildeling"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 #, fuzzy
 #| msgid "assignment"
 msgid "pointer assignment"
@@ -22749,233 +22757,233 @@ msgstr "tildeling"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 #, fuzzy
 #| msgid "Do not allocate BK register"
 msgid "pointer or allocatable result"
 msgstr "Allokér ikke BK-registeret"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 #, fuzzy
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ugyldigt udtryk som operand"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -22988,27 +22996,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -23970,7 +23978,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-g er kun understøttet ved brug af GAS på denne processor,"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at '%s' token"
 msgid "Syntax error in %s statement at %C"
@@ -24370,7 +24378,7 @@ msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
@@ -24475,10 +24483,10 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -24621,7 +24629,7 @@ msgstr "kan ikke læse funktionsprofil fra %s."
 msgid "offset %qwi outside bounds of constant string"
 msgstr "forskydning udenfor grænserne af konstant streng"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qE declared here"
@@ -26628,7 +26636,7 @@ msgstr "stort heltal forkortes underforstået til type uden fortegn"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "sammenligning er altid %d på grund af den begrænsede rækkevidde af bitfeltet"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -27467,7 +27475,7 @@ msgstr "funktion returnerer adressen på en lokal variabel"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -28682,14 +28690,14 @@ msgstr "antager henvisning til medlemmet '%D'"
 msgid "using a dangling pointer to %qD"
 msgstr "ugyldig henvisningstilstand '%s'"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD declared here"
@@ -28740,7 +28748,7 @@ msgstr "kald af ikke-funktion '%D'"
 msgid "call to %qD"
 msgstr "  i kald af '%D'"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -29893,7 +29901,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "Ugyldig erklæring"
@@ -30912,7 +30920,7 @@ msgstr "Udfør krydsspringsoptimering"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "der mangler en parameter til tilvalget '-%s'"
@@ -30955,13 +30963,13 @@ msgstr "-mapcs-26 og -mapcs-32 kan ikke bruges på samme tid"
 msgid "unrecognized argument in option %qs"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s"
@@ -31127,7 +31135,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -31172,197 +31180,197 @@ msgstr "der blev anmodt om variabelsporing, men den er nytteløs uden fejlsøgni
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "der blev anmodt om variabelsporing, men den er ikke understøttet af dette fejlsøgningsformat"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments ændrer selektiv planlægning"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute directive ignored"
 msgid "%qs attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized section name \"%s\""
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "ukendt sektionsnavn \"%s\""
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "ugyldig typeparameter"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "for få parametre til funktionen '%s'"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malign-loops=%d er ikke mellem 0 og %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "justering skal være en lille potens af to, ikke %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown stack check parameter %qs"
 msgstr "ukendt registernavn: %s"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "målsystemet understøtter ikke fejlfindingsuddata"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "fejlsøgningsformatet %qs er i modstrid med tidligere valg"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level %qs"
 msgid "unrecognized debug output level %qs"
 msgstr "ukendt fejlsøgningsuddataniveau %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "fejlsøgningsuddataniveau %qs er for højt"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level %qs"
 msgid "unrecognized btf debug output level %qs"
 msgstr "ukendt fejlsøgningsuddataniveau %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "henter maksimumbegrænsning på kernefilens størrelse: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "angiver kernefilens størrelsesbegrænsning til maksimum: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "ukendt GCC-fejlfindingstilvalg: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: intet tilvalg -%s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid option to the preprocessor"
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
@@ -32091,197 +32099,197 @@ msgstr "generel thunk-kode mislykkes for metoden '%#D' som bruger '...'"
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D omdøbt efter at være refereret i maskinkode"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "funktionsymbol er ikke en funktion"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "variabelsymbol er ikke en variabel"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "node har ukendt type"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "node has invalid order %i"
 msgstr "#%s med ugyldig parameter"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "node blev ikke fundet node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "node er forskellig fra node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "maskinekodenavn på hashliste er ødelagt"
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "node blev ikke fundet i symtabs maskinkodehash"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "dobbelt lænket liste på maskinekodenavne er ødelagt"
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "node har body_removed men er en definition"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 #| msgid "node is analyzed byt it is not a definition"
 msgid "node is analyzed but it is not a definition"
 msgstr "node er analyseret byt, det er ikke en definition"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "node er alias men ikke implicit alias"
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "node er alias men ikke definition"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, fuzzy, gcc-internal-format
 #| msgid "node is weakref but not an alias"
 msgid "node is weakref but not an transparent_alias"
 msgstr "node er weakref men ikke et alias"
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, fuzzy, gcc-internal-format
 #| msgid "node is weakref but not an alias"
 msgid "node is transparent_alias but not an alias"
 msgstr "node er weakref men ikke et alias"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not implicit alias"
 msgid "node is symver but not alias"
 msgstr "node er alias men ikke implicit alias"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "node er i same_comdat_grooup-liste men har ingen comdat_group"
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group-liste over forskellige grupper"
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "blanding af forskellige symboltyper i samme comdata-gruppe er ikke understøttet"
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "node er alene i en comdat-gruppe"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group er ikke en cirkulær liste"
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "comdat-local-symbol refereret ti laf %s uden for dets comdat"
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit_section flag is set but section isn't"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "implicit_section-flag er angivet men sektion er ikke"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Både sektion og comdat-gruppe er angivet"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's section differs"
 msgid "Alias and target%'s section differs"
 msgstr "Alias og måls sektion er forskellige"
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's comdat groups differs"
 msgid "Alias and target%'s comdat groups differs"
 msgstr "Alias og måls comdat-grupper er forskellige"
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's section differs"
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "Alias og måls sektion er forskellige"
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify mislykkedes"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode `%s'"
 msgid "invalid order in asm node %i"
 msgstr "ugyldig henvisningstilstand '%s'"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "To symboler med samme comdat_group er ikke lænket af same_comdat_group-listen."
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "funktion %q+D del af aliascyklus"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabel %q+D del af aliascyklus"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "sektion for alias %q+D skal matche sektion for dens målarkitektur"
@@ -34102,27 +34110,27 @@ msgstr "den hexadecimale undvigesekvens er uden for det gyldige interval"
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -35005,7 +35013,7 @@ msgstr "'%s' brugt, men aldrig defineret"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "'%s' brugt, men aldrig defineret"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
@@ -37348,7 +37356,7 @@ msgstr "muligvis begyndelsen af uafsluttet strengkonstant"
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionel C tillader ikke strengsammensætning"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -39213,7 +39221,7 @@ msgstr "for mange inddatafiler"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -39248,16 +39256,16 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s"
@@ -39349,55 +39357,55 @@ msgstr "-mcpu=%s er ikke gyldig"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops is obsolete, use -falign-loops"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops er forældet, benyt -falign-loops"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d er ikke mellem 0 og %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malign-jumps er forældet, benyt -falign-jumps"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps=%d is not between 1 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-jumps=%d er ikke mellem 1 og %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions is obsolete, use -falign-functions"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions er forældet, benyt -falign-functions"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 1 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-functions=%d er ikke mellem 1 og %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d er ikke mellem 0 og 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -39932,14 +39940,14 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
@@ -40211,7 +40219,7 @@ msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingn
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate definition of class method `%s'"
 msgid "duplicate definition of %qs"
@@ -40259,7 +40267,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, fuzzy, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr "'%s' brugt, men aldrig defineret"
@@ -40360,365 +40368,365 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa NSA option"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Benyt ikke Xtensa-NSA-indstillingen"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "egenskaben '%s' ignoreret"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "invalid format for %<sve_width%>"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %h value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "ugyldig %h-værdi"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid range %s in option %s"
 msgid "tuning string missing in option (%s)"
 msgstr "ugyldigt interval %s i tilvalg %s"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function `%s'"
 msgid "unknown tuning option (%s)"
 msgstr "ukendt specifikationsfunktion '%s'"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length"
 msgstr "Angiv registerallokeringsordnen"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "ukendt maskintilstand '%s'"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arg to `__builtin_frame_address'"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ugyldig parameter til '__builtin_frame_address'"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing arch name in %<-march=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "unknown value %qs for %<-march%>"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "et filnavn mangler efter '-%s'"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "tilvalget -mcpu=%s er i konflikt med tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 #| msgid "malformed spec function name"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "forkert udformet specifikationsfunktionsnavn"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the %qs debug format"
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "målarkitektursystem understøtter ikke %qs-fejlsøgningsformatet"
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "lane %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %wd"
 msgstr "versionen er ikke understøttet"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "The -shared option is not currently supported for VAX ELF."
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -40922,13 +40930,13 @@ msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -41093,19 +41101,19 @@ msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 msgid "%qE attribute only applies to variables"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for %<asm%> flag output"
@@ -41329,7 +41337,7 @@ msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -41391,7 +41399,7 @@ msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -41505,7 +41513,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -41561,33 +41569,33 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan ikke beregne virkelig placering af stakkede parametre"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "ingen lave registre er tilgængelige til at modtage værdier fra høje registre"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -41596,24 +41604,24 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -41699,19 +41707,19 @@ msgstr "-pipe understøttes ikke"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional and -ansi are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-traditional og -ansi er indbyrdes uforenelige"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have arguments"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%qs function cannot return a value"
@@ -42063,7 +42071,7 @@ msgstr "for mange parametre til funktionen"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "invalid argument to built-in function"
@@ -42738,734 +42746,734 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodemodellen %s understøtter ikke PIC-tilstand"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %qs argument is not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "forkert parameter %qs for tilvalget %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "forkert strateginavn %qs er angivet for tilvalget %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "ukendt justering %qs angivet for tilvalget %qs"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "intet klassenavn angivet med '-%s'"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= understøttes ikke på 32 bit-systemer"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 #| msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressetilstanden %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodemodellen %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel understøttes ikke af denne konfiguration"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bit-tilstand er ikke oversat med ind"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "den valgte processor understøtter ikke x86-64-instruktionssættet"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d er ikke mellem 0 og %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "profilering understøttes ikke endnu"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-instruktionssæt deaktiveret, bruger 387-beregninger"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-instruktionssæt deaktiveret, bruger SSE-beregninger"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall og fastcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-egenskaben bruges til ikke-klasse metode"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "X32 does not support ms_abi attribute"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "X32 understøtter ikke egenskaben ms_abi"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ms_hook_prologue er ikke forenelig med den indlejrede funktion"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "ms_hook_prologue er ikke forenelig med den indlejrede funktion"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "-indlejrede funktioner er ikke understøttet på denne målarkitektur"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
@@ -43473,83 +43481,83 @@ msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported size for integer register"
 msgid "%<V%> modifier on non-integer register"
 msgstr "størrelse er ikke understøttet for heltalsregister"
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "størrelse er ikke understøttet for heltalsregister"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "udvidede registre har ikke høje halvdele"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ikke-understøttet operandstørrelse for udvidede registre"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand type used with operand code 'Z'"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "ugyldig operandtype brugt med operandkoden »Z«"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown architecture specific memory model"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -43928,7 +43936,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -45148,60 +45156,60 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "ragelse i slutningen af '#pragma options'"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "fields cannot have RVV type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "array elements cannot have RVV type %qT"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of type `%T'"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "kan ikke allokere et objekt af typen '%T'"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of type `%T'"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "kan ikke allokere et objekt af typen '%T'"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "capture by copy of RVV type %qT"
@@ -45223,71 +45231,76 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "--resource påkræver -o"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have different interrupt type"
 msgstr "tilvalget '-%c' skal have en parameter"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -45815,105 +45828,105 @@ msgstr "%s har ingen %s"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ugyldig parametertype '%T'"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s%qs%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -47464,7 +47477,7 @@ msgstr "kan ikke anbringe et objekt med et volatile-felt i et register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "konstant '%D' uden startværdi"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -47678,7 +47691,7 @@ msgstr "lagringsklasse angivet for parameter '%s'"
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklasse angivet for typenavn"
@@ -47869,7 +47882,7 @@ msgstr "typenavn er erklæret som en funktion, der returnerer en array"
 msgid "function definition has qualified void return type"
 msgstr "funktiondefinition har kvalificeret void-returtype"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
@@ -48009,7 +48022,7 @@ msgstr "ISO C forbyder const eller volatile funktionstyper"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable or field %qE declared void"
@@ -48234,7 +48247,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr "ukendt felt '%s' angivet i startværdi"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "erklæring erklærer ikke noget"
@@ -48290,7 +48303,7 @@ msgstr "navngivne medlemmer"
 msgid "struct has no members"
 msgstr "%s har intet medlem ved navn '%s'"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "fleksibelt tabelmedlem i union"
@@ -48338,7 +48351,7 @@ msgstr "omerklæring af 'enum %s'"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -48389,7 +48402,7 @@ msgstr "tabelindeks er ikke et heltal"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline funktion '%s' givet egenskaben noinline"
@@ -48421,7 +48434,7 @@ msgstr "ingen tidligere prototype for '%s'"
 msgid "%qD was used with no prototype before its definition"
 msgstr "'%s' blev brugt uden en prototype før dens definition"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidligere erklæring af '%s'"
@@ -48542,12 +48555,12 @@ msgstr "parameteren '%s' passer ikke til prototypen"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -50768,7 +50781,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
@@ -50909,13 +50922,13 @@ msgstr "forventede %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "'%s' er ikke en funktion,"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s og -msdata=%s er indbyrdes uforenelige"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -51189,7 +51202,7 @@ msgstr "ugyldig brug af void-udtryk"
 msgid "invalid use of flexible array member"
 msgstr "ugyldig brug af fleksibelt tabelmedlem"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "ugyldig brug af tabel uden angivne grænser"
@@ -52279,12 +52292,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
@@ -52328,7 +52341,7 @@ msgstr "startværdielement kan ikke beregnes ved indlæsningstidspunktet"
 msgid "invalid initializer"
 msgstr "ugyldig startværdi"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
@@ -52344,8 +52357,8 @@ msgid "braces around scalar initializer"
 msgstr "krøllede paranteser omkring skalarstartværdi"
 
 # RETMIG: eller er det fleksibel tabel-medlem
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "klargøring af fleksibelt tabelmedlem i en indlejret kontekst"
@@ -52441,7 +52454,7 @@ msgstr "for mange elementer i struct-startværdi"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "ikke-statisk klargøring af fleksibelt tabelmedlem"
@@ -53925,7 +53938,7 @@ msgstr "ingen passende 'operator delete' for '%T'"
 msgid "%q#D is private within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared private here"
@@ -53937,7 +53950,7 @@ msgstr "  '%#D' erklæret her"
 msgid "%q#D is protected within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared protected here"
@@ -53956,7 +53969,7 @@ msgstr "'%+#D' er ikke tilgængelig"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "overbringelse af NULL benyttet for ikke-henvisnings%s %P af '%D'"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
@@ -54330,7 +54343,7 @@ msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
@@ -54980,7 +54993,7 @@ msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 msgid "next member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
@@ -55119,7 +55132,7 @@ msgstr "ugyldig returtype for medlemsfunktionen '%#D'"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -55193,7 +55206,7 @@ msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
@@ -55245,7 +55258,7 @@ msgstr "'%T' er en tvetydig stamklasse til '%T'"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
@@ -55386,7 +55399,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -55491,7 +55504,7 @@ msgstr "manglende startværdi for medlemmet '%D'"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
@@ -55580,7 +55593,7 @@ msgstr "ugyldig konvertering fra '%T' til '%T'"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -55651,208 +55664,208 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "cast from %qT is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "uventet operand"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "uventet adresseudtryk"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "ugyldig reinterpret_cast fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
@@ -56491,7 +56504,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%qD-mål erklæret her"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 #| msgid "no type named `%#T' in `%#T'"
 msgid "no member named %qE in %qT"
@@ -56595,7 +56608,7 @@ msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 msgid "no suspend point info for %qD"
 msgstr "ingen tidligere prototype for '%s'"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -56618,23 +56631,23 @@ msgstr "henvisningsvariabler er ikke tilladt som case-værdier"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
@@ -57181,7 +57194,7 @@ msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "erklæring af '%D' som %s"
 
 # hænger sammen med næste tekst
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -57636,686 +57649,686 @@ msgstr "'%D' er ikke en funktionsskabelon"
 msgid "%q#T is not a class"
 msgstr "'%#T' er ikke en skabelon"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named `%#T' in `%#T'"
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klasseskabelon ved navn '%#T' i '%#T'"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 #| msgid "no type named `%#T' in `%#T'"
 msgid "no type named %q#T in %q#T"
 msgstr "ingen type ved navn '%#T' i '%#T'"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "'%D::%D' er ikke en skabelon"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameters do not match template %qD"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d understøttes ikke"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
 msgstr "-traditional er forældet og kan blive fjernet"
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "anonym struct er ikke inden i en navngiven type"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with constructor not allowed in anonymous aggregate"
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med konstruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with destructor not allowed in anonymous aggregate"
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med destruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with copy assignment operator not allowed in anonymous aggregate"
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med kopitildelingsoperator er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flere typer i én erklæring"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type `%T'"
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omerklæring af indbygget type i C++ '%T'"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "manglende typenavn i typedef-erklæring"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ forbyder anonyme strukturer"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<friend%> can only be specified inside a class"
 msgstr "'%D' kan kun angives inden i en klasse"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for constructors"
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "'%D' kan kun angives for konstruktionsfunktioner"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "a storage class can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "tom erklæring"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter list used in explicit instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
 # init dækker over værditildeling her - samme for de næste mange
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef '%D' bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "non-member-template declaration of %qD"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "does not match member template declaration here"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not permit `%T::%D' to be defined as `%T::%D'"
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillader ikke '%T::%D' at blive defineret som '%T::%D'"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "duplicate initialization of %qD"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variablen '%#D' bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate `%#D' has incomplete type and cannot be defined"
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "den sammensatte type '%#D' er af en ufuldstændig type og kan ikke defineres"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as reference but not initialized"
 msgid "%qD declared as reference but not initialized"
 msgstr "'%D' erklæret som en reference, men bliver ikke tildelt en startværdi"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ikke-trivielle udpegede startværdier er ikke understøttet"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "startværdien giver ikke størrelsen af %qD"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "tabelstørrelsen mangler i %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nulstørrelsestabel %qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstørrelsen af %qD er ikke kendt"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  du kan arbejde dig rundt om dette ved at fjerne startværdien"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized %<const %D%>"
 msgstr "konstant '%D' uden startværdi"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "typen '%T' har ingen destruktionsfunktion"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for `%T' must be brace-enclosed"
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "startværdi for '%T' skal være indesluttet i krøllede paranteser"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "%qT has no non-static data member named %qD"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "%qD is not a direct member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "ugyldig startværdi"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in aggregate initializer"
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "for mange elementer i startværdi til sammensat type"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "for mange startværdier for %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing braces around initializer for %qT"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C89 forbyder sammensatte konstanter"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "'%D' er af en ufuldstændig type"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be initialized by constructor, not by `{...}'"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "'%D' skal klargøres af en konstruktionsfunktion, ikke af '{...}'"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "tildeling af startværdi er ugyldig for statisk medlem med konstruktionsfunktion"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en klargøring uden for klassens erklæring er nødvendig)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' with uninitialized const fields"
 msgid "reference %qD is initialized with itself"
 msgstr "medlem '%D' med konstante felter uden startværdi"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "could not find variant declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillader ikke %<register%>-lagerklasseangivelse"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "%<register%> storage class specifier used"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the `&' ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "ugyldig brug af medlem (glemte du en '&'?)"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing previous type declaration of `%#D'"
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skygger for tidligere typeerklæring af '%#D'"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen '%#D' bliver tildelt en startværdi som en variabel"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%u name provided for structured binding"
@@ -58323,1926 +58336,1926 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "lagringsklasse angivet for strukturfelt '%s'"
 msgstr[1] "lagringsklasse angivet for strukturfelt '%s'"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "in initialization of structured binding variable %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose union type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "nulstørrelsestabel '%D'"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "'%D' erklæret som 'virtual' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "'%D' er erklæret som en ven"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "'%D' erklæret med en undtagelsesspecifikation"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion '%#D' erklæret med typemodifikationer"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 #| msgid "Java method '%D' has non-Java return type `%T'"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java-metoden '%D' har har en returtype '%T' som ikke er fra Java"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not definition"
 msgid "concept %qD has no definition"
 msgstr "node er alias men ikke definition"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "a function concept cannot be constrained"
 msgstr "funktion kan ikke indbygges"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "constraints on a non-templated function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-id `%D' in declaration of primary template"
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ugyldig brug af skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "'inline' er ikke tilladt i erklæring venneskabelonsspecialisering '%D'"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "kan ikke erklære %<::main%> som en skabelon"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "kan ikke erklære %<::main%> som indlejret"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be static"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%qD has invalid argument list"
 msgstr "#%s med ugyldig parameter"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "'main' skal returnere typen 'int'"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of implicitly-declared %qD"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, fuzzy, gcc-internal-format
 #| msgid "no `%#D' member function declared in class `%T'"
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion '%#D' erklæret i klassen '%T'"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "concept must be defined at namespace scope"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids initialization of member constant `%D' of non-integral type `%T'"
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ forbyder tildeling af startværdi til medlemskonstant '%D' af en ikke-heltallig type"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "størrelsen af tabellen '%D' er ikke af en heltalstype"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array `%D'"
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med størrelsen nul"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array `%D'"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med variabel størrelse"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tabeldimension for stor"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating array of template placeholder type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of void"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of references"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when a variable is unused"
 msgid "variable-length array of %<auto%>"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "angivelse af returneringstypen til konstruktionsfunktion er ugyldigt"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "return type specified for %<operator %T%>"
 msgstr "returtype angivet for 'operator %T'"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unavngiven variabel eller felt erklæret void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qE as non-member"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, fuzzy, gcc-internal-format
 #| msgid "declarator-id missing; using reserved word `%D'"
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "erklærer-id mangler; bruger reserveret ord '%D'"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition does not declare parameters"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, fuzzy, gcc-internal-format
 #| msgid "both long and short specified for `%s'"
 msgid "both %qs and %qs specified"
 msgstr "både long og short er angivet for '%s'"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration of %qs"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids declaration of `%s' with no type"
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ forbyder erklæring af '%s' uden en type"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ understøtter ikke 'long long'"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for `%s'"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "signed og unsigned er begge angivet for '%s'"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for `%s'"
 msgid "%<long%> and %<short%> specified together"
 msgstr "long og short er begge angivet for '%s'"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with %qT"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with %qD"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with %<typeof%>"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-erklæringer er ugyldig i parametererklæringer"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "structured binding declaration cannot be %qs"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "Ugyldig erklæring"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "storage class specified for %qs"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qs declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, fuzzy, gcc-internal-format
 #| msgid "top-level declaration of `%s' specifies `auto'"
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "'%s' i funktionsvirkefelt underforstået auto og erklæret '__thread'"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "egenskaben '%s' ignoreret"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses"
 msgstr "uventet operand"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "requires-clause on return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ugyldig brug af '%D"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "'%s' er erklæret som en funktion der returnerer en tabel"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "konstruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "constructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "kan ikke definere vennefunktion '%s' i en lokal klassedefinition"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktionsfunktioner må ikke have parametre"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "kan ikke erklære henvisning til '%#T'"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "kan ikke erklære henvisning til medlemmet '%#T'"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner er underforstået venner af deres klasse"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra modifikation '%T::' af medlemmet '%s' ignoreret"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlem '%T::%s' inde i '%T'"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "kun erklæringer af konstruktionsfunktioner kan være 'explicit'"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referencen %qs kan ikke erklæres %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef erklæret %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ forbyder indlejret type %qD med samme navn som den omgivende klasse"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet for friend class-erklæring"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "forsøg på at gøre klassen %qT til ven af det globale virkningsfelt"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt erklærer '%T' benyttet som erklæring"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter `%D' to be of type `%T'"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "kan ikke erklære parameteren '%D' til at være af typen '%T'"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "ugyldig brug af '::'"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "erklæring af C-funktionen '%#D' strider mod"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "'%D' kan ikke erklæres virtual eftersom den altid er statisk"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %qs"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a constructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "kan ikke åbne %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen 'auto' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen 'register' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "kan ikke erklære medlemsfunktion '%D' til at have statisk kædning"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan ikke erklære en funktion for static inden i en anden funktion"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "'static' må ikke bruges ved definering (i modsætning til erklæring) af et statisk datamedlem"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "kan ikke eksplicit erklære medlemmet '%#D' til at have extern-kædning"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ugyldig brug af 'virtual' i skabelonserklæring af '%#D'"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ugyldig konstruktionsfunktion; du mente sandsynligvis '%T (const %T&)'"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "'%D' skal enten være en ikke-statisk medlemsfunktion eller ikke en medlemsfunktion"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "'%D' skal have en parameter af en klasse- eller enum-type"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ forbyder flertydiggørelse af operatoren ?:"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "'%D' skal tage mod nul eller én parameter"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfiks '%D' skal tage mod 'int' som parameter"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfiks '%D' skal tage mod 'int' som den anden parameter"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "præfiks '%D' skal returnere '%T'"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfiks '%D' skal returnere '%T'"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "'%D' skal returnere pr. værdi (ikke reference)"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "bruger skabelonstypeparameter '%D' efter '%s'"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "bruger typedef-navn '%D' efter '%s'"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "tidligere erklæring som '%#D'"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "'%#D' omerklæret som %C"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dette er en tidligere erklæring"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "'%#D' omerklæret som %C"
@@ -60254,121 +60267,121 @@ msgstr "'%#D' omerklæret som %C"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "brug af enum '%#D' uden tidligere erklæring"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration `%#D' declares a non-template function"
 msgid "redeclaration of %qT as a non-template"
 msgstr "friend-erklæring '%#D' erklærer en ikke-skabelonsfunktion"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `%D' to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "kan ikke erklære '%D' til at være en bitfeltstype"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "nedarvet union '%T' ugyldig"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in the class %T"
 msgid "%qT defined with multiple direct bases"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "%qT defined with direct virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "stamklassetype '%T' er hverken en struct- eller class-type"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "rekursiv type '%T' ikke defineret"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "stamklassetype '%T' optræder mere end én gang"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "specialisering af %qD i andet navnerum"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -60378,93 +60391,93 @@ msgstr "parameter til '%s' skal være en 2 bit-konstant"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "enum-værdier for store ved '%D'"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "'operator=' bør returnere en reference til '*this'"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "using %qs"
 msgstr "fejl ved lukning af %s: %m"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -61427,7 +61440,7 @@ msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -62565,7 +62578,7 @@ msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -63375,7 +63388,7 @@ msgstr "new kan ikke bruges på en referencetype"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -64153,12 +64166,12 @@ msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 msgid "cannot expand initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -64811,7 +64824,7 @@ msgstr "skabelonsparameter er påkrævet for '%T'"
 msgid "%qT not permitted in template argument"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
@@ -65726,7 +65739,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
@@ -66865,7 +66878,7 @@ msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "template constraint failure for %qD"
@@ -66970,316 +66983,316 @@ msgstr "funktion returnerer en værdi af en sammensat type"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "opretter tabel af '%T'"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "startværdielement er ikke en konstant"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to __builtin_choose_expr not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "første parameter til '__builtin_choose_expr' skal være en konstant"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "forkert antal parametre angivet til egenskaben '%s'"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "'%#T' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "exception specification of %qD depends on itself"
@@ -67292,184 +67305,184 @@ msgstr "eksplicit specialisering af %D efter første brug"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "'%T' er ikke et navnerum"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of `%#T' inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "definition af '%#T' inden i skabelonsparameterliste"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "use %qD directly instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "funktion overvejes ikke for indbygning"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "Ugyldig erklæring"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ugyldig standardparameter i skabelon"
@@ -67820,7 +67833,7 @@ msgstr "ugyldig stamklasseangivelse"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
@@ -68267,31 +68280,31 @@ msgstr "`__builtin_next_arg' kaldt uden en parameter"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a class or alias template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
 # flertalsform unødvendig
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported arg to `__builtin_return_address'"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -68300,22 +68313,22 @@ msgstr "ikke-understøttet parameter til '__builtin_return_address'"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -69723,256 +69736,256 @@ msgstr "forhåndserklæring af '%#T'"
 msgid "declaration of %q#T"
 msgstr "erklæring af '%#T'"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%qD has incomplete type"
 msgstr "'%D' er af en ufuldstændig type"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef `%s'"
 msgid "invalid use of incomplete type %q#T"
 msgstr "ugyldig brug af ufuldstændig typedef '%s'"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the `&' ?)"
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "ugyldig brug af medlem (glemte du en '&'?)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the `&' ?)"
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "ugyldig brug af medlem (glemte du en '&'?)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of placeholder %qT"
 msgstr "ugyldig brug af '%T'"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type `%#T'"
 msgid "invalid use of dependent type %qT"
 msgstr "ugyldig brug af en ikke-defineret type '%#T'"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "adresse af flertydig funktion uden kontekstuelle typeoplysninger"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "flertydig funktion uden kontekstuelle typeoplysninger"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "utilstrækkelige kontekstuelle oplysninger til at afgøre typen"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, fuzzy, gcc-internal-format
 #| msgid "constructor syntax used, but no constructor declared for type `%T'"
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "konstruktionsfunktionsyntaks benyttet, men ingen konstruktionsfunktion er erklæret for typen '%T'"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "startværdistrengen til char-tabellen er for lang"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "krøllede paranteser omkring skalarstartværdi"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "intet felt '%D' i union der tildeles startværdi"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indeksværdi i stedet for feltnavn i union-startværdi"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grundoperanden til '->' har en ikke-henvisningstype '%T'"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet af 'operator->()' er ikke en henvisning"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "'%E' kan ikke bruges som en medlemshenvisning eftersom udtrykkets type er '%T'"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "kan ikke anvende medlemshenvisning '%E' på '%E' som er af den ikke-sammensatte type '%T'"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "medlemstypen '%T::' uforenelige med objekttypen '%T'"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "funktion kan ikke indbygges"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "kald af en funktion '%D' som kaster en ufuldstændig type '%#T'"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -70985,7 +70998,7 @@ msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -72126,12 +72139,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -72326,7 +72339,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -74450,7 +74463,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -74732,7 +74745,7 @@ msgstr "ugyldig venstreværdi i tildeling"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -74852,7 +74865,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
@@ -74862,7 +74875,7 @@ msgstr ""
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
@@ -74997,7 +75010,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of `%T'"
@@ -75222,12 +75235,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -75340,585 +75353,585 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "Invalid procedure argument at %L"
 msgstr "ugyldig typeparameter '%s'"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return specifier at %0 invalid within a function"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returangivelse ved %0 er ugyldig inden i en funktion"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return specifier at %0 invalid within a function"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returangivelse ved %0 er ugyldig inden i en funktion"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 #| msgid "Missing value at %1 for real-number exponent at %0"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Manglende værdi ved %1 for reel eksponent ved %0"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid option argument `%s'"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "ugyldig tilvalgsparameter '%s'"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic `%A' is passed as actual argument at %0 but not explicitly declared INTRINSIC"
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "Indbygget '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret INTRINSIC"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "kunne ikke finde klassen '%s'"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "intern fejl - for mange grænsefladetyper"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator number is out of bounds"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "akkumulatortal er uden for det gyldig interval"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "complex arguments must have identical types"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "komplekse parametre skal have identiske typer"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "SAVE-sætning eller -egenskab ved %1 kan ikke angives sammen med SAVE-sætning eller -egenskab ved %0"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -76115,7 +76128,7 @@ msgstr "konvertering fra NaN til int"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
@@ -76712,7 +76725,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -77321,7 +77334,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -79287,8 +79300,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -81331,741 +81344,751 @@ msgstr ""
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "inkonsistent instansvariabelangivelse"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "inkonsistent instansvariabelangivelse"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr ""
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "%qs at %L is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function `%A' defined at %0 is not used"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Sætningsfunktion '%A' defineret ved %0, men er ikke brugt"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "'%s' er ikke en funktion,"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "resolve_function(): bad function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "Using function %qs at %L is deprecated"
 msgstr "'%s' er forældet"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "resolve_subroutine(): bad function type"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "'%s' er forældet"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "shared and mdll are not compatible"
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared og mdll er indbyrdes uforenelige"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Advar når en inline funktion ikke kan indbygges"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Equality comparison for %s at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Inequality comparison for %s at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Argument dim at %L must be scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Null element at %0 for array reference at %1"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Nulelement ved %0 for tabelreference ved %1"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array `%A' at %0 is too large to handle"
 msgid "Array index at %L is an array of rank %d"
 msgstr "Tabellen '%A' ved %0 er for stor til at håndtere"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring begin/end point at %0 out of defined range"
 msgid "Substring end index at %L must be scalar"
 msgstr "Understrengs begyndelses-/slutpunkt ved %0 er uden for det definerede interval"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "Substring end index at %L is too large"
 msgstr "angivet justering er for stor"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -82074,12 +82097,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -82088,302 +82111,302 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "'%s' er forældet"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in typebound call at %L"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" after # is not a positive integer"
 msgid "%s at %L must be integer"
 msgstr "\"%s\" efter # er ikke et positivt heltal"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -82392,291 +82415,291 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" cannot be used as a macro name as it is an operator in C++"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" kan ikke bruges som et makronavn da det er en operator i C++"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Selector at %L cannot be NULL()"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "Selector at %L has no type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -82684,216 +82707,216 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "FORALL construct at %L"
 msgstr "I konstruktionen"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Pointer procedure assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid NULL at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' declared void"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parameteren '%s' erklæret void"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -82901,1002 +82924,1002 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fejl ved egenskabsundersøgelse af filen %s"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "funktion kan ikke indbygges"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "'%#D' kan ikke erklæres"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelig afledt type i PARAMETER ved %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No specification for implied-DO iterator `%A' at %0"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Ingen angivelse af underforstået DO-iterator '%A' ved %0"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting definable entity near %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in method specification"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -84825,7 +84848,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -84837,12 +84860,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -84937,86 +84960,92 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "parameter `%s' has incomplete type"
+msgid "%s at %C has no default type"
+msgstr "parameteren '%s' er af en ufuldstændig type"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared %s"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "instansvariablen '%s' er erklæret '%s'"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared %s"
 msgid "Unused variable %qs declared at %L"
 msgstr "instansvariablen '%s' er erklæret '%s'"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' declared void"
 msgid "Unused parameter %qs declared at %L"
 msgstr "parameteren '%s' erklæret void"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -85032,29 +85061,29 @@ msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, fuzzy, gcc-internal-format
 #| msgid "unknown insn mode"
 msgid "Unknown intrinsic op"
 msgstr "ukendt instruktionstilstand"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "for få parametre til funktionen '%s'"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -87076,6 +87105,9 @@ msgstr "ubenyttet parameter '%s'"
 #~ msgid "PIC register isn't set up"
 #~ msgstr "PIC-register er ikke sat op"
 
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "ugyldig operandstørrelse for operandkoden »Z«"
+
 #~ msgid "__float128 and __ibm128 cannot be used in the same expression"
 #~ msgstr "__float128 og __ibm128 kan ikke bruges i det samme udtryk"
 
diff --git a/gcc/po/de.po b/gcc/po/de.po
index 66fd5710f01..c3b34b8e3d6 100644
--- a/gcc/po/de.po
+++ b/gcc/po/de.po
@@ -8,10 +8,10 @@
 # Roland Illig <roland.illig@gmx.de>, 2015, 2017-2023.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 13.1-b20230409\n"
+"Project-Id-Version: gcc 13.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
-"PO-Revision-Date: 2023-04-12 20:15+0200\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
+"PO-Revision-Date: 2023-04-27 09:54+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
 "Language: de\n"
@@ -3999,7 +3999,7 @@ msgstr "ISO-Dialekt von Modula-2 verwenden"
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr "Reihenfolge der Bibliotheken kommagetrennt angeben, erlaubte Einträge sind: log,min,pim,iso oder deren entsprechende Verzeichnisnamen m2log,m2min,m2pim,m2iso."
 
 #: m2/lang.opt:127
@@ -7643,6 +7643,11 @@ msgstr "Konservatives abrollen kleiner Schleifen einschalten."
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr "-mlam=[none|u48|u57] Position der Metadaten in Nutzer-Datenzeigern instrumentieren."
 
+#: config/i386/i386.opt:1280
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Eingebaute Funktionen und Codeerzeugung für AMX-COMPLEX unterstützen."
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17174,12 +17179,12 @@ msgstr "»%%l«-Operand ist keine Marke"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "Gleitkommakonstante falsch verwendet"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18264,63 +18269,63 @@ msgstr "Diese Option ist undokumentiert."
 msgid "Uses of this option are diagnosed."
 msgstr "Die Verwendung dieser Option wird diagnostiziert."
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr "Dasselbe wie %s%s (oder, in negierter Form, %s%s)."
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr "Dasselbe wie %s%s."
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr "Dasselbe wie %s."
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s ist identisch mit %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr "[verfügbar in "
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[Standard]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr "%llu Bytes"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[eingeschaltet]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[ausgeschaltet]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Keine Optionen mit den gewünschten Eigenschaften gefunden\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Nichts gefunden. Bitte verwenden Sie »--help=%s«, um *alle* vom Frontend %s unterstützten Optionen anzuzeigen\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Alle Optionen mit den gewünschten Eigenschaften wurden bereits angezeigt\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -18329,47 +18334,47 @@ msgstr ""
 "  Bekannte gültige Argumente für Option »%s«:\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Die folgenden Optionen sind zielspezifisch"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Die folgenden Optionen steuern Warnmeldungen des Compilers"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Die folgenden Optionen steuern Optimierungen"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Die folgenden Optionen sind sprachunabhängig"
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr "Die folgenden Optionen steuern Parameter"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Die folgenden Optionen sind nur spezifisch für die Sprache "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Die folgenden Optionen werden von der Sprache unterstützt "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Die folgenden Optionen sind nicht dokumentiert"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Die folgenden Optionen verwenden separate Argumente"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Die folgenden Optionen verwenden gemeinsame Argumente"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Die folgenden Optionen sind sprachbezogen"
 
@@ -18752,72 +18757,72 @@ msgstr "Längenmodifizierer im strfmon-Format"
 msgid "<command-line>"
 msgstr "<Kommandozeile>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ungültiger Operand für »%%%c«"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr "ungültige Vektorkonstante"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "unverträglicher Gleitkomma- / Vektorregisteroperand für »%%%c«"
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "unverträglicher Registeroperand für »%%%c«"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "fehlender Operand"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "ungültige Konstante"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "ungültiger Operand"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ungültiger Operandenpräfix »%%%c«"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "ungültiger Adressierungsmodus"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "GNU- und SVE-Vektoren können nicht in einer binären Operation kombiniert werden"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« ohne lokale dynamische TLS-Referenzen verwendet"
@@ -18834,18 +18839,18 @@ msgid "invalid %%r value"
 msgstr "ungültiger %%r-Wert"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "ungültiger %%R-Wert"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
@@ -18875,7 +18880,7 @@ msgstr "ungültiger %%M-Wert"
 msgid "invalid %%U value"
 msgstr "ungültiger %%U-Wert"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
@@ -18885,7 +18890,7 @@ msgstr "ungültiger %%s-Wert"
 msgid "invalid %%C value"
 msgstr "ungültiger %%C-Wert"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
@@ -18898,7 +18903,7 @@ msgstr "unbekannte Adressverschiebungs-Unspec"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ungültiger %%xn-Code"
@@ -18981,35 +18986,35 @@ msgstr "ungültiges UNSPEC als Operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "unerkannte vermutete Konstante"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "ungültiger Schiebeoperand"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "bedingter Thumb-Befehl"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "bedingter Befehl in bedingter Sequenz"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19018,26 +19023,26 @@ msgstr "Operand für Code »%c« nicht unterstützt"
 msgid "invalid operand for code '%c'"
 msgstr "ungültiger Operand für Code »%c«"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "Befehl wird niemals ausgeführt"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "veralteter Maverick-Formatcode »%c«"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung von Typ %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung in Typ %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "Operation nicht erlaubt auf Typ %<bfloat16_t%>"
 
@@ -19402,97 +19407,97 @@ msgstr "ungültige Gleitkomma-Konstante"
 msgid "Expected register or constant integer."
 msgstr "Register oder konstante Ganzzahl erwartet."
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ungültiges UNSPEC als Operand"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "Ungültige Verwendung von Register »%s«"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ungültige Verwendung der asm-Schalter-Ausgabe"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ungültige Operandengröße für Operandencode »O«"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ungültige Operandengröße für Operandencode »z«"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, c-format
-msgid "invalid operand type used with operand code 'Z'"
-msgstr "ungültiger Operandentyp mit Operandencode »Z« verwendet"
+msgid "invalid operand type used with operand code '%c'"
+msgstr "ungültiger Operandentyp mit Operandencode »%c« verwendet"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "ungültige Operandengröße für Operandencode »Z«"
+msgid "invalid operand size for operand code '%c'"
+msgstr "ungültige Operandengröße für Operandencode »%c«"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »Y«"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »D«"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »%c«"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "Operand ist keine ausgleichbare Speicherreferenz, ungültiger Operandencode »H«"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »K«"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »r«"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ungültiger Operandencode »%c«"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ungültige Bedingungen für Operand"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ungültiger Vektordirektwert"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "unbekannter Befehlsmodus"
 
@@ -19523,7 +19528,7 @@ msgstr "ungültige Operation auf %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ungültiger %%P-Operand"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -19568,8 +19573,8 @@ msgstr "»%%%c« ist kein gültiger Operandenpräfix"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ungültige Verwendung von »%%%c«"
@@ -19601,7 +19606,7 @@ msgid "post-increment address is not a register"
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -19759,7 +19764,7 @@ msgstr "nicht unterstützte konstante Adresse:"
 msgid "unsupported memory expression:"
 msgstr "nicht unterstützter Speicherausdruck:"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, c-format
 msgid "invalid vector operand"
 msgstr "ungültiger Vektoroperand"
@@ -19811,143 +19816,143 @@ msgstr "%<-mquad-memory%> ist im Little-Endian-Modus nicht verfügbar"
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "Falsche 128-Bit-Verschiebung"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, c-format
 msgid "invalid %%A value"
 msgstr "ungültiger %%A-Wert"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "ungültiger %%D-Wert"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "ungültiger %%e-Wert"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "ungültiger %%t-Wert"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "ungültiger %%V-Wert"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "ungültiger %%z-Wert"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Unerlaubtes Mischen von IEEE-128-Bit- und IBM-128-Bit-Gleitkommatypen"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr "Addis-Wert für Fusion kann nicht erzeugt werden"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Lade-/Speicheroffset für Fusion kann nicht generiert werden"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "Falsche GPR-Fusion"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ungültige Umwandlung von Typ %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ungültige Umwandlung in Typ %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ungültige Umwandlung von %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ungültige Umwandlung in %<__vector_pair%>"
 
@@ -20404,7 +20409,7 @@ msgstr "Kandidat:"
 msgid "  after user-defined conversion:"
 msgstr "  nach benutzerdefinierter Umwandlung:"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
@@ -20871,7 +20876,7 @@ msgstr "Unstimmige Arraygrenzen für Dimension 2 des Arrays (%ld/%ld)"
 msgid "Driving:"
 msgstr "Angesteuert:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "effektives Argument für INTENT = OUT/INOUT"
 
@@ -21029,11 +21034,11 @@ msgstr "Block-IF"
 msgid "implied END DO"
 msgstr "impliziertes END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "Zuweisung"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "Zeigerzuweisung"
 
@@ -21041,199 +21046,199 @@ msgstr "Zeigerzuweisung"
 msgid "simple IF"
 msgstr "einfaches IF"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "Elementares Unterprogramm"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr "allozierbares Argument"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr "asynchrones Argument"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "optionales Argument"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr "Zeigerargument"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr "Zielargument"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr "Wertargument"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr "flüchtiges Argument"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr "Argument mit angenommener Form"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr "Argument mit angenommenem Rang"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr "Coarray-Argument"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr "parametrisiertes abgeleitetes Typargument"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr "polymorphes Argument"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr "NO_ARG_CHECK-Attribut"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr "Argument von angenommenem Typ"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr "Arrayergebnis"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr "Zeiger oder allozierbares Resultat"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr "Resultat mit nicht konstanter Zeichenlänge"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr "bind(c)-Prozedur"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand des unären numerischen Operators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Unerwartete Entitäten mit abgeleitetem Typ im binären intrinsischen numerischen Operator %%<%s%%> bei %%L"
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des binären numerischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanden des Zeichenkettenverkettungsoperators bei %%L sind %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des logischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand des Operators .not. bei %%L ist %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-Größen können nicht bei %L verglichen werden"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logische Werte bei %%L müssen mit %s statt mit %s verglichen werden"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Vergleichsoperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L; meinten Sie %%<%s%%>?"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operand des Benutzeroperators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Benutzeroperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Ränge für Operator bei %%L und %%L stimmen nicht überein"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "Schleifenvariable"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr "Iteratorvariable"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr "Anfangs-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr "End-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr "Schrittausdruck in DO-Schleife"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE Objekt"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr "ALLOCATE Objekt"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr "STAT-Variable"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr "ERRMSG-Variable"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr "Element in READ"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr "Variable ACQUIRED_LOCK"
 
@@ -21246,27 +21251,27 @@ msgstr "Unterschiedliche CHARACTER-Längen (%ld/%ld) in Feldkonstruktor"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Ganzzahlüberlauf bei der Berechnung des zu reservierenden Speichers"
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Der Wert des Parameters PDT LEN »%s« stimmt nicht mit dem in der Dummy-Deklaration überein"
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge passt nicht zur deklarierten für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge ist kürzer als die deklarierte für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Ziel für neue Rangabbildung ist zu klein (%ld < %ld)"
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr "Zuweisung von Skalar zu unalloziertem Array"
 
@@ -22134,7 +22139,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "%<-mrelax%> wird nur für RTP PIC unterstützt"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfehler in Anweisung %s bei %C"
@@ -22505,7 +22510,7 @@ msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -22602,10 +22607,10 @@ msgstr "Typattribute ignoriert, nachdem Typ bereits definiert ist"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -22740,7 +22745,7 @@ msgstr "Funktionsprofil aus %s kann nicht gelesen werden"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "Offset %qwi ist außerhalb der Grenzen der konstanten Zeichenkette"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE ist hier deklariert"
@@ -24575,7 +24580,7 @@ msgstr "große Festkommakonstante implizit auf Festkommatypen abgeschnitten"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "Vergleich ist immer %d wegen Breite des Bitfeldes"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bereichsprüfung vereinfacht wird"
@@ -25345,7 +25350,7 @@ msgstr "Funktion liefert Adresse einer lokalen Variablen zurück"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26463,14 +26468,14 @@ msgstr "baumelnder Zeiger auf %qD wird möglicherweise verwendet"
 msgid "using a dangling pointer to %qD"
 msgstr "baumelnder Zeiger auf %qD wird verwendet"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD ist hier deklariert"
@@ -26515,7 +26520,7 @@ msgstr "%qD wird mit Zeiger aufgerufen, der aus der unpassenden Allozierungsfunk
 msgid "call to %qD"
 msgstr "Aufruf von %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr "Adresse der lokalen Variable %qD wird in %qE gespeichert"
@@ -27582,7 +27587,7 @@ msgstr "IPA-Inline-Zusammenfassung fehlt in Eingabedatei"
 msgid "IPA modref summary is missing in input file"
 msgstr "IPA-modref-Zusammenfassung fehlt in Eingabedatei"
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "ungültige Sprungfunktion in LTO-Datenstrom"
@@ -28540,7 +28545,7 @@ msgstr "Fehler beim Schließen der Datei für Optimierungsdatensätze %qs"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "Kommandozeilenoption %qs wird von dieser Konfiguration nicht unterstützt"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "fehlendes Argument für %qs"
@@ -28580,12 +28585,12 @@ msgstr "%qs und %qs schließen sich gegenseitig aus und können nicht zusammen a
 msgid "unrecognized argument in option %qs"
 msgstr "nicht erkanntes Kommandozeilenargument in Option %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %qs sind: %s; meinten Sie %qs?"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "gültige Argumente für %qs sind: %s"
@@ -28741,7 +28746,7 @@ msgstr "%<-fsanitize=pointer-subtract%> muss mit %<-fsanitize=address%> oder %<-
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "%<-fsanitize-recover=%s%> wird nicht unterstützt"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "%<-fsanitize-trap=%s%> wird nicht unterstützt"
@@ -28781,183 +28786,183 @@ msgstr "Variablenverfolgung angefordert, jedoch nutzlos ohne Debug-Info"
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "Variablenverfolgung angefordert, jedoch nicht von diesem Debug-Format unterstützt"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments ändert selektive Planung"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr "%<-Wstrict-flex-arrays%> wird ignoriert, wenn %<-fstrict-flex-arrays%> nicht angegeben wurde"
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> funktioniert auf dieser Architektur nicht mit Ausnahmen"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> unterstützt auf dieser Architektur nicht Unwind-Info"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> funktioniert auf dieser Architektur nicht"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "nicht erkanntes %<include_flags 0x%x%> an %<print_specific_help%> weitergegeben"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr "%<-fsanitize=all%> ist ungültig"
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "unbekanntes Argument für Option %<-f%ssanitize%s=%>: %q.*s; meinten Sie %qs?"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "unbekanntes Argument für Option %<-f%ssanitize%s=%>: %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "Attribut-Direktive %qs ignoriert"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "Argument für Option %<-fzero-call-used-regs=%> nicht erkannt: %qs"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "ungültige Argumente für Option %<-falign-%s%>: %qs"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "Falsche Anzahl der Argumente für Option %<-falign-%s%>: %qs"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "%<-falign-%s%> ist nicht zwischen 0 und %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "ungültige Argumente für %<-fpatchable-function-entry%>"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "Argument %q.*s für %<--help%> ist mehrdeutig, bitte präzisieren"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "Argument %q.*s für Option %<--help=%> nicht erkannt"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr "Argumente für %<-Wattributes=%> ignoriert; verwenden Sie stattdessen %<-Wno-attributes=%>"
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr "abschließendes %<,%> in Argumenten für %<-Wno-attributes=%>"
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr "Option %<-foffload-abi%> kann nur für Offload-Compiler angegeben werden"
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "Strukturausrichtung muss eine kleine Zweierpotenz sein, nicht %wu"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "unbekannter Stapel-Überprüfungsparameter %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90141
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr "%<-gdwarf=%s%> ist mehrdeutig; verwenden Sie %<-gdwarf-%s%> für die DWARF-Version und %<-gdwarf -g%s%> für die Debugstufe"
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "Dwarf-Version %wu wird nicht unterstützt"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "Argument %qs für Option %<-flto=%> nicht erkannt"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "Zielsystem unterstützt keine Testausgaben"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "Debugformat %qs steht in Konflikt mit vorheriger Auswahl"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "Unbekannte Debugausgabestufe %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "Debugausgabestufe %qs ist zu groß"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "Unbekannte BTF-Debugausgabestufe %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "Kern-Dateigrößenlimit kann nicht geholt werden: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "Kern-Dateigrößenlimit kann nicht gesetzt werden: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "GCC-Debuggingoption nicht erkannt: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "%<-W%serror=%s%>: unbekannte Option %<-%s%>; meinten Sie %<-%s%>?"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "%<-W%serror=%s%>: Keine Option %<-%s%>"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "%<-Werror=%s%>: %<-%s%> ist keine Option, die Warnungen steuert"
@@ -29646,213 +29651,213 @@ msgid "%qD renamed after being referenced in assembly"
 msgstr "%qD nach Referenzierung in Assemblierung umbenannt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "Interner Fehler: function symbol is not function"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr "inkonsistentes %<ifunc%>-Attribut"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "Interner Fehler: variable symbol is not variable"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "Interner Fehler: node has unknown type"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "Knoten hat ungültige Reihenfolge %i"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "Interner Fehler: node not found node->decl->decl_with_vis.symtab_node"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "Interner Fehler: node differs from node->decl->decl_with_vis.symtab_node"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "Interner Fehler: assembler name hash list corrupted"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "Interner Fehler: node not found in symtab assembler name hash"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "Interner Fehler: double linked list of assembler names corrupted"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "Interner Fehler: node has body_removed but is definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "Interner Fehler: node is analyzed but it is not a definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "Interner Fehler: node is alias but not implicit alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "Interner Fehler: node is alias but not definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "Interner Fehler: node is weakref but not an transparent_alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "Interner Fehler: node is transparent_alias but not an alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "Interner Fehler: node is symver but not alias"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr "Interner Fehler: symver target is not exported with default visibility"
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr "Interner Fehler: symver is not exported with default visibility"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "Interner Fehler: node is in same_comdat_group list but has no comdat_group"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "Interner Fehler: same_comdat_group list across different groups"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "Interner Fehler: mixing different types of symbol in same comdat groups is not supported"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "Interner Fehler: node is alone in a comdat group"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "Interner Fehler: same_comdat_group is not a circular list"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "Interner Fehler: comdat-local symbol referred to by %s outside its comdat"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "Interner Fehler: implicit_section flag is set but section isn%'t"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Interner Fehler: Both section and comdat group is set"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr "Interner Fehler: Alias and target%'s section differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr "Interner Fehler: Alias and target%'s comdat groups differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "Interner Fehler: Transparent alias and target%'s assembler names differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Interner Fehler: Chained transparent aliases"
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "Interner Fehler: symtab_node::verify failed"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "ungültige Reihenfolge in asm-Knoten %i"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Interner Fehler: Two symbols with same comdat_group are not linked by the same_comdat_group list."
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "Funktion %q+D Teil des Alias-Zyklus"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "Variable %q+D Teil des Alias-Zyklus"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "Abschnitt des Aliases %q+D muss zum Abschnitt seines Ziels passen"
@@ -31557,27 +31562,27 @@ msgstr "maschinenunabhängiger eingebauter Code außerhalb des Wertebereiches"
 msgid "target specific builtin not available"
 msgstr "zielspezifische eingebaute Funktion ist nicht verfügbar"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "Vektoroperation wird stückweise ausgeweitet"
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "Vektoroperation wird parallel ausgeweitet"
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "Vektoroperation wird mit einzelner skalarer Operation ausgeweitet"
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "Vektorbedingung wird stückweise ausgeweitet"
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "Vektorumverteilungsoperation wird stückweise ausgeweitet"
@@ -32393,7 +32398,7 @@ msgstr "Attribut %qE ignoriert, da %qD keine Variable ist"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "Attribut %qE ignoriert, da %qD keine lokale Variable ist"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "Attribut %qE wirkt sich nur auf öffentliche Objekte aus"
@@ -34483,7 +34488,7 @@ msgstr "nicht unterstützte Nicht-Standard-Verkettung von Zeichenkettenliteralen
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionelles C weist Zeichenkettenkonstantenverkettung zurück"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> mit %<hint%>-Klausel erfordert einen Namen, außer wenn %<omp_sync_hint_none%> verwendet wird"
@@ -36154,7 +36159,7 @@ msgstr "zu viele Eingabedateien"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%qs ist im Header %qs definiert; haben Sie vergessen, %<#include %s%> zu schreiben?"
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "unbekannter Wert %qs für %<-mcpu%>"
@@ -36185,15 +36190,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "unbekannte Option an %%:%<target_mode_check%> weitergegeben"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "gültige Argumente sind: %s; meinten Sie %qs?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "gültige Argumente sind: %s"
@@ -36279,48 +36284,48 @@ msgstr "%<-mcpu=%s%> ist nicht gültig"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "%<-mcpu=%s%> hat ungültige Silizium-Revision"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "%<-malign-loops%> ist veraltet, Ersatz: %<-falign-loops%>"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "%<-malign-loops=%d%> liegt nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "%<-malign-jumps%> ist veraltet, Ersatz: %<-falign-jumps%>"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "%<-malign-jumps=%d%> liegt nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "%<-malign-functions%> ist veraltet, Ersatz: %<-falign-functions%>"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "%<-malign-functions=%d%> liegt nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "%<-mbranch-cost=%d%> liegt nicht zwischen 0 und 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> wird derzeit nur auf GNU/Linux unterstützt"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> erfordert Assemblerunterstützung für CFI-Direktiven"
@@ -36807,13 +36812,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "ACLE-Funktion %qD ist nicht kompatibel mit der Verwendung von %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "Argument %d von %qE muss ein konstanter ganzzahliger Ausdruck sein"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr "Übergabe von %wd an das Argument %d von %qE, das einen Wert im Bereich [%wd, %wd] erwartet"
@@ -37051,7 +37056,7 @@ msgstr "Übergabe von %qT an Argument %d von %qE, das jedoch in der %qT-Form kei
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "doppelte Definition von %qs"
@@ -37092,7 +37097,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "der SVE-Typ %qT hat keine definierte Ausrichtung"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr "Variablen vom Typ %qT können keine thread-lokale Speicherdauer haben"
@@ -37179,330 +37184,330 @@ msgstr "Sie können SVE mit der Befehlszeilenoption %<-march%>, oder mit dem Att
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "Argumente vom Typ %qT erfordern die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "der SVE-Typ %qT kann nur an prototypisierte Funktionen übergeben werden"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 13.1 geändert"
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 9.1 geändert"
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE benötigt die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "Aufrufe von Funktionen vom Typ %qT erfordern die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "Stapelsonde für SVE-Rahmen"
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "unbekanntes Flag wurde in %<-moverride=%s%> übergeben (%s)"
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr "Zeichenkette %qs ist falsch geformt"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "ungültiges Format für %<sve_width%>"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr "ungültiger Wert für %<sve_width%>: %d"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Tuning-Zeichenkette fehlt in Option »%s«"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "unbekannte Tuning-Option »%s«"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "die Optionen %<-mstack-protector-guard=global%> und %<-mstack-protector-guard-offset=%s%> sind unverträglich"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90153
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "wenn %<-mstack-protector-guard=sysreg%> angegeben ist, müssen sowohl %<-mstack-protector-guard-offset%> als auch %<-mstack-protector-guard-reg%> angegeben werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90154
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr "Systemregister mit einem kurzem Namen angeben"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs ist in %qs kein gültiger Offset"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr "%<-fsanitize=shadow-call-stack%> erfordert %<-ffixed-x18%>"
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "nur die Werte 12 (4 kB) und 16 (64 kB) werden für die Wächtergröße unterstützt. Der angegebene Wert %d (%llu kB) liegt außerhalb des gültigen Bereichs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90155
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "Größe des Stapelkollisionswächters %d muss gleich dem Sondierungsintervall %d sein"
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "fehlender CPU-Name in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "unbekannter Feature-Modifizierer %qs in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ungültiges Argument für %<-mharden-sls=%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr "%qs muss für sich allein stehen, für %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "ungültiges Argument %qs für %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "fehlender Architekturname in %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "unbekannter Wert %qs für %<-march%>"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "meinten Sie %<-mcpu=%s%>?"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "unbekannter Feature-Modifizierer %qs in %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "fehlender CPU-Name in %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "unbekannter Wert %qs für %<-mtune%>"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "Schalter %<-mcpu=%s%> steht mit dem Schalter %<-march=%s%> in Konflikt"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "Assembler unterstützt %<-mabi=ilp32%> nicht"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "Signieren der Rückgabeadresse wird nur für %<-mabi=lp64%> unterstützt"
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "Codemodell %qs mit %<-f%s%>"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "Codemodell %qs wird im ilp32-Modus nicht unterstützt"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ungültiger Name %qs für Pragma oder Attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "ungültiger Featuremodifizierer %qs mit Wert %qs in Pragma oder Attribut %<target()%>"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ungültiger Name %qs für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "ungültiger Featuremodifizierer %qs mit Wert %qs in Pragma oder Attribut %<target()%>"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "fehlendes Argument für Pragma oder Attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ungültiger Schutztyp %qs in Pragma oder Attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ungültiger Name %qs für Pragma oder Attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "fehlender Wert für Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> akzeptiert keine Argumente"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> erlaubt keine negierte Form"
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s=%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr "der Arch-Erweiterung %qs sollte ein %<+%> vorangestellt werden"
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT mit %<[[no_unique_address]]%>-Elementen hat sich %{in GCC 10.1%} geändert"
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich, sofern C++17 aktiviert ist, so geändert, dass es C++14 %{in GCC 10.1%} entspricht"
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich %{mit GCC 12.1%} geändert"
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "Spur %wd ist außerhalb des Wertebereiches %wd bis %wd"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "nicht unterstützte simdlen %wd"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC unterstützt derzeit keine Typen gemischter Größe für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC bietet derzeit keine Unterstützung für Rückgabetyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "nicht unterstützter Rückgabetyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC bietet derzeit keine Unterstützung für Parametertyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "GCC unterstützt derzeit %<simdlen %wd%> für Typ %qT nicht"
@@ -37687,13 +37692,13 @@ msgstr "Argument des Attributes %qE ist weder »ilink« oder »firq«"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -37834,17 +37839,17 @@ msgstr "Argument des Attributs %qE wird ignoriert"
 msgid "%qE attribute only applies to variables"
 msgstr "Attribut %qE bezieht sich nur auf Variablen"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "Alternativen sind in %<asm%>-Flag-Ausgabe nicht erlaubt"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "unbekannte Ausgabe %qs des %<asm%>-Schalters"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "ungültiger Typ für %<asm%>-Schalter-Ausgabe"
@@ -38054,7 +38059,7 @@ msgstr "Ziel-CPU unterstützt keine THUMB-Befehle"
 msgid "target CPU does not support unaligned accesses"
 msgstr "Ziel-CPU unterstützt keine unausgerichteten Zugriffe"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "Diese Architektur unterstützt keine Befehle mit Sprungschutz"
@@ -38109,7 +38114,7 @@ msgstr "Grenze für Strukturgröße kann nur auf 8 oder 32 gesetzt werden"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC ist mit %<-msingle-pic-base%> unverträglich"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "Der FDPIC-Modus wird im Thumb-1-Modus nicht unterstützt"
@@ -38215,7 +38220,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "Argument vom Typ %qT ist zusammen mit %<-mgeneral-regs-only%> nicht erlaubt"
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 7.1 geändert"
@@ -38266,32 +38271,32 @@ msgstr "Zugriff auf threadlokalen Speicher wird derzeit mit %<-mpure-code%> oder
 msgid "%s %wd out of range %wd - %wd"
 msgstr "»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "Wirkliche Stelle des gestapelten Parameters kann nicht berechnet werden"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Unexpected thumb1 far jump"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "keine unteren Register für das Hervorholen der hohen Register verfügbar"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Interrupt-Dienst-Routinen können nicht im »Thumb-1«-Modus codiert werden"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> für Thumb-1"
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
@@ -38299,22 +38304,22 @@ msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatische FPU-Auswahl ist hier momentan nicht erlaubt"
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "Ungültige Architektur für Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "Unbekanntes Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%<asm%>-Schalter werden im Thumb1-Modus nicht unterstützt"
@@ -38388,17 +38393,17 @@ msgstr "%<-fpie%> wird nicht unterstützt"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> wird nicht unterstützt"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "Funktionsattribute %qs und %qs schließen sich gegenseitig aus"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Funktion %qs kann keine Argumente haben"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "Funktion %qs kann keinen Wert zurückgeben"
@@ -38713,7 +38718,7 @@ msgstr "ungültiges zweites Argument für eingebaute Funktion"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "ungültiges Argument für eingebaute Funktion"
@@ -39306,751 +39311,751 @@ msgstr "Funktionsversionen können nicht als %<gnu_inline%> markiert werden, Kö
 msgid "virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "Multiversionierung erfordert %<ifunc%>, was auf diesem Ziel nicht unterstützt wird"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "Codemodell %s unterstützt keinen PIC-Modus"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "Argument von Attribut %qs muss eine Zeichenkette sein"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "beim Attribut %qs ist das Argument %qs unbekannt"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "der Wert %qs wurde bereits im Attribut %qs angegeben"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Attributwert %qs ist im %qs-Attribut unbekannt"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "falsches Argument %qs für Option %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "Größenbereiche der Option %qs sollten aufsteigend sein"
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "falscher Strategiename %qs für Option %qs angegeben"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "Strategiename %qs für Option %qs angegeben, wird jedoch für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "unbekannte Ausrichtung %qs für Option %qs angegeben"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "der Maximalwert für den letzten Größenbereich sollte für Option %qs -1 sein"
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "zu viele Größenbereiche in Option %qs angegeben"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Unbekannter Parameter für Option %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel-MCU-psABI wird im %s-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> ist veraltet; stattdessen entsprechend %<-mtune=k8%> oder %<-mtune=generic%> verwenden"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> ist veraltet; stattdessen entsprechend %<target(\"tune=k8\")%> oder %<target(\"tune=generic\")%> verwenden"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "%<-mlam=%>-Option: [u48|u57] wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "Adressmodus %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> wird in der X32-ABI nicht unterstützt"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=address%> unterstützt"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=kernel-address%> unterstützt"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=thread%> unterstützt"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "Codemodell %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "Codemodell %qs wird im x32-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> wird in dieser Konfiguration nicht unterstützt"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-Bit-Modus nicht einkompiliert"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%>-CPU kann nur für %<-mtune=%>-Schalter verwendet werden"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%>-CPU kann nur für %<target(\"tune=\")%>-Schalter verwendet werden"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "die CPU %<intel%> kann nur für den Schalter %<-mtune=%> verwendet werden"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "die CPU %<intel%> kann nur für das Attribut %<target(\"tune=\")%> verwendet werden"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Die ausgewählte CPU unterstützt nicht den x86-64-Befehlssatz"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "falscher Wert %qs für Schalter %<-march=%>"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "unbekannter Wert %qs für Attribut %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-march=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "gültige Argumente für %<-march=%> sind: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "falscher Wert %qs für Schalter %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "falscher Wert %qs für Attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> wird für Intel-MCU-psABI ignoriert"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> liegt nicht zwischen 0 und %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> wird für dieses Ziel nicht unterstützt"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> liegt nicht zwischen %d und %d"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> liegt nicht zwischen %d und 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> ist für %<-fPIC%> nicht implementiert"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-Befehlssatz ausgeschaltet, es wird 387-Arithmetik verwendet"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-Befehlssatz ausgeschaltet, es wird SSE-Arithmetik verwendet"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<-maccumulate-outgoing-args%> für Korrektheit"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<target(\"accumulate-outgoing-args\")%> für Korrektheit"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "feststehendes ebp-Register erfordert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "feststehendes ebp-Register erfordert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> wird für 32 Bit in Kombination mit %<-fpic%> nicht unterstützt"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> ist nicht mit SEH verträglich"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> wird derzeit nicht zusammen mit SEH unterstützt"
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "unbekannte Option für %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs ist keine gültige Zahl in %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs ist kein gültiger Offset in %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs ist kein gültiges Basisregister in %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "die Attribute %<interrupt%> und %<naked%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Nur das DWARF-Debugformat ist für Interrupt-Service-Routinen unterstützt"
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-Befehle sind in Exception-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-Befehle sind in Interrupt-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-Befehle sind in Funktionen mit %<no_caller_saved_registers%>-Attribut nicht erlaubt"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "Attribute %qs und %qs sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Argument des Attributes %qE ist nicht (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "in Interrupt-Service-Routinen sollte das erste Argument ein Zeiger sein"
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "in Interrupt-Service-Routinen sollte das zweite Argument vom Typ %qs sein"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "Interrupt-Service-Routine darf nur ein Zeiger- und ein optionales Ganzzahl-Argument haben"
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "Interrupt-Service-Routine muss den Rückgabetyp %<void%> haben"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qT mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "X32 unterstützt %<ms_abi%>-Attribut nicht"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "Attribut %<ms_hook_prologue%> ist mit geschachtelter Funktion nicht verträglich"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorargument ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorrückgabe ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-Vektorrückgabe ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-Vektorargument ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-Vektorrückgabe ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-Vektorargument ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-Vektorrückgabe ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "Das ABI der Struct-Übergabe mit einem flexiblen Arrayelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "das ABI der Union-Übergabe mit %<long double%> hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "das ABI der Strukturübergabe mit %<complex float%>-Element hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "das ABI der C-Strukturübergabe mit Bitfeldern der Breite 0 hat sich in GCC %{12.1%} geändert"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-Registerrückgabe mit SSE ausgeschaltet"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-Registerargument mit SSE ausgeschaltet"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-Registerrückgabe mit ausgeschaltetem x87"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit SSE-Aufrufkonvention, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "dies ist ein GCC-Bug; ein Workaround ist, die aufgerufene Funktion mit dem »used«-Attribut zu markieren"
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "Das ABI der Parameterübergabe mit %d-Byte-Ausrichtung hat sich in GCC 4.6 geändert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90163
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "%<-mcall-ms2sysv-xlogues%> ist nicht kompatibel mit %<%s%>"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "Attribut %<ms_hook_prologue%> ist mit %<-mfentry%> für 32 Bit nicht verträglich"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) wird in Interrupt-Service-Routinen nicht unterstützt. Ein Workaround ist, Funktionen mit Aggregat-Rückgabetypen zu vermeiden."
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "Stapel-Neuausrichtung mit %<__builtin_eh_return%> wird nicht unterstützt"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "geschachtelte Funktion mit regparm wird mit %<__builtin_eh_return%> nicht unterstützt"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "%<-fsplit-stack%> unterstützt nicht fastcall mit geschachtelter Funktion"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "%<-fsplit-stack%> unterstützt nicht 2 Registerparameter für eine geschachtelte Funktion"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "%<-fsplit-stack%> unterstützt nicht 3 Registerparameter"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr "%<V%>-Modifikator an nicht-ganzzahligem Register"
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "nicht unterstützte Größe für Ganzzahlregister"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "erweiterte Register haben keine oberen Hälften"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "nicht unterstützte Operandengröße für erweitertes Register"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "Nicht-Ganzzahl-Operand mit Operandencode %<z%> verwendet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90164
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "das ABI zum Übergeben von leeren Klassen (%qT) als Parametern hat sich mit %<-fabi-version=12%> (GCC 8) geändert"
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "die Ausrichtung von %<_Atomic %T%>-Feldern wurde mit %{GCC 11.1%} geändert"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "Profiling von %<-mcmodel=large%> wird mit PIC nicht unterstützt"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Unbekanntes architekturspezifisches Speichermodell"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "%<HLE_ACQUIRE%> wird mit %<ACQUIRE%> oder stärkerem Speichermodell nicht verwendet"
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "%<HLE_RELEASE%> wird mit %<RELEASE%> oder stärkerem Speichermodell nicht verwendet"
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "nicht unterstützter Rückgabetyp %qT für SIMD"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "nicht unterstützter Argumenttyp %qT für SIMD"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> ist nicht mit %<-mfpmath=387%> kompatibel"
@@ -40395,7 +40400,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE mit in Konflikt stehenden Attributen %qs redeklariert"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
@@ -41520,52 +41525,52 @@ msgstr "%<#pragma riscv intrinsic%>-Option %qs erfordert, dass die Erweiterung '
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "unbekannte Option %qs für %<#pragma riscv intrinsic%>"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr "der RVV-Typ %qT hat keine feste Größe"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "der RVV-Typ %qT hat keine definierte Ausrichtung"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "Arithmetik mit Zeiger auf RVV-Typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr "Membervariablen können nicht vom RVV-Typ %qT sein"
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "Felder können nicht vom RVV-Typ %qT sein"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr "Arrayelemente können nicht vom RVV-Typ %qT sein"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "Objekte vom RVV-Typ %qT können nicht alloziert werden"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "Objekte vom RVV-Typ %qT können nicht gelöscht werden"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr "der RVV-Typ %qT kann weder geworfen noch gefangen werden"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr "der RVV-Typ %qT kann nicht durch Kopieren gefangen werden"
@@ -41585,66 +41590,71 @@ msgstr "diese Operation erfordert die RVV-ISA-Erweiterung"
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "Sie können RVV mit der Befehlszeilenoption %<-march%>, oder mit dem Attribut %<target%> oder Pragma aktivieren"
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI für abgeflachte Struktur mit Bit-Feldern der Länge 0 hat wurde mit GCC 10 geändert"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "Argument des Attributs %qE muss %<\"user\"%>, %<\"supervisor\"%> oder %<\"machine\"%> sein"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> erfordert %<-march%>, um die %<M%>-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "die angeforderte ABI erfordert %<-march%>, um die %qc-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e erfordert die ilp32e-ABI"
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr "z*inx erfordert ABI ilp32, ilp32e oder lp64"
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI erfordert %<-march=rv%d%>"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> muss zwischen %d und %d liegen"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V-ELF-Attribut erfordert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs ist in %qs kein gültiges Basisregister"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs ist in %qs keine gültige Zahl"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs-Funktion kann keine andere Interrupt-Art haben"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr "vl-Register für %qs kann auf diesem Ziel nicht alloziert werden"
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, gcc-internal-format
@@ -42114,97 +42124,97 @@ msgstr "%qs ist veraltet und wird unter keinen Umständen empfohlen"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs ist ein undurchsichtiger Typ, und Sie können ihn nicht auf andere Werte setzen"
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Bei Verwendung der Option %qs kann die Adresse von geschachtelten Funktionen nicht verwendet werden"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne %qs ungültig"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ungültige CPU %qs für %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s ist ungültig"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> schaltet %<-m%s%> aus"
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "das Attribut %<target_clones%> erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "das Ergebnis des Befehls xxspltidp ist für denormalisierte Eingabewerte undefiniert"
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "Typ %<__vector_quad%> erfordert die Option %qs"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "Typ %<__vector_pair%> erfordert die Option %qs"
@@ -43603,7 +43613,7 @@ msgstr "Objekt mit volatile-Feld kann nicht in Register geladen werden"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "nicht initialisiertes %<const %qD%> ist in C++ ungültig"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
@@ -43788,7 +43798,7 @@ msgstr "Speicherklasse für Parameter %qE angegeben"
 msgid "storage class specified for unnamed parameter"
 msgstr "Speicherklasse für unbenannten Parameter angegeben"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "Speicherklasse für Typnamen angegeben"
@@ -43957,7 +43967,7 @@ msgstr "Typname als Funktion, die ein Array zurückgibt, deklariert"
 msgid "function definition has qualified void return type"
 msgstr "Funktionsdefinition hat qualifizierten void-Rückgabetypen"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "Typkennzeichner an Funktions-Rückgabewert ignoriert"
@@ -44084,7 +44094,7 @@ msgstr "ISO-C verbietet const- oder volatile-Funktionstypen"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "Ein Element einer Struktur oder Union kann nicht variabel modifizierten Typ haben"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "Variable oder Feld %qE als »void« deklariert"
@@ -44284,7 +44294,7 @@ msgstr "Typdefinition in Ausdruck %qs ist in C++ ungültig"
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qT wurde in unvollständig angegebenem Objektinitialisierer definiert"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "Deklaration deklariert nichts"
@@ -44334,7 +44344,7 @@ msgstr "struct hat keine benannten Elemente"
 msgid "struct has no members"
 msgstr "struct hat keine Elemente"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibles Arrayelement in Union"
@@ -44379,7 +44389,7 @@ msgstr "Redeklaration von %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr "%<enum%> deklariert aber ohne festen zugrundeliegenden Typen definiert"
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angegebener Modus zu klein für Aufzählungswerte"
@@ -44424,7 +44434,7 @@ msgstr "Aufzählungswert ist außerhalb des Gültigkeitsbereichs von %qs"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C vor C2X beschränkt Aufzählungswerte auf den Bereich von %<int%>"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "der inline-Funktion %qD wurde das Attribut %qs gegeben"
@@ -44454,7 +44464,7 @@ msgstr "kein vorheriger Prototyp für %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Prototyp verwendet"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "keine vorherige Deklaration für %qD"
@@ -44569,12 +44579,12 @@ msgstr "Argument %qD passt nicht zu eingebautem Prototypen"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "keine return-Anweisung in nicht void zurückgebender Funktion"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
@@ -46587,7 +46597,7 @@ msgstr "nicht genügend perfekt geschachtelte Schleifen"
 msgid "collapsed loops not perfectly nested"
 msgstr "zusammengelegte Schleifen sind nicht perfekt geschachtelt"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
@@ -46717,12 +46727,12 @@ msgstr "%<match%> erwartet"
 msgid "variant %qD is not a function"
 msgstr "Variante %qD ist keine Funktion"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "Variante %qD und Basis %qD haben unverträgliche Typen"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "die Variante %qD ist eine eingebaute"
@@ -46983,7 +46993,7 @@ msgstr "falsche Verwendung eines void-Ausdruckes"
 msgid "invalid use of flexible array member"
 msgstr "falsche Verwendung eines flexiblen Arrayelements"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "falsche Verwendung eines Arrays mit unbekannten Grenzen"
@@ -47933,12 +47943,12 @@ msgstr "%<constexpr%>-Initialisierer für einen reellen Typen hat komplexen Typ"
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr "%<constexpr%>-Initialisierer für einen binären Gleitkommatypen hat dezimalen Typ"
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "Initialisierung eines flexiblen Array-Elements"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "Array von %qT kann nicht aus einem Zeichenkettenliteral mit Typ %<Array von %T%> initialisiert werden"
@@ -47979,7 +47989,7 @@ msgstr "Initialisierungs-Element ist zur Lade-Zeit nicht berechenbar"
 msgid "invalid initializer"
 msgstr "ungültige Initialisierung"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opake Vektortypen können nicht initialisiert werden"
@@ -47994,8 +48004,8 @@ msgstr "zusätzliche geschweifte Klammern am Ende der Initialisierung"
 msgid "braces around scalar initializer"
 msgstr "geschweifte Klammern um Skalar-Initialisierung"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "Initialisierung eines flexiblen Array-Elements in geschachteltem Kontext"
@@ -48085,7 +48095,7 @@ msgstr "Elementüberschreitung in struct-Initialisierung"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionelle Initialisierung eines Feldes in %<struct%>, die mit dem %<designated_init%>-Attribut deklariert wurde"
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "nicht-statische Initialisierung eines flexiblen Arrayelements"
@@ -49428,7 +49438,7 @@ msgstr "kein geeignetes %<operator %s%> für %qT"
 msgid "%q#D is private within this context"
 msgstr "%q#D ist in diesem Zusammenhang »private«"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "hier als »private« deklariert"
@@ -49438,7 +49448,7 @@ msgstr "hier als »private« deklariert"
 msgid "%q#D is protected within this context"
 msgstr "%q#D ist in diesem Zusammenhang »protected«"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "hier als »protected« deklariert"
@@ -49453,7 +49463,7 @@ msgstr "%q#D ist in diesem Zusammenhang unzugänglich"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Übergabe von NULL an Nicht-Zeiger-Argument %P von %qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, gcc-internal-format
 msgid "  declared here"
@@ -49782,7 +49792,7 @@ msgstr "keine passende Funktion für Aufruf von %<%T::%s%E(%A)%#V%>"
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
@@ -50351,7 +50361,7 @@ msgstr "flexibles Arrayelement %qD in ansonsten leerem %q#T"
 msgid "next member %q#D declared here"
 msgstr "nächstes Feld %q#D hier deklariert"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
@@ -50472,7 +50482,7 @@ msgstr "ungültiger Typ für Parameter %d der %<constexpr%>-Funktion %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "Lambdas sind erst ab C++17 implizit %<constexpr%>"
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%>-Destruktoren sind erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
@@ -50541,7 +50551,7 @@ msgstr "%qE wird zu »false« ausgewertet"
 msgid "failed %<assume%> attribute assumption"
 msgstr "%<assume%>-Attribut-Annahme fehlgeschlagen"
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -50588,7 +50598,7 @@ msgstr "%qT ist eine mehrdeutige Basisklasse des dynamischen Typen %qT seines Op
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "der dynamische Typ %qT des Operanden hat keine eindeutige öffentliche Basisklasse %qT"
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -50712,7 +50722,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "Dereferenzierung eines Nullzeigers in %qE"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -50811,7 +50821,7 @@ msgstr "%qs greift auf das uninitialisierte Byte an Offset %d zu"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs kann nicht als konstanter Ausdruck ausgewertet werden, da das Argument nicht interpretiert werden kann"
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -50887,7 +50897,7 @@ msgstr "Änderung des aktiven Elements einer union von %qD zu %qD"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Änderung des aktiven Elements einer union von %qD zu %qD während der Initialisierung"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -50953,189 +50963,189 @@ msgstr "der Programmfluss geht durch die Definition von %qD mit thread-lokaler S
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "der Programmfluss geht durch die Definition von %qD mit statischer Speicherdauer"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "Zwischenergebnis des nicht-literalen Typs %qT in konstantem Ausdruck"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "Ein %<reinterpret_cast%> ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Umwandlung von Zeigertyp %qT in arithmetischen Typ %qT in Konstantenausdruck"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "Cast von %qT ist nicht erlaubt"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE ist kein konstanter Ausdruck, solange die Klasse %qT noch unvollständig ist"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "Ausdruck %qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "Vertragsbedingung ist false in konstantem Ausdruck"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "unerwartete Template-ID %qE"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "Funktionskonzept muss aufgerufen werden"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "Adresse des Aufrufs von %qs ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "unexpected expression %qE of kind %s"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE ist kein Konstantenausdruck, da er auf veränderliche Teilobjekte von %qT verweist"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE ist kein Konstantenausdruck, da er auf eine unvollständig initialisierte Variable verweist"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE ist kein konstanter Ausdruck, da er auf das Ergebnis von %<operator new%> verweist"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE ist kein konstanter Ausdruck, da der angeforderte Speicher nicht vollständig freigegeben wurde"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "unmittelbare Auswertung liefert die Adresse der unmittelbaren Funktion %qD"
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "Umwandlung lvalue-in-rvalue eines volatile-lvalue %qE mit Typ %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Lambda-Einfangen von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "da er als glvalue verwendet wird"
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> von Ganzzahl zu Zeiger"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "Adresse eines Objektes %qE mit thread-lokalem oder automatischem Speicher ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "Verwendung von %<this%> in Konstantenausdruck"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Lambda-Ausdruck ist erst ab C++17 ein konstanter Ausdruck"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "new-expression ist erst ab C++20 ein konstanter Ausdruck"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "virtuelle Funktionen können erst mit C++20 %<constexpr%> sein"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> ist kein konstanter Ausdruck, da %qE polymorphen Typ hat"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Umwandlung in Nicht-Ganzzahltyp %qT in konstantem Ausdruck"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<thread_local%> definiert"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<static%> definiert"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "keiner der Zweige des %<if%> ist ein Konstantenausdruck"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "nicht konstante Arrayinitialisierung"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Definition einer Sprungmarke innerhalb einer %<constexpr%>-Funktion ist erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> verfügbar"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
@@ -51710,7 +51720,7 @@ msgstr "der Versprechens-Typ %qT der Koroutine deklariert sowohl %<return_value%
 msgid "%<return_void%> declared here"
 msgstr "%<return_void%> wurde hier deklariert"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "kein Mitglied namens %qE in %qT"
@@ -51802,7 +51812,7 @@ msgstr "das Richtungsargument für %<__builtin_coro_promise%> muss eine Konstant
 msgid "no suspend point info for %qD"
 msgstr "keine Informationen zum Aufschiebepunkt für %qD"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr "%qE wird von %qT bereitgestellt, ist aber nicht mit der Funktionssignatur %qD verwendbar"
@@ -51822,23 +51832,23 @@ msgstr "await-Ausdrücke sind in Handlern nicht erlaubt"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "Arrays mit variabler Länge werden in Koroutinen noch nicht unterstützt"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr "%qE wird von %qT bereitgestellt, aber %qE ist nicht mit %<throw()%> oder %<noexcept%> gekennzeichnet"
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr "%qE ist mit %<throw()%> oder %<noexcept%> markiert, aber %qT liefert kein brauchbares %<get_return_object_on_allocation_failure%>"
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr "%qE wird von %qT bereitgestellt, aber %<std::nothrow%> wurde nicht gefunden"
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "ein Rückgabeobjekt vom Typ %qT kann nicht mit einem r-Wert vom Typ %<void%> initialisiert werden"
@@ -52319,7 +52329,7 @@ msgstr "von vorheriger Deklaration %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Redeklaration %qD unterscheidet sich in %qs von vorheriger Deklaration"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "vorherige Deklaration %qD"
@@ -52719,2275 +52729,2275 @@ msgstr "%qD ist eine Funktion, kein Typ"
 msgid "%q#T is not a class"
 msgstr "%q#T ist keine Klasse"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "kein Klassentemplate namens %q#T in %q#T"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "kein Typ namens %q#T in %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "Nachschlagen von %qT in %qT ist nicht eindeutig"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Klassentemplate ist"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> benennt %q#D, das ist jedoch kein Typ"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "Template-Parameter passen nicht zum Template %qD"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> ist keine Zweierpotenz"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr "%<--param destructive-interference-size=%d%> ist kleiner als %d"
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> ist kleiner als %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr "%<--param constructive-interference-size=%d%> ist kleiner als %d"
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> ist größer als %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "diese Flexibilität ist veraltet und wird demnächst entfernt"
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonyme Struktur mit Basisklassen"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Konstruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Destruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Zuweisungsoperator ist in anonymem Aggregt nicht erlaubt"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "Attribut in Deklaration von %q#T ignoriert"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "Attribut für %q#T muss dem Schlüsselwort %qs folgen"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "mehrere Typen in einer Deklaration"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "Redeklaration des eingebauten C++-Typs %qT"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kann nur für Variablen oder Funktionsdeklarationen angegeben werden"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "fehlender Typname in typedef-Deklaration"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO-C++ verbietet anonyme structs"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kann nur innerhalb einer Klasse angegeben werden"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kann nur für Konstruktoren angegeben werden"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "eine Speicherklasse kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> wurde in dieser Deklaration ignoriert"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kann nicht für Typdeklarationen verwendet werden"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "Attribut in expliter Instanziierung %q#T ignoriert"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "auf explizite Instanziierung kann kein Attribut angewendet werden"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "auf Klassentyp %qT angewandte Attribute außerhalb einer Definition werden ignoriert"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "auf abhängigen Typ %qT angewandte Attribute ohne zugehörige Deklaration werden ignoriert"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ist initialisiert (stattdessen %qs verwenden)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "Deklaration von %q#D hat %<extern%> und ist initialisiert"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "Definition von %q#D ist als %<dllimport%> markiert"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D ist kein static-Datenelement von %q#T"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "Nichtelement-Templatedeklaration von %qD"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "entspricht nicht der Element-Templatedeklaration hier"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO-C++ erlaubt nicht, %<%T::%D%> als %<%T::%D%> zu definieren"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "doppelte Initialisierung von %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "Deklaration von %q#D außerhalb einer Klasse ist keine Definition"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr "extern-Deklaration %q#D mit Gültigkeitsbereich Block ist im Zuständigkeitsbereich des Moduls nicht erlaubt"
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD kann in einer %qs-Funktion erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> als %<thread_local%> definiert werden"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD kann in einer %qs-Funktion erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> als %<static%> definiert werden"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "Variable %q#D hat Initialisierung, aber unvollständigen Typ"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "Elemente des Arrays %q#D haben unvollständigen Typ"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "Aggregat %q#D hat unvollständigen Typ und kann nicht definiert werden"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD als Referenz deklariert, aber nicht initialisiert"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "Name in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "Name %qD in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "nicht-trivial markierte Initialisierungen nicht unterstützt"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-Designator %qE ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "Initialisierung gibt nicht die Größe von %qD an"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "Arraygröße fehlt in %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "Array %qD der Größe null"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Speichergröße von %qD ist unbekannt"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Speichergröße von %qD ist nicht konstant"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik der Inline-Variable %q#D ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik von static-Variable %q#D in inline-Funktion ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "dies kann durch das Löschen der Initialisierung umgangen werden"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "nicht initialisiertes %<const %D%>"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Funktion"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Kontext"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T hat keinen benutzerdefinierten Default-Konstruktor"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "Konstruktor ist nicht benutzerdefiniert, da er im Klassenkörper ausdrücklich standardisiert ist"
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "und der implizit definierte Konstruktor initialisiert %q#D nicht"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Ungültiger Typ %qT als Initialisierung für einen Vektor des Typs %qT"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "Initialisierung für %qT muss geklammert sein"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> in benannter Initialisierung im GNU-Stil für Klasse %qT verwendet"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT hat kein nicht-statisches Datenelement namens %qD"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD ist kein direktes Element von %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ungültige Initialisierung für %q#D"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-Bezeichner %qE außerhalb von Aggregatinitialisierung"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "zu viele Initialisierer für %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90182
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "zu viele geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "geschweifte Klammern fehlen um Initialisierung für %qT"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "Strukturierte Bindung hat unvollständigen Typen %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "Elemente des Arrays %q#T haben unvollständigen Typ"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "zusammengesetztes Literal variabler Größe"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D hat unvollständigen Typ"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalares Objekt %qD erfordert ein Element in Initialisierung"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "in C++98 muss %qD mit Konstruktor initialisiert werden, nicht mit %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "Array %qD mit geklammerter Zeichenkettenkonstante %qE initialisiert"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "Initialisierung ungültig für statisches Element mit Konstruktor"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(eine Initialisierung außerhalb der Klasse ist erforderlich)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "Referenz %qD wird mit sich selbst initialisiert"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Variantendeklaration nicht gefunden"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> für Konstruktor %qD"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> für Destruktor %qD"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> an %qD mit Vorgabewert"
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> an gelöschter %qD"
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> an virtueller %qD"
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "Zuweisung (nicht Initialisierung) in Deklaration"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO-C++17 erlaubt Speicherklassenangabe %<register%> nicht"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-Speicherklassenangabe verwendet"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "Deklaration von %q#D hat keine Initialisierung"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "Initialisierung für %<decltype(auto) %D%> hat Funktionstyp; %<()%> vergessen?"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "deduzierter Typ %qT für %qD ist unvollständig"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "Variablenkonzept hat keine Initialisierung"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "vorherige Typdeklaration von %q#D wird überschattet"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Attribut %<constinit%> kann nur für Variablen verwendet werden, die »static« oder threadlokel sind"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "Funktion %q#D ist wie eine Variable initialisiert"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Strukturelement hat"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Unionelement hat"
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "unzugreifbares Element %qD von %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da sowohl er als auch seine Basisklasse %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da seine Basisklassen %qT und %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Typen %qT"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "Array mit variabler Länge %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u Name für strukturelle Bindung angegeben"
 msgstr[1] "%u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "nur %u Name für strukturelle Bindung angegeben"
 msgstr[1] "nur %u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "während %qT in %wu Element zerlegt wird"
 msgstr[1] "während %qT in %wu Elemente zerlegt wird"
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "Vektor %qT variabler Länge kann nicht zerlegt werden"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "während %qT in %E Elemente zerlegt wird"
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr "%<std::tuple_element<%u, %T>::type%> ist %<void%>"
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "in Initialisierung der Variable %qD für strukturierte Bindung"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "Union-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "nicht-Array-nicht-Klassentyp %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Lambda-Abschluss-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Klassentypen %qT"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "Klassentyp %qT ohne nicht-static-Datenelemente kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "nicht-lokale %<__thread%>-Variable %qD erfordert dynamische Initialisierung"
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "nicht-lokale %<__thread%>-Variable %qD hat einen nicht-trivialen Destruktor"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> in C++11 erlaubt dynamische Initialisierung und Zerstörung"
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Initialisierung gibt nicht die Größe von %qT an"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "Arraygröße fehlt in %qT"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "Array %qT der Größe null"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Destruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Konstruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD als eine %<virtual%> Variable deklariert"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Variablendeklaration"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD als ein %<virtual%> Parameter deklariert"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD als ein %<inline%> Parameter deklariert"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Parameterdeklaration"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD als ein %<virtual%> Typ deklariert"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD als ein %<inline%> Typ deklariert"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Typdeklaration"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD als ein %<virtual%> Feld deklariert"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD als ein %<inline%> Feld deklariert"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Felddeklaration"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D mit einer Ausnahmespezifikation deklariert"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "Deklaration von %qD ist nicht in einem Namensbereich um %qT"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statische Elementfunktion %q#D mit Typqualifizierern deklariert"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "Konzept %q#D mit Funktionsparametern deklariert"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "Konzept %q#D mit hergeleitetem Rückgabetyp deklariert"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Konzept %q#D mit nicht-%<bool%>-Rückgabetyp %qT"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "Konzept %qD hat keine Definition"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "ein Funktionskonzept kann nicht eingeschränkt werden"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "Einschränkungen auf einer Funktion, die kein Template hat"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "Definition der expliziten Spezialisierung %qD in friend-Deklaration"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ungültige Verwendung der Template-ID %qD in Deklaration des ursprünglichen Templates"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "Standardargumente sind nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> ist nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "»friend«-Deklaration von %qD gibt Defaultargumente an und ist keine Definition"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> kann nicht als Template deklariert werden"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> kann nicht inline deklariert werden"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> kann nicht als %qs deklariert werden"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> kann nicht statisch deklariert werden"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statische Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statische Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "Herleitungshinweis %qD muss im selben Gültigkeitsbereich wie %qT deklariert sein"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "Herleitungshinweis %qD muss denselben Zugriff wie %qT haben"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "Herleitungshinweis %qD darf keinen Funktionskörper haben"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "literaler Operator mit C-Bindung"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD hat ungültige Argumentliste"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "Ganzzahl-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "Gleitkomma-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD muss eine Nicht-Elementfunktion sein"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> muss %<int%> zurückgeben"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "Definition des implizit deklarierten %qD"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "Definition des explizit standardisierten %q+D"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D wurde hat hier ausdrücklichen Standardwert bekommen"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "keine Elementfunktion %q#D in Klasse %qT deklariert"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> kann nicht als globale Variable deklariert werden"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "eine Nicht-Template-Variable kann nicht %<concept%> sein"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "Konzept muss im Gültigkeitsbereich des Namensbereiches definiert werden"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "Konzept muss Typ %<bool%> haben"
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "ein Variablenkonzept kann nicht eingeschränkt werden"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit unvollständigem Typ"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> erforderlich für Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ungültige Initialisierung innerhalb der Klasse des statischen Datenelements vom nicht eingebauten Typen %qT"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO-C++ verbietet Initialisierung des nicht konstanten statischen Elements %qD in der Klasse"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO-C++ verbietet Initialisierung der Elementkonstante %qD vom nicht eingebauten Typen %qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "Arraygröße von %qD hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "Arraygröße hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "Größe des Arrays %qD ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "Größe des Arrays ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO-C++ verbietet Array %qD der Größe null"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO-C++ verbietet Array der Größe null"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO-C++ verbietet Array %qD variabler Länge"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO-C++ verbietet Array variabler Länge"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "Array %qD variabler Länge wird verwendet"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "Array variabler Größe wird verwendet"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "Überlauf in Arraygröße"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD ist als Array vom Template-Platzhaltertyp %qT deklariert"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "Array des Template-Platzhaltertyps %qT wird erzeugt"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "Deklaration von %qD als Array von voids"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "Array von void wird erzeugt"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "Deklaration von %qD als Array von Funktionen"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "Array von Funktionen wird erzeugt"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "Deklaration von %qD als Array von Referenzen"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "Feld von Referenzen wird erzeugt"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "Deklaration von %qD als Feld von Funktionselementen"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "Feld von Funktionselementen wird erzeugt"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qD als multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "Array variabler Größe von %<auto%>"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "Angabe des Rückgabetyps für Konstruktor ist ungültig"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Qualifizierer sind bei Konstruktordeklarationen nicht erlaubt"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "Angabe des Rückgabetyps für Destruktor ist ungültig"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "Qualifizierer sind bei Destruktordeklarationen nicht erlaubt"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "Rückgabetyp für %<operator %T%> angegeben"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "Qualifizierer sind bei Deklaration von %<operator %T%> nicht erlaubt"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "Rückgabetyp für Herleitungshinweis angegeben"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "Qualifizierer sind bei Deklaration von Herleitungshinweis nicht erlaubt"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Template-Template-Parameter %qT in Deklaration von Ableitungshinweis"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> in Deklaration von Ableitungshinweis"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unbenannte Variable oder Feld als »void« deklariert"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "Variable oder Feld als »void« deklariert"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%>-Spezifizierer ungültig für Variable %qD mit Gültigkeitsbereich Block"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "»inline«-Variablen sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT als Typ statt als einfaches %<decltype(auto)%>"
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> darf nicht CV-qualifiziert sein"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T ist weder Klasse noch Namensbereich"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "Deklaration von %qE als Nicht-Funktion"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "Deklaration von %qE als Nicht-Element"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "Deklarator-ID fehlt: reserviertes Wort %qD wird verwendet"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "Funktionsdefinition deklariert keine Parameter"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "Deklaration von %qD als Nicht-Funktion"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "Deklaration von %qD als %<typedef%>"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "Deklaration von %qD als Parameter"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "sowohl %qs als auch %qs angegeben"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs kann nicht in einer typedef-Deklaration auftreten"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "höchstens einer der Spezifizierer %<constinit%> und %<constexpr%> kann verwendet werden"
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "zwei oder mehr Datentypen in Deklaration von %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C++ unterstützt nicht, dass einfaches %<complex%> %<double complex%> bedeutet"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO-C++ verbietet Deklaration von %qs ohne Typ"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> wird von diesem Ziel nicht unterstützt"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO-C++ unterstützt %<__int%d%> für %qs nicht"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> und %<unsigned%> gleichzeitig angegeben"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> und %<short%> gleichzeitig angegeben"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs mit %qT angegeben"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "%qs mit %qD angegeben"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs mit %<decltype%> angegeben"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs mit %<typeof%> angegeben"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ungültig für %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "fehlende Template-Argumentliste nach %qE; für die Deduktion muss auf den Template-Platzhalter eine einfache Deklarator-ID folgen"
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Element %qD kann nicht gleichzeitig %<virtual%> und %<static%> sein"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Element %qD kann erst mit %<-std=c++20%> oder %<-std=gnu++20%> gleichzeitig %<virtual%> und %<constexpr%> sein"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "»typedef«-Deklaration in Parameterdeklaration ungültig"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Speicherklasse für Template-Parameter %qs angegeben"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "Speicherklasse für Parameter %qs angegeben"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "ein Parameter kann nicht als %qs deklariert sein"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %qs deklariert werden"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "strukturierte Bindungsdeklarationen können erst ab %<-std=c++20%> oder %<-std=gnu++20%> %qs sein"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "%<volatile%>-qualifizierte strukturierte Bindung ist veraltet"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<auto%> (C++98) deklariert werden"
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "Deklaration für strukturierte Bindung darf nicht vom Typen %qT sein"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "Typ muss cv-qualifizierter %<auto%> oder Referenz auf cv-qualifizierten %<auto%> sein"
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "Deklaration für strukturierte Bindung darf nicht vom eingeschränkten %<auto%>-Typen %qT sein"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "mehrere Speicherklassen in Deklaration von %qs"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Speicherklasse %qs angegeben"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geschachtelte Funktion %qs als %<extern%> deklariert"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "Deklaration höchster Ebene von %qs gibt %<auto%> an"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "Funktions-Gültigkeitsbereich %qs ist implizit auto und deklarierte %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "Speicherklassenangaben sind in friend-Funktionsdeklarationen ungültig"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "Attribut wird ignoriert"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ein Attribut, das sich auf eine Typspezifizierung bezieht, wird ignoriert"
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "unnötige Klammern in Deklaration von %qs"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "entfernen Sie die Klammern"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "»requires«-Klausel für Rückgabetyp"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "Funktion %qs verwendet Typspezifikation %<auto%> ohne folgenden Rückgabetypen"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "hergeleiteter Rückgabetyp nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "virtuelle Funktionen kann keinen hergeleiteten Rückgabetyp haben"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit folgendem Rückgabetypen hat %qT als seinen Typ statt einfaches %<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit nachgestelltem Rückgabetyp hat %<decltype(auto)%> als Typ statt einfachem %<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ungültige Verwendung von %<decltype(auto)%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "hergeleiteter Klassentyp %qD in Rückgabetyp von Funktion"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "Herleitungshinweis für %qT muss angehängten Rückgabetyp haben"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "angehängter Rückgabetyp %qT den Ableitungshinweises ist keine Spezialisierung von %qT"
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "nachgestellter Rückgabetyp nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Funktion %qs mit folgendem Rückgabetypen nicht mit Typspezifikation %<auto%> deklariert"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "eine Umwandlungsfunktion darf keinen angehängten Rückgabetyp haben"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-qualifizierter Rückgabetyp ist veraltet"
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> ist am Rückgabetyp einer Funktion nicht erlaubt"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Destruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Konstruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Konstruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "Destruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "Konstruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Konstruktoren dürfen nicht als %<virtual%> deklariert sein"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-Deklaration nicht in Klassendefinition"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "%<friend%>-Funktion %qs kann nicht in einer lokalen Klassendefinition definiert werden"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<::%> qualifiziert ist"
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<%D::%> qualifiziert ist"
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "Destruktoren dürfen keine Parameter haben"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "Zeiger auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Referenz auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "Zeiger auf Element %q#T kann nicht deklariert werden"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Referenz auf %q#T kann nicht deklariert werden, da letzteres weder Typedef noch Templatetyp-Argument ist"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "Template-ID %qD als Deklarator verwendet"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "Elementfunktionen sind implizite »friends« ihrer Klasse"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "zusätzliche Qualifizierung %<%T::%> an Element %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT definiert werden"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT deklariert werden"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "Element %<%T::%s%> kann nicht in %qT deklariert werden"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Nicht-Parameter %qs kann kein Parameterpack sein"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "Datenelement darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "Parameter darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> in »friend«-Deklaration"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "nur Deklarationen von Konstruktoren und Umwandlungsoperatoren können %<explicit%> sein"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Objekt-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Funktion %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<static%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<const%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Referenz %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "mit %<typedef%> definierte Funktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "mit %<typedef%> definierte Elementfunktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> ist in Aliasdeklaration nicht erlaubt"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "»typedef« als %<auto%> deklariert"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-clause an Typedef"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-Name darf kein Spezifizierer mit geschachteltem Namen sein"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO-C++ verbietet geschachtelten Typen %qD mit gleichem Namen wie umschließende Klasse"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Template-Parameter können keine »friends« sein"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Versuch, die Klasse %qT zu einem »friend« des globalen Gültigkeitsbereiches zu machen"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ungültige Qualifizierer an Nicht-Element-Funktionstyp"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-clause an type-id"
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakter Deklarator %qT als Deklaration verwendet"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "»requires«-Klausel in Deklaration von Nichtfunktionstyp %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "%<::%> kann nicht in Parameterdeklaration verwendet werden"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "Parameter kann nicht mit %<decltype(auto)%> deklariert werden"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr "fehlende Template-Argumentliste nach %qE; Template-Platzhalter ist in Parameter nicht erlaubt"
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "oder verwenden Sie %<auto%> für ein abgekürztes Funktionstemplate"
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%>-Parameter darf in diesem Kontext nicht verwendet werden"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "nicht-statisches Datenelement mit Platzhalter %qT deklariert"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO-C++ verbietet flexibles Arrayelement %qs"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO-C++ verbietet flexible Arrayelemente"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ungültige Verwendung von %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "Deklaration der Funktion %qD in ungültigem Kontext"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Funktion %qD wurde innerhalb einer Union als %<virtual%> deklariert"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kann nicht als %<virtual%> deklariert werden, da es immer statisch ist"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Destruktor %qD erwartet"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "Deklaration von %qD als Element %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ein Destruktor kann nicht %qs sein"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Konstruktor %qD erwartet"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "ein Konstruktor kann nicht %<concept%> sein"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ein Konzept kann keine Elementfunktion sein"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kann nicht %qs sein"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "Spezialisierung des Variablentemplates %qD als Funktion deklariert"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "Variablentemplate hier deklariert"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "Feld %qD hat unvollständigen Typen %qT"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "Name %qT hat unvollständigen Typen"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ist weder eine Funktion noch Elementfunktion; kann nicht als »friend« deklariert werden"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "unbenanntes Feld ist weder eine Funktion noch Elementfunktion; kann nicht als %<friend%> deklariert werden"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "ein Attribut, das zu einer »friend«-Deklaration gehört, die keine Definition ist, wird ignoriert"
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statisches Datenelement %qD (%<constexpr%>) muss Initialisierung haben"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "nicht-statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "Speicherklasse %<auto%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "Speicherklasse %<register%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "Speicherklasse %<__thread%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-Spezifikation in %qs ist außerhalb einer Klassendefinition nicht erlaubt"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> ist für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs ungültig"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuelle Nicht-Klassen-Funktion %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs nicht in Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs in einem Nicht-Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "Elementfunktion %qD kann nicht deklariert werden, statische Bindung zu haben"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statische Funktion innerhalb anderer Funktion kann nicht deklariert werden"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> darf nicht bei der Definition (im Gegensatz zu Deklaration) eines statischen Datenelementes verwendet werden"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisches Element %qD als %<register%> deklariert"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "Element %q#D kann nicht explizit deklariert werden, externe Bindung zu haben"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "Deklaration der %<constexpr%>-Variable %qD ist keine Definition"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "eine Variable kann nicht als %<consteval%> deklariert sein"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisiert und als %<extern%> deklariert"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hat sowohl %<extern%> als auch Initialisierung"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Standardargument %qE verwendet %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Standardargument %qE verwendet lokale Variable %qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ungültige Verwendung von cv-qualifiziertem Typ %qT in Parameterdeklaration"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ungültige Verwendung von Typ %<void%> in Parameterdeklaration"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-qualifizierter Parameter ist veraltet"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "Parameter %qD deklariert ungültigerweise Methodentyp"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Zeiger auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Referenz auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ungültiger Konstruktor; wahrscheinlich war %<%T (const %T&)%> gemeint"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD darf nicht innerhalb eines Namensbereiches definiert werden"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD darf nicht als »static« deklariert werden"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD muss eine nichtstatische Elementfunktion sein"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD muss eine Memberfunktion sein"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%qD darf erst ab %<-std=c++23%> oder %<-std=gnu++23%> eine statische Memberfunktion sein"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD muss entweder eine nichtstatische Elementfunktion oder eine Nicht-Element-Funktion sein"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD muss ein Argument von einem Klassen- oder Aufzählungstyp haben"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO-C++ verbietet Überladen von %<operator ?:%>"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "»%qD« darf keine variable Argumentanzahl haben"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD muss entweder null oder ein Argument nehmen"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD muss entweder ein oder zwei Argumente nehmen"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Suffix-%qD muss %<int%> als sein Argument nehmen"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Suffix-%qD muss %<int%> als sein zweites Argument nehmen"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD darf keine Argumente nehmen"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD muss genau ein Argument nehmen"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD muss genau zwei Argumente nehmen"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kann keine Standardargumente haben"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "Umwandlung von %qT in %<void%> wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "benutzerdefiniertes %qD wertet immer beide Argumente aus"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "Präfix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "Suffix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD sollte Wert zurückgeben"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "Templatetyp-Parameter %qT wird nach %qs verwendet"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "Templatespezialisierung alias %qT hinter %qs wird verwendet"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-Name %qD wird nach %qs verwendet"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD hat eine vorherige Deklaration hier"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT als %qs verwendet"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT hat hier eine vorherige Deklaration"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT als enum verwendet"
@@ -54999,110 +55009,110 @@ msgstr "%qT als enum verwendet"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "Template-Argument für %<%s %T%> benötigt"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "Klassentemplate %qD als Nicht-Template redeklariert"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "Sie könnten ein explizites %<%T::%> hinzufügen"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "Verwendung des enum %q#D ohne vorherige Deklaration"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Redeklaration von %qT als Nicht-Template"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "%qD kann nicht in einem anderen Modul deklariert sein"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "abgeleitete Union %qT ist ungültig"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT ist mit mehreren direkten Basisklassen definiert"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT ist mit direkter virtueller Basisklasse definiert"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "Basistyp %qT ist kein struct- oder Klassentyp"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiver Typ %qT nicht definiert"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "doppelter Basistyp %qT ungültig"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "falsche Zuordnung des zugrunde liegenden Typs in enum %q#T"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "anderer zugrunde liegender Typ in enum %q#T"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "%qD kann nicht in einem anderen Modul definiert sein"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
@@ -55111,82 +55121,82 @@ msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "kein Ganzzahltyp kann alle Aufzählungswerte für %qT darstellen"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Aufzählungswert für %qD muss ganzzahligen oder Aufzählungstyp ohne Gültigkeitsbereich haben"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Aufzählungswert für %qD ist keine Ganzzahlkonstante"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<unsigned long%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<long%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "Überlauf in Aufzählungswerten bei %qD"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Aufzählungswert %qE ist außerhalb des Gültigkeitsbereichs des zugrundeliegenden Typen %qT"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "eine %<constexpr%>-Funktion, die etwas Anderes als %<void%> zurückgibt, muss eine return-Anweisung enthalten"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ist bereits in Klasse %qT definiert"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "%qs wird verwendet"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "Verwendung von %qD vor Herleitung von %<auto%>"
@@ -56035,7 +56045,7 @@ msgstr "Typ %qT ist keine direkte oder virtuelle Basis von %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "Typ %qT ist keine direkte Basis von %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Array muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
@@ -57090,7 +57100,7 @@ msgstr "»using«-Deklaration für Nicht-Element im Gültigkeitsbereich der Klas
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> mit Gültigkeitsbereich in enum-Typ %q#T ist erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT ist weder eine Klasse, noch ein Namensbereich oder eine Aufzählung"
@@ -57836,7 +57846,7 @@ msgstr "Typen dürfen nicht in einem %<typeid%>-Ausdruck definiert werden"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_addressof%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_launder%>"
@@ -58546,12 +58556,12 @@ msgstr "nur Konstruktoren nehmen Elementinitialisierungen"
 msgid "cannot expand initializer for member %qD"
 msgstr "Initialisierung für Element %qD kann nicht expandiert werden"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "Speicherinitialisierung für %qD folgt Konstruktordelegation"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "Konstruktordelegation folgt Speicherinitialisierung für %qD"
@@ -59152,7 +59162,7 @@ msgstr "fehlende Templateargumente nach %qE"
 msgid "%qT not permitted in template argument"
 msgstr "%qT ist in einem Templateargument nicht erlaubt"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -60014,7 +60024,7 @@ msgstr "%<[[omp::directive(%s)]]%> muss das einzige angegebene Attribut in einer
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%>-Klausel mit Parameter in %<for%>-Schleife über einen Bereich"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte keine Reduktion sein"
@@ -61021,7 +61031,7 @@ msgstr "Nicht-Template-Typ %qT als Template verwendet"
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "Template-Einschränkung für %qD fehlgeschlagen"
@@ -61114,276 +61124,276 @@ msgstr "Funktion gibt ein Array zurück"
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Array von %qT wird erzeugt"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD wird für ein leeres Pack instanziiert"
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT wird in %qT aufgelöst, aber das ist kein Klassentyp"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "Initialisierer für %q#D expandiert zu einer leeren Ausdrucksliste"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Verwendung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "leere Initialisierung in »init-capture« für Lambda"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD hier deklariert, später in der Übersetzungseinheit"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "Falsche Anzahl an Argumenten für das Attribut %<assume%> angegeben"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Template-Instanziierung für %q#T"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Template-Instanziierung für %q#D"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "Explizite Instanziierung des Variablenkonzepts %q#D"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "Explizite Instanziierung des Funktionskonzepts %q#D"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
@@ -61395,163 +61405,163 @@ msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d beim Instanziieren von %q+D, möglicherweise wegen Generierung der virtuellen Tabelle (%<-ftemplate-depth=%> verwenden, um den Höchstwert zu erhöhen)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Nichttypen-Templateparameter von hergeleitetem Klassentyp sind erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT ist kein gültiger Typ für einen Nichttyp-Templateparameter, da er nicht strukturell ist"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Nichttypen-Templateparameter von Klassentyp sind nur mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "Schlüsselwort %<template%> nicht innerhalb der declarator-id erlaubt"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ein Konzept kann nicht eingeschränkt werden"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "das Konzept %qE ist nicht im Gültigkeitsbereich des Namensraums"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "das Konzept %qE hat mehrere Vorlagenparameterlisten"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert %<#include <initializer_list>%>"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "nicht herleitbares Templates %qT wird ohne Template-Argumente verwendet"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Alias-Template-Herleitung ist erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "verwenden Sie stattdessen %qD"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "Templateargumente für die Kopierinitialisierung von %qT können nicht abgeleitet werden, da es keine expliziten Ableitungshinweise oder benutzerdeklarierten Konstruktoren gibt"
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "Templateargumente für %qT können nicht abgeleitet werden, da es keine Ableitungshinweise gibt"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "Argumentherleitung für Klassentemplate gescheitert:"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Explizite Herleitungshinweise werden nicht für »copy-initialization« berücksichtigt"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "Argumentherleitung für Klassentemplate von %qT fehlgeschlagen: expliziter Herleitungshinweis in copy-list-initialization ausgewählt"
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "der explizite Herleitungshinweis ist hier deklariert"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT beabsichtigt möglicherweise nicht, Argumentherleitung für Klassentemplates zu unterstützen"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "fügen Sie einen Herleitungshinweis hinzu, um diese Warnung zu unterdrücken"
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization von %<auto%> erfordert genau ein Element"
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "um %<std::initializer_list%> herzuleiten, verwenden Sie einen copy-list-initialization (also mit %<=%> vor dem %<{%>)"
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "Platzhalter-Beschränkungen nicht erfüllt"
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "hergeleiteter Initialisierer erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Rückgabetyp erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Ausdruckstyp erfüllt die Platzhalterbeschränkungen nicht"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ungültige Verwendung von %qT in Templateargument"
@@ -61862,7 +61872,7 @@ msgstr "ungültige Spezifizierung der Basisklasse"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "Element %qD von unbenannter Union kann nicht eingefangen werden"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht eingefangen"
@@ -62270,27 +62280,27 @@ msgstr "%<__builtin_is_corresponding_member%> benötigt zwei Argumente"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr "Argument von %<__builtin_is_corresponding_member%> muss ein Zeiger auf Member sein"
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qD ist weder ein Klassen- noch ein Alias-Template"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Operand des Faltungsausdrucks hat keine unexpandierten Parameterpackungen"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "beide Argumente in binärer Faltung haben unexpandierte Parameterpackungen"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "keine unexpandierten Parameterpackungen in binärer Faltung"
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
@@ -62298,22 +62308,22 @@ msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "Zieltyp %qT von %<__builtin_bit_cast%> ist ein Arraytyp"
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "Zieltyp %qT von %<__builtin_bit_cast%> ist nicht trivial kopierbar"
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "Quelltyp %qT von %<__builtin_bit_cast%> ist nicht trivial kopierbar"
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "in %<__builtin_bit_cast%> ist die Quellgröße %qE ungleich der Zieltypgröße %qE"
@@ -63546,220 +63556,220 @@ msgstr "Vorwärtsdeklaration von %q#T"
 msgid "declaration of %q#T"
 msgstr "Deklaration von %q#T"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qD hat unvollständigen Typ"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "falsche Verwendung des unvollständigen Typs %q#T"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "ungültige Verwendung von Elementfunktion %qD (%<()%> vergessen?)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "ungültige Verwendung des Elements %qD (%<&%> vergessen?)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "ungültige Verwendung des Platzhalters %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "ungültige Verwendung des Parameters %qT für Templatetyp"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "ungültige Verwendung des Parameters %qT für Template-Templateparameter"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "falsche Verwendung von %<pack expansion%> %qT"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "ungültige Verwendung des abhängigen Typen %qT"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "ungültige Verwendung von geschweift geklammerter Initialisierungsliste"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "Adresse einer überladenen Funktion ohne Typinformationen aus Kontext"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "überladene Funktion ohne Typinformationen aus Kontext"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "unzureichende Informationen für Typbestimmung aus Kontext"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "Konstruktorsyntax verwendet, aber kein Konstruktor für Typ %qT deklariert"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%<constinit%>-Variable %qD muss eine konstante Initialisierung haben"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "verengende Umwandlung von %qE von %qH nach %qI ist in C++11 ungültig"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "verengende Umwandlung von %qE von %qH nach %qI"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr " der Ausdruck hat einen konstanten Wert, ist aber kein konstanter Ausdruck im Sinne von C++"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "Initialisierungs-Zeichenkette für %qT ist zu lang"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr "das Initialisieren einer Basisklasse vom Typ %qT führt zu Objektslicing"
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "entfernen Sie die %<{ }%> um den Initialisierer"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "Aggregat des Typs %qT kann nicht mit zusammengesetztem Literal initialisiert werden"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Element %qD mit nicht initialisierten Feldern"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "Designator-Reihenfolge für Feld %qD passt nicht zur ursprünglichen Deklaration in %qT"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "kein Feld %qD in initialisierter Union gefunden"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "Indexwert statt Feldname in Union-Initialisierung"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "ringförmige Zeigerdelegation erkannt"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "Basisoperand von %<->%> hat Nicht-Zeiger-Typ %qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "Ergebnis von %<operator->()%> ergibt Nicht-Zeiger-Ergebnis"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "Basisoperand von %<->%> ist kein Zeiger"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kann nicht als Elementzeiger verwendet werden, da es vom Typ %qT ist"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "Elementzeiger %qE kann nicht auf %qE angewandt werden, da letzteres vom Nicht-Klassen-Typ %qT ist"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "Zeiger auf Elementtyp %qT mit Objekttyp %qT inkompatibel"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen rvalue"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen lvalue"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "Zeiger-auf-Element-Funktions-Typ %qT braucht vor C++20 einen lvalue"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionale Umwandlung in Arraytyp %qT"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "%<auto(x)%> kann nicht eingeschränkt werden"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto{x}%> ist erst mit %<-std=c++2b%> oder %<-std=gnu++2b%> verfügbar"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "Aufruf der Funktion %qD, die unvollständigen Typen %q#T wirft"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "Aufruf einer Funktion, die unvollständigen Typen %q#T wirft"
@@ -64715,7 +64725,7 @@ msgstr "Die BOZ-Literalkonstante bei %L darf kein tatsächliches Argument für %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argumente von %qs bei %L und %L können nicht beide literale BOZ-Konstanten sein"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Ungültige Verwendung der BOZ-Literalkonstante bei %L"
@@ -65810,12 +65820,12 @@ msgstr "Unbenutzte Initialisierungszeichenkette bei %L, da die Variable die Län
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initialisierungszeichenkette bei %L wurde abgeschnitten, um zur Variable zu passen (%ld/%ld)"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L ist kleiner als Eins"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "End-Index der Teilzeichenkette bei %L überschreitet Zeichenkettenlänge"
@@ -65997,7 +66007,7 @@ msgstr "Falsche INTENT-Spezifikation bei %C"
 msgid "deferred type parameter at %C"
 msgstr "Parameter mit zurückgestelltem Typ bei %C"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalarer INTEGER-Ausdruck bei %L erwartet"
@@ -68024,7 +68034,7 @@ msgstr "Transformierende intrinsische Routine %qs bei %L ist in einem Initialisi
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Auswertung des nicht standardisierten Initialisierungsausdrucks bei %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "Funktion %qs in Initialisierungs-Ausdruck bei %L muss eine intrinsische Funktion sein"
@@ -68300,7 +68310,7 @@ msgstr "Unpassende Schnittstellen bei Zuweisung des Prozedurzeigers bei %L: %qs
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explizite Schnittstelle für Komponente %qs bei %L erforderlich: %s"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explizite Schnittstelle für %qs bei %L erforderlich: %s"
@@ -68418,7 +68428,7 @@ msgstr "Zuweisung an zusammenhängenden Zeiger von nichtzusammenhängendem Ziel
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Zeiger bei %L in Zeigerzuweisung könnte Zeigerziel überdauern"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Ziel der Zeigerinitialisierung bei %L darf nicht ALLOCATABLE sein"
@@ -68428,7 +68438,7 @@ msgstr "Ziel der Zeigerinitialisierung bei %L darf nicht ALLOCATABLE sein"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das TARGET-Attribut haben"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das SAVE-Attribut haben"
@@ -68559,7 +68569,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Illegal id in copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -68776,12 +68786,12 @@ msgstr "Erstes Argument der definierten Zuweisung bei %L muss INTENT(OUT) oder I
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
@@ -68891,567 +68901,567 @@ msgstr "Unverträgliche Ränge zwischen Argument bei %L und Argument bei %L (Ran
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Unverträgliche Ränge zwischen Argument bei %L und Argument bei %L (Rang-%d und Rang-%d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ungültiges Argument für Prozedur bei %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Schnittstelle in Scheinprozedur %qs bei %L passt nicht: %s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Effektives Argument für fortlaufenden Schein-Zeiger %qs bei %L muss einfach fortlaufend sein"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Unverträgliche Typen zwischen Argument bei %L und Argument bei %L (%s/%s)."
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Unpassender Typ in Argument %qs bei %L; %s wurde an %s übergeben"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Feld mit vermutetem Rang bei %L erfordert Scheinargument %qs mit vermutetem Rang"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "Argument für angenommenen Typ bei %L, das dem Dummy-Argument %qs für den angenommenen Rang entspricht, muss von angenommener Form oder angenommenem Rang sein"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Effektives Argument für %qs bei %L muss polymorph sein"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Effektives Argument für %qs bei %L muss denselben deklarierten Typ haben"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Effektives Argument für %qs bei %L muss unbegrenzt polymorph sein, da das formale Argument ein Zeiger oder reservierbare unbegrenzt polymorphe Entität ist [F2008: 12.5.2.5]"
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Effektives Argument für %qs bei %L sein muss Koarray sein"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Unpassender Korang in Argument %qs bei %L (%d und %d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Effektives Argument für %qs bei %L muss einfach fortlaufend oder ein Element eines solchen Feldes sein"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Effektives Argument für Nicht-INTENT(INOUT)-Platzhalter %qs bei %L mit Typ LOCK_TYPE oder einer Komponente LOCK_TYPE"
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Effektives Argument für Nicht-INTENT(INOUT)-Platzhalter %qs bei %L mit Typ EVENT_TYPE oder einer EVENT_TYPE-Komponente"
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Scheinargument %qs muss Zeiger oder Feld mit angenommener Form ohne CONTIGUOUS-Attribut sein, da das effektive Argument bei %L nicht einfach fortlaufend ist und beide ASYNCHRONOUS oder VOLATILE sind"
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray, INTENT(OUT) Scheinargument %qs übergeben"
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray-Scheinargument %qs übergeben, das ungültig wird, wenn der Reservierungsstatus geändert wird"
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphes Skalar wird an Feld-Scheinargument %qs bei %L übergeben"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Element des Feldes mit vermuteter Form oder von Zeigern bei %L kann nicht zum Argument bei %L passen"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element des Feldes mit vermuteter Form oder von Zeigern wird bei %2$L an ein Feld-Scheinargument %1$qs übergeben"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Erweiterung: Skalares effektives nicht-standardartiges, nicht-C_CHAR CHARACTER-Argument mit Feld-Scheinargument %qs bei %L"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalares effektives CHARACTER-Argument mit Feld-Scheinargument %qs bei %L"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Schlüsselwort-Argument %qs bei %L darf innerhalb einer Anweisungsfunktion nicht auftauchen"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Schlüsselwort-Argument %qs bei %L ist nicht in der Prozedur; meinen Sie %qs?"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Schlüsselwort-Argument %qs bei %L ist nicht in der Prozedur"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Schlüsselwort-Argument %qs bei %L ist bereits mit einem anderen effektiven Argument verbunden"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Mehr effektive als formale Argumente in Prozeduraufruf bei %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Fehlende alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Unerwartete alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Unerwartetes intrinsisches NULL() bei %L für Schein-%qs"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nullzeiger bei %L an Nicht-Zeiger-Schein-%qs"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr "Argument bei %L für den angenommenen Typ des Dummys hat Typparameter oder hat einen abgeleiteten Typ mit typgebundenen oder FINAL-Prozeduren"
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Zeiger oder reservierbarem Scheinargument %qs bei %L"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Scheinargument %qs mit vermuteter Form bei %L"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Effektives Argument bei %L an reservierbares oder Zeiger-Scheinargument %qs muss Parameter mit Typ aufgeschobener Länge haben, genau dann, wenn das Scheinargument einen solchen hat"
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Zeichenlänge des effektiven Arguments kürzer als das des Scheinarguments %qs (%lu/%lu) bei %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Effektives Argument enthält zuwenige Elemente für Scheinargument %qs (%lu/%lu) bei %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Prozedurzeiger für Argument %qs bei %L erwartet"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Prozedur für Argument %qs bei %L erwartet"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Effektives Argument für %qs kann nicht Feld vermuteter Größe bei %L sein"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr "Argument des INTENT(OUT)-Dummy für angenommenen Rang %qs bei %L muss eine bekannte Größe haben"
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Tatsächliches Argument für %qs bei %L muss ein Zeiger sein"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Effektives Nicht-Zeiger-Argument bei %L an Scheinzeiger %qs"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr "Tatsächliches Argument für %qs bei %L muss ein Zeiger oder ein gültiges Ziel für den Dummy-Zeiger in einer Anweisung für Zeiger-Zuweisung sein"
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Koindiziertes effektives Argument bei %L an Scheinzeiger %qs"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L an scheinreservierbares %qs erfordert INTENT(IN)"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Koindiziertes effektives ASYNCHRONOUS- oder VOLATILE-Argument bei %L erfordert, dass Schein-%qs weder ASYNCHRONOUS noch VOLATILE hat"
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L mit reservierbarer endgültiger Komponente für Schein-%qs erfordert entweder VALUE oder INTENT(IN)"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Effektives CLASS-Feldargument für %qs muss ein vollständiges Feld bei %L sein"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Effektives Argument für %qs muss ALLOCATABLE bei %L sein"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Feldbereich mit Vektorindex als effektives Argument bei %L ist unverträglich mit INTENT(OUT), INTENT(INOUT), VOLATILE- und ASYNCHRONOUS-Attribut des Scheinarguments %qs"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Effektives Argument mit vermuteter Form bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form %qs"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Feldbereich als effektives Argument bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form %qs"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Zeigerfeld als effektives Argument bei %L erfordert wegen VOLATILE-Attribut ein Scheinargument %qs mit vermuteter Form oder als Zeigerfeld"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Fehlende alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Fehlendes effektives Argument für Argument %qs bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Bad component code"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): List mismatch"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): corrupted data"
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Gleiches effektives Argument mit INTENT(%s)-Argument %qs und INTENT(%s)-Argument %qs bei %L verbunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): List mismatch"
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prozedurargument bei %L ist lokal für PURE-Prozedur und hat das POINTER-Attribut"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an INTENT(%s)-Argument übergeben"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an POINTER-Scheinargument übergeben"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Koindiziertem polymorphen effektiven Argument bei %L wird polymorphes Scheinargument %qs übergeben"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Prozedur %qs, die bei %L aufgerufen wird, ist nicht explizit deklariert; meinen Sie %qs?"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Prozedur %qs, die bei %L aufgerufen wird, ist nicht explizit deklariert"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prozedur %qs mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das Zeigerobjekt %qs bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das reservierbare Objekt %qs bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Reservierbare Funktion %qs bei %L muss eine explizite Funktionsschnittstelle haben"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Explizite Schnittstelle für polymorphes Argument bei %L erforderlich"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Schlüsselwort-Argument erfordert explizite Schnittstelle für Prozedur %qs bei %L"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argument »%s« bei %L vermuteten Typs erfordert eine explizite Schnittstelle"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Effektives Argument mit LOCK_TYPE oder mit LOCK_TYPE-Komponente bei %L erfordert eine explizite Schnittstelle für Prozedur %qs"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Effektives Argument mit EVENT_TYPE oder mit EVENT_TYPE-Komponente bei %L erfordert eine explizite Schnittstelle für Prozedur %qs"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-Argument an NULL bei %L erforderlich"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "Das Übergeben des eingebauten NULL als tatsächliches Argument bei %L erfordert eine explizite Schnittstelle"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argument vermuteten Ranges erfordert eine explizite Schnittstelle bei %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prozedurzeiger-Komponente %qs mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Schlüsselwortargument erfordert explizite Schnittstelle für Prozedurzeigerkomponente %qs bei %L"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "In NULL()-Argument bei %L wird MOLD= benötigt: Mehrdeutig zwischen spezifischen Funktionen %s und %s"
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Symbol %qs kann nicht gefunden werden"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entität %qs bei %L ist bereits in der Schnittstelle vorhanden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Bad interface type"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "GENERIC %qs bei %L kann nicht überschrieben werden"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs bei %L überschreibt eine Prozedurbindung, die als NON_OVERRIDABLE deklariert ist"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs bei %L darf nicht DEFERRED sein, da es eine Nicht-DEFERRED-Bindung überschreibt"
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs bei %L überschreibt eine PURE-Prozedur und muss auch PURE sein"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs bei %L überschreibt eine ELEMENTAL-Prozedur und muss auch ELEMENTAL sein"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs bei %L überschreibt eine Nicht-ELEMENTAL-Prozedur und darf ebenfalls nicht ELEMENTAL sein"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs bei %L überschreibt eine SUBROUTINE und muss auch eine SUBROUTINE sein"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs bei %L überschreibt eine FUNCTION und muss auch eine FUNCTION sein"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassendes Ergebnis für die überschreibende Prozedur %qs bei %L: %s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs bei %L überschreibt eine PUBLIC-Prozedur und darf nicht PRIVATE sein"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Scheinargument %qs von %qs bei %L sollte %qs genannt werden, um zum zugehörigen Argument der überschriebenen Prozedur zu passen"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassende Argumente für die überschreibende Prozedur %qs bei %L: %s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs bei %L muss die gleiche Anzahl formaler Argumente wie die überschriebene Prozedur haben"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs bei %L überschreibt eine NOPASS-Bindung und muss ebenfalls NOPASS sein"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs bei %L überschreibt eine Bindung mit PASS und muss ebenfalls PASS sein"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Scheinargument des übergebenen Objektes von %qs bei %L muss an der gleichen Stelle wie das Scheinargument des übergebenen Objektes der überschriebenen Prozedur stehen"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO-Scheinargument bei %L muss vom Typ %s sein"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO-Scheinargument bei %L muss von KIND = %d sein"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO-Scheinargument bei %L muss ein Skalar sein"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO-Scheinargument bei %L muss ein ASSUMED SHAPE ARRAY sein"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "DTIO-Zeichenargument bei %L muss angenommene Länge haben"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO-Scheinargument bei %L muss INTENT %s haben"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Alternativer Rücksprung bei %L ist in einer DTIO-Prozedur nicht erlaubt"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO-Prozedur %qs bei %L muss ein Unterprogramm sein"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Zu wenige Scheinargumente in DTIO-Prozedur %qs bei %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Zu viele Scheinargumente in DTIO-Prozedur %qs bei %L"
@@ -69641,7 +69651,7 @@ msgstr "Umwandlung von %s in %s bei %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "%s kann nicht nach %s bei %L umgewandelt werden"
@@ -70192,7 +70202,7 @@ msgstr "NAMELIST %qs in READ-Anweisung bei %L enthält Symbol %qs, das im Kontex
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
@@ -70762,7 +70772,7 @@ msgstr "STOP-Code bei %L muss Standardzeichentyp KIND=%d sein"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-Code bei %L muss Standardganzzahltyp KIND=%d sein"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "Der Spezifizierer QUIET bei %L muss ein skalarer LOGICAL sein"
@@ -72629,8 +72639,8 @@ msgstr "ORDERED-Parameter der Klausel bei %L ist weniger als COLLAPSE"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "ORDER-Klausel bei %L darf nicht zusammen mit ORDERED verwendet werden"
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
@@ -74606,717 +74616,727 @@ msgstr "Zeichenwertige Modulprozedur %qs bei %L darf keine vermutete Länge habe
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Zeichenwertige interne Funktion %qs bei %L darf keine angenommene Länge haben"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "Funktion »%s« bei %L hat Einträge mit unpassenden Feldspezifikationen"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "Funktion »%s« bei %L hat Eintrag »%s« mit unpassenden Charakteristika"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "Funktion »%s« bei %L mit Einträgen, die Variablen mit verschiedenen Zeichenkettenlängen zurückgeben"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "FUNCTION-Ergebnis %s kann kein Feld in FUNCTION %s bei %L sein"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "ENTRY-Ergebnis %s kann kein Feld in FUNCTION %s bei %L sein"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "FUNCTION-Ergebnis %s kann kein POINTER in FUNCTION %s bei %L sein"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "ENTRY-Ergebnis %s kann kein POINTER in FUNCTION %s bei %L sein"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "FUNCTION-Ergebnis %s kann nicht ALLOCATABLE in FUNCTION %s bei %L sein"
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "ENTRY-Ergebnis %s kann nicht ALLOCATABLE in FUNCTION %s bei %L sein"
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "FUNCTION-Ergebnis %s kann nicht vom Typ %s in FUNCTION %s bei %L sein"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "ENTRY-Ergebnis %s kann nicht vom Typ %s in FUNCTION %s bei %L sein"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "Globale Entität %qs bei %L kann nicht in einem COMMON-Block bei %L vorkommen"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "Globale Entität %qs bei %L darf nicht in einem COMMON-Block vorkommen"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr "COMMON-Block bei %L"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "Variable %qs bei %L ist in COMMON, aber Initialisierung ist nur in BLOCK DATA erlaubt"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "Initialisierte Variable %qs bei %L ist in leerem COMMON, aber Initialisierung ist nur in benannten COMMON-Blöcken erlaubt"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr "%qs bei %L kann nicht in COMMON auftreten [F2008:C5100]"
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "Variable %qs abgeleiteten Typs in COMMON bei %L hat weder das SEQUENCE- noch das BIND(C)-Attribut"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "Variable %qs abgeleiteten Typs in COMMON bei %L hat eine endgültige Komponente, die allozierbar ist"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "Variable %qs abgeleiteten Typs in COMMON bei %L darf nicht Standardinitialisierung haben"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr "In Fortran 2003 ist der COMMON-Block %qs bei %L ein globaler Bezeichner und muss daher den selben Bindungsnamen haben wie der gleichbenannte COMMON-Block bei %L: %s vs. %s"
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "COMMON-Block %qs bei %L verwendet denselben globalen Bezeichner wie die Entität bei %L"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr "Fortran 2008: COMMON-Block %qs mit Binde-Marke bei %L teilt sich Bezeichner mit gobaler nicht-COMMON-Blockentität bei %L"
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "COMMON-Block bei %L mit Bindungsmarke %qs verwendet denselben globalen Bezeichner wie Entität bei %L"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "COMMON-Block %qs bei %L wird bei %L als PARAMETER verwendet"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "COMMON-Block %qs bei %L ist auch eine intrinsische Prozedur"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "COMMON-Block %qs bei %L, der auch ein Funktionsergebnis ist"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "COMMON-Block %qs bei %L, der auch eine globale Prozedur ist"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr "Der KIND-Parameter %qs im PDT-Konstruktor bei %C hat keinen Wert"
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "Der Rang des Elements im Strukturkonstruktor bei %L passt nicht zu dem der Komponente (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "Das Element im Strukturkonstruktor bei %L für Zeigerkomponente %qs ist %s, sollte aber %s sein"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Ungleiche Zeichenlängen (%wd/%wd) für Zeigerkomponente %qs in Konstruktor bei %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "Das NULL im Strukturkonstruktor bei %L wird auf Komponente %qs angewandt, die aber weder ein POINTER noch ein ALLOCATABLE ist"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "Unpassende Schnittstelle für Prozedurzeiger-Komponente %qs in Strukturkonstruktor bei %L: %s"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "Der Strukturkonstruktor bei %2$L verweist auf die falsche Feldangabe der Komponente %1$qs"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "Die Form der Komponente %qs im Strukturkonstruktor bei %L unterscheidet sich von der Form der deklarierten Komponente für die Dimension %d (%ld/%ld)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "Das Element im Strukturkonstruktor bei %L für Zeigerkomponente %qs sollte ein POINTER oder ein TARGET sein"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Ungültiger Ausdruck im Strukturkonstruktor für Zeigerkomponente %qs bei %L in PURE-Prozedur"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "Die obere Schranke in der letzten Dimension muss in der Referenz auf das Feld %qs vermuteter Größe bei %L auftreten"
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "%qs bei %L ist mehrdeutig"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC-Prozedur %qs ist bei %L nicht als effektives Argument erlaubt"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Für intrinsische Funktion %qs angegebener Typ bei %L wird ignoriert"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Intrinsisches Unterprogramm %qs bei %L darf keine Typspezifizierung haben"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "INTRINSIC deklariertes %qs bei %L existiert nicht"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Das bei %2$L deklarierte INTRINSIC %1$qs ist in den derzeitigen Standardeinstellungen nicht verfügbar, außer %3$s. Entsprechende Option %<-std=*%> verwenden, oder %<-fall-intrinsics%> einschalten, um es zu verwenden."
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur %qs bei %L ruft sich möglicherweise rekursiv selbst auf. Sollte als RECURSIVE oder mit %<-frecursive%> verwendet werden"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Marke %d wird bei %L referenziert, aber nirgendwo definiert"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Abgeleiteter Typ %qs wird als Argument bei %L verwendet"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Anweisungsfunktion %qs bei %L ist nicht als effektives Argument erlaubt"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Eingebautes %qs bei %L ist nicht als effektives Argument erlaubt"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Interne Prozedur %qs wird als effektives Argument bei %L verwendet"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL, nicht-INTRINSIC-Prozedur %qs ist nicht als effektives Argument bei %L erlaubt"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Spezifische INTRINSIC-Prozedur für Referenz %qs bei %L kann nicht gefunden werden"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Symbol %qs bei %L ist mehrdeutig"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Wertargument bei %L hat keinen numerischen Typ"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Wertargument bei %L kann kein Feld oder Feldabschnitt sein"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Wertargument bei %L ist in diesem Kontext nicht erlaubt"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Übergabe der eingebauten Prozedur über die Speicherstelle ist bei %L nicht erlaubt"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL Prozedurzeigerkomponente %qs ist nicht als effektives Argument bei %L erlaubt"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Koindiziertes effektives Argument bei %L mit endgültiger Zeigerkomponente"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "%qs bei %L ist ein Feld und OPTIONAL; wenn es fehlt, kann es nicht das effektive Argument einer ELEMENTAL-Prozedur sein, es sei denn, es gibt ein nicht-optionales Argument mit demselben Rang (Fortran 2018, 15.5.2.12)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Effektives Argument bei %L für INTENT(%s)-Dummy %qs von ELEMENTAL-Unterprogramm %qs ist skalar, aber ein anderes effektives Argument ist ein Feld"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Unpassender Rückgabetyp der Funktion %qs bei %L (%s/%s)"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Schnittstelle in globaler Prozedur %qs bei %L passt nicht: %s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Es gibt keine spezifische Funktion für das allgemeine %qs bei %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generische Funktion %qs bei %L ist nicht mit spezifischer intrinsischer Schnittstelle vereinbar"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Funktion %qs bei %L ist INTRINSIC, aber nicht mit einer intrinsischen Funktion verträglich"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Spezifische Funktion %qs bei %L kann nicht aufgelöst werden"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr "Fehlende explizite Deklaration mit EXTERNAL-Attribut für Symbol %qs bei %L"
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ; meinen Sie %qs?"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Referenz auf Nicht-PURE-Funktion %qs bei %L innerhalb eines FORALL %s"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Referenz auf Nicht-PURE-Funktion %qs bei %L innerhalb eines DO CONCURRENT %s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Referenz auf Nicht-PURE-Funktion %qs bei %L innerhalb einer PURE-Prozedur"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Unerwarteter Ausschuss hinter %qs bei %L"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs bei %L ist keine Funktion"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs darf bei %L nicht referenziert werden"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr "ABSTRACT INTERFACE %qs bei %L darf kein angenommenes Zeichenlängenergebnis haben (F2008: C418)"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Funktion %qs ist als CHARACTER(*) deklariert und kann nicht bei %L verwendet werden, da es kein Scheinargument ist"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "Interner Fehler: resolve_function(): bad function type"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr "Eine BOZ-Literalkonstante bei %L kann nicht als tatsächliches Argument in einer Funktionsreferenz verwendet werden"
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Benutzerdefinierte nicht-ELEMENTAL-Funktion %qs bei %L ist in WORKSHARE-Konstrukt nicht erlaubt"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs bei %L kann nicht rekursiv aufgerufen werden, da Funktion %qs nicht RECURSIVE ist"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktion %qs bei %L kann nicht rekursiv aufgerufen werden, da sie nicht RECURSIVE ist"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "Verwendung der Funktion %qs bei %L ist veraltet"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Unterprogrammaufruf von %qs in FORALL-Block bei %L ist nicht PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Unterprogrammaufruf von %qs in »DO CONCURRENT«-Block bei %L ist nicht PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Unterprogrammaufruf von %qs bei %L ist nicht PURE"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Es gibt kein spezifisches Unterprogramm für allgemeines %qs bei %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generisches Unterprogramm %qs bei %L ist nicht mit intrinsischer Unterprogrammschnittstelle vereinbar"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Unterprogramm %qs bei %L ist INTRINSIC, aber nicht mit intrinsischer Funktion verträglich"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Spezifisches Unterprogramm %qs bei %L kann nicht aufgelöst werden"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs bei %L hat einen Typen, der nicht zum CALL bei %L passt"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs bei %L kann nicht rekursiv aufgerufen werden, da Unterprogramm %qs nicht RECURSIVE ist"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs bei %L kann nicht rekursiv aufgerufen werden, da sie nicht RECURSIVE ist"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): bad function type"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "Verwenden der Subroutine %qs bei %L ist veraltet"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Formen der Operanden bei %L und %L stimmen nicht überein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Bad intrinsic"
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Unreine Funktion %qs bei %L wird möglicherweise nicht ausgewertet"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "Unreine Funktion bei %L wird möglicherweise nicht ausgewertet"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "BOZ-Literalkonstante bei %L kann kein Operand des einstelligen Operators %qs sein"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Operanden bei %L und %L können nicht als Operanden des binären Operators %qs verwendet werden"
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "BOZ-Literalkonstante bei %L kann nicht als Operand eines Vergleichsoperators vorkommen"
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "Vergleich auf Gleichheit für %s bei %L"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "Vergleich auf Ungleichheit für %s bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Bad intrinsic"
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld < %ld) in Kodimension %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld > %ld) in Kodimension %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Unzulässiger Schritt von Null bei %L"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Bad array reference"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rechte obere Schranke des Feldabschnitts angenommener Größe nicht angegeben bei %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge des Koindex in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Koindex der Kodimension %d muss bei %L ein Skalar sein"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Feldindex bei %L muss skalar sein"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Feldindex bei %L muss INTEGER-Typ haben, %s gefunden"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-Feld-Index bei %L"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argument dim bei %L muss skalar sein"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argument dim bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Ungültige Feldreferenz der Nicht-Feld-Entität bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): unused as(1)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): unused as(2)"
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Feldindex bei %L ist ein Feld mit Rang %d"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "End-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "End-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "End-Index der Teilzeichenkette bei %L ist zu groß"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Bad array reference"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang größer Null darf kein POINTER-Attribut bei %L haben"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang ungleich Null darf bei %L kein Attribut ALLOCATABLE haben"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Zwei oder mehr Teilreferenzen mit Rang größer Null dürfen nicht bei %L angegeben werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Two array specs"
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut kann nur als effektives Argument verwendet werden"
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verwendet werden"
@@ -75325,12 +75345,12 @@ msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verw
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Typs bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument verwendet werden"
@@ -75339,294 +75359,294 @@ msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument ve
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Ranges bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variable %s vermuteten Typs bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variable »%s« vermuteten Ranges bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "In Spezifikationsausdruck verwendete Variable %qs wird bei %L vor Anweisung ENTRY referenziert, in der sie ein Parameter ist"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variable %qs wird bei %L vor Anweisung ENTRY verwendet, in der sie ein Parameter ist"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphes Subobjekt des koindizierten Objektes bei %L"
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Koindiziertes Objekt mit polymorpher reservierbarer Subkomponente bei %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Verwendung der Variable %qs bei %L ist veraltet"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs bei %L ist Host-verbunden bei %L in eine enthaltene Prozedur mit einer gleichnamigen internen Prozedur"
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fehler in Typbeschränktem Aufruf bei %L"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Weitergegebenes Objekt bei %L muss Skalar sein"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der Prozedurzeigerkomponente bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der typgebundenen Prozedur bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basisobjekt für Aufruf der typgebundenen NOPASS-Prozedur bei %L muss skalar sein"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Keine passende spezifische Bindung für Aufruf des GENERIC %qs bei %L gefunden"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs bei %L sollte eine SUBROUTINE sein"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs bei %L sollte eine FUNCTION sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Bad expression type"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s bei %L muss skalar sein"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s bei %L muss ganzzahlig sein"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s bei %L muss INTEGER sein"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Schrittausdruck in DO-Schleife bei %L kann nicht Null sein"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-Schleife bei %L wird null mal ausgeführt"
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie überläuft"
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie unterläuft"
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Anfangsausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Endausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-Schrittausdruck bei %L muss skalares %s sein"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-Schrittausdruck bei %L kann nicht Null sein"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-Index %qs kann nicht in Tripel-Spezifikation bei %L auftreten"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "ALLOCATE-Objekt bei %L muss ALLOCATABLE oder ein POINTER sein"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Quell-Ausdruck bei %L muss skalar sein oder den selben Rang wie das ALLOCATE-Objekt bei %L haben"
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Quell-Ausdruck bei %L und ALLOCATE-Objekt bei %L müssen dieselbe Form haben"
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typ der Entität bei %L ist mit Quellausdruck bei %L typunverträglich"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Das ALLOCATE-Objekt bei %L und der Quellausdruck bei %L müssen Typparameter der gleichen Art haben"
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ LOCK_TYPE sein noch eine LOCK_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ EVENT_TYPE sein noch eine EVENT_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Reservierung von %s mit ABSTRACT-Basistyp bei %L erfordert Typspezifikation oder Quellausdruck"
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Reservierung von %s bei %L mit Typspezifikation erfordert den selben Zeichenkettenlängenparameter wie in der Deklaration"
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "In ALLOCATE-Anweisung bei %L ist Feld-Spezifikation erforderlich"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Feldspezifikation oder feldwertiger SOURCE=-Ausdruck erforderlich in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Koarray-Spezifikation in ALLOCATE-Anweisung bei %L erforderlich"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Falsche Koarray-Spezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze bei %L"
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze von 1 bei %L"
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Falsche Feldspezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs darf nicht bei %L in einer Feldspezifikation in der gleichen ALLOCATE-Anweisung auftreten, wo es selbst alloziert wird"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "In Koindex-Spezifikation in ALLOCATE-Anweisung bei %L wird %<*%> erwartet"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-Variable bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-Variable bei %L darf nicht %s innerhalb der gleichen %s-Anweisung sein"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG bei %L ist ohne STAT-Marke nutzlos"
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "»ERRMSG=«-Variable bei %L muss skalare Default-CHARACTER-Variable sein"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "ERRMSG-Variable bei %L darf nicht »%s« innerhalb der selben »%s«-Anweisung sein"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "ALLOCATE-Objekt bei %L tritt auch bei %L auf"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
@@ -75635,284 +75655,284 @@ msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-Marke bei %L überschneidet sich mit CASE-Marke bei %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss Typ %s haben"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss von der Art %d sein"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss skalar sein"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Auswahlausdruck in berechneter GOTO-Anweisung bei %L muss ein skalarer Ganzzahlausdruck sein"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument der SELECT-Anweisung bei %L kann nicht %s sein"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argument der SELECT-Anweisung bei %L muss ein skalarer Ausdruck sein"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L ist nicht im Bereich von %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Der DEFAULT CASE bei %L kann nicht von zweitem DEFAULT CASE bei %L gefolgt werden"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logischer Bereich in CASE-Anweisung bei %L ist nicht erlaubt"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstanter logischer Wert in CASE-Anweisung wird bei %L wiederholt"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Bereichsspezifikation bei %L kann nie passen"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logischer SELECT CASE Block bei %L hat mehr als zwei Fälle"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurzeiger"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Abgeleiteter Typ %qs kann bei %L nicht als Variable verwendet werden"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurname"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Der zuordnende Selektor-Ausdruck bei %L ergibt eine Prozedur"
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektor bei %L darf nicht NULL() sein"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektor bei %L hat keinen Typ"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Zugeordneter Name %qs bei %L wird als Feld verwendet"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-Selektor bei %L erfordert Zwischenspeicher, was noch nicht implementiert ist"
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektor muss in SELECT TYPE-Anweisung bei %L polymorph sein"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektor bei %L darf nicht koindiziert sein"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS bei %L überlappt sich mit TYPE IS bei %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Abgeleiteter Typ %qs bei %L muss erweiterbar sein"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Abgeleiteter Typ %qs bei %L muss eine Erweiterung von %qs sein"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Unerwarteter intrinsischer Typ %qs bei %L"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Die Typspezifikation bei %L muss angeben, dass jeder Parameter mit Längentyp vermutet ist"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Doppelter CLASS IS-Block in SELECT TYPE-Anweisung bei %L"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) bei %L kann nicht mit dem Zeiger oder dem allozierbaren Selektor bei %L verwendet werden"
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO-%s-Prozedur bei %L muss rekursiv sein"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Element zum Datenaustausch bei %L kann nicht polymorph sein, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine POINTER-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Datenübertragungselement bei %L kann keine Prozedurzeiger-Komponenten haben"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine ALLOCATABLE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Datenübertragungselement bei %L kann keine vollständige Referenz auf Feld vermuteter Größe sein"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock-Variable bei %L muss Skalar mit LOCK_TYPE sein"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Ereignis-Variable bei %L muss Skalar mit EVENT_TYPE sein"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray oder koindiziert sein"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray, aber nicht koindiziert sein"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "»STAT=«-Argument bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "»ERRMSG=«-Argument bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "»ACQUIRED_LOCK=«-Argument bei %L muss skalare LOGICAL-Variable sein"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Argument UNTIL_COUNT= bei %L muss ein skalarer INTEGER-Ausdruck sein"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argument für Imageset bei %L muss Skalar oder Rang-1-INTEGER-Ausdruck sein"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argument für Imageset bei %L muss zwischen 1 und num_images() liegen"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Anweisung bei %L ist keine gültige Sprungzielanweisung für Sprungziel bei %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Sprung bei %L könnte Endlosschleife bewirken"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt CRITICAL-Konstrukt für Marke bei %L"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke bei %L"
@@ -75920,210 +75940,210 @@ msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke be
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Marke bei %L ist nicht im gleichen Block wie GOTO-Anweisung bei %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-Maske bei %L hat ungültige Form"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-Zuweisungsziel bei %L hat ungültige Form"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Benutzerdefinierte Nicht-ELEMENTAL-Zuweisung in WHERE bei %L"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Nicht unterstützte Anweisung in WHERE bei %L"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Das FORALL mit Index %qs wird nicht auf der linken Seite der Zuweisung bei %L verwendet und könnte somit mehrere Zuweisungen an dieses Objekt auslösen"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-Konstrukt bei %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Ein äußeres FORALL-Konstrukt hat bereits einen Index mit Namen %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Klausel WHERE/ELSEWHERE bei %L erfordert ein LOGICAL-Feld"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Bad block type"
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-Ausdruck wird in Zuweisung (%ld/%ld) bei %L abgeschnitten"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Koindizierter Ausdruck bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "In einem reinen Unterprogramm darf ein INTENT(IN)-Dummy-Argument nicht als »expr« bei %L einer intrinsischen Zuweisungsanweisung verwendet werden, in der die Variable von einem abgeleiteten Typ ist, wenn der abgeleitete Typ eine Zeigerkomponente auf irgendeiner Ebene der Komponentenauswahl hat."
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Zuweisung an koindizierte Variable bei %L in einer PURE-Prozedur"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Zuweisung an polymorphes Koarray bei %L ist nicht erlaubt"
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L erfordert %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "Nicht allozierbare Variable darf in intrinsischer Zuweisung bei %L nicht polymorph sein – bitte prüfen, ob es ein passendes spezifisches Unterprogramm für den »=«-Operator gibt"
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Koindizierte Variable darf keine reservierbare endgültige Komponente in Zuweisung bei %L haben"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: als typgebunden definierte Zuweisung(en) bei %L nicht durchgeführt, da Feldreferenzen mit mehreren Teilen in Ausdrücken als Zwischenergebnisse auftreten würden."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsergebnis auf der linken Seite der Zuweisung bei %L muss Zeiger-Attribut haben."
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "TEAM-Argument für %qs bei %L muss ein skalarer Ausdruck vom Typ TEAM_TYPE sein"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "»TEAM NUMBER«-Argument für FORM TEAM bei %L muss skalares INTEGER sein"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine skalare INTEGER-Variable"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variable %qs bei %L wurde keine Zielmarke zugewiesen"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternative RETURN-Anweisung bei %L erfordert einen SCALAR-INTEGER-Spezifizierer als Rückgabe"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Erwarteter intrinsischer Initialisierungsausdruck OMP WORKSHARE bei %L"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-Anweisung bei %L erfordert eine skalare Standard-INTEGER-Variable"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ungültiges NULL bei %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Arithmetische IF-Anweisung bei %L erfordert einen skalaren REAL- oder INTEGER-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): No expression on DO WHILE"
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Abbruchbedingung der DO WHILE-Schleife bei %L muss ein skalarer LOGICAL-Ausdruck sein"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-Maskenklausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Bad statement code"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Verwendung von Parameter %qs, der bei %L deklariert wurde, ist veraltet"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variable %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet denselben globalen Bezeichner wie Entität bei %L aus Modul %qs"
@@ -76131,985 +76151,985 @@ msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet densel
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Prozedur %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Zeichenkettenlänge bei %L ist zu groß"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Reservierbares Feld %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalares Objekt %qs bei %L kann nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Feldzeiger %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Feld %qs bei %L kann keine aufgeschobene Form haben"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typ %qs der CLASS-Variable %qs bei %L ist nicht erweiterbar"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-Variable %qs bei %L muss Attrappe, reservierbar oder Zeiger sein"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Der Typ %qs bei %L darf nicht mit Wirt verbunden sein, da er von unverträglichem bei %L definierten Objekt mit gleichem Namen blockiert wird"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Einbezogenes SAVE für Modulvariable %qs bei %L, benötigt wegen Standardinitialisierung"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Entität %qs bei %L hat Parameter mit aufgeschobenem Typ und benötigt entweder das POINTER- oder ALLOCATABLE-Attribut"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Das Feld %qs im Modul oder Hauptprogramm bei %L muss konstante Form haben"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entität mit vermuteter Zeichenlänge bei %L muss ein Scheinargument oder ein PARAMETER sein"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs bei %L muss in diesem Zusammenhang konstante Zeichenlänge haben"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-Variable %qs bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Zuordnungsfähiges %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Externes %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Schein-%qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsisches %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsergebnis %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisches Feld %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s bei %L"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Zeichenwertige Anweisungsfunktion %qs bei %L muss konstante Länge haben"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs hat PRIVATE-Typ und kann kein Scheinargument von %qs bei %L sein, das PUBLIC ist"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Prozedur %qs in PUBLIC-Schnittstelle %qs bei %L nimmt Scheinargumente von %qs, das PRIVATE ist"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externes Objekt %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-Funktion %qs bei %L muss ein skalares Ergebnis haben"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Anweisungsfunktion %qs bei %L darf weder POINTER- oder ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht feld-wertig sein"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht zeiger-wertig sein"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rein sein"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rekursiv sein"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-Funktion %qs bei %L"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prozedurzeiger %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Scheinprozedur %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionsergebnisvariable %qs bei %L von elementarer Funktion %qs darf nicht die Attribute ALLOCATABLE oder POINTER haben"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut SAVE in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut INTENT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut RESULT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Attribut EXTERNAL steht mit Attribut FUNCTION in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Dem Ergebnis %qs als Prozedurzeiger bei %L fehlt das POINTER-Attribut"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in ELEMENTAL-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in PURE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in RECURSIVE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s zwischen der MODULE-PROCEDURE-Deklaration in Modul %qs und der Deklaration bei %L in (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Schnittstelle von %qs bei %L muss explizit sein"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-Prozedur %qs bei %L ist keine SUBROUTINE"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-Prozedur bei %L muss genau ein Argument haben"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument der FINAL-Prozedur bei %L muss Typ %qs haben"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr "FINAL-Prozedur bei %L mit angenommenem Rangargument muss der einzige Finalisierer mit derselben Art/Typ sein (F2018: C790)"
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument der FINAL-Prozedur bei %L darf kein POINTER sein"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht OPTIONAL sein"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Nicht-skalare FINAL-Prozedur bei %L sollte Argument mit vermuteter Form haben"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Bei %2$L deklarierte FINAL-Prozedur %1$qs hat denselben Rang (%3$d) wie %4$qs"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Für den abgeleiteten Typ %qs, der bei %L definiert ist, sind ausschließlich Array-FINAL-Prozeduren deklariert. Empfohlen ist auch eine skalare, es sei denn, ein Finalisierer mit angenommenem Rang wurde deklariert"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs und %qs können nicht gemischte FUNCTION/SUBROUTINE für GENERIC %qs bei %L sein"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs und %qs für GENERIC %qs bei %L sind mehrdeutig"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Undefinierte spezifische Bindung %qs als Ziel des GENERIC %qs bei %L"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs bei %L muss auf spezifische Bindung abzielen, %qs ist ebenfalls GENERIC"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs bei %L kann nicht spezifische Bindung mit gleichem Namen überschreiben"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typgebundener Operator bei %L kann nicht NOPASS sein"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs bei %L muss eine Modulprozedur oder eine externe Prozedur mit expliziter Schnittstelle sein"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedur %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prozedur %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Nicht-polymorphes Scheinargument von %qs für weitergegebenes Objekt bei %L"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L muss ein Skalar sein"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht POINTER sein"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prozedur %qs bei %L hat den gleichen Namen wie eine Komponente von %qs"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prozedur %qs bei %L hat den selben Namen wie eine vererbte Komponente von %qs"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Bei %2$L deklarierter abgeleiteter Typ %1$qs muss ABSTRACT sein, da %3$qs DEFERRED und nicht überschrieben ist"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Koarray-Komponente %qs bei %L muss reservierbar mit aufgeschobener Form sein"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponente %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponente %qs bei %L mit Koarray-Komponente darf ein Nicht-Zeiger und nicht-reservierbares Skalar sein"
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Komponente %qs bei %L hat das CONTIGUOUS-Attribut, aber ist kein Feldzeiger"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponente %qs von BIND(C)-Typ bei %L muss Länge eins haben"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Parameter %qs von %qs mit PASS(%s) bei %L muss skalar sein"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf kein POINTER-Attribut haben"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponente %qs von %qs bei %L hat den gleichen Namen wie eine geerbte typgebundene Prozedur"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Zeichenlänge der Komponente %qs muss ein konstanter Spezifikationsausdruck bei %L sein"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Ausdruck für Zeichenlänge der Komponente %qs bei %L muss vom Typ INTEGER sein, nicht %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Zeichenkomponente %qs von %qs bei %L mit aufgeschobener Länge muss POINTER oder ALLOCATABLE sein"
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Die Komponente %qs ist ein PRIVATE-Typ und kann nicht Komponente von %qs sein, die PUBLIC bei %L ist"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphe Komponente %s bei %L in SEQUENCE oder BIND(C)-Typ %s"
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponente %s des bei %L deklarierten SEQUENCE-Typen hat kein SEQUENCE-Attribut"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "In Konflikt stehende Initialisierungen in Union bei %L und %L"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Da der erweiterte Typ %qs bei %L eine Koarray-Komponente hat, muss der Elterntyp %qs auch eine haben"
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Nicht-erweiterbarer abgeleiteter Typ %qs bei %L darf nicht ABSTRACT sein"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parametrisierter Typ %1$qs hat bei %3$L keine Komponente, die zu Parameter %2$qs gehört"
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name %qs der Funktion %qs bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Abgeleiteter Typ %qs bei %L wurde nicht deklariert"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %L ist nicht erlaubt"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs mit vermuteter Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs ohne konstante Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs ohne konstante Zeichenlänge in Namensliste %qs bei %L"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat Verwendungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste %qs bei %L sein"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld %qs bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER %qs bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Das Objekt %qs bei %L hat aufgeschobenen LEN-Parameter %qs und ist weder allozierbar noch ein Zeiger"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "Das AUTOMATIC-Objekt %qs bei %L darf kein SAVE-Attribut haben und dard auch keine Variable im main-Programm, einem Modul oder einem Teilmodus sein (F08/C513)"
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Das Objekt %qs bei %L mit ASSUMED-Typparametern muss ein Dummy oder ein SELECT-TYPE-Selektor sein (F08/4.2)"
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Sorry, allozierbare/Zeiger-Komponenten in polymorphen (CLASS-)getypten Koarrays bei %L werden nicht unterstützt"
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr "%<omp_all_memory%>, bei %L deklariert, darf nur in der OpenMP-DEPEND-Klausel verwendet werden"
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Falsche Spezifikation für Feld bei %L mit angenommener Größe"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ %qs bei %L hat Typ %qs, der nicht definiert wurde"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss ein Scheinargument sein"
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss vom Typ TYPE(*) oder von einem numerischen intrinsischen Typ sein"
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss entweder skalar sein oder ein Feld vermuteter Größe"
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L darf kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable %qs bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-Variable %qs bei %L muss Länge eins haben"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs bei %L mit abgeleitetem PRIVATE-Typen %qs"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79866
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variable %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument %qs bei %L hat ASSUMED SIZE und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit LOCK_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit EVENT_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis %qs bei %L darf weder Koarray sein noch eine Koarray-Komponente haben"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable %qs bei %L mit Koarraykomponente muss ein Nichtzeiger, nichtallozierbares Skalar und damit kein Koarray sein"
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable %qs bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable %qs bei %L darf keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable %qs bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable %qs bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Scheinvariable %qs bei %L in BIND(C)-Prozedur %qs nicht erlaubt"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namensliste %qs kann bei %L nicht als Argument für Unterprogramm oder Funktion verwendet werden"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "»!$OMP DECLARE TARGET«-Variable %qs bei %L ist nicht gespeichert (SAVE)"
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbare Entität bei %L erwartet"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element %qs bei %L muss in COMMON sein"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld %qs bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element %qs bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element %qs bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "Das DATA-Objekt in der Nähe von %L hat das Zeiger-Attribut und der entsprechende DATA-Wert ist kein gültiges initial-data-target"
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Das DATA-Element %qs bei %L kann kein ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Schrittweite der implied-do-Schleife bei %L darf nicht 0 sein"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE muss das Attribut PROTECTED haben"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-Blockelement %qs bei %L darf in der PURE-Prozedur %qs kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld %qs bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Selbstreferenz im Zeichenlängenausdruck für %qs bei %L"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion %qs bei %L mit PRIVATE-Typ %qs"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss eine FUNCTION sein"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator %qs bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Enthaltene Prozedur %qs bei %L einer PURE-Prozedur muss auch PURE sein"
@@ -78025,7 +78045,7 @@ msgstr "Überlappende ungleiche Initialisierungen in EQUIVALENCE bei %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Überlappende ungleiche Initialisierungen in EQUIVALENCE bei %C"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr "Der Strukturkonstruktor bei %C wurde finalisiert. Dieses Feature wurde von f08/0011 entfernt. Verwenden Sie -std=f2018 oder -std=gnu, um die Finalisierung zu entfernen."
@@ -78037,12 +78057,12 @@ msgstr "Der Strukturkonstruktor bei %C wurde finalisiert. Dieses Feature wurde v
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Die Anzahl der Elemente im Feldkonstruktor bei %L erfordert Erhöhung der erlaubten oberen Grenze %d. Siehe Option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Bei %L wird ein vorübergehendes Feld für Argument %qs erzeugt"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Falscher Ausdruckstyp beim Durchlaufen (%d)"
@@ -78136,81 +78156,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr "Das Feld %qs bei %L ist größer als der Grenzwert, der durch %<-fmax-stack-var-size=%> festgelegt wurde, daher wurde es vom Stapel in den statischen Speicher verschoben. Dies macht die Prozedur unsicher, wenn sie rekursiv oder gleichzeitig von mehreren Threads aus aufgerufen wird. Erwägen Sie, die Grenze für %<-fmax-stack-var-size=%> anzuheben, verwenden Sie %<-frecursive%> (dadurch wird die Beschränkung von %<-fmax-stack-var-size%> aufgehoben), oder ändern Sie den Code so, dass er ein ALLOCATABLE-Feld verwendet. Wenn auf die Variable niemals nebenläufig zugegriffen wird, können Sie diese Warnung ignorieren, Sie könnten diese Variable auch mit dem Attribut SAVE deklarieren."
 
 #: fortran/trans-decl.cc:1795
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "%s bei %C hat keinen Vorgabe-Typ"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "innere Variable, die keine Prozedur ist"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Rückgabewert der Funktion %qs bei %L nicht gesetzt"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Parameter aufgeschobenen Typs wird noch nicht unterstützt"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Backend-Deklaration für Modulvariable %qs ist bereits vorhanden"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Ungenutzte PRIVATE-Variable %qs bei %L deklariert"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "Symbol %qs bei %L hat das Attribut WEAK, ist aber ein Scheinargument"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "Symbol %qs bei %L hat das Attribut WEAK, ist aber eine lokale Variable"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Scheinargument %qs bei %L war als INTENT(OUT) deklariert, aber nicht gesetzt"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Scheinargument %qs abgeleiteten Typs bei %L war als INTENT(OUT) deklariert, aber nicht gesetzt und hat keine Standardinitialisierung"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Ungenutztes Dummyargument %qs bei %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Ungenutzte Modulvariable »%qs«, die bei %L ausdrücklich importiert wurde"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Ungenutzte Variable %qs, bei %L deklariert"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Ungenutzter Parameter %qs, bei %L deklariert"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Ungenutzter Parameter %qs, der bei %L ausdrücklich importiert wurde"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Rückgabewert %1$qs der bei %3$L deklarierten Funktion %2$qs nicht gesetzt"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Entschuldigung, !$ACC DECLARE bei %L ist in einem BLOCK-Konstrukt nicht erlaubt"
@@ -78225,27 +78250,27 @@ msgstr "Länge des Arrays bei %L kann nicht berechnet werden."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Code zur Neu-Reservierung der reservierbaren Variable bei %L wird hinzugefügt"
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf ein unbegrenzt polymorphes Objekt wird nicht unterstützt"
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf eine unbegrenzt polymorphe Komponente wird nicht unterstützt"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Unbekannte eingebauter Operator"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Unbekannte Argumentlistenfunktion bei %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Wenn die Neuzuordnung von Grenzen bei %L angegeben wird, darf das Zeigerziel nicht NULL sein"
@@ -80049,6 +80074,9 @@ msgstr "der Rückgabewert vom Typ %qT wird ignoriert, muss aber verwendet werden
 msgid "unused name %qE"
 msgstr "unverwendeter Name %qE"
 
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "ungültige Operandengröße für Operandencode »Z«"
+
 #~ msgid "Implement DIP25: Sealed references."
 #~ msgstr "DIP25 \"Versiegelte Referenzen\" implementieren."
 
diff --git a/gcc/po/el.po b/gcc/po/el.po
index bf5487fa7df..2fd1c3e7c40 100644
--- a/gcc/po/el.po
+++ b/gcc/po/el.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -4047,7 +4047,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7692,6 +7692,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr ""
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17230,12 +17235,12 @@ msgstr ""
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, fuzzy, c-format
 msgid "invalid expression as operand"
@@ -18386,110 +18391,110 @@ msgstr "Αυτή η παράμετρος δεν έχει ακόμα τεκμηρ
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr ""
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr ""
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr ""
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr ""
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
 "   "
 msgstr "πολύ λίγα ορίσματα"
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr ""
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr ""
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr ""
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr ""
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr ""
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr ""
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr ""
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr ""
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr ""
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr ""
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr ""
 
@@ -18881,72 +18886,72 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "RPC: Μη συμβατές εκδόσεις του RPC"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -18963,18 +18968,18 @@ msgid "invalid %%r value"
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, fuzzy, c-format
 msgid "invalid %%R value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
@@ -19004,7 +19009,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "invalid %%U value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
@@ -19014,7 +19019,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "invalid %%C value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
@@ -19027,7 +19032,7 @@ msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, fuzzy, c-format
 msgid "invalid %%xn code"
 msgstr "μη έγκυρο δικαίωμα"
@@ -19111,35 +19116,35 @@ msgstr "μη έγκυρη μετατόπιση UTC"
 msgid "unrecognized supposed constant"
 msgstr "άγνωστο πρόθεμα: %s"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19148,28 +19153,28 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 msgid "invalid operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19577,98 +19582,98 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "Expected register or constant integer."
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 msgid "invalid use of register '%s'"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "μη έγκυρο δικαίωμα"
 
 # src/grep.c:1133
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "άγνωστη μέθοδος καταλόγων"
@@ -19703,7 +19708,7 @@ msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 msgid "invalid %%P operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -19750,8 +19755,8 @@ msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -19783,7 +19788,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -19945,7 +19950,7 @@ msgstr "Εμφάνιση έκδοσης προγράμματος"
 msgid "unsupported memory expression:"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "μη έγκυρος χρήστης"
@@ -19999,149 +20004,149 @@ msgstr ""
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 msgid "invalid %%A value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
@@ -20612,7 +20617,7 @@ msgstr ""
 msgid "  after user-defined conversion:"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -21107,7 +21112,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "προειδοποίηση: "
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -21283,12 +21288,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 #, fuzzy
 msgid "assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 #, fuzzy
 msgid "pointer assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -21297,224 +21302,224 @@ msgstr "προσπέρασμα ορίσματος"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 #, fuzzy
 msgid "elemental procedure"
 msgstr "πολύ λίγα ορίσματα"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 msgid "allocatable argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 msgid "value argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 #, fuzzy
 msgid "parametrized derived type argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "Δεν είναι δυνατό να δεσμευτεί μνήμη"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr ""
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -21527,27 +21532,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -22480,7 +22485,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at %qs token"
 msgid "Syntax error in %s statement at %C"
@@ -22858,7 +22863,7 @@ msgstr ""
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -22955,10 +22960,10 @@ msgstr ""
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -23094,7 +23099,7 @@ msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -24938,7 +24943,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25713,7 +25718,7 @@ msgstr ""
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26834,14 +26839,14 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 msgid "using a dangling pointer to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -26886,7 +26891,7 @@ msgstr ""
 msgid "call to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr ""
@@ -27955,7 +27960,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
@@ -28918,7 +28923,7 @@ msgstr "Το βήμα αρχικοποίησης απέτυχε"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -28958,12 +28963,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -29120,7 +29125,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "Το ai_family δεν υποστηρίζεται"
@@ -29160,185 +29165,185 @@ msgstr ""
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr ""
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr ""
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr ""
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr ""
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr ""
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr ""
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr ""
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
 # src/request.c:806 src/request.c:912
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
 # src/request.c:806 src/request.c:912
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
 # src/request.c:806 src/request.c:912
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "μη αναγνωρίσημη επιλογή `-%c'"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr ""
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -30013,187 +30018,187 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr ""
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -31856,27 +31861,27 @@ msgstr "μη έγκυρη διαδικασία διαφυγής στο τέλο
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -32692,7 +32697,7 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -34780,7 +34785,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36462,7 +36467,7 @@ msgstr "υπερβολικά πολλά αρχεία εισόδου"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
@@ -36493,15 +36498,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -36588,48 +36593,48 @@ msgstr ""
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -37117,13 +37122,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -37361,7 +37366,7 @@ msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς με
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "διπλός ορισμός συνόλου"
@@ -37402,7 +37407,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -37489,325 +37494,325 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, fuzzy, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
 # src/dfa.c:569 src/dfa.c:583 src/dfa.c:587
 # src/dfa.c:577 src/dfa.c:591 src/dfa.c:595
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "κακοσχηματισμένος μετρητής επανάληψης"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "%s: αριθμός γραμμής έξω από τα όρια"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -37994,13 +37999,13 @@ msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένα
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -38141,17 +38146,17 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "%qE attribute only applies to variables"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
@@ -38358,7 +38363,7 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr ""
@@ -38413,7 +38418,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -38521,7 +38526,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -38571,32 +38576,32 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -38604,22 +38609,22 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -38695,17 +38700,17 @@ msgstr "το -pipe δεν υποστηρίζεται"
 msgid "%<-fPIE%> is not supported"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "οι επιλογές --string και --check είναι αμοιβαίως αποκλειόμενες"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
@@ -39023,7 +39028,7 @@ msgstr "πάρα πολλά ορίσματα"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -39618,749 +39623,749 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%s: η υποστήριξη εκσφαλμάτωσης δεν έχει συμπεριληφθεί στη μεταγλώττιση.\n"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "Άγνωστη επιλογή: %s %s %s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr ""
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr ""
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, fuzzy, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -40708,7 +40713,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -41831,52 +41836,52 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "αδυναμία ανάγνωσης καταλόγου locale `%s'"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "αδυναμία ανάγνωσης καταλόγου locale `%s'"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -41896,66 +41901,71 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, gcc-internal-format
@@ -42426,97 +42436,97 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -43920,7 +43930,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -44106,7 +44116,7 @@ msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεω
 msgid "storage class specified for unnamed parameter"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -44275,7 +44285,7 @@ msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 msgid "function definition has qualified void return type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -44402,7 +44412,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
@@ -44602,7 +44612,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr ""
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -44653,7 +44663,7 @@ msgstr "επώνυμα μέλη"
 msgid "struct has no members"
 msgstr "%s σε %s"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -44699,7 +44709,7 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -44744,7 +44754,7 @@ msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr ""
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -44774,7 +44784,7 @@ msgstr "διατήρηση ωρών στο %s"
 msgid "%qD was used with no prototype before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -44889,12 +44899,12 @@ msgstr "λάθος αριθμός ορισμάτων"
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -46907,7 +46917,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
@@ -47037,12 +47047,12 @@ msgstr ""
 msgid "variant %qD is not a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47303,7 +47313,7 @@ msgstr "Μη έγκυρη κανονική έκφραση"
 msgid "invalid use of flexible array member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr ""
@@ -48263,12 +48273,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -48309,7 +48319,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
@@ -48324,8 +48334,8 @@ msgstr "ακολουθούν σκουπίδια στο τέλος της γρα
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -48415,7 +48425,7 @@ msgstr ""
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -49772,7 +49782,7 @@ msgstr ""
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -49782,7 +49792,7 @@ msgstr "Δεν υπάρχει προηγούμενη κανονική έκφρα
 msgid "%q#D is protected within this context"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -49797,7 +49807,7 @@ msgstr "το `%s' είναι μη-προσπελάσιμο"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
@@ -50135,7 +50145,7 @@ msgstr "δεν ταιριάζει συνάρτηση για την κλήση σ
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -50711,7 +50721,7 @@ msgstr "μη έγκυρη ώρα της μέρας"
 msgid "next member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
@@ -50832,7 +50842,7 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -50901,7 +50911,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -50949,7 +50959,7 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -51074,7 +51084,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -51173,7 +51183,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -51249,7 +51259,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -51315,189 +51325,189 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
@@ -52072,7 +52082,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -52166,7 +52176,7 @@ msgstr "Λείπει παράμετρος για `%s'"
 msgid "no suspend point info for %qD"
 msgstr "Ο αντιτοποθετητής επιφάνειας έχει τεθεί περισσότερο από μια φορά για το `%s'"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -52186,23 +52196,23 @@ msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -52690,7 +52700,7 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -53093,2279 +53103,2279 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 msgid "%q#T is not a class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> πρέπει να επιστρέψει %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, fuzzy, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "Δεν υπάρχουν αρχεία εισόδου"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "μη ορισμένο"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "μη ορισμένο"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "μη ορισμένο"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
 # src/shred.c:1134
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -55377,112 +55387,112 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -55491,82 +55501,82 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "σφάλμα ανάγνωσης %s"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -56421,7 +56431,7 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 msgid "type %qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -57477,7 +57487,7 @@ msgstr ""
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -58223,7 +58233,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -58932,12 +58942,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -59537,7 +59547,7 @@ msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 msgid "%qT not permitted in template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -60399,7 +60409,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
@@ -61407,7 +61417,7 @@ msgstr ""
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -61500,278 +61510,278 @@ msgstr ""
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
 # src/request.c:37
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -61783,165 +61793,165 @@ msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr ""
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -62253,7 +62263,7 @@ msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -62663,27 +62673,27 @@ msgstr ""
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -62691,22 +62701,22 @@ msgstr "Λείπει παράμετρος για `%s'"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -63945,222 +63955,222 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "declaration of %q#T"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr ""
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
@@ -65101,7 +65111,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -66194,12 +66204,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -66381,7 +66391,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -68402,7 +68412,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -68673,7 +68683,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -68791,7 +68801,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
@@ -68801,7 +68811,7 @@ msgstr ""
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
@@ -68932,7 +68942,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -69148,12 +69158,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -69263,562 +69273,562 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "πολύ λίγα ορίσματα"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, fuzzy, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to procedure `%s'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -70005,7 +70015,7 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
@@ -70556,7 +70566,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -71125,7 +71135,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -72978,8 +72988,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -74945,712 +74955,722 @@ msgstr ""
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr ""
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "Μεταγλωττισμός προδιαγραφών τοπικών ρυθμίσεων"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr ""
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr ""
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr ""
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75659,12 +75679,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75673,294 +75693,294 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -75969,284 +75989,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -76254,207 +76274,207 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -76462,986 +76482,986 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
 # src/request.c:37
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr ""
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -78335,7 +78355,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -78347,12 +78367,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -78444,83 +78464,88 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "μη πλήρης εγγραφή"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -78535,28 +78560,28 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
 # src/grep.c:1133
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
diff --git a/gcc/po/es.po b/gcc/po/es.po
index a91ed39fe73..399cb5ef3cd 100644
--- a/gcc/po/es.po
+++ b/gcc/po/es.po
@@ -42,7 +42,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1-b20200209\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2020-03-22 16:48+0100\n"
 "Last-Translator: Antonio Ceballos Roa <aceballos@gmail.com>\n"
 "Language-Team: Spanish <es@tp.org.es>\n"
@@ -4123,7 +4123,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7888,6 +7888,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support XOP built-in functions and code generation."
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Admite funciones internas XOP y generación de código."
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17640,12 +17646,12 @@ msgstr "el operando '%%l' no es una etiqueta"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "constante de coma flotante mal usada"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18729,68 +18735,68 @@ msgstr "Esta opción carece de documentación."
 msgid "Uses of this option are diagnosed."
 msgstr "Los usos de esta opción están diagnosticados."
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s%s."
 msgstr "%s  Igual que %s."
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s."
 msgstr "%s  Igual que %s."
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  Igual que %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 #, fuzzy
 #| msgid "variable"
 msgid "[available in "
 msgstr "variable"
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[por defecto]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, fuzzy, c-format
 #| msgid " bytes"
 msgid "%llu bytes"
 msgstr " bytes"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[activado]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[desactivado]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " No se encontraron opciones con las características deseadas\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " No se encontró ninguna.  Use --help=%s para mostrar *todas* las opciones admitidas por el frente %s.\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr "Ya se mostraron todas las opciones con las características deseadas\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -18799,49 +18805,49 @@ msgstr ""
 "  Argumentos válidos conocidos para la opción %s:\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Las siguientes opciones son específicas del objetivo"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Las siguientes opciones controlan los mensajes de aviso del compilador"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Las siguientes opciones controlan las optimizaciones"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Las siguientes opciones son independientes del lenguaje"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options control optimizations"
 msgid "The following options control parameters"
 msgstr "Las siguientes opciones controlan las optimizaciones"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Las siguientes opciones son específicas sólo para el lenguaje "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Las siguientes opciones se admiten en el lenguaje "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Las siguientes opciones no están documentadas"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Las siguientes opciones toman argumentos separados"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Las siguientes opciones toman argumentos conjuntos"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Las siguientes opciones son relacionadas al lenguaje"
 
@@ -19227,75 +19233,75 @@ msgstr "modificador de longitud en formato strfmon"
 msgid "<command-line>"
 msgstr "<línea-de-órdenes>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "no se admite el operando para el código '%c'"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "operando no válido para '%%%c'"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante de vector no válida"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "falta un operando"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "constante no válida"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "operando no válido"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "prefijo de operando no válido '%%%c'"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "modo de direccionamiento no válido"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operandos no válidos en la operación binaria"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "se usó '%%&' sin ninguna referencia TLS dinámica local"
@@ -19312,18 +19318,18 @@ msgid "invalid %%r value"
 msgstr "valor %%r no válido"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "valor %%R no válido"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N no válido"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P no válido"
@@ -19353,7 +19359,7 @@ msgstr "valor %%M no válido"
 msgid "invalid %%U value"
 msgstr "valor %%U no válido"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s no válido"
@@ -19363,7 +19369,7 @@ msgstr "valor %%s no válido"
 msgid "invalid %%C value"
 msgstr "valor %%C no válido"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E no válido"
@@ -19376,7 +19382,7 @@ msgstr "reubicación unspec desconocida"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "código %%xn no válido"
@@ -19459,35 +19465,35 @@ msgstr "UNSPEC no válido como operando: %d"
 msgid "unrecognized supposed constant"
 msgstr "no se reconoce la constante supuesta"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "operando de desplazamiento no válido"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instrucción de predicado Thumb"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instrucción de predicado en una secuencia condicional"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "No se admite el operando para el código '%c'"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19496,26 +19502,26 @@ msgstr "No se admite el operando para el código '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operando no válido para el código '%c'"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "la instrucción nunca se ejecuta"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "código de formato Maverick obsoleto '%c'"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operación no permitida con el tipo %<bfloat16_t%>"
 
@@ -19886,98 +19892,100 @@ msgstr "constante fp no válida"
 msgid "Expected register or constant integer."
 msgstr "se esperaba interfaz o puntero a interfaz"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC no válido como operando"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "uso no válido del registro '%s'"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "tipo no válido de la salida del indicador asm"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "tamaño de operando no válido para el código de operando 'O'"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "tamaño de operando no válido para el código de operando 'z'"
 
-#: config/i386/i386.cc:13283
-#, c-format
-msgid "invalid operand type used with operand code 'Z'"
+#: config/i386/i386.cc:13290
+#, fuzzy, c-format
+#| msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "se usó un tipo de operando no válido con el código de operando 'Z'"
 
-#: config/i386/i386.cc:13288
-#, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "tamaño de operando no válido para el código de operando 'Z'"
+#: config/i386/i386.cc:13295
+#, fuzzy, c-format
+#| msgid "invalid operand size for operand code 'O'"
+msgid "invalid operand size for operand code '%c'"
+msgstr "tamaño de operando no válido para el código de operando 'O'"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "el operando no es un código de condición, código de operando 'Y' no válido"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "el operando no es un código de condición, código de operando 'D' no válido"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "el operando no es un código de condición, código de operando '%c' no válido"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "el operando no es una referencia de memoria desplazable, código de operando 'H' no válido"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "el operando no es un entero, código de operando 'K' no válido"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "el operando no es un entero concreto, código de operando 'r' no válido"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "el operando no es un entero, código de operando 'R' no válido"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "el operando no es un entero concreto, código de operando 'R' no válido"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "código de operando '%c' no válido"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "restricciones no válidas para el operando"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 #| msgid "invalid vector constant"
 msgid "invalid vector immediate"
 msgstr "constante de vector no válida"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "modo insn desconocido"
 
@@ -20008,7 +20016,7 @@ msgstr "operación no válida en %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "operando %%P no válido"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p no válido"
@@ -20053,8 +20061,8 @@ msgstr "'%%%c' no es un prefijo de operando válido"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "uso no válido de '%%%c'"
@@ -20086,7 +20094,7 @@ msgid "post-increment address is not a register"
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -20252,7 +20260,7 @@ msgstr "no se admite la combinación: %s"
 msgid "unsupported memory expression:"
 msgstr "conversión de coma fija no admitida"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -20305,152 +20313,152 @@ msgstr "%<-mquad-memory%> no está disponible en modo little endian"
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "Movimiento de 128 bits erróneo"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "valor %%J no válido"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "valor %%D no válido"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "valor %%e no válido"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f no válido"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F no válido"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G no válido"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j no válido"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J no válido"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k no válido"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K no válido"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O no válido"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q no válido"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "valor %%t no válido"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T no válido"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u no válido"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v no válido"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "valor %%V no válido"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x no válido"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "valor %%z no válido"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y no válido, pruebe usando la restricción 'Z'"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Activa el uso de instrucciones de coma flotante de 128 bits IEEE."
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr "No se ha podido generar valor addis para fusión"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr "No se puede generar desplazamiento de carga/almacenamiento para fusión"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "Fusión GPR errónea"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "conversión no válida de %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -20918,7 +20926,7 @@ msgstr "candidato 1:"
 msgid "  after user-defined conversion:"
 msgstr "Activa las instrucciones definidas por el usuario."
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
@@ -21410,7 +21418,7 @@ msgstr "Desajuste de frontera de matriz en la dimensión 2 de la matriz (%ld/%ld
 msgid "Driving:"
 msgstr "Conduciendo:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argumento actual de INTENT = OUT/INOUT"
 
@@ -21584,11 +21592,11 @@ msgstr "bloque IF"
 msgid "implied END DO"
 msgstr "END DO implícito"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "asignación"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "asignación de puntero"
 
@@ -21596,200 +21604,200 @@ msgstr "asignación de puntero"
 msgid "simple IF"
 msgstr "IF simple"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "procedimiento elemental"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr "argumento asignable"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr "argumento asíncrono"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "argumento opcional"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr "argumento puntero"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr "argumento destino"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr "argumento de valor"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr "argumento volátil"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr "se asume argumento de aspecto"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr "se asume argumento de rango"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr "argumento de coarray"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr "argumento de tipo derivado parametrizado"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr "argumento polimórfico"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr "atributo NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr "se asume argumento de tipo"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr "resultado array"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr "puntero o resultado asignable"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr "resultado con longitud de carácter no constante"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr "procedimiento bind(c)"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador numérico unitario %%<%s%%> en %%L es %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Entidades de tipos derivados no esperadas en el operador numérico intrínseco binario %%<%s%%> en %%L"
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador numérico binario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Los operandos del operador de concatenación de cadenas en %%L son %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador lógico %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "El operando del operador .not. en %%L es %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Las cantidades COMPLEX no se pueden comparar en %L"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Los lógicos en %%L se deben comparar con %s en lugar de %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de comparación %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Operador %%<%s%%> desconocido en %%L; ¿quiso decir '%s'?"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operador %%<%s%%> desconocido en %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador de usuario %%<%s%%>  en %%L es %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de usuario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangos inconsistentes para el operador en %%L y %%L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "Variable de ciclo"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr "variable de iterador"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr "Expresión de inicio en el bucle DO"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr "Expresión de fin en el bucle DO"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr "Expresión de paso en el bucle DO"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr "objeto DEALLOCATE"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr "objeto ALLOCATE"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr "elemento en READ"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -21802,27 +21810,27 @@ msgstr "Longitudes de CHARACTER diferentes (%ld/%ld) en el constructor de matriz
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Desborde entero al calcular la cantidad de memoria a reservar"
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "El valor del parámetro PDT LEN '%s' no concuerda con el de la declaración «dummy»"
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual no coincide con la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual es más corta que la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "El objetivo del remapeo de rango es demasiado pequeño (%ld < %ld)"
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr "Asignación de escalar a un array sin espacio asignado"
 
@@ -22715,7 +22723,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax sólo se admite pare el PIC de RTP"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Error sintáctico en la declaración %s en %C"
@@ -23110,7 +23118,7 @@ msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atribut
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -23209,10 +23217,10 @@ msgstr "se descartan los atributos de tipo después de que el tipo ya se defini
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -23350,7 +23358,7 @@ msgstr "no se puede leer el perfil de función de %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "el desplazamiento %qwi fuera de los límites de la constante de cadena"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -25277,7 +25285,7 @@ msgstr "se truncó la constante de coma fija grande implícitamente al tipo de c
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparación siempre es %d debido a la anchura del campo de bit"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar la prueba de rango"
@@ -26101,7 +26109,7 @@ msgstr "la función devuelve la dirección de una variable local"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -27394,14 +27402,14 @@ msgstr "asumiendo el puntero a miembro %qD"
 msgid "using a dangling pointer to %qD"
 msgstr "modo de puntero %qs no válido"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
@@ -27451,7 +27459,7 @@ msgstr "en una llamada a la función de reserva interna %qD"
 msgid "call to %qD"
 msgstr "  en la llamada a %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -28611,7 +28619,7 @@ msgstr "falta el resumen de inclusión en línea ipa en el fichero de entrada"
 msgid "IPA modref summary is missing in input file"
 msgstr "falta el resumen de inclusión en línea ipa en el fichero de entrada"
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid jump function in LTO stream"
@@ -29637,7 +29645,7 @@ msgstr "Realiza optimizaciones de saltos cruzados."
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "la opción de línea de órdenes %qs no se admite en esta configuración"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "faltan argumentos para %qs"
@@ -29680,12 +29688,12 @@ msgstr "las opciones de FPX fast y compact no pueden especificarse juntas"
 msgid "unrecognized argument in option %qs"
 msgstr "no se reconoce el argumento en la opción %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para %qs son: %s; ¿quiso decir %qs?"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "los argumentos válidos para %qs son: %s"
@@ -29852,7 +29860,7 @@ msgstr "%<-fsanitize=pointer-subtract%> debe combinarse con %<-fsanitize=address
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "no se admite %<-fsanitize-recover=%s%>"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsanitize-recover=%s%> is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -29895,200 +29903,200 @@ msgstr "se solicitó seguimiento de variables, pero es inútil a menos que se pr
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "se solicitó seguimiento de variables, pero no se admite este formato de depuración"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "las asignaciones-de-rastreo-de-variable cambian el planificador selectivo"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> no funciona con excepciones en esta arquitectura"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> no admite información de desenredo en esta arquitectura"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> no funciona en esta arquitectura"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "no se reconocen las include_flags 0x%x pasadas a print_specific_help"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr "la opción %<-fsanitize=all%> no es válida"
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "no se reconoce el argumento para la opción -f%ssanitize%s=: %q.*s; ¿quiso decir %qs?"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "no se reconoce el argumento para la opción -f%ssanitize%s=: %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute directive ignored"
 msgid "%qs attribute directive ignored"
 msgstr "se descarta la directiva de atributo %qE"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument of -mcpu: %s"
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "no se reconoce el argumento de -mcpu=: %s"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument %qs to %qs"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "argumento %qs no válido para %qs"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect number of arguments to function %qE"
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "número incorrecto de argumentos para la función %qE"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-falign-loops=%d no está entre 0 y %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "argumento no válido para %<-fpatchable_function_entry%>"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, fuzzy, gcc-internal-format
 #| msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "el argumento %q.*s de --help es ambiguo, por favor sea más específico"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "no se reconoce el argumento para la opción --help=: %q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr "la opción %<-foffload-abi%> solo puede especificarse para compilador de descarga"
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "la alineación de la estructura debe ser una potencia pequeña de dos, no %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "parámetro de revisión de pila desconocido %qs"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, fuzzy, gcc-internal-format
 #| msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr "%<-gdwarf%s%> es ambiguo; use %<-gdwarf-%s%> para la versión DWARF o %<-gdwarf -g%s%> para nivel de depuración"
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "dwarf version %d is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "no se admite dwarf versión %d"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "no se reconoce el argumento para la opción --help=: %q.*s"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "el sistema objetivo no admite salida de depuración"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "el formato de depuración %qs genera un conflicto con una selección previa"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "no se reconoce el nivel de salida de depuración %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "el nivel de salida de depuración %qs es demasiado elevado"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized debug output level %qs"
 msgid "unrecognized btf debug output level %qs"
 msgstr "no se reconoce el nivel de salida de depuración %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "obteniendo el límite del tamaño máximo del fichero core: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "estableciendo el límite del tamaño máximo del fichero core: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "no se reconoce la opción de depuración de gcc: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "no se reconoce la opción de línea de órdenes %<-%s%>; ¿quería decir %<-%s%>?"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: no existe la opción -%s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
@@ -30827,197 +30835,197 @@ msgstr "el código de thunk genérico falló para el método %qD que utiliza %<.
 msgid "%qD renamed after being referenced in assembly"
 msgstr "se renombró %qD después de ser referenciado en el ensamblado"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "el símbolo de función no es una función"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent file architecture detected"
 msgid "inconsistent %<ifunc%> attribute"
 msgstr "se detectó una arquitectura de fichero inconsistente"
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "el símbolo de variable no es una variable"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "el nodo tiene un tipo desconocido"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD has invalid argument list"
 msgid "node has invalid order %i"
 msgstr "%qD tien una lista de argumentos no válida"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nodo no encontrado node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "el nodo difiere de node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "lista hash de nombres del ensamblador corrupta"
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "no se encontró un nodo en cgraph_hash"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "lista doblemente enlazada de nombres del ensamblador corrrupta"
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "el nodo tiene body_removed y sin embargo es una definición"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "el nodo está analizado pero no es una definición"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "el nodo es un alias pero no un alias implícito"
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "el nodo es un alias pero no una definición"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "el nodo es una weakref pero no un transparent_alias"
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "el nodo es un transparent_alias pero no un alias"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not implicit alias"
 msgid "node is symver but not alias"
 msgstr "el nodo es un alias pero no un alias implícito"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "Set the default symbol visibility"
 msgid "symver is not exported with default visibility"
 msgstr "Establece la visibilidad de símbolos por defecto"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "el nodo está en la lista same_comdat_group no tiene comdat_group"
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "list same_comdat_group con grupos diferentes"
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "no se permite mezclar diferentes símbolos de tipos en los mismos grupos comdat"
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "el nodo está solo en un grupo comdat"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group no es una lista circular"
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "el símbolo comdat-local referenciado en %s fuera de su comdat"
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit_section flag is set but section isn't"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "el indicador implicit_section está puesto pero la sección on lo es"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Tanto la sección como el grupo comdat están puestos"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's section differs"
 msgid "Alias and target%'s section differs"
 msgstr "Alias y sección del objetivo difieren"
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's comdat groups differs"
 msgid "Alias and target%'s comdat groups differs"
 msgstr "El alias y los grupos comdat del objetivo difieren"
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, fuzzy, gcc-internal-format
 #| msgid "Transparent alias and target's assembler names differs"
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "El alias transparente y los nombres de ensamblador del objetivo difieren"
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Alias transparentes encadenados"
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::falló verify"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "modo de puntero %qs no válido"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Hay dos símbolos con el mismo comdat_group que no están vinculados a la lista same_comdat_group."
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "la función %q+D es parte de un ciclo de alias"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "la variable %q+D es parte de un ciclo de alias"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "la sección del alias %q+D debe cuadrar con la sección de su objetivo"
@@ -32826,27 +32834,27 @@ msgstr "código interno independiente de máquina fuera de rango"
 msgid "target specific builtin not available"
 msgstr "no está disponible la orden interna específica del objetivo"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "la operación vectorial se expandirá por piezas"
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "la operación vectorial se expandirá en paralelo"
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "la operación vectorial se expandirá con una sola operación escalar"
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "la condición vectorial se expandirá por piezas"
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "la operación de ordenamiento vectorial se expandirá por piezas"
@@ -33754,7 +33762,7 @@ msgstr "se descarta el atributo %qE porque %qT ya está definido"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "se descarta el atributo %qE porque %qT ya está definido"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "el atributo %qE sólo tiene efecto en objetos públicos"
@@ -36005,7 +36013,7 @@ msgstr "no se admite la concatenación no estándar de literales de cadena"
 msgid "traditional C rejects string constant concatenation"
 msgstr "C tradicional rechaza la concatenación de constantes de cadenas"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37765,7 +37773,7 @@ msgstr "demasiados ficheros de entrada"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%qE es un puntero; ¿pretendía utilizar %<->%>?"
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -37801,15 +37809,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "se pasa opción no reconocida a %%:target_mode_check"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "los argumentos válidos son: %s; ¿quiso decir %qs?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "los argumentos válidos son: %s"
@@ -37901,55 +37909,55 @@ msgstr "-mcpu=%s no es válido"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "-mcpu=%s tiene una versión de silicio no válida"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops is obsolete, use -falign-loops"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops es obsoleto, use -falign-loops"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malign-jumps es obsoleto, use -falign-jumps"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps=%d is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-jumps=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions is obsolete, use -falign-functions"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions es obsoleto, use -falign-functions"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-functions=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d no está entre 0 y 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "sólo se admite %<-fsplit-stack%> en GNU/Linux"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> requiere soporte del ensamblador para las directivas CFI"
@@ -38489,14 +38497,14 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "%qs es incompatible con %s %s"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a pointer to a constant size type"
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "el argumento %d de %qE debe ser un puntero a un tipo de tamaño constante"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
@@ -38769,7 +38777,7 @@ msgstr "el paso del argumento %d de %qE crea un entero desde un puntero sin una
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate definition of '%s'"
 msgid "duplicate definition of %qs"
@@ -38817,7 +38825,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "el tipo %qT no tiene un tamaño conocido"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored because %qT is already defined"
 msgid "variables of type %qT cannot have thread-local storage duration"
@@ -38919,361 +38927,361 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, fuzzy, gcc-internal-format
 #| msgid "unknown flag passed in -moverride=%s (%s)"
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "indicador pasado en -moverride=%s (%s) desconocido"
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%s string ill-formed\n"
 msgid "%qs string ill-formed"
 msgstr "cadena %s mal formada\n"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for %<sve_width%>"
 msgstr "formato no válido de %s"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %h value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "valor %h no válido"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "falta la cadena de ajuste en la opción (%s)"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "opción de cadena de ajuste desconocida (%s)"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length"
 msgstr "Especifica el orden de asignación de registros"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs no es un desplazamiento válido en %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "falta el nombre de la cpu en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "modificador de característica no válido en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument %qs to %qs"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "argumento %qs no válido para %qs"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "argumento no válido para %<-fpatchable_function_entry%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "falta el nombre de la arquitectura en %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "valor %qs desconocido para -march"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in %<-mcpu=%s%>"
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "falta el nombre de la cpu en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "modificador de característica no válido en %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "falta el nombre de la cpu en %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "valor %qs desconocido para -mtune"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "la opción -mcpu=%s genera un conflicto con la opción -march=%s"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "el ensamblador no tiene soporte para -mabi=ilp32"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "modelo de código %qs con -f%s"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "falta el nombre en atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "valor no válido (\"%s\") en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "falta el nombre en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "valor no válido (\"%s\") en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, fuzzy, gcc-internal-format
 #| msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "falta el nombre en atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, fuzzy, gcc-internal-format
 #| msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, fuzzy, gcc-internal-format
 #| msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "falta el valor en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "pragma o atributo %<target()%> mal formado"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta un argumento"
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta forma negada"
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s=%s\")%> no es válido"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "el argumento del atributo %<target%> no es una cadena"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s\")%> no es válido"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "pragma o atributo %<target(\"%s\")%> mal formado"
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "vía %wd fuera de rango %wd - %wd"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
 msgstr "simdlen %d no admitido"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported return type %qT for simd"
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported return type %qT for simd"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type %qT for simd"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de argumento %qT para simd"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -39476,13 +39484,13 @@ msgstr "el argumento del atributo %qE no es \"ilink\" o \"firq\""
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -39628,19 +39636,19 @@ msgstr "falta el argumento del atributo %qE"
 msgid "%qE attribute only applies to variables"
 msgstr "el atributo %qE solamente se aplica a variables"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, fuzzy, gcc-internal-format
 #| msgid "alternatives not allowed in asm flag output"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "no se permiten alternativas en la salida del indicador asm"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 #| msgid "unknown asm flag output %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "salida del indicador asm %qs desconocida"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for asm flag output"
 msgid "invalid type for %<asm%> flag output"
@@ -39866,7 +39874,7 @@ msgstr "el CPU objetivo no admite las instrucciones THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "el CPU objetivo no admite accesos sin alinear"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -39928,7 +39936,7 @@ msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8 o
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "El PIC de RTP es incompatible con -msingle-pic-base"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -40045,7 +40053,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
@@ -40096,35 +40104,35 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "no se puede calcular la ubicación real del parámetro apilado"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Fin de módulo inesperado"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "no hay registros inferiores disponibles para extraer registros superiores"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "no se pueden codificar las Rutinas de Servicios de Interrupción en el modo Thumb"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific para Thumb-1"
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
@@ -40132,22 +40140,22 @@ msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "selección automática de fpu actualmente no permitida aquí"
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "arquitectura no válida para el atributo o pragma objetivo %qs"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "atributo o pragma objetivo %qs desconocido"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -40226,17 +40234,17 @@ msgstr "no se admite -fpie"
 msgid "%<-fPIE%> is not supported"
 msgstr "no se admite -fPIE"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "los atributos de función %qs y %qs son mutuamente excluyentes"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la función %qs no puede tener argumentos"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la función %qs no puede devolver un valor"
@@ -40577,7 +40585,7 @@ msgstr "argumento no válido para la función interna"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "argumento no válido para la función interna"
@@ -41230,729 +41238,729 @@ msgstr "Las versiones de funciones no pueden marcarse como gnu_inline; hay que g
 msgid "virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 #| msgid "multiversioning needs ifunc which is not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "el modelo de código %s no admite el modo PIC"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "el argumento del atributo %qE no es una cadena"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "El atributo SEQUENCE en %C ya se especificó en la declaración TYPE"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "El atributo %s de '%s' genera un conflicto con el atributo %s en %L"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argumento %qs incorrecto para la opción %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "los rangos de tamaño de la opción %qs deberían ser crecientes"
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "se especificó un nombre de estrategia %qs incorrecto para la opción %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "no se admite el nombre de estrategia %qs especificado para la opción %qs para código de 32 bits"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "se especificó una alineación %qs desconocida para la opción %qs"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "el valor máximo para el último rango de tamaños debería ser -1 para la opción %qs"
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "se especificaron demasiados rangos de tamaños en la opción %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, fuzzy, gcc-internal-format
 #| msgid "unknown parameter to option -mtune-ctrl: %s"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "parámetro desconocido para la opción -mtune-ctrl: %s"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "no se admite Intel MCU psABI en el modo %s"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> es obsoleto; use en su lugar %<-mtune=k8%> o %<-mtune=generic%> como sea adecuado"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> es obsoleto; use %<target(\"tune=k8\")%> o %<target(\"tune=generic\")%> en su lugar como convenga"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mcmodel= no se admite en sistemas de 32 bits"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "el modelo de direcciones %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 #| msgid "-mabi=ms not supported with X32 ABI"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "no se admite -mabi=ms con X32 ABI"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "la memoria transaccional no se admite con %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "la memoria transaccional no se admite con %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsanitize=leak%> is incompatible with %<-fsanitize=thread%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-fsanitize=leak%> es incompatible con %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "el modelo de código %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "no se admite -masm=intel en esta configuración"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "no está compilado el modo bit-%i"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<generic%> solo se puede usar para el ajuste %<-tune=%>"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<generic%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<intal%> solo se puede usar para el ajuste %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<intel%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "el CPU que seleccionó no admite el conjunto de instrucciones x86-64"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-march=%>"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s; ¿qiuso decir %qs?"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-mtune=%> switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "se descarta -mregparm en modo de 64-bit"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "se descarta -mregparm para Intel MCU psABI"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d no está entre 0 y %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "se descarta %<-mrtd%> en el modo de 64bit"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "se descarta %<target(\"rtd\")%> en el modo de 64bit"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "no se admite -mpreferred-stack-boundary en este objetivo"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d no está entre %d y %d"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d no está entre %d y 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount no está implementada para -fPIC"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "se usó %<-msseregparm%> sin SSE activado"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "se usó %<target(\"ssseregparm\")%> sin SSE activado"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "el conjunto de instrucciones SSE está desactivado, usando la aritmética 387"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "el conjunto de instrucciones 387 está desactivado, usando la aritmética SSE"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "la prueba de pila requiere %<-maccumulate-outgoing-args%> para ser correcta"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "la prueba de pila requiere %<target(\"accumulate-outgoing-args\"%> para ser correcta"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "el registro ebp fijo requiere %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "el registro ebp fijo requiere %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry no se admite para 32-bit en combinación con -fpic"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues no es compatible con %s"
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "opción desconocida para -mrecip=%s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs no es un número válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs no es un desplazamiento válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs no es un registro base válido en -mstack-protector-guard-reg="
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "interrupción y atributos desnudos no es compatible"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, fuzzy, gcc-internal-format
 #| msgid "Only DWARF debug format is supported for interrupt service routine."
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Solo se admite el formato de depuración DWARF para la rutina de servicio de interrupciones."
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Las instrucciones %s no están permitidas en funciones con el atributo no_caller_saved_registers"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para método no de clase"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "el atributo %qE requiere una constante entera como argumento"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la rutina de servicio de interrupciones debería tener un puntero como primer argumento"
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la rutina de atención de interrupciones debería tener como segundo argumento un unsigned %sint"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la rutina de servicio de interrupciones solo puede tener un argumento puntero y un argumento entero opcional"
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
 msgstr "ls rutina de servicio de interrupción no puede tener valor de retorno que no sea void"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qT con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "X32 does not support ms_abi attribute"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "X32 no admite el atributo ms_abi"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ms_hook_prologue no es compatible con la función anidada"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "el argumento de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "el retorno de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "el retorno de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "el argumento de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "la devolución de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "el argumento de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "la devolución de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "la ABI para pasar un struct con un miembro de matriz flexible cambió en GCC 4.4"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "la ABI para pasar un union con long double cambió en GCC 4.4"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 #, fuzzy
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "se devuelve el registro SSE con SSE desactivado"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumento de registro SSE con SSE desactivado"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "se devuelve el registro x87 con x87 desactivado"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el convenio de llamadas SSE sin activar SSE/SSE2"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "esto es un error de GCC que se puede sortear añadiendo el atributo usado a la función llamada"
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues no es compatible con %s"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "el atributo ms_hook_prologue no es compatible con -mfentry para 32-bit"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "No se admite Puntero de Argumento de Realineamiento Dinámico (DRAP) en la rutina de servicio de interrupciones.  Esto puede sortearse evitando funciones con retorno agregado."
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "el atributo %qE no se admite en esta plataforma"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "no se admiten funciones anidadas en este objetivo"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support fastcall with nested function"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "-fsplit-stack no admite fastcall con funciones anidadas"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
@@ -41960,85 +41968,85 @@ msgstr "-fsplit-stack no admite 2 parámetros de registro para una función anid
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 3 register parameters"
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "-fsplit-stack no admite 3 parámetros de registro"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, fuzzy, gcc-internal-format
 #| msgid "'V' modifier on non-integer register"
 msgid "%<V%> modifier on non-integer register"
 msgstr "modificador 'V' en registro no entero"
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "no se admite el tamaño para registro de enteros"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "los registros extendidos no tiene mitades superiores"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "no se admite el tamaño de operando para el registro extendido"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 #| msgid "non-integer operand used with operand code 'z'"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "se usó un operando que no es entero con el código de operando 'z'"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 #, fuzzy
 #| msgid "the mangling of %<va_list%> has changed in GCC 4.4"
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "la decodificación de %<va_list%> cambió en GCC 4.4"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "-mcmodel= no se admite en sistemas de 32 bits"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modelo de memoria específico de la arquitectura desconocido"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "HLE_ACQUIRE no se usa con ACQUIRE o modelos de memoria más fuertes"
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "HLE_RELEASE no se usa con RELEASE o modelos de memoria más fuertes"
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "no se admite el tipo de argumento %qT para simd"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 #| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -42420,7 +42428,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE se redeclaró con los atributos %qs en conflicto"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "el atributo %qE requiere una cadena como argumento"
@@ -43649,60 +43657,60 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "basura al final de #pragma GCC coprocessor %E"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "el tipo %qT no tiene un tamaño conocido"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "el tipo %qT no tiene un tamaño conocido"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "aritmética en puntero a un tipo de dato incompleto"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "fields cannot have RVV type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 #| msgid "function parameters cannot have __fp16 type"
 msgid "array elements cannot have RVV type %qT"
 msgstr "los parámetros de la función no pueden tener el tipo __fp16"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "no se puede asignar un objeto de tipo abstracto %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "no se puede asignar un objeto de tipo abstracto %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "no se puede asignar un objeto de tipo abstracto %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete type %q#T"
 msgid "capture by copy of RVV type %qT"
@@ -43725,73 +43733,78 @@ msgstr "No usa las extensiones de ABI SPE."
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv requiere -march para subsumir la extensión %<M%>"
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "la ABI solicitada requiere -march para subsumir la extensión %qc"
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI requiere -march=rv%d"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d debe estar entre %d y %d"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs no es un registro base válido en %qs"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs no es un número válido en %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "la función %qs no puede tener argumentos"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -44301,99 +44314,99 @@ msgstr "%qs está obsoleto y no está recomendada bajo ninguna circunstancia"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "no se puede tomar la dirección de una función anindada si se usa la opción %qs"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "el uso de %<long%> en tipos AltiVec no es válido para código de 64 bits sin %qs"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<long long%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<double%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "cpu %qs no válida para %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s no es válido"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno=%s%> anula %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -45903,7 +45916,7 @@ msgstr "no se puede poner un objeto con un campo volatile en register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "const %qD sin inicializar es no válida en C++"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D en directiva de objetivo de declaración no tiene tipo asociable"
@@ -46094,7 +46107,7 @@ msgstr "se especificó una clase de almacenamiento para el parámetro %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "se especificó una clase de almacenamiento para un parámetro sin nombre"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "se especificó una clase de almacenamiento para el nombre de tipo"
@@ -46263,7 +46276,7 @@ msgstr "el nombre de tipo que se declaró como función devuelve una matriz"
 msgid "function definition has qualified void return type"
 msgstr "la definición de la función tiene un tipo de devolución void calificado"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
@@ -46390,7 +46403,7 @@ msgstr "ISO C prohíbe los tipos de función const o volatile"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un miembro de una estructura o union no puede tener un tipo modificado variablemente"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "se declaró la variable o campo %qE como void"
@@ -46594,7 +46607,7 @@ msgstr "la definición de tipo en %qs es no válida en C++"
 msgid "%qT defined in underspecified object initializer"
 msgstr "se especificó el campo desconocido %qE en el inicializador"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la declaración no declara nada"
@@ -46644,7 +46657,7 @@ msgstr "struct no tiene miembros nombrados"
 msgid "struct has no members"
 msgstr "struct no tiene miembros"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "miembro de matriz flexible en union"
@@ -46690,7 +46703,7 @@ msgstr "redeclaración de %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -46740,7 +46753,7 @@ msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C restringe los valores de enumeración al rango de %<int%>"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -46772,7 +46785,7 @@ msgstr "no hay un prototipo previo para %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "se usó %qD sin prototipo antes de su definición"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "no hay declaración previa para %qD"
@@ -46888,12 +46901,12 @@ msgstr "el argumento %qD no coincide con el prototipo interno"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "el argumento %qD no coincide con el prototipo"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "se definió el parámetro %qD pero no se usa"
@@ -49018,7 +49031,7 @@ msgstr "no hay suficientes bucles perfectamente anidados"
 msgid "collapsed loops not perfectly nested"
 msgstr "los bucles colapsados no están perfectamente anidados"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
@@ -49166,13 +49179,13 @@ msgstr "se esperaba %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "'%s' en %L no es una función"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%qs y %qs son incompatibles"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -49453,7 +49466,7 @@ msgstr "uso no válido de la expresión void"
 msgid "invalid use of flexible array member"
 msgstr "uso no válido de un miembro de matriz flexible"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "uso no válido de matrices con límites sin especificar"
@@ -50440,12 +50453,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of %qT from incompatible pointer type %qT"
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
@@ -50487,7 +50500,7 @@ msgstr "el elemento inicializador no es calculable al momento de la carga"
 msgid "invalid initializer"
 msgstr "inicializador no válido"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "no se pueden inicializar los tipos de vector opacos"
@@ -50502,8 +50515,8 @@ msgstr "grupo extra de llaves al final del inicializador"
 msgid "braces around scalar initializer"
 msgstr "llaves alrededor del inicializador escalar"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inicialización de un miembro de matriz flexible en un contexto anidado"
@@ -50594,7 +50607,7 @@ msgstr "exceso de elementos en el inicializador de struct"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "inicialización posicional de un campo de %<struct%> declarado con el atributo %<designated_init%>"
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inicialización no estática de un miembro de matriz flexible"
@@ -52052,7 +52065,7 @@ msgstr "no hay un %<operator %s%> adecuado para %qT"
 msgid "%q#D is private within this context"
 msgstr "desde este contexto"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
@@ -52064,7 +52077,7 @@ msgstr "se declara aquí"
 msgid "%q#D is protected within this context"
 msgstr "desde este contexto"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
@@ -52081,7 +52094,7 @@ msgstr "%q+#D es inaccesible"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "se pasó NULL al argumento %P de %qD que no es puntero"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
@@ -52457,7 +52470,7 @@ msgstr "no se encontró una función coincidente para la llamada a %<%T::%s(%A)%
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
@@ -53096,7 +53109,7 @@ msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
@@ -53222,7 +53235,7 @@ msgstr "tipo no válido del parámetro %d en la función %<constexpr%> %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -53300,7 +53313,7 @@ msgstr "autocomparación siempre falsa"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
@@ -53353,7 +53366,7 @@ msgstr "  %qT es una clase base ambigua de %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-constexpr function %qD"
@@ -53497,7 +53510,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "deferenciando el puntero %<void *%>"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -53611,7 +53624,7 @@ msgstr "falta el inicializador para el miembro %qD"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -53694,7 +53707,7 @@ msgstr "Cambio de valor en la conversión de %s a %s en %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
@@ -53767,219 +53780,219 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "captura de la variable %qD con duración de almacenamiento que no es automática"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%s%qs%s is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "contract predicate is false in constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "la función interna %qE ha de ser llamada directamente"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "expresión %qE inesperada de género %s"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast no válido del tipo `%T' al tipo `%T'"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "la dirección de un objeto %qE con hilo local o almacenamiento automático no es una expresión constante"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "inicialización de una matriz que no es constante"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
@@ -54632,7 +54645,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%qD se declaró aquí"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "no member named %qE in %qT"
@@ -54739,7 +54752,7 @@ msgstr "el tercer argumento de %<__builtin_prefetch%> debe ser una constante"
 msgid "no suspend point info for %qD"
 msgstr "no hay un prototipo previo para %qD"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54762,23 +54775,23 @@ msgstr "no se permite usar punteros como valores case"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "el límite del array de longitud variable es desconocido"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -55293,7 +55306,7 @@ msgstr "de la declaración previa de %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %qD"
@@ -55747,650 +55760,650 @@ msgstr "%qD no es una plantilla de función"
 msgid "%q#T is not a class"
 msgstr "%q#T no es una clase"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "no hay una plantilla de clase llamada %q#T en %q#T"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la búsqueda de %qT en %qT es ambigua"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es una plantilla de clase"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es un tipo"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "los parámetros de la plantilla no coinciden con la plantilla"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "no se admite -falign-labels=%d"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D no válido; una union anónima solo puede tener miembros con datos no estáticos públicos"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "esta flexibilidad es obsoleta y será eliminada"
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "struct anónimo no está dentro de un tipo nombrado"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con constructor en un agregado anónimo"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con destructor en un agregado anónimo"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en un agregado anónimo"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "el atributo para %q#T debe estar a continuación de la palabra clave %qs"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "tipos múltiples en una declaración"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeclaración del tipo interno de C++ %qT"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "falta el nombre del tipo en la declaración typedef"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ prohíbe structs anónimos"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sólo se puede especificar dentro de una clase"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sólo se puede especificar para constructores"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "se descartó %<typedef%> en esta declaración"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> no se puede usar en declaraciones de tipo"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "se descartan los atributos aplicados al tipo de clase %qT fuera de la definición"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "se descartan los atributos aplicados al tipo dependiente %qT sin una declaración asociada"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD está inicializado (utilice decltype en su lugar)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la declaración de %q#D tiene %<extern%> y está inicializada"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la definición de %q#D se marca como %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "declaración de la plantilla miembro %qD no válida"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ no permite que %<%T::%D%> se defina como %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "inicialización duplicada de %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D tiene inicializador pero de tipo de dato incompleto"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementos de la matriz %q#D con tipo de dato incompleto"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "el agregado %q#D tiene un tipo incompleto y no se puede definir"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD declarado como referencia pero no se inicializa"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "se usó un nombre en un inicializador designado de estilo GNU para una matriz"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "el nombre %qD se utiliza en un inicializador designado en estilo GNU para una matriz"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "no se admiten los inicializadores designados como no triviales"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "el inicializador no puede determinar el tamaño de %qD"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "falta el tamaño de la matriz en %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "matriz %qD de tamaño cero"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %qD"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "el tamaño de almacenamiento de %qD no es constante"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  puede evitar esto eliminando el inicializador"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "const %qD sin inicializar"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T no tiene constructor por defecto proporcionado por el usuario"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "el constructor no es proporcionado por el usuario porque está marcado explícitamente por defecto en el cuerpo de la clase"
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, fuzzy, gcc-internal-format
 #| msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "y el constructor implícitamente definido no inicializa %q+#D"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipo %qT no válido como inicializador para un vector de tipo %qT"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "el inicializador para %qT debe estar encerrado entre llaves"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "se usa %<[%E] =%> en un inicializador designado en estilo GNU para la clase %qT"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT no tiene un dato miembro que no es static llamado %qD"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "invalid initializer for %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "asignador C99 %qE fuera del inicializador agregado"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "demasiados inicializadores para %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementos de la matriz %q#T tienen tipo de dato incompleto"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "literal compuesta de tamaño variable"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D tiene un tipo incompleto"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "el objeto escalar %qD requiere un elemento en el inicializador"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98 %qD debe ser inicializado por un constructor, no por %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "matriz %qD inicializada con una constante de cadena entre paréntesis %qE"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "inicializador no válido para el miembro static con constructor"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant in-class initialization invalid for static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(se requiere una inicialización fuera de la clase)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: invocación recursiva del constructor %qs"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la declaración de %q#D no tiene inicializadores"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member function (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "uso no válido de la función miembro (¿Olvidó el %<&%>?)"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "se oscurece la declaración de tipo previa de %q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "el atributo %qE se aplica solamente a variables en almacenamiento estático"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la función %q#D se inicializa como una variable"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  no se puede usar la asignación obsoleta en %q+D porque tiene un destructor"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 #| msgid "cannot form pointer to member of non-class %q#T"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -56398,7 +56411,7 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "se especificó %qs para el campo de estructura"
 msgstr[1] "se especificó %qs para el campo de estructura"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "only %u name provided for structured binding"
@@ -56406,1803 +56419,1803 @@ msgid_plural "only %u names provided for structured binding"
 msgstr[0] "inicializador no válido para la cadena de bits"
 msgstr[1] "inicializador no válido para la cadena de bits"
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "tipo no válido para la variable de iteración %qE"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "no se puede aplicar %<offsetof%> al dato miembro static %qD"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "el inicializador no puede determinar el tamaño de %qT"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "falta el tamaño de la matriz en %qT"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "matriz %qT de tamaño cero"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "el destructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "el constructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD se declaró como una variable %<virtual%>"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de variable"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD se declaró como un parámetro %<virtual%>"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD se declaró como un parámetro %<inline%>"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de parámetro"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD se declaró como un tipo %<virtual%>"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD se declaró como un tipo %<inline%>"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de tipo"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD se declaró como un campo %<virtual%>"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD se declaró como un campo %<inline%>"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de campo"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D se declaró con una especificación de excepción"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la definición de %qD no está en un espacio de nombres que contenga a %qT"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la función miembro static %q#D se declara con calificadores de tipo"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "el método Java %qD tiene un tipo de devolución %qT que no es de Java"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "a function concept cannot be constrained"
 msgstr "no se puede instrumentar la función"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD no es una función plantilla"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definiendo la especialización explícita %qD en la declaración friend"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "uso no válido del id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "no se permiten los argumentos por defecto en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "no se permite %<inline%> en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "operador literal con enlace C"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD tien una lista de argumentos no válida"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, fuzzy, gcc-internal-format
 #| msgid "integer suffix %<%s%> shadowed by implementation"
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo entero %<%s%> por la implementación"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %<%s%> shadowed by implementation"
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo de coma flotante %<%s%> por la implementación"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> debe devolver %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "la definición de %qD declarado implícitamente"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "la definición de %qD explícitamente por defecto"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D explicitly defaulted here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D explícitamente por defecto aquí"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "no hay una función miembro %q#D declarada en la clase %qT"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo incompleto"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "se necesita %<constexpr%> para la inicialización en la clase no válida del miembro de datos static %q#D de tipo que no es integral"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo que no es literal"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "inicialización en la clase no válida para el miembro de datos static de tipo %qT que no es integral"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ prohíbe la inicialización en la clase del miembro static %qD que no es constante"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ prohíbe la inicialización de la constante miembro %qD del tipo %qT que no es entero"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "el tamaño de la matriz %qD tiene un tipo %qT que no es integral"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de tamaño cero"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ prohíbe matrices de tamaño cero"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de longitud variable"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ prohíbe las matrices de longitud variable"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "se usa la matriz de longitud variable %qD"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "desbordamiento en la dimensión de la matriz"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "la declaración de %qD como una matriz de voids"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "se crea la matriz de voids"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "la declaración de %qD como una matriz de funciones"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "se crea la matriz de funciones"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "la declaración de %qD como una matriz de referencias"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "se crea la matriz de referencias"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "la declaración de %qD como una matriz de miembros de función"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "se crea la matriz de miembros de función"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qD como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "una matriz multidimensional debe tener límites para todas las dimensiones excepto para la primera"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la especificación del tipo de devolución para el constructor es no válida"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "se especificó un tipo de devolución para %<operator %T%>"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "se declaró la variable o campo sin nombre como void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "se declaró la variable o campo como void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "uso no válido del nombre calificado %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "uso no válido del nombre calificado %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "uso no válido del nombre calificado %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
 #  FIXME traducción
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "declaración de %qD como algo que no es miembro"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "falta el id del declarador; se utiliza la palabra reservada %qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la definición de la función no declara parámetros"
 
 #  FIXME traducción
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "declaración de %qD como %<typedef%>"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "la declaración de %qD como parámetro"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "no se especificó ninguna clase"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dos o más tipos de datos en la declaración de %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ prohíbe la declaración de %qs sin tipo"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "no se admite %<__int128%> en este objetivo"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ no admite %<__int128%> para %qs"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> y %<unsigned%> se especificaron juntos para %qs"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> y %<short%>  se especificaron juntos para %qs"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "se usó %qs con %qE"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qD"
 msgstr "se usó %qs con %qE"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex no válido para %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "declaración typedef no válida en la declaración de parámetros"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro de plantilla %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weak"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weak"
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "la función anidada %qs se declaró %<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la declaración del nivel superior de %qs especifica %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "el ámbito de la función %qs es implícitamente auto y declarado %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "especificadores de clase de almacenamiento no válidos en las declaraciones de funciones friend"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "se descarta el atributo"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Se esperaba un paréntesis izquierdo"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la función %qs usa el especificador de tipo %<auto%> sin un tipo de devolución trailing"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "uso no válido de %<auto%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "no se declaró la función %qs con tipo de devolución trailing con el especificador de tipo %<auto%>"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "calificado %<_Atomic%> el tipo de retorno de %qD"
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs que se declaró como función devuelve una función"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs que se declaró como función devuelve una matriz"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "la función %<noreturn%> devuelve un valor que no es void"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "el destructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "los constructores tal vez no sean cv-calificados"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "no se puede definir la función friend %qs en una definición de clase local"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "los destructores no pueden tener parámetros"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "no se puede declarar el puntero a %q#T"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "no se puede declarar el puntero al miembro %q#T"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "no se puede declarar la referencia a %q#T, el cual no es una definición de tipo o un argumento de tipo de plantilla"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "el id de plantilla %qD se usa como un declarador"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "las funciones miembros son implícitamente friends de su clase"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "calificación extra %<%T::%> en el miembro %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "no se puede definir la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "no se puede declarar la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "no se puede declarar el miembro %<%T::%s%> dentro de %qT"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "%qs que no es parámetro no puede ser un paquete de parámetro"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "los datos miembro pueden no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "el miembro que no es objeto %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la referencia %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "la definición de tipo se declaró %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ prohíbe el tipo anidado %qD con el mismo nombre que la clase que lo contiene"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "se especificó %<inline%> para la declaración de clase friend"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "los parámetros de la plantilla no pueden ser friends"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "la declaración friend requere una llave de clase, p.e. %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "la declaración friend requiere una llave de clase, p.e. %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "se intenta hacer que la clase %qT sea un friend de ámbito global"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "calificadores no válidos en el tipo de función que no es miembro"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "el declarador abstracto %qT se usó como declaración"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "no se puede usar %<::%>  en la declaración de parámetros"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "no se puede declarar que el parámetro %q+D sea del tipo abstracto %qT"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "uso no válido del nombre-de-plantilla %qE sin una lista de argumentos"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared %<auto%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "se declaró el miembro dato que no es static como %<auto%>"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "uso no válido de %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "declaración de la función %qD en un contexto no válido"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD no se puede declarar virtual, ya que siempre es static"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el destructor %qD"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el constructor %qD"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "no se puede abrir %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "el tipo original se definió aquí"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "el nombre %qT tiene tipo de dato incompleto"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, fuzzy, gcc-internal-format
 #| msgid "an attribute that appertains to a type-specifier is ignored"
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<auto%> es no válida para la función %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<register%> es no válida para la función %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "no se permiten los especificadores-virt en %qs fuera de una definición de clase"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<static%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "función virtual %qs que no es clase"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "se definió %qs en un ámbito que no es una clase"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "se declaró %qs en un ámbito que no es una clase"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "no se puede declarar que la función miembro %qD tenga enlace estático"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "no se puede declarar una función static dentro de otra función"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> puede no ser utilizado cuando se define (opuesto a la declaración) un dato miembro static"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "se declaró el miembro static %qD como %<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "no se puede declarar explícitamente que el miembro %q#D tenga un enlace externo"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la declaración de la variable constexpr %qD no es una definición"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs inicializado y declarado como %<extern%>"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs tiene %<extern%> e inicializador al mismo tiempo"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "el argumento por defecto %qE usa %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "el argumento por defecto %qE usa la variable local %qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "tipo de parámetro cualificado %<_Atomic%> %qT de %q+D"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye un puntero a matriz %qT de límite desconocido"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye una referencia a matriz %qT de límite desconocido"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructor no válido; tal vez quiso decir %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD no se puede declarar como static"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD debe ser una función miembro que no sea static o una función que no sea miembro"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD debe tener un argumento de tipo clase o enumerado"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ prohíbe la sobrecarga del operador ?:"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD no debe tener un número variable de argumentos"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD debe tomar cero o un argumentos"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD debe tomar uno o dos argumentos"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su argumento"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su segundo argumento"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD debe tomar un argumento exactamente"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD no puede tener argumentos por defecto"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversión a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversión a una referencia al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversión al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una referencia a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "el %qD definido por el usuario siempre evalúa ambos argumentos"
 
 #  En esta traducción se emplea 'devolver' por 'return'. Si embargo, aquí
 #  se cambió por cacofonía: no es agradable escuchar 'debe devolver'. cfuga
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "el prefijo %qD debe regresar %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "el postfijo %qD debe regresar %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD debe devolver por valor"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "usando el parámetro de tipo plantilla %qT después de %qs"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "se usa especialización de plantilla %qT alias después de %qs"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "se usó el nombre de definición de tipo %qD después de %qs"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD tiene una declaración previa aquí"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "se refirió a %qT como %qs"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T tiene una declaración previa aquí"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "se refirió a %qT como un enum"
@@ -58214,66 +58227,66 @@ msgstr "se refirió a %qT como un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "se requiere un argumento de plantilla para %<%s %T%>"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "uso del enum %q#D sin declaración previa"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeclaración de %qT como algo que no es plantilla"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "no se puede declarar %qD que sea un tipo de campo de bits"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union derivada %qT no válida"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
@@ -58281,49 +58294,49 @@ msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
 #  No me gusta mucho esta traducción. Creo que es mejor
 #  "el tipo base %qT no es de tipo struct o clase". cfuga
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "el tipo base %qT falla en ser un tipo struct o clase"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipo recursivo %qT sin definir"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "tipo base duplicado %qT no válido"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "no coincide el tipo subyacente en el enum %q#T"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tipos subyacentes diferentes en el enum %q#T"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "Option %s with different values"
 msgid "cannot define %qD in different module"
 msgstr "Opción %s con valores diferentes"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -58333,89 +58346,89 @@ msgstr "el tipo subyacente %<%T%> de %<%T%> debe ser un tipo integral"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ningún tipo integral puede representar todos los valores de enumerador de %qT"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 #| msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "desbordamiento en valores de enumeración en %qD"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ya se definió en la clase %qT"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %qs"
 msgid "using %qs"
 msgstr "%qs contenedora"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -59341,7 +59354,7 @@ msgstr "el tipo %qT no es una base directa o virtual de %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
@@ -60496,7 +60509,7 @@ msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -61304,7 +61317,7 @@ msgstr "no se pueden definir tipos en una expresión %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -62085,12 +62098,12 @@ msgstr "solamente los constructores toman inicializadores miembro"
 msgid "cannot expand initializer for member %qD"
 msgstr "no se puede expandir el inicializador para el miembro %<%D%>"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "inicializador mem para %qD después de una delegación de constructor"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "delegación de constructor después de un inicializador mem para %qD"
@@ -62739,7 +62752,7 @@ msgstr "en el argumento de plantilla para el tipo %qT "
 msgid "%qT not permitted in template argument"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -63661,7 +63674,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
@@ -64756,7 +64769,7 @@ msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
@@ -64858,291 +64871,291 @@ msgstr "la función devuelve una matriz"
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo no válido %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "número erróneo de argumentos para %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "se especificó el número equivocado de argumentos para el atributo %qE"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -65155,185 +65168,185 @@ msgstr "especialización explícita de %qD después del primer uso"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT no es un espacio de nombres"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "la definición de %q#T dentro de la lista de parámetros de plantilla"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qD directly instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "la función no se consideró para la inclusión en línea"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "explicit deduction guide declared here"
 msgstr "en una llamada a la función %qD declarada aquí"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %qT in template argument"
@@ -65679,7 +65692,7 @@ msgstr "especificación de clase base no válida"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
@@ -66134,30 +66147,30 @@ msgstr "se llamó a %<__builtin_next_arg%> sin un argumento"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE no es una plantilla"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -66166,22 +66179,22 @@ msgstr "argumento no admitido para %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -67526,240 +67539,240 @@ msgstr "declaración adelantada de %q+#T"
 msgid "declaration of %q#T"
 msgstr "la declaración de %q+#T"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D has incomplete type"
 msgid "%qD has incomplete type"
 msgstr "%q#D tiene un tipo incompleto"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "uso no válido del tipo incompleto %q#T"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member function (did you forget the %<()%> ?)"
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "uso no válido de la función miembro (¿Olvidó el %<&%>?)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the %<&%> ?)"
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "uso no válido del miembro (¿Olvidó el %<&%>?)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qT"
 msgid "invalid use of placeholder %qT"
 msgstr "uso no válido de %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "uso no válido del parámetro de tipo plantilla %qT"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "uso no válido del parámetro de plantilla plantilla %qT"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of pack expansion expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "uso no válido del tipo dependiente %qT"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "uso no válido  de la lista del inicializador dentro de llaves"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "dirección de la función sobrecargada sin información contextual de tipo"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "función sobrecargada sin información contextual de tipo"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "información contextual insuficiente para determinar el tipo"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "se usó la sintaxis de constructor, pero no se declaró un constructor para el tipo %qT"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "la conversión estrechadora de %qE desde %qT a %qT dentro de { } está mal formada en C++11"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "conversión estrechadora de %qE desde %qT a %qT dentro de { }"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "la expresión en la aserción static no es una expresión constante entera"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "la cadena del inicializador para la matriz de caracteres es demasiado larga"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "llaves alrededor del inicializador escalar"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "no se puede inicializar el agregado del tipo %qT con una literal compuesta"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "no existe el campo %qD en la union que se está inicializando"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valor de índice en lugar del nombre del campo en el inicializador de union"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "se detectó una delegación de puntero circular"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "el operando base de %<->%> tiene el tipo %qT que no es puntero"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "el resultado de %<operator->()%> produce un resultado que no es puntero"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "el operando base de %<->%> no es un puntero"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "no se puede usar %qE como un puntero miembro, porque es de tipo %qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "no se puede aplicar el puntero a miembro %qE a %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "el tipo de puntero a miembro %qT es incompatible con el tipo objeto %qT"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "conversión funcional al tipo de matriz %qT"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "llamada a la función %qD la cual arroja el tipo incompleto %q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "llamada a una función la cual arroja el tipo incompleto %q#T"
@@ -68799,7 +68812,7 @@ msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "'I' en %L y 'J' en %L no pueden ser constantes literal BOZ al mismo tiempo"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -70051,12 +70064,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Se truncó la cadena de inicialización que inicia en %L para coincidir con la variable (%d%d)"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "El índice de inicio de la subcadena en %L es menor a uno"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "El índice de final de la subcadena en %L excede la longitud de la cadena"
@@ -70260,7 +70273,7 @@ msgstr "Especificación INTENT errónea en %C"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003: parámetro de tipo diferido en %C"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -72486,7 +72499,7 @@ msgstr "no se permite el intrínseco transformacional '%s' en %L en una expresi
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Extensión: Evaluación de una expresión de inicialización no estándar en %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -72794,7 +72807,7 @@ msgstr "No coincide la interfaz en la asignación de puntero a procedimiento en
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -72918,7 +72931,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
@@ -72930,7 +72943,7 @@ msgstr "El objetivo de inicialización de puntero en %L no debe ser ALLOCATABLE"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "El objetivo de inicialización de puntero en %C debe tener el atributo TARGET"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "El objetivo de inicialización de puntero en %L debe tener el atributo SAVE"
@@ -73079,7 +73092,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -73318,12 +73331,12 @@ msgstr "El primer argumento de la asignación definida en %L debe ser INTENT(OUT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
@@ -73448,659 +73461,659 @@ msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y escalar)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y rango %d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Argumento de procedimiento no válido en %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento dummy '%s' en %L: %s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to contiguous pointer dummy '%s' at %L must be simply contigous"
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "El argumento actual para el puntero dummy contiguo '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "El argumento actual INTENT(%s) en %L puede interferir con el argumento actual en %L."
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "No coincide el tipo en el argumento '%s' en %L; se pasa %s a %s"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must have the same declared type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "El argumento actual para '%s' en %L debe tener el mismo tipo declarado"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 #| msgid "Corank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "No coincide el corango en el argumento '%s' en %L (%d y %d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be simply contiguous"
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "El argumento actual para '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' has to be a pointer or assumed-shape array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "El argumento dummy '%s' tiene que ser un puntero o una matriz de tamaño asumida sin atributo CONTIGUOUS - porque el argumento actual en %L no es simplemente contiguo y ambos son ASYNCHRONOUS o VOLATILE"
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument '%s'"
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Se pasa una comatriz en %L al argumento dummy INTENT(OUT) '%s', que no es comatriz, alojable"
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray dummy argument '%s', which is invalid if the allocation status is modified"
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Se pasa una comatriz en %L al argumento dummy '%s' que no es comatriz, el cual es no válido si se modifica el estado de alojamiento"
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic scalar passed to array dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Se pasó un escalar polimórfico al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Se pasó un elemento de forma asumida o puntero a matriz al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Se pasó un elemento de forma asumida o puntero a matriz al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Extensión: Argumento actual CHARACTER de género diferente a C_CHAR, sin género por defecto escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Argumento actual CHARACTER escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "El argumento de palabra clave '%s' en %L ya está asociado con otro argumento actual"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Más argumentos actuales que formales en la llamada a procedimento en %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Falta la especificación de devolución alternativa en la llamada a subrutina en %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Especificación de devolución alternativa inesperada en la llamada a subrutina en %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Null pointer at %L to non-pointer dummy '%s'"
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Puntero nulo en %L a un dummy '%s' que no es puntero"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy puntero o alojable '%s' en %L"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy de forma asumida '%s' en %L"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L to allocatable or pointer dummy argument '%s' must have a deferred length type parameter if and only if the dummy has one"
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "El argumento actual en %L para el argumento alojable o dummy puntero '%s' debe tener un parámetro de tipo de longitud diferido si y sólo si el dummy tiene uno"
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "La longitud del carácter del argumento actual es más corta que la del argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "El argumento actual contiene muy pocos elementos para el argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Se esperaba un puntero procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Falta un procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "El argumento actual para '%s' no puede ser una matriz de tamaño asumido en %L"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy '%s'"
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: El argumento actual que no es puntero en %L para el puntero dummy '%s'"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray and thus shall not have an array designator"
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr "El argumento actuar para '%s' en %L debe ser una comatriz y por lo tanto no debe tener un designador de matriz"
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to pointer dummy '%s'"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Argumento actual coindizado en %L para el puntero dummy '%s'"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to allocatable dummy '%s' requires INTENT(IN)"
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "El argumento actual coindizado en %L para el dummy alojable '%s' requiere INTENT(IN)"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy '%s' has neither ASYNCHRONOUS nor VOLATILE"
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "El argumento actual coindizado ASYNCHRONOUS o VOLATILE en %L requiere que el dummy '%s' no tenga ASYNCHRONOUS ni VOLATILE"
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy '%s' requires either VALUE or INTENT(IN)"
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "El argumento actual coindizado en %L con componente último alojable para el dummy '%s' requiere uno de VALUE o INTENT(IN)"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "Actual CLASS array argument for '%s' must be a full array at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "El argumento de la matriz CLASS actual para '%s' debe ser una matriz completa en %L"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "El argumento actual para '%s' debe ser ALLOCATABLE en %L"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "El argumento actual de sección de matriz con subíndices vectoriales en %L es incompatible con el atributo INTENT(OUT), INTENT(INOUT), VOLATILE o ASYNCHRONOUS del argumento dummy '%s'"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de sección de matriz en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de matriz de puntero en %L requiere un argumento dummy de forma asumida o matriz de puntero '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Falta la especificación de devolución alternativa en la llamada a subrutina en %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Falta el argumento actual para el argumento '%s' en %L"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "El mismo argumento actual está asociado con el argumento INTENT(%s) '%s' y el argumento INTENT(%s) '%s' en %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "El argumento del procedimiento en %L es local a un procedimiento PURE y tiene el atributo POINTER"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "El argumento coindizado en %L en un procedimiento PURE se pasa a un argumento INTENT(%s)"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "El argumento actual coindizado en %L es un procedimiento PURE se pasa a un argumento dummy POINTER"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument '%s'"
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "El argumento actual polimórfico coindizado en %L se pasa al argumento dummy polimórfico '%s'"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "El procedimiento '%s' que se llama en %L no tiene una interfaz explícita"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "El procedimiento '%s' que se llama en %L no tiene una interfaz explícita"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto puntero '%s' en %L debe tener una interfaz de función explícita o declrararse como matriz"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, fuzzy, gcc-internal-format
 #| msgid "The allocatable object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto allocatable '%s' en %L debe tener una interfaz de función explícita o declararse como matriz"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable function '%s' at %L must have an explicit function interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "La función allocatable '%s' en %L debe tener una interfaz de función explícita"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "El argumento actual de LOCK_TYPE o con componente LOCK_TYPE en %L requiere una interfaz explícita para el procedimiento '%s'"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "El argumento actual de LOCK_TYPE o con componente LOCK_TYPE en %L requiere una interfaz explícita para el procedimiento '%s'"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "se requiere el argumento MOLD para NULL en %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento de componente puntero '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure pointer component '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento de componente puntero '%s' en %L"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "Se require MOLD= en un argumento NULL en %L: Ambigüedad entre las funciones específicas %s y %s "
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D es un alias del símbolo sin definir %qE"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "La entidad '%s' en %C ya está presente en la interfaz"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "error interno - demasiados tipos de interfaz"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "No se puede sobreescribir el GENERIC '%s' en %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' en %L sobreescribe un enlace de procedimiento declarad como NON_OVERRIDABLE"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "'%s' en %L no debe ser DEFERRED porque sobreescribe un enlazado que no es DEFERRED"
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' en %L sobreescribe un procedimiento PURE y también debe ser PURE"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' en %L sobreescribe un procedimiento ELEMENTAL y también debe ser ELEMENTAL"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' en %L sobreeescribe un procedimiento que no es ELEMENTAL y tampoco debe ser ELEMENTAL"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' en %L sobreescribe una SUBROUTINE y también debe ser una SUBROUTINE"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' en %L sobreescribe una FUNCTION y también debe ser una FUNCTION"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' en %L sobreescribe un procedimiento PUBLIC y no debe ser PRIVATE"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "El argumento dummy '%s' de '%s' en %L se debe llamar '%s' para que coincida con el argumento correspondiente al procedimiento sobreescrito"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' en %L debe tener el mismo nombre de argumentos formales que el procedimiento sobreeescrito"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' en %L sobreescribe un enlace NOPASS y también debe ser NOPASS"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' en %L sobreescribe un enlace con PASS y también debe ser PASS"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "El argumento dummy del objeto pasado de '%s' en %L debe estar en la misma posición que el argumento dummy del objeto pasado del procedimiento sobreescrito"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "La etiqueta %s en %L debe ser de tipo %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "El argumento %s en %L debe ser de longitud uno"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued %s '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "La función %s valuada con carácter '%s' en %L no debe tener longitud asumida"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "No se permite la declaración DATA en %C en un procedimiento PURE"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL procedure '%s' at %L must have an explicit interface"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "El procedimiento ELEMENTAL '%s' en %L debe tener una interfaz explícita"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to procedure `%s'"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "faltan argumentos para el procedimiento `%s'"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to procedure `%s'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -74311,7 +74324,7 @@ msgstr "Conversión de %s a %s en %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -74928,7 +74941,7 @@ msgstr "NAMELIST '%s' en la declaración READ en %L contiene el símbolo '%s' el
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -75554,7 +75567,7 @@ msgstr "El código STOP en %L debe ser un carácter por defecto KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "El código STOP en %L debe ser un entero por defecto KIND=%d"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -77600,8 +77613,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula IF en %L requiere una expresión LOGICAL escalar"
@@ -79793,602 +79806,614 @@ msgstr "La función %s valuada con carácter '%s' en %L no debe tener longitud a
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "La función %s valuada con carácter '%s' en %L no debe tener longitud asumida"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "El procedimiento %s en %L tiene entradas con especificaciones de matriz no coincidentes"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function %s at %L has entries with mismatched array specifications"
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "El procedimiento %s en %L tiene entradas con especificaciones de matriz no coincidentes"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Function %s at %L with entries returning variables of different string lengths"
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "Extensión: La función %s en %L con entradas que devuelven variables de longitudes de cadena diferentes"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be an array in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "El resultado de FUNCTION %s no puede ser una matriz en FUNCTION %s en %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be an array in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "El resultado de ENTRY %s no puede ser una matriz en FUNCTION %s en %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "El resultado de FUNCTION %s no puede ser un POINTER en FUNCTION %s en %L"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "El resultado de ENTRY %s no puede ser un POINTER en FUNCTION %s en %L"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "El resultado de FUNCTION %s no puede ser un POINTER en FUNCTION %s en %L"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "El resultado de ENTRY %s no puede ser un POINTER en FUNCTION %s en %L"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be of type %s in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "El resultado de FUNCTION %s no puede ser de tipo %s en FUNCTION %s en %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be of type %s in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "El resultado de ENTRY %s no puede ser de tipo %s en FUNCTION %s en %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "El símbolo '%s' en %C ya está en un bloque COMMON"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "El símbolo '%s' en %C ya está en un bloque COMMON"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "COMMON block /%s/ not found at %C"
 msgid "COMMON block at %L"
 msgstr "No se encontró el bloque COMMON /%s/ en %C"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "La variable '%s' en %L está en COMMON pero sólo se permite la inicialización en BLOCK DATA"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized variable '%s' at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "La variable inicializada '%s' en %L está en un COMMON vacío pero la inicialización sólo se permite en bloques common nombrados"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "La variable de tipo derivado '%s' en COMMON en %L no tiene el atributo SEQUENCE ni el atributo BIND(C)"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' in COMMON at %L has an ultimate component that is allocatable"
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "La variable de tipo derivado '%s' en COMMON en %L tiene un componente ultimate que es allocatable"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' in COMMON at %L may not have default initializer"
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "La variable de tipo derivado '%s' en COMMON en %L tal vez no tiene inicializador por defecto"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "El bloque COMMON '%s' en %L se usa como PARAMETER en %L"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "El bloque COMMON '%s' en %L se usa como PARAMETER en %L"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L is also an intrinsic procedure"
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "El bloque COMMON '%s' en %L también es un procedimiento intrínseco"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: COMMON block '%s' at %L that is also a function result"
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "Fortran 2003: El bloque COMMON '%s' en %L también es un resultado de función"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: COMMON block '%s' at %L that is also a global procedure"
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "Fortran 2003: El bloque COMMON '%s' en %L también es un procedimiento global"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "El rango del elemento en el constructor de estructura en %L no coincide con el del componente (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the structure constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "El elemento en el constructor de estructura en %L, para el componente puntero '%s', es %s pero debería ser %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, fuzzy, gcc-internal-format
 #| msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Longitudes de caracteres desiguales (%ld/%ld) en %s en %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, fuzzy, gcc-internal-format
 #| msgid "The NULL in the structure constructor at %L is being applied to component '%s', which is neither a POINTER nor ALLOCATABLE"
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "El NULL en el constructor de estructura en %L se aplica para el componente '%s', el cual no es ni POINTER ni ALLOCATABLE"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch for procedure-pointer component '%s' in structure constructor at %L: %s"
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "No coincide la interfaz en el componente puntero-a-procedimiento '%s' en el constructor de estructura en %L: %s"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %L!"
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "¡Demasiados componentes en el constructor de estructura en %L!"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 #| msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "El rango del elemento en el constructor de estructura en %L no coincide con el del componente (%d/%d)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the structure constructor at %L, for pointer component '%s' should be a POINTER or a TARGET"
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "El elemento en el constructor de estructura en %L, para el componente puntero '%s', debe ser un POINTER o un TARGET"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid expression in the structure constructor for pointer component '%s' at %L in PURE procedure"
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Expresión no válida en el constructor de estructura para el componente puntero '%s' en %L en el procedimiento PURE"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, fuzzy, gcc-internal-format
 #| msgid "The upper bound in the last dimension must appear in the reference to the assumed size array '%s' at %L"
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "El límite superior en la última dimensión debe aparecer en la referencia a la matriz de tamaño asumido '%s' en %L"
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%qs at %L is ambiguous"
 msgstr "'%s' en %L es ambiguo"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "El procedimiento GENERIC '%s' no se permite como un argumento actual en %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, fuzzy, gcc-internal-format
 #| msgid "Type specified for intrinsic function '%s' at %L is ignored"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Se descarta el tipo para la función intrínseca '%s' en %L"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "La subrutina intrínseca '%s' en %L no debe tener un especificador de tipo"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared INTRINSIC at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "No existe '%s' declarado como INTRINSIC en %L"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, fuzzy, gcc-internal-format
 #| msgid "The intrinsic '%s' declared INTRINSIC at %L is not available in the current standard settings but %s.  Use an appropriate -std=* option or enable -fall-intrinsics in order to use it."
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "El intrínseco '%s' declarado como INTRINSIC en %L no está disponible en la configuración actual de estándares pero %s.  Use una opción -std=* apropiada o active -fall-intrinsics para poder usarlo."
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, fuzzy, gcc-internal-format
 #| msgid "Non-RECURSIVE procedure '%s' at %L is possibly calling itself recursively.  Declare it RECURSIVE or use -frecursive"
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "La etiqueta %d referenciada en %L nunca se define"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Internal procedure '%s' is used as actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Fortran 2008: Se usa el procedimiento interno '%s' como un argumento actual en %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "La función de declaración '%s' en %L no se permite como un argumento actual"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "El intrínseco '%s' en %L no se permite como un argumento actual"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Internal procedure '%s' is used as actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Fortran 2008: Se usa el procedimiento interno '%s' como un argumento actual en %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "El procedimiento ELEMENTAL que no es INTRINSIC '%s' no se permite como un argumento actual en %L"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to find a specific INTRINSIC procedure for the reference '%s' at %L"
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "No se puede encontrar un procedimiento INTRINSIC específico para la referencia '%s' en %L"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "El símbolo '%s' en %L es ambiguo"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "El argumento por valor en %L no es de tipo numérico"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "El argumento por valor en %L no puede ser una matriz o una sección de matriz"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "El argumento por valor en %L no se permite en este contexto"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "No se permite el paso del procedimiento interno en %L por ubicación"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "El procedimiento ELEMENTAL que no es INTRINSIC '%s' no se permite como un argumento actual en %L"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Argumento actual coindizado en %L con componente puntero último"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "'%s' en %L es una matriz y OPTIONAL; SI FALTA, no puede ser el argumento actual de un procedimiento ELEMENTAL a menos que exista un argumento que no sea opcional con el mismo rango (12.4.1.5)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "El argumento actual en %L para el dummy INTENT(%s) '%s' de la subrutina ELEMENTAL '%s' es un escalar, pero otro argumento actual es una matriz"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 #| msgid "Return type mismatch of function '%s' at %L (%s/%s)"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "No coincide el tiop de devolución de la función '%s' en %L (%s/%s)"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento dummy '%s' en %L: %s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "No hay una función específica para el genérico '%s' en %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "La función genérica '%s' en %L no es consistente con una interfaz intrínseca específica"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La función '%s' en %L es INTRINSIC pero no es compatible con un intrínseco"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "No se puede resolver la función específica '%s' en %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un FORALL %s"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a DO CONCURRENT %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un DO CONCURRENT %s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un FORALL %s"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after NOWAIT clause at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Basura inesperada después de la cláusula NOWAIT en %C"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "'%s' en %L no es una función"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "La ABSTRACT INTERFACE '%s' no se debe referenciar en %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "La función '%s' se declara CHARACTER(*) y no se puede usar en %L ya que no es un argumento de prueba"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "La función definida por el usuario '%s' que no es ELEMENTAL en %L no se permite en la construcción WORKSHARE"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY '%s' en %L no se puede llamar recursivamente, porque la función '%s' no es RECURSIVE"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "La función '%s' en %L no se puede llamar recursivamente, porque no es RECURSIVE"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is deprecated."
 msgid "Using function %qs at %L is deprecated"
 msgstr "la interna %qF es obsoleta."
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque FORALL en %L no es PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque DO CONCURRENT en %L no es PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en %L no es PURE"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "No hay una subrutina específica para el genérico '%s' en %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "La subrutina genérica '%s' en %L no es consistente con una interfaz de subrutina intrínseca"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La subrutina '%s' en %L es INTRINSIC pero no es compatible con un intrínseco"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "No se puede resolver la subrutina específica '%s' en %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' en %L tiene un tipo, el cual no es consistente con CALL en %L"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY '%s' en %L no se puede llamar recursivamente, porque la subrutina '%s' no es RECURSIVE"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE '%s' en %L no se puede llamar recursivamente, porque no es RECURSIVE"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is deprecated."
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "la interna %qF es obsoleta."
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Las formas para los operandos en %L y %L no son conformables"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "always_inline function might not be inlinable"
 msgid "Impure function at %L might not be evaluated"
 msgstr "una función always_inline tal vez no se puede incluir en línea"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "El argumento por valor en %L no puede ser una matriz o una sección de matriz"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
@@ -80396,7 +80421,7 @@ msgstr "El argumento por valor en %L no puede ser una matriz o una sección de m
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
@@ -80404,192 +80429,192 @@ msgstr "Género no válido para %s en %L"
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la codimensión %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la codimensión %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tranco ilegal de cero en %L"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "No se especificó el límite superior a la derecha de la sección de matriz de tamaño asumido en %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango de coíndice no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "El coíndice en la codimensión %d debe ser un escalar en %L"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "El índice de matriz en %L debe ser escalar"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "El índice de matriz en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Extensión: índice de matriz REAL en %L"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "El argumento dim en %L debe ser escalar"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid array initializer for non-array type %qs"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Inicializador de matriz no válido para el tipo %qs que no es matriz"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "El índice de matriz en %L es una matriz de rango %d"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "El índice de inicio de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "El índice de inicio de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "El índice de final de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "El índice de final de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "El índice de final de la subcadena en %L es demasiado grande"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo POINTER en %L"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo ALLOCATABLE en %L"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "No se deben especificar dos o más referencias de parte con rango que no es cero en %L"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -80599,12 +80624,12 @@ msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -80614,313 +80639,313 @@ msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' at %L with BIND(C) attribute must have an explicit interface"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "El procedimiento '%s' en %L con atributo BIND(C) debe tener una interfaz explícita"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s', usada en una expresión de especificación, se referencía en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s' se usa en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Subobjecto polimórfico de un objeto coindizado en %L"
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objeto coindizado con subcomponente alojable polimórfico en %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs es obsoleto"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Error en la especificación de tipo en %L"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "El objeto pasado en %L debe ser escalar"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a componente procedimiento-puntero en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo NOPASS en %L debe ser escalar"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "No se encontró un enlace específico coincidente para la llamada al GENERIC '%s' en %L"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' en %L debe ser una SUBROUTINE"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' en %L debe ser una FUNCTION"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s en %L debe ser un escalar"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s en %L debe ser INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "La expresión de paso en el bucle DO en %L no puede ser cero"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "El bucle DO en %L se ejecutará cero veces"
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "La expresión de inicio FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "La expresión de fin FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "La expresión de tranco FORALL en %L no puede ser cero"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "El índice FORALL '%s' no puede aparecer en la especificación triplet en %L"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "El objeto de alojamiento en %L debe ser ALLOCATABLE o un POINTER"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "La expresión fuente en %L debe ser escalar o tener el mismo rango que el objeto de alojamiento en %L"
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "La expresión fuente en %L y el objeto de alojamiento en %L deben tener la misma forma"
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la expresión fuente en %L"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "El objeto de alojamiento en %L y la expresión fuente en %L deben tener el mismo parámetro de tipo de género"
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "El alojamiento %s del tipo de base ABSTRACT en %L requiere una especificación de tipo o una expresión source"
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Alojar %s en %L con especificación de tipo requiere el mismo parámetro de longitud de carácter que el de la declaración"
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Especificación de comatriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Especificación de matriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' no debe aparecer en la especificación de matriz en %L en la misma declaración ALLOCATE donde se aloja a sí misma"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Se esperaba '*' en la especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat en %L no no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG en %L es inútil sin una etiqueta STAT"
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg en %L no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "El objeto de alojamiento en %L también aparece en %L"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
@@ -80929,303 +80954,303 @@ msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "La expresión en la declaración CASE en %L debe ser de tipo %s"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "La expresión en la declaración CASE en %L debe ser de género %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "La expresión de selección en una declaración GOTO computada en %L debe ser una expresión entera escalar"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "El argumento de la declaración SELECT en %L no puede ser %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "La expresión en la declaración CASE en %L no está en el rango de %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "El DEFAULT CASE en %L no puede tener después un segundo DEFAULT CASE en %L"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "No se permite un rango lógico en una declaración CASE en %L"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Se repite un valor lógico constante en una declaración CASE en %L"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La especificación de rango en %L nunca puede coincidir"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "El bloque SELECT CASE lógico en %L tiene más de dos cases"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "El nombre '%s' no se puede usar como un operador definido en %C"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L cannot be NULL()"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L has no type"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "El selector debe ser polimórfico en la declaración SELECT TYPE en %L"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "El tipo derivado '%s' en %L debe ser una extensión de '%s'"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloque CLASS IS doble en la declaración SELECT TYPE  en %L"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede ser polimórfico a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes ALLOCATABLE a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes PRIVATE"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "El elemento de transferencia de datos en %L no puede ser una referencia completa a una matriz de tamaño asumido"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "El argumento ACQUIRED_LOCK= en %L debe ser una variable LOGICAL escalar"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "El argumento de conjunto de imagen en %L debe estar entre 1 y num_images()"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "La declaración en %L no es una declaración de objetivo de ramificación válida para la declaración de ramificación en %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "La ramificación en %L puede resultar en un bucle infinito"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción CRITICAL por la etiqueta en %L"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la etiqueta en %L"
@@ -81233,221 +81258,221 @@ msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la et
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "La etiqueta en %L no está en el mismo bloque que la declaración GOTO en %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "La máscara WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "El objetivo de asignación WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Asignación definida por el usuario de un no-ELEMENTAL en WHERE en %L"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Declaración sin soporte dentro de WHERE en %L"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "No se usa el FORALL con índice '%s' en el lado izquierdo de la asignación en %L y podría causar múltiples asignaciones a este objeto"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008: Constructor BLOCK en %C"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Una construcción FORALL externa ya tiene un índice con este nombre %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "la cláusula WHERE/ELSEWHERE en %L requiere una matriz LOGICAL"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "La expresión con coíndice en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Asignación a una variable coindizada en %L en un procedimiento PURE"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, fuzzy, gcc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "La variable no debe ser polimórfica en la asignación intrínseca en %L - revise que hay una subrutina específica coincidente para el operador '='"
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable coindizada no debe tener un componente último alojable en la asignación en %L"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero."
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "La declaración ASSIGNED GOTO en %L requiere una variable INTEGER"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "La declaración RETURN alternativa en %L requiere de un especificador de devolución SCALAR-INTEGER"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Se esperaba la inicialización de la expresión en CASE en %C"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "La declaración de ASSIGN en %L requiere una variable INTEGER escalar por defecto"
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "La declaración IF aritmética en %L requiere una expresión numérica"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condición de salida del bucle DO WHILE en %L debe ser una expresión LOGICAL escalar"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula de máscara FORALL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Se declaró el parámetro '%s' sin uso en %L"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -81455,7 +81480,7 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -81464,66 +81489,66 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longitud de la cadena en %L es demasiado grande"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz allocatable '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "El objeto escalar '%s' en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz de puntero '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "La matriz '%s' en %L no puede tener una forma diferida"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "El tipo '%s' de la variable CLASS '%s' en %L no es extensible"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS '%s' en %L debe ser dummy, allocatable o pointer"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "El tipo '%s' no se puede asociar al anfitrión en %L porque está bloqueado por un objeto incompatible del mismo nombre declarado en %L"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008: SAVE implícito para la variable de módulo '%s' en %L, se necesita por la inicialización por defecto"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -81531,1065 +81556,1065 @@ msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "El módulo o la matriz del programa principal '%s' en %L deben tener una forma constante"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "La entidad con longitud de carácter asumida en %L debe ser un argumento de prueba o un PARAMETER"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "El allocatable '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "El intrinsic '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "El resultado de la función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "La matriz automática '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La función de declaración valuada con carácter '%s' en %L debe tener longitud constante"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' es de un tipo PRIVATE y no puede ser un argumento dummy de '%s', el cual es PUBLIC en %L"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: El procedimiento '%s' en la interfaz PUBLIC '%s' en %L toma argumentos dummy de '%s' el cual es PRIVATE"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "El objeto external '%s' en %L puede no tener un inicializador"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La función ELEMENTAL '%s' en %L debe tener un resultado escalar"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La función de declaración '%s' en %L no debe tener atributo puntero o alojable"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser matriz-valuada"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser recursiva"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "El procedimiento dummy '%s' en %C no puede tener una interfaz genérica"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo SAVE en '%s' en %L"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo INTENT en '%s' en %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo RESULT en '%s' en %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "El atributo EXTERNAL genera un conflicto con el atributo FUNCTION en '%s' en %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Al resultado del puntero de procedimiento '%s' en %L le falta el atributo puntero"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "La interfaz '%s' del procedimiento '%s' en %L debe ser explícita"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "El procedimiento FINAL '%s' en %L no debe ser una SUBROUTINE"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "El procedimiento FINAL en %L debe tener exactamente un argumento"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "El argumento del procedimiento FINAL en %L debe ser de tipo '%s'"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser un POINTER"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "El argumento del procedimiento final en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser OPTIONAL"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser INTENT(OUT)"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "El procedimiento FINAL que no es escalar en %L debe tener un argumento sharp asumido"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "El procedimiento FINAL '%s' declarado en %L tiene el mismo rango (%d) que '%s'"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Sólo se declaran procedimientos FINAL de matriz para el tipo derivado '%s' definido en %L, se sugiere también uno escalar"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' y '%s' no pueden ser FUNCTION/SUBROUTINE mezcladas para el GENERIC '%s' en %L"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' y '%s' para el GENERIC '%s' en %L son ambiguos"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "El enlace específico '%s' no está definido como objetivo del GENERIC '%s' en %L"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "El GENERIC '%s' en %L debe apuntar a un enlace específico, '%s' es GENERIC también"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "El GENERIC '%s' en %L no puede sobreescribir el enlace específico con el mismo nombre"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "El operador enlazado a tipo en %L no puede ser NOPASS"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' debe ser un procedimiento de módulo o un procedimiento externo con una interfaz explícita en %L"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argumento dummy pasado como objeto no polimórfico de '%s' en %L"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser POINTER"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente de '%s'"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente heredado de '%s'"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "El tipo derivado '%s' declarado en %L debe ser ABSTRACT porque '%s' es DEFERRED y no se sobreescribió"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "El componente de comatriz '%s' en %L debe sel alojable con forma diferida"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "El componente '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "El componenten '%s' en %L con componente comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "El argumento de ICHAR en %L debe ser de longitud uno"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento de componente puntero '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento de componente puntero '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser escalar"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede tener el atributo POINTER"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "El componente '%s' de '%s' en %L tiene el mismo nombre que un procedimiento enlazado a tipo heredado"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longitud de carácter del componente '%s' necesita ser una expresión de especificación constante en %L"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "La expresión en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "El componente de carácter '%s' de '%s' en %L con longitud diferida debe ser POINTER o ALLOCATABLE"
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: el componente '%s' es un tipo PRIVATE y no puede ser un componente de '%s' el cual es PUBLIC en %L"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "El componente polimórfico %s en %L en SEQUENCE o de tipo BIND(C) %s"
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "El componente %s del tipo SEQUENCE declarado en %L no tiene el atributo SEQUENCE"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Especificaciones de control de E/S en conflicto en %0 y %1"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Como al extender el tipo '%s' en %L tiene un componente de comatriz, el tipo padre '%s' también debe tener uno"
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "El tipo derivado '%s' que no es extensible en %L no debe ser ABSTRACT"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Especificación errónea para la matriz de tamaño asumido en %C"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the ALLOCATABLE attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "El argumento '%s' del procedimiento elemental en %L no puede tener el atributo ALLOCATABLE"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Longitudes de carácter diferentes en la asignación de puntero en %L"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -83557,7 +83582,7 @@ msgstr "Se sobreescriben los inicializadores desiguales en EQUIVALENCE en %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Se sobreescriben los inicializadores desiguales en EQUIVALENCE en %L"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -83570,13 +83595,13 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "El número de elementos en el constructor de matriz en %L requiere un incremento del límite superior %d permitido.  Vea la opción -fmax-array-constructor"
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Se crea una matriz temporal en %L para el argumento '%s'"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipo de expresión errónea durante la caminata (%d)"
@@ -83679,94 +83704,100 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Symbol '%s' at %L has no IMPLICIT type"
+msgid "%s at %C has no default type"
+msgstr "El símbolo '%s' en %L no tiene tipo IMPLICIT"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variable intrínseca que no es un procedimiento"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return value of function %qs at %L not set"
 msgstr "No se define el valor de devolución de la función '%s' en %L"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Aún no se admite un parámetro de tipo diferido"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "ya existe la declaración del extremo trasero para la variable de módulo %s"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Se declaró la variable '%s' sin uso en %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "El argumento dummy '%s' en %L se declaró INTENT(OUT) pero no se estableció"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type dummy argument '%s' at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "El argumento dummy de tipo derivado '%s' en %L se declaró INTENT(OUT) pero no se estableció y no tiene un inicializador por defecto"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 #| msgid "Unused dummy argument '%s' at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argumento dummy sin uso '%s' en %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 #| msgid "Unused module variable '%s' which has been explicitly imported at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Variable de módulo '%s' sin uso la cual se importó explícitamente en %L"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Se declaró la variable '%s' sin uso en %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Se declaró el parámetro '%s' sin uso en %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' which has been explicitly imported at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Parámetro '%s' sin uso el cual se importó explícitamente en %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "Return value '%s' of function '%s' declared at %L not set"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "No se define el valor de devolución '%s' de la función '%s' declarada en %L"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -83782,29 +83813,29 @@ msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Operador intrínseco desconocido"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Lista de argumentos de función desconocida en %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -85761,6 +85792,9 @@ msgstr "parámetro %qD sin uso"
 #~ msgid "PIC register isn't set up"
 #~ msgstr "el registro PIC aún no está preparado"
 
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "tamaño de operando no válido para el código de operando 'Z'"
+
 #, fuzzy
 #~| msgid "operand is not a condition code, invalid operand code 'Y'"
 #~ msgid "operand is not a condition code, invalid operand code 'I'"
diff --git a/gcc/po/fi.po b/gcc/po/fi.po
index ea21d8c83ea..0430b997c88 100644
--- a/gcc/po/fi.po
+++ b/gcc/po/fi.po
@@ -32,7 +32,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1-b20210321\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2021-03-23 21:16+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -4094,7 +4094,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7746,6 +7746,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17318,12 +17323,12 @@ msgstr "FORMAT-nimiö %d kohdassa %L ei ole määritelty"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "liukulukuvakiota käytetty väärin"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18394,115 +18399,115 @@ msgstr "Tältä valitsimelta puuttuu dokumentaatio"
 msgid "Uses of this option are diagnosed."
 msgstr "%s: oletetaan RTC:n käyttävän UTC:tä...\n"
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr "Sama kuin %s%s (tai kielteisessä muodossa %s%s)."
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, fuzzy, c-format
 msgid "Same as %s%s."
 msgstr "on vaarallista toimia rekursiivisesti hakemistossa %s (sama kuin %s)"
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, fuzzy, c-format
 msgid "Same as %s."
 msgstr "on vaarallista toimia rekursiivisesti hakemistossa %s (sama kuin %s)"
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, fuzzy, c-format
 msgid "%s  Same as %s."
 msgstr "on vaarallista toimia rekursiivisesti hakemistossa %s (sama kuin %s)"
 
-#: opts.cc:1732
+#: opts.cc:1733
 #, fuzzy
 msgid "[available in "
 msgstr "Silmukkamuuttuja"
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[oletus]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr "%llu tavua"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[käytössä]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[ei käytössä]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Yhtään valitsinta halutuilla ominaisuuksilla ei löytynyt\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Mitään ei löytynyt.  Käytä --help=%s näyttämään *kaikki* valitsimet, joita %s-edusta tukee.\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Kaikki valitsimet halutuilla ominaisuuksilla on jo näytetty\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
 "   "
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Seuraavat valitsimet ovat kohdekohtaisia"
 
-#: opts.cc:1961
+#: opts.cc:1962
 #, fuzzy
 msgid "The following options control compiler warning messages"
 msgstr "Seuraavat valitsimet ohjaavat optimointeja"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Seuraavat valitsimet ohjaavat optimointeja"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Seuraavat valitsimet ovat kielestä riippumattomia"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 msgid "The following options control parameters"
 msgstr "Seuraavat valitsimet ohjaavat optimointeja"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Seuraavat valitsimet ovat liittyvät kieleen "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Kieli tukee seuraavia valitsimia "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Seuraavia valitsimia ei ole dokumentoitu"
 
-#: opts.cc:1991
+#: opts.cc:1992
 #, fuzzy
 msgid "The following options take separate arguments"
 msgstr "Seuraavia valitsimia ei ole dokumentoitu"
 
-#: opts.cc:1993
+#: opts.cc:1994
 #, fuzzy
 msgid "The following options take joined arguments"
 msgstr "Seuraavia valitsimia ei ole dokumentoitu"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Seuraavat valitsimet ovat kieleen liittyviä"
 
@@ -18898,73 +18903,73 @@ msgstr "pituusmääre strfmon-muotoilussa"
 msgid "<command-line>"
 msgstr "<komentorivi>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "puuttuva operandi"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "virheellinen etuliite ”0b” liukulukuvakiolle"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "virheellinen %%G-tila"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "Virheellinen liukulukuoperaatio"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -18981,18 +18986,18 @@ msgid "invalid %%r value"
 msgstr "virheellinen %%r-arvo"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "virheellinen %%R-arvo"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
@@ -19022,7 +19027,7 @@ msgstr "virheellinen %%M-arvo"
 msgid "invalid %%U value"
 msgstr "virheellinen %%U-arvo"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
@@ -19032,7 +19037,7 @@ msgstr "virheellinen %%s-arvo"
 msgid "invalid %%C value"
 msgstr "virheellinen %%C-arvo"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
@@ -19045,7 +19050,7 @@ msgstr "uudelleensijoitusvirhe"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "virheellinen %%xn-koodi"
@@ -19129,35 +19134,35 @@ msgstr "virheellinen lauseke kohdemuuttujana"
 msgid "unrecognized supposed constant"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Virheellinen käsky"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19166,28 +19171,28 @@ msgstr "fr30_print_operand: tuntematon koodi"
 msgid "invalid operand for code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19600,97 +19605,97 @@ msgstr "virheellinen rotate-käsky"
 msgid "Expected register or constant integer."
 msgstr "Odotettiin nimetöntä rajapintaa kohdassa %C"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "virheellinen const_double-operandi"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "virheellinen rekisterin ”%s” käyttö"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "tuntematon move-käsky:"
@@ -19725,7 +19730,7 @@ msgstr "Virheellinen operaatiokoodi"
 msgid "invalid %%P operand"
 msgstr "virheellinen %%P-operandi"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -19771,8 +19776,8 @@ msgstr "Nolla ei ole kelvollinen lausekenimiö kohdassa %C"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "virheellinen ”%%%c”:n käyttö"
@@ -19808,7 +19813,7 @@ msgid "post-increment address is not a register"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "virheellinen osoite"
 
@@ -19979,7 +19984,7 @@ msgstr "yritettiin käyttää ominaisuutta, jolle ei ole tukea: ”%s”"
 msgid "unsupported memory expression:"
 msgstr "kiintopistevakiot ovat GCC-laajennos"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -20040,151 +20045,151 @@ msgstr "Tuota little-endian-koodia"
 msgid "bad move"
 msgstr "Siirrä alas"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 #, fuzzy
 msgid "Bad 128-bit move"
 msgstr "Käytä 128-bittistä long double -tyyppiä"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 msgid "invalid %%A value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "virheellinen %%D-arvo"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "virheellinen vektoripermutaatiovakio"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Älä luo #line-direktiivejä"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 #, fuzzy
 msgid "Bad GPR fusion"
 msgstr "Virheelliset merkit"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "virheellinen muunnos gimple-kutsussa"
@@ -20667,7 +20672,7 @@ msgstr "ehdokas 1:"
 msgid "  after user-defined conversion:"
 msgstr "Ota käyttöön käyttäjän määrittelemät käskyt"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
@@ -21184,7 +21189,7 @@ msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 msgid "Driving:"
 msgstr "Varoitus:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -21371,11 +21376,11 @@ msgstr "lohkolaite"
 msgid "implied END DO"
 msgstr "syötteen loppu"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "sijoitus"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 #, fuzzy
 msgid "pointer assignment"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
@@ -21394,224 +21399,224 @@ msgstr ""
 "                  muuten yksinkertaisia\n"
 "  never, simple   tee aina yksinkertaisia varmuuskopioita\n"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 #, fuzzy
 msgid "elemental procedure"
 msgstr "RPC: Proseduuri ei ole käytettävissä"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 msgid "allocatable argument"
 msgstr "Virheellinen argumentti"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "ei argumentteja"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "valinnainen argumentti"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr "osoitinargumentti"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr "kohdeargumentti"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr "arvoargumentti"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 msgid "volatile argument"
 msgstr "ylimääräinen %<volatile%>"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "oletetaan palauttavan %<id%> ja hyväksyvän"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "oletetaan palauttavan %<id%> ja hyväksyvän"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 msgid "coarray argument"
 msgstr "Virheellinen argumentti"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 #, fuzzy
 msgid "parametrized derived type argument"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "Virheellinen argumentti"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 #, fuzzy
 msgid "NO_ARG_CHECK attribute"
 msgstr "liian pitkä riviargumentti"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 #, fuzzy
 msgid "array result"
 msgstr "MD5-tulos on:\n"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "tulosta ei voi kirjoittaa: %s"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, fuzzy, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, fuzzy, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, fuzzy, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, fuzzy, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, fuzzy, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, fuzzy, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, fuzzy, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, fuzzy, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "Silmukkamuuttuja"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 #, fuzzy
 msgid "iterator variable"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "Ennenaikainen säännöllisen lausekkeen loppu"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 #, fuzzy
 msgid "STAT variable"
 msgstr "tiedoston tilan lukeminen epäonnistui"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%qD ei ole muuttuja"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 #, fuzzy
 msgid "item in READ"
 msgstr "Soita numero"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "uutta arkistoa ei voi lukita"
@@ -21625,27 +21630,27 @@ msgstr "Odotettiin PARAMETER-symbolia kompleksivakiossa kohdassa %C"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, fuzzy, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, fuzzy, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, fuzzy, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "virheellinen taulukkosijoitus"
@@ -22587,7 +22592,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "Vain 1k-lohkot/vyöhykkeet ovat tuettuja"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaksivirhe %s-lauseessa kohdassa %C"
@@ -22959,7 +22964,7 @@ msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -23057,10 +23062,10 @@ msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -23195,7 +23200,7 @@ msgstr "tiedoston ”%s” otsaketta ei voi lukea"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "siirros vakiomerkkijonon rajojen ulkopuolelle"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE esitelty täällä"
@@ -25029,7 +25034,7 @@ msgstr "suuri kokonaisluku implisiittisesti katkaistu etumerkittömäksi tyypiks
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25805,7 +25810,7 @@ msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26933,14 +26938,14 @@ msgstr "%qD ei ole %qD:n jäsen"
 msgid "using a dangling pointer to %qD"
 msgstr "epäkelpo osoitintila %qs"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
@@ -26985,7 +26990,7 @@ msgstr "%qD on tavallisesti ei-staattinen funktio"
 msgid "call to %qD"
 msgstr "%J%qD esitelty turhaan uudestaan"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
@@ -28054,7 +28059,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "virheellinen muunnos gimple-kutsussa"
@@ -29014,7 +29019,7 @@ msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "komentorivivalitsin %qs on kelvollinen kohteelle %s, mutta ei kohteelle %s"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "polku puuttuu %qs:n jälkeen"
@@ -29054,12 +29059,12 @@ msgstr "valitsimia -mcorea ja -mcoreb ei voi käyttää yhdessä"
 msgid "unrecognized argument in option %qs"
 msgstr "tuntematon komentorivivalitsin %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Kelvolliset argumentit:"
@@ -29214,7 +29219,7 @@ msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "valitsin %qs ei ole enää tuettu"
@@ -29254,182 +29259,182 @@ msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr "Kelvolliset argumentit --quoting-style-valitsimelle ovat:"
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "tuntematon komentorivivalitsin ”%s”"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "tuntematon komentorivivalitsin ”%s”"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "tuntematon komentorivivalitsin ”%s”"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "tuntematon konetila %qs"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "dwarfin versio %wu ei ole tuettu"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "tuntematon komentorivivalitsin ”%s”"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, fuzzy, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "tunnistamaton gcc:n vianjäljitysvalitsin: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "tunnistamaton komentorivivalitsin %<-fdump-%s%>"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "%s: valitsin ”%s” on moniselitteinen\n"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "tuntematon komentorivivalitsin %qs"
@@ -30103,187 +30108,187 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "funktion palauttava funktio"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%qD ei ole muuttuja"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "solmun tyyppi on tuntematon"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "virheellinen IACC-argumentti"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, fuzzy, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, fuzzy, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr "%qD esiteltiin tyyppinä %qs, mikä edellyttää oletusnäkyvyyttä"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, fuzzy, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, fuzzy, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, fuzzy, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr "Sama kuin --help=target"
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, fuzzy, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr "Sama kuin --help=target"
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, fuzzy, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "Sama kuin --help=target"
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, fuzzy, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify epäonnistui"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "epäkelpo osoitintila %qs"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -31958,27 +31963,27 @@ msgstr "sulkumerkkien käyttö laskulausekkeen ympärillä on suositeltavaa |-op
 msgid "target specific builtin not available"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -32799,7 +32804,7 @@ msgstr "%qE-attribuuttia ei huomioida koska %qT on jo määritelty"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE-attribuuttia ei huomioida koska %qT on jo määritelty"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE-attribuutti vaikuttaa vain julkisiin objekteihin"
@@ -34905,7 +34910,7 @@ msgstr "virheellinen loppuliite ”%.*s” liukulukuvakiolla"
 msgid "traditional C rejects string constant concatenation"
 msgstr "perinteinen C ei salli merkkijonovakioiden katenointia"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36583,7 +36588,7 @@ msgstr "liikaa syötetiedostoja"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "tuntematon cc_attr-arvo"
@@ -36615,15 +36620,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "tuntematon komentorivivalitsin %qs"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "kelvolliset argumentit ovat: %s; tarkoititko %qs?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "kelvolliset argumentit ovat: %s"
@@ -36708,48 +36713,48 @@ msgstr "-mcpu=%s ei ole kelvollinen"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "-mcpu=%s ei ole kelvollinen"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "funktion palauttava funktio"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "funktion palauttava funktio"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "funktion palauttava funktio"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
@@ -37234,13 +37239,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "%s %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, fuzzy, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr "%s: kentän ”%s” arvon on oltava välillä %d...%d"
@@ -37508,7 +37513,7 @@ msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "kaksinkertainen <%s>:n määrittely"
@@ -37552,7 +37557,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, fuzzy, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr "%qE-attribuuttia ei huomioida koska %qT on jo määritelty"
@@ -37640,327 +37645,327 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr ""
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr "virheellinen %%h-arvo"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "tuntematon valitsin -%s"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Funktio %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "tuntematon konetila %qs"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, fuzzy, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr "-Wformat-y2k jätetty huomiotta ilman valitsinta -Wformat"
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s ei tue %%n$-operandinumeromuotoilua"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, fuzzy, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, fuzzy, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "tuntematon värimoodi"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
@@ -38145,13 +38150,13 @@ msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -38292,17 +38297,17 @@ msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 msgid "%qE attribute only applies to variables"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "Funktio %qs"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
@@ -38509,7 +38514,7 @@ msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
@@ -38564,7 +38569,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "Muodostin %qs"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
@@ -38670,7 +38675,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -38720,32 +38725,32 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
@@ -38753,22 +38758,22 @@ msgstr "epäkelpo vektorityyppi attribuutille %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qE"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "<tuntematon>"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -38842,17 +38847,17 @@ msgstr "%<-fpie%> ei ole tuettu"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> ei ole tuettu"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "valitsimet %s ja %s ovat toisensa poissulkevat"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
@@ -39168,7 +39173,7 @@ msgstr "virheellinen sisäinen makro ”%s”"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "virheellinen sisäinen makro ”%s”"
@@ -39766,751 +39771,751 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
 "Käyttö: %s KOMENTO [ARGUMENTTI]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "Tuntematon valitsin: %s %s %s"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, fuzzy, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "__COUNTER__ lavennettu direktiivin sisällä valitsimella -fdirectives-only"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-käskykanta poistettu käytöstä, käytetään 387-aritmetiikkaa"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-käskykanta poistettu käytöstä, käytetään SSE-aritmetiikkaa"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "”%s”-liitännäinen on yhteensopiva."
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "tuntematon valitsin -%s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, fuzzy, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, fuzzy, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, fuzzy, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, fuzzy, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, fuzzy, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, fuzzy, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, fuzzy, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, fuzzy, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "”%s”-liitännäinen on yhteensopiva."
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "Rinnakkaiset työt (-j) eivät ole tuettuja tällä alustalla."
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, fuzzy, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, fuzzy, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, fuzzy, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, fuzzy, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "valitsin -mmultiple ei ole tuettu little-endian-järjestelmissä"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -40862,7 +40867,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
@@ -41985,55 +41990,55 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "tuntematon #pragma GCC coprocessor %E"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
 # XXX
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, fuzzy, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "tiedostoa %s ei voi avata"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "määrittelemättömän tyypin %<%s %E%> epäkelpo käyttö"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
@@ -42053,66 +42058,71 @@ msgstr "Älä varoita Microsoft-laajennosten käytöstä"
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, fuzzy, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "Funktio %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -42585,97 +42595,97 @@ msgstr "Vanhentunut. Tämä valitsin ei vaikuta mihinkään"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, fuzzy, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, fuzzy, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, fuzzy, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, fuzzy, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ei ole sallittu"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s on virheellinen"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
@@ -44081,7 +44091,7 @@ msgstr "ei voi laittaa volatile-kenttäistä objektia rekisteriin"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "alustamaton vakio %qD on virheellinen C++-kielessä"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, fuzzy, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%qE nimiavaruudessa %qE ei nimeä tyyppiä"
@@ -44268,7 +44278,7 @@ msgstr "tallennusluokka annettu parametrille %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "tallennusluokka annettu nimettömälle parametrille"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "tallennusluokka annettu typenamelle"
@@ -44437,7 +44447,7 @@ msgstr "tyyppinimi esitelty taulukon palauttavan funktiona"
 msgid "function definition has qualified void return type"
 msgstr "funktion määrittely oikeuttaa tyhjän paluutyypin"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tyyppimääritteet jätetään huomiotta funktion paluutyypissä"
@@ -44564,7 +44574,7 @@ msgstr "ISO C kieltää const- ja volatile-funktiotyypit"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "muuttuja tai kenttä %qE esitelty voidiksi"
@@ -44765,7 +44775,7 @@ msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kieless
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qs määritelty tietueen kentälle %qE"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "esittely ei esittele mitään"
@@ -44815,7 +44825,7 @@ msgstr "structilla ei ole nimettyjä jäseniä"
 msgid "struct has no members"
 msgstr "structilla ei ole jäseniä"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "joustava taulukkojäsen unionissa"
@@ -44860,7 +44870,7 @@ msgstr "%<enum %E%>:n uudelleenmäärittely"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "annettu tila on liian pieni luetelluille arvoille"
@@ -44907,7 +44917,7 @@ msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C rajoittaa luetellun tyypin arvot %<int%>-tyypin arvoalueelle"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
@@ -44937,7 +44947,7 @@ msgstr "%qD:lle ei ole edellistä prototyyppiä"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
@@ -45052,12 +45062,12 @@ msgstr "argumentti %qD ei vastaa sisäistä prototyyppiä"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametri %qD on alustettu"
@@ -47084,7 +47094,7 @@ msgstr "liian vähän argumentteja"
 msgid "collapsed loops not perfectly nested"
 msgstr "liian vähän argumentteja"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
@@ -47215,12 +47225,12 @@ msgstr "  siirtyy catch-lohkoon"
 msgid "variant %qD is not a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47481,7 +47491,7 @@ msgstr "void-lausekkeen epäkelpo käyttö"
 msgid "invalid use of flexible array member"
 msgstr "joustavien taulukkoalkioiden epäkelpo käyttö"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
@@ -48444,12 +48454,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen alustus"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
@@ -48490,7 +48500,7 @@ msgstr "alustusalkiota ei pystytä laskemaan latausajankohtana"
 msgid "invalid initializer"
 msgstr "epäkelpo alustin"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
@@ -48505,8 +48515,8 @@ msgstr "alustimen lopussa on ylimääräinen lohko"
 msgid "braces around scalar initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "joustavan taulukkojäsenen alustaminen sisäkkäisessä asiayhteydessä"
@@ -48596,7 +48606,7 @@ msgstr "ylimääräisiä alkioita struct-alustimessa"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "Varoita mahdollisesti puuttuvista aaltosuluista alustimissa"
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen ei-staattinen alustus"
@@ -49947,7 +49957,7 @@ msgstr "%<operator new%>:n on palautettava tyyppi %qT"
 msgid "%q#D is private within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
@@ -49957,7 +49967,7 @@ msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 msgid "%q#D is protected within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qD esiteltiin täällä"
@@ -49972,7 +49982,7 @@ msgstr "tässä yhteydessä"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "annettu NULL funktion %2$qD ei-osoitinargumenttina %1$P"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, gcc-internal-format
 msgid "  declared here"
@@ -50329,7 +50339,7 @@ msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 msgid "call to non-function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -50912,7 +50922,7 @@ msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 msgid "next member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
@@ -51033,7 +51043,7 @@ msgstr "epäkelpo tallennusluokka funktiolle %qs"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
@@ -51102,7 +51112,7 @@ msgstr "vertailu ”etumerkitön lauseke < 0” on aina epätosi"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -51149,7 +51159,7 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -51274,7 +51284,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -51373,7 +51383,7 @@ msgstr "jäsen %qD on alustamaton viittaus"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -51449,7 +51459,7 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -51516,189 +51526,189 @@ msgstr "%qD:n poistettu määrittely"
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "poistettu funktio %q+D"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s%qs%s ei ole sallittu"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "odotettiin %<template%>"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, fuzzy, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "virheellinen %%s-arvo"
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Jako nollalla kohdassa %L"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "taulukon alustus ei-vakiolla"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Odottamaton %s-lause kohdassa %C"
@@ -52299,7 +52309,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "paluutyyppi %q#T on vaillinainen"
@@ -52396,7 +52406,7 @@ msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 msgid "no suspend point info for %qD"
 msgstr "%qD:lle ei ole edellistä prototyyppiä"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -52418,23 +52428,23 @@ msgstr "osoittimet eivät ole sallittuja case-arvoja"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
@@ -52921,7 +52931,7 @@ msgstr "edellisestä esittelystä %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "edellinen esittely %q+D"
@@ -53322,2279 +53332,2279 @@ msgstr "%qD ei ole funktiomalli"
 msgid "%q#T is not a class"
 msgstr "%q#T ei ole luokka"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nimeää %q#T:n, joka ei ole tyyppi"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
 # semi-fuzzy
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonyymillä structilla ei voi olla funktiojäseniä"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T:n attribuutin on oltava %qs-avainsanan perässä"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "useita tyyppejä yhdessä esittelyssä"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ kieltää nimettömät structit"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "muuttujalla %q#D on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD esitelty viitteenä, mutta alustamatta"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, fuzzy, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD:n koko muistissa ei ole tunnettu"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD:n koko muistissa ei ole vakio"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  voit kiertää tämän poistamalla alustimen"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "liikaa alustimia %qT:lle"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "muuttuvakokoinen yhdysliteraali"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D on vaillinaista tyyppiä"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalaariobjekti %qD vaatii yhden alkion alustimeensa"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "C++98:ssa %qD on alustettava muodostimessa, ei käyttäen %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "taulukko %qD alustettu sulkujen sisällä olevalla merkkijonoliteraalilla %qE"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, fuzzy, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, fuzzy, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-tallennusluokkamääritteen käyttö"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D:n esittelyllä ei ole alustimia"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "%q+D:n edellinen esittely"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE-attribuutti soveltuu vain muuttujiin ja funktioihin"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktio %q#D alustetaan kuin muuttuja"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "nimike %qD esitelty muttei määritelty"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%qD:n poistettu määrittely"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "%qD ei ole malli"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, fuzzy, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "virheellinen IACC-argumentti"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, fuzzy, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "keskeytysfunktiolla on oltava void-paluutyyppi"
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
 # semi-fuzzy
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, fuzzy, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ kieltää jäsenen %qD alustuksen"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "taulukon %qD koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon %qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "taulukon koon ylivuoto"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD:n esittely void-taulukkona"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "luodaan void-taulukko"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD:n esittely funktioiden taulukkona"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "luodaan funktioiden taulukko"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "luodaan viitteiden taulukko"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD:n esittely funktiojäsenten taulukkona"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "luodaan funktiojäsenten taulukkoa"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "nimetön muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktion määrittely ei esittele parametrejä"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ kieltää muuttujan %qs esittelyn ilman tyyppiä"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "sekä %<signed%> että %<unsigned%> määritelty %qs:lle"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, fuzzy, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "tallennusluokka annettu malliparametrille %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, fuzzy, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuuttia ei huomioida"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "tarpeettomat sulkeet %qs:n esittelyssä"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses"
 msgstr "Odotettiin oikeaa sulkumerkkiä lausekkeessa kohdassa %C"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs esitelty taulukon palauttavan funktiona"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%>-funktio palauttaa ei-void-arvon"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "muodostin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "muodostimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hajottimilla ei voi olla parametreja"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, fuzzy, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ylimääräinen kvalifiointi %<%T::%> jäsenelle %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "vain muodostimen esittely voi olla %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, fuzzy, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "%qD ei ole funktiomalli"
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "tiedostoa %s ei voi avata"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "tallennusluokka %<auto%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "tallennusluokka %<register%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, fuzzy, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, fuzzy, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "virheellinen muodostin; tarkoitit todennäköisesti %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, fuzzy, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ kieltää ?:-operaattorin ylikuormituksen"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD:n on otettava joko nolla tai yksi argumenttia"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD:n on otettava joko yksi tai kaksi argumenttia"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, fuzzy, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, fuzzy, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, fuzzy, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "<paluuarvo> "
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "lueteltu tyyppi määritelty täällä"
@@ -55606,111 +55616,111 @@ msgstr "lueteltu tyyppi määritelty täällä"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD-viittaus on moniselitteinen"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "on ristiriidassa %q+#D:n edellisen esittelyn kanssa"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT määritelty monella suoralla kannoalla"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT määritelty suoralla virtuaalisella kannalla"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
@@ -55719,82 +55729,82 @@ msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, fuzzy, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "          %s"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%q+D:n oletustyyppi on %<int%>"
@@ -56645,7 +56655,7 @@ msgstr "perustyypin %qT kaksoiskappale virheellinen"
 msgid "type %qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
@@ -57704,7 +57714,7 @@ msgstr "virtuaalinen ei-luokkafunktio %qs"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE ei ole luokka, nimiavaruus eikä lueteltu tyyppi"
@@ -58448,7 +58458,7 @@ msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
@@ -59158,12 +59168,12 @@ msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 msgid "cannot expand initializer for member %qD"
 msgstr "ei voi laajentaa alustinta jäsenelle %<%D%>"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
@@ -59761,7 +59771,7 @@ msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole obj
 msgid "%qT not permitted in template argument"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -60625,7 +60635,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
@@ -61633,7 +61643,7 @@ msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "%qT ei ole malli"
@@ -61726,198 +61736,198 @@ msgstr "taulukon palauttava funktio"
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "luodaan void-taulukko"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "attribuutille %qE annettu väärä määrä argumentteja"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "ohjelman alustusta yritettäessä"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 msgid "%s %#qS"
 msgstr ""
@@ -61925,82 +61935,82 @@ msgstr ""
 "%s, %s, %s, %s,\n"
 "%s, %s ja %s.\n"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "%q+D:n edellinen esittely oli täällä"
@@ -62012,163 +62022,163 @@ msgstr "%q+D:n edellinen esittely oli täällä"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Tiedostoa ”%s” on jo tarkasteltu.\n"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qE:n muunnos tyypistä %qT tyyppiin %qT ei ole yksiselitteinen"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
@@ -62479,7 +62489,7 @@ msgstr "perustyypin %qT kaksoiskappale virheellinen"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "        %qD"
@@ -62888,27 +62898,27 @@ msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
@@ -62916,22 +62926,22 @@ msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -64186,222 +64196,222 @@ msgstr "%J%qD esitelty turhaan uudestaan"
 msgid "declaration of %q#T"
 msgstr "edellinen esittely %q+D"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "muodostinsyntaksia on käytetty, mutta %qT-tyypin muodostinta ei ole esitelty"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "%qE:n kaventava muunnos tyypistä %qT tyyppiin %qT { }:n sisällä"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "merkkitaulukon alustusmerkkijono on liian pitkä"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "alustettavassa unionissa ei ole kenttää %qD"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, fuzzy, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "ylimääräisiä alkioita union-alustimessa"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, fuzzy, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "PRINT_OPERAND null-osoitin"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, fuzzy, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "sijoitus yhteensopimattomasta osoitintyypistä"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
@@ -65351,7 +65361,7 @@ msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava vakio"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "epäkelpo osoitintila %qs"
@@ -66445,12 +66455,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "alustusmerkkijono typistetty, jotta se täsmäisi muuttujaan kohdassa %L"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
@@ -66633,7 +66643,7 @@ msgstr "Kaksoiskappale %s-spesifikaatio kohdassa %C"
 msgid "deferred type parameter at %C"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "odotettiin kokonaislukulauseketta"
@@ -68645,7 +68655,7 @@ msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -68916,7 +68926,7 @@ msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
@@ -69034,7 +69044,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(%qs:n alustuksen lähistöllä)"
@@ -69044,7 +69054,7 @@ msgstr "(%qs:n alustuksen lähistöllä)"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
@@ -69175,7 +69185,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -69391,12 +69401,12 @@ msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
@@ -69506,562 +69516,562 @@ msgstr "ehtolausekkeessa on tyyppiristiriita"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L on jo liitetty toiseen varsinaiseen argumenttiin"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Odotettiin proseduuriosoitinta argumentille ”%s” kohdassa %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, fuzzy, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "ei voi emuloida %qs"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, fuzzy, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "ei voi kirjoittaa tiedostoon %s: %m"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei saa olla OPTIONAL"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
@@ -70245,7 +70255,7 @@ msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
@@ -70796,7 +70806,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -71363,7 +71373,7 @@ msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
@@ -73227,8 +73237,8 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
@@ -75195,710 +75205,720 @@ msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, fuzzy, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, fuzzy, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, fuzzy, gcc-internal-format
 #| msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Erisuuret merkkipituudet (%ld/%ld) merkkijonossa %s kohdassa %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, fuzzy, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, fuzzy, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, fuzzy, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, fuzzy, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT-tyyppiä ”%s” käytetty kohdassa %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, fuzzy, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, fuzzy, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "%s: paniikki: Virheellinen ”l_value” %d\n"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "%s: paniikki: Virheellinen ”l_value” %d\n"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, fuzzy, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Arvo sallitun välin ulkopuolella."
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of array reference at %C"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Virheellinen taulukkoviitemuoto kohdassa %C"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -75907,12 +75927,12 @@ msgstr "muuttuvakokoista objektia ei voi alustaa"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -75921,293 +75941,293 @@ msgstr "muuttuvakokoista objektia ei voi alustaa"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "<tyyppivirhe>"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "tulosta ei voi kirjoittaa: %s"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
@@ -76216,284 +76236,284 @@ msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABL
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %d-kaltainen"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "”%s” ei ole kelvollinen makron nimi, sillä se on C++:n operaattori"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -76501,208 +76521,208 @@ msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Odotettiin alustuslauseketta CASE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Käyttämätön parameteri ”%s” esitelty kohdassa %L"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -76710,114 +76730,114 @@ msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Merkkijonon pituus kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, fuzzy, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Varattavalla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
@@ -76825,872 +76845,872 @@ msgstr ""
 "  tai:  %s -l [SIGNAALI]...\n"
 "  tai:  %s -t [SIGNAALI]...\n"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Ulkoisella objektilla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktiolla ”%s” kohdassa %L täytyy olla skalaaritulos"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla taulukkoarvoinen"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla rekursiivinen"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa RESULT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribuutti on ristiriidassa FUNCTION-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla skalaari"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, fuzzy, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, fuzzy, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Proseduurilla ”%s” kohdassa %C on eksplisiittinen rajapinta ja sillä ei saa olla attribuutteja, jotka on esitelty kohdassa %L"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Ei voi sijoitaa nimettyyn vakioon kohdassa %C"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
@@ -78583,7 +78603,7 @@ msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -78595,12 +78615,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Luodaan väliaikainen komentotiedosto %s\n"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
@@ -78692,81 +78712,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
+
+#: fortran/trans-decl.cc:1798
 #, fuzzy, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, fuzzy, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "%Jmuuttuja %qD esitelty %<inline%>:ksi"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Käyttämätön parameteri ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -78781,27 +78806,27 @@ msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "last-op"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -80620,6 +80645,10 @@ msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result
 msgid "unused name %qE"
 msgstr "käyttämätön parametri %qD"
 
+#, fuzzy
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "fr30_print_operand: virheellinen %%x-koodi"
+
 #, fuzzy
 #~ msgid "invalid conversion from type %<* __vector_quad%>"
 #~ msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
diff --git a/gcc/po/fr.po b/gcc/po/fr.po
index fd999309f28..552a0414fec 100644
--- a/gcc/po/fr.po
+++ b/gcc/po/fr.po
@@ -97,10 +97,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 13.1-b20230409\n"
+"Project-Id-Version: gcc 13.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
-"PO-Revision-Date: 2023-04-12 10:39+0200\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
+"PO-Revision-Date: 2023-04-27 16:11+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
 "Language: fr\n"
@@ -4087,7 +4087,7 @@ msgstr "utiliser le dialecte ISO de Modula-2"
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr "spécifier l'ordre des bibliothèques. Les bibliothèques peuvent être spécifiées par des abréviations séparées par des virgules : log,min,pim,iso ou par noms de répertoires : m2log,m2min,m2pim,m2iso."
 
 #: m2/lang.opt:127
@@ -7731,6 +7731,11 @@ msgstr "Activer le dépliage conservatif de petites boucles"
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr "-mlam=[none|u48|u57] Instrumentalise la position des méta données dans les pointeurs de données utilisateurs."
 
+#: config/i386/i386.opt:1280
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Supporter les fonctions internes AMX-COMPLEX et la génération de code."
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17268,12 +17273,12 @@ msgstr "l'opérande « %%l » n'est pas une étiquette"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "constante flottante mal utilisée"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18347,63 +18352,63 @@ msgstr "Il manque la documentation pour cette option."
 msgid "Uses of this option are diagnosed."
 msgstr "Les utilisations de cette option sont diagnostiquées."
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr "Comme %s%s (ou, dans la forme négative, %s%s)."
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr "Comme %s%s."
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr "Comme %s."
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  Comme %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr "[disponible dans "
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[par défaut]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr "%llu octets"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[activé]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[désactivé]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Aucune option avec les caractéristiques désirées a été trouvée\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Aucune trouvée.  Utilisez --help=%s pour voir *toutes* les options acceptées par l'interface %s.\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Toutes les options avec les caractéristiques désirées ont déjà été affichées\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -18412,47 +18417,47 @@ msgstr ""
 "  Arguments valides connus pour l’option %s:\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Les options suivantes sont spécifiques à la cible"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Les options suivantes contrôlent les messages d’avertissement du compilateur"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Les options suivantes contrôlent les optimisations"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Les options suivantes sont indépendantes du langage"
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr "Les options suivantes contrôlent les paramètres"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Les options suivantes sont uniquement spécifiques au langage "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Les options suivantes sont prises en charge par le langage "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Les options suivantes ne sont pas documentées"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Les options suivantes prennent des arguments séparées"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Les options suivantes prennent des arguments groupés"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Les options suivantes concernent des langages"
 
@@ -18835,72 +18840,72 @@ msgstr "modificateur de longueur dans le format de strfmon"
 msgid "<command-line>"
 msgstr "<ligne-de-commande>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "opérande non supporté pour le code « %c »"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "opérande invalide pour « %%%c »"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante vecteur invalide"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "opérande en virgule flottante ou registre vecteur incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "opérande de registre incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "opérande manquant"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "constante invalide"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "opérande invalide"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "préfixe d'opérande invalide « %%%c »"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "mode d'adresse invalide"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "impossible de combiner les vecteurs GNU et SVE dans l'opération binaire"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "« %%& » utilisé sans référence à un TLS dynamique local"
@@ -18917,18 +18922,18 @@ msgid "invalid %%r value"
 msgstr "valeur %%r invalide"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "valeur %%R invalide"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
@@ -18958,7 +18963,7 @@ msgstr "valeur %%M invalide"
 msgid "invalid %%U value"
 msgstr "valeur %%U invalide"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
@@ -18968,7 +18973,7 @@ msgstr "valeur %%s invalide"
 msgid "invalid %%C value"
 msgstr "valeur %%C invalide"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
@@ -18981,7 +18986,7 @@ msgstr "relocalisation unspec inconnue"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "valeur %%xn invalide"
@@ -19064,35 +19069,35 @@ msgstr "UNSPEC invalide comme opérande : %d"
 msgid "unrecognized supposed constant"
 msgstr "constante supposée non reconnue"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "opérande shift invalide"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruction Thumb établie"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruction établie dans la séquence conditionnelle"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Opérande non supporté pour le code « %c »"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19101,26 +19106,26 @@ msgstr "Opérande non supporté pour le code « %c »"
 msgid "invalid operand for code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "instruction jamais exécutée"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "code de format Maverick « %c » obsolète"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversion invalide depuis le type %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversion invalide vers le type %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "opération non permise sur le type %<bfloat16_t%>"
 
@@ -19485,97 +19490,97 @@ msgstr "constante en virgule flottante invalide"
 msgid "Expected register or constant integer."
 msgstr "Registre ou constante entière attendus."
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC invalide comme opérande"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "utilisation invalide du registre « %s »"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "utilisation invalide de la sortie du fanion asm"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "taille d'opérande invalide pour le code d'opérande « 0 »"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « z »"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, c-format
-msgid "invalid operand type used with operand code 'Z'"
-msgstr "type opérande invalide utilisé avec le code d'opérande « Z »"
+msgid "invalid operand type used with operand code '%c'"
+msgstr "type opérande invalide utilisé avec le code d'opérande « %c »"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "taille d'opérande invalide pour le code d'opérande « Z »"
+msgid "invalid operand size for operand code '%c'"
+msgstr "taille d'opérande invalide pour le code d'opérande « %c »"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « Y » invalide"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « D » invalide"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « %c » invalide"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "l'opérande n'est pas une référence mémoire avec décalage, code d'opérande « H » invalide"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « K » invalide"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « r » invalide"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « R » invalide"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « R » invalide"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "contrainte invalide pour l'opérande"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, c-format
 msgid "invalid vector immediate"
 msgstr "immédiat vecteur invalide"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "mode insn inconnu"
 
@@ -19606,7 +19611,7 @@ msgstr "opération invalide sur %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "opérande %%P invalide"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -19651,8 +19656,8 @@ msgstr "« %%%c » n'est pas un préfixe d'opérande valide"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "utilisation invalide de « %%%c »"
@@ -19684,7 +19689,7 @@ msgid "post-increment address is not a register"
 msgstr "le post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "mauvaise adresse"
 
@@ -19842,7 +19847,7 @@ msgstr "adresse constante non supportée :"
 msgid "unsupported memory expression:"
 msgstr "expression mémoire non supportée :"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, c-format
 msgid "invalid vector operand"
 msgstr "opérande vectoriel invalide"
@@ -19894,143 +19899,143 @@ msgstr "%<-mquad-memory%> n'est pas disponible en mode petit-boutiste"
 msgid "bad move"
 msgstr "mauvais déplacement"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "Mauvais déplacement sur 128 bits"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, c-format
 msgid "invalid %%A value"
 msgstr "valeur %%A invalide"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "valeur %%D invalide"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "valeur %%t invalide"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "valeur %%V invalide"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "valeur %%z invalide"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valeur %%y invalide, essayez d'utiliser la contrainte « Z »"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Mélange invalide de types en virgule flottante IEEE 128 bits et IBM 128 bits"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argument AltiVec passé à une fonction sans prototype"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr "N'a pu générer de valeur addis pour la fusion"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Impossible de générer un offset load/store pour la fusion"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "Mauvaise fusion GPR"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "conversion invalide depuis le type %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "conversion invalide vers le type %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "conversion invalide depuis le type %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "conversion invalide vers le type %<__vector_pair%>"
 
@@ -20487,7 +20492,7 @@ msgstr "candidat :"
 msgid "  after user-defined conversion:"
 msgstr "  après la conversion définie par l'utilisateur :"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "le candidat est :"
@@ -20952,7 +20957,7 @@ msgstr "Désaccord de la limite du tableau pour la dimension 2 du tableau (%ld/%
 msgid "Driving:"
 msgstr "Pilotage:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argument effectif de INTENT = OUT/INOUT"
 
@@ -21110,11 +21115,11 @@ msgstr "bloc IF"
 msgid "implied END DO"
 msgstr "END DO implicite"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "affectation"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "affectation de pointeur"
 
@@ -21122,199 +21127,199 @@ msgstr "affectation de pointeur"
 msgid "simple IF"
 msgstr "IF simple"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "procédure élémentaire"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr "argument qui peut être alloué"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr "argument asynchrone"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "argument optionnel"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr "argument pointeur"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr "argument cible"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr "argument valeur"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr "argument volatile"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr "argument de forme tacite (assumed-shape)"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr "argument de rang tacite (assumed-rank)"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr "argument co-tableau"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr "argument de type dérivé paramétrisé"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr "argument polymorphique"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr "attribut NO_ARG_CHECK "
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr "argument de type tacite (assumed-type)"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr "résultat tableau"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr "résultat pointeur ou allouable"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr "résultat avec une longueur de caractères non constante"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr "procédure bind(c)"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Contexte invalide pour un pointeur NULL() à %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur numérique unaire %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Entités de type dérivé inattendues dans l'opérateur numérique intrinsèque binaire %%<%s%%> à %%L"
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur numérique binaire %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de concaténation de chaînes à %%L sont %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur logique %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "L'opérande de l'opérateur .not. à %%L est %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Les quantités COMPLEX ne peuvent pas être comparées à %L"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Les valeurs logiques à %%L doivent être comparées avec %s au lieu de %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de comparaison %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Opérateur %%<%s%%> inconnu à %%L; vouliez-vous utiliser %%<%s%%> ?"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Opérateur %%<%s%%> inconnu à %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur utilisateur %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur utilisateur %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangs inconsistant pour l'opérateur à %%L et %%L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "Variable de boucle"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr "variable d'itérateur"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr "Expression de départ dans la boucle DO"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr "Expression de fin dans la boucle DO"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr "Expression de pas dans la boucle DO"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr "objet DEALLOCATE"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr "objet ALLOCATE"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr "élément dans READ"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -21327,27 +21332,27 @@ msgstr "Longueurs de CHARACTER différentes (%ld/%ld) dans le constructeur de ta
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Débordement d'entier en calculant la quantité de mémoire à allouer"
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "La valeur du paramètre PDT LEN « %s » n'est pas en accord avec celle dans la déclaration fictive"
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne ne correspond pas à celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne est plus courte que celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "La cible du remappage de rang est trop petite (%ld < %ld)"
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr "Assignation d'un scalaire à un tableau non alloué"
 
@@ -22215,7 +22220,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "%<-mrelax%> est uniquement supporté pour le PIC RTP"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction %s à %C"
@@ -22587,7 +22592,7 @@ msgstr "l'attribut %qE est ignoré car il est en conflit avec l'attribut %qs"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -22684,10 +22689,10 @@ msgstr "les attributs de type sont ignorés après que le type ait déjà été
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -22822,7 +22827,7 @@ msgstr "impossible de lire le profil de la fonction depuis %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "le décalage %qwi est hors des limites de la chaîne constante"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE déclaré ici"
@@ -24658,7 +24663,7 @@ msgstr "la constante de grande taille en virgule fixe a été tronquée implicit
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparaison est toujours %d en raison de la largeur du champ de bits"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "suppose qu'un débordement signé n'a pas lieu quand le test de la plage est simplifié"
@@ -25429,7 +25434,7 @@ msgstr "la fonction retourne l'adresse d'une variable locale"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26547,14 +26552,14 @@ msgstr "le pointeur ballant vers %qD est peut-être utilisé"
 msgid "using a dangling pointer to %qD"
 msgstr "utilisation d'un pointeur ballant vers %qD"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD déclaré ici"
@@ -26599,7 +26604,7 @@ msgstr "%qD appelé sur un pointeur passé à la fonction de réallocation %qD i
 msgid "call to %qD"
 msgstr "appel à %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr "stockage de l'adresse de la variable locale %qD dans %qE"
@@ -27669,7 +27674,7 @@ msgstr "le résumé en ligne ipa est manquant dans le fichier d'entrée"
 msgid "IPA modref summary is missing in input file"
 msgstr "le résumé de modref IPA est manquant dans le fichier d'entrée"
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "fonction de saut invalide dans un flux LTO"
@@ -28628,7 +28633,7 @@ msgstr "erreur lors de la fermeture des enregistrements optimisés %qs"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "l'option %qs en ligne de commande n'est pas supportée par cette configuration"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "argument manquant à %qs"
@@ -28668,12 +28673,12 @@ msgstr "%qs est mutuellement exclusif avec %qs et ne peuvent pas être spécifi
 msgid "unrecognized argument in option %qs"
 msgstr "argument non reconnu pour l'option %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "les arguments valables pour %qs sont: %s; vouliez vous utiliser %qs ?"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "les arguments valables pour %qs sont: %s"
@@ -28828,7 +28833,7 @@ msgstr "%<-fsanitize=pointer-subtract%> doit être combiné avec %<-fsanitize=ad
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "%<-fsanitize-recover=%s%> n'est pas supporté"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "%<-fsanitize-trap=%s%> n'est pas supporté"
@@ -28868,182 +28873,182 @@ msgstr "le pistage des variables a été demandé mais il est inutile sans produ
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "le pistage des variables a été demandé mais il n'est pas supporté par ce format de débogage"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments change l'ordonnancement sélectif"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr "%<-Wstrict-flex-arrays%> est ignoré quand %<-fstrict-flex-arrays%> n'est pas présent"
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> ne fonctionne pas avec les exceptions sur cette architecture"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> ne supporte pas les informations de retour en arrière sur cette architecture"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> ne fonctionne pas sur cette architecture"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "%<include_flags 0x%x%> non reconnu passé à %<print_specific_help%>"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr "l'option %<-fsanitize=all%> n'est pas valide"
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "argument non reconnu pour l'option %<-f%ssanitize%s=%>: %q.*s; vouliez-vous utiliser %qs ?"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "argument non reconnu pour l'option %<-f%ssanitize%s=%>: %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "directive d'attribut %qs ignorée"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "argument non reconnu pour %<-fzero-call-used-regs=%>: %qs"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "arguments invalides pour l'option %<-falign-%s%>: %qs"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "nombre d'arguments invalide pour l'option %<-falign-%s%>: %qs"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "%<-falign-%s%> n'est pas entre 0 et %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "argument invalide pour %<-fpatchable-function-entry%>"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "l'argument de %<--help%> %q.*s est ambigu, veuillez être plus précis"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "argument non reconnu pour l'option %<--help=%> : %q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr "arguments ignorés pour %<-Wattributes=%> ; utilisez %<-Wno-attributes=%> à la place"
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr "%<,%> à la fin dans les arguments pour %<-Wno-attributes=%>"
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr "l'option %<-foffload-abi%> ne peut être spécifiée qu'avec un compilateur pour le délestage"
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "l'alignement de la structure doit être une petite puissance de 2, pas %wu"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "paramètre de contrôle de la pile %qs inconnu"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr "%<-gdwarf%s%> est ambigu; utilisez %<-gdwarf-%s%> pour la version DWARF ou %<-gdwarf%> %<-g%s%> pour le niveau de débogage"
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "la version dwarf %wu n'est pas supportée"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "argument non reconnu pour l'option %<-flto=%> : %qs"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "le système cible ne supporte pas la sortie de débogage"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "le format de débogage %qs entre en conflit avec une sélection précédente"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "niveau de sortie de débogage %qs non reconnu"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "le niveau de sortie de débogage %qs est trop élevé"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "niveau de sortie de débogage btf %qs non reconnu"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "obtention de la limite maximale de la taille du fichier de vidange (core file): %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "initialisation de la limite maximale de la taille du fichier de vidange (core file): %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "option gcc de débogage non reconnue: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "%<-W%serror=%s%>: pas d'option %<-%s%>; aviez-vous l'intention d'utiliser %<-%s%> ?"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "%<-W%serror=%s%>: pas d'option %<-%s%>"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "%<-Werror=%s%>: %<-%s%> n'est pas une option qui contrôle les avertissements"
@@ -29724,187 +29729,187 @@ msgstr "le code du fragment générique échoue pour la méthode %qD qui utilise
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%qD renommé après avoir été référencé dans l'assembleur"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "le symbole de la fonction n'est pas une fonction"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr "attribut %<ifunc%> inconsistant"
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "le symbole de la variable n'est pas une variable"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "le nœud a un type inconnu"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "le nœud a l'ordre %i invalide"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nœud pas trouvé node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "le nœud diffère de node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "la liste de hachage des noms assembleur est corrompue"
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "le nœud n'a pas été trouvé dans le hachage des noms assembleur symtab"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "la liste doublement liée des noms assembleur est corrompue"
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "le nœud a body_removed mais il est une définition"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "le nœud est analysé mais il n'est pas une définition"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "le nœud est un alias mais pas un alias implicite"
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "le nœud est un alias mais pas une définition"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "le nœud est une référence faible (weakref) mais pas un transparent_alias"
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "le nœud est un transparent_alias mais pas un alias"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "le nœud est symver mais pas un alias"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr "la cible symver n'est pas exportée avec la visibilité par défaut"
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr "symver n'est pas exporté avec la visibilité par défaut"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "le nœud est dans la liste same_comdat_group mais il n'a aucun comdat_group"
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "liste same_comdat_group au travers de groupes différents"
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "le mélange de types de symboles différents dans les mêmes groupes comdat n'est pas supporté"
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "le nœud est seul dans un groupe comdat"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group n'est pas une liste circulaire"
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "un symbole comdat local est référencé par %s hors de son comdat"
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "le fanion implicit_section est défini mais la section ne l%'est pas"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "La section et le groupe comdat sont tous les deux définis"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr "Les sections de l%'alias et de la cible diffèrent"
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr "Les groupes comdat de l%'alias et de la cible diffèrent"
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "Les noms assembleurs de l%'alias transparent et de la cible diffèrent"
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Alias transparents enchaînés"
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify a échoué"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "ordre invalide dans le nœud asm %i"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Deux symboles avec le même comdat_group ne sont pas liés par la liste same_comdat_group."
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "la fonction %q+D fait partie du cycle des alias"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "la variable %q+D fait partie du cycle des alias"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "la section de l'alias %q+D doit correspondre à la section de sa cible"
@@ -31567,27 +31572,27 @@ msgstr "le code de la fonction intégrée indépendant de la machine est hors li
 msgid "target specific builtin not available"
 msgstr "la fonction intégrée spécifique à la cible n'est pas disponible"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "l'opération vectorielle sera développée à la pièce"
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "l'opération vectorielle sera développée en parallèle"
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "l'opération vectorielle sera développée avec une seule opération scalaire"
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "la condition vectorielle sera développée à la pièce"
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "l'opération de brassage vectoriel sera développée à la pièce"
@@ -32408,7 +32413,7 @@ msgstr "l'attribut %qE est ignoré car %qD n'est pas une variable"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "l'attribut %qE est ignoré car %qD n'est pas une variable locale"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "l'attribut %qE n'a d'effet que sur les objets publics"
@@ -34497,7 +34502,7 @@ msgstr "concaténation non standard de chaînes littérales non supportée"
 msgid "traditional C rejects string constant concatenation"
 msgstr "le C traditionnel rejette la concaténation de chaînes constantes"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> avec la clause %<hint%> requiert un nom sauf quand %<omp_sync_hint_none%> est utilisé"
@@ -36171,7 +36176,7 @@ msgstr "trop de fichiers d'entrée"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%qs est défini dans l'en-tête %qs ; avez-vous oublié %<#include %s%> ?"
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "valeur %qs inconnue pour %<-mcpu%>"
@@ -36202,15 +36207,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "option non reconnue passée à %%:%<target_mode_check%>"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "les arguments valides sont: %s; vouliez-vous utiliser %qs ?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "les arguments valables sont: %s"
@@ -36295,48 +36300,48 @@ msgstr "%<-mcpu=%s%> n'est pas valable"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "%<-mcpu=%s%> a une révision de silicium invalide"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "%<-malign-loops%> est obsolète, utilisez %<-falign-loops%>"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "%<-malign-loops=%d%> n'est pas entre 0 et %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "%<-malign-jumps%> est obsolète, utilisez %<-falign-jumps%>"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "%<-malign-jumps=%d%> n'est pas entre 0 et %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "%<-malign-functions%> est obsolète, utilisez %<-falign-functions%>"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "%<-malign-functions=%d%> n'est pas entre 0 et %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "%<-mbranch-cost=%d%> n'est pas entre 0 et 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> n'est actuellement uniquement supporté que par GNU/Linux"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> a besoin de l'assistance d'un assembleur pour les directives CFI"
@@ -36820,13 +36825,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "la fonction ACLE %qD est incompatible avec l'utilisation de %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "l'argument %d de %qE doit être une expression constante entière"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr "passage de %wd à l'argument %d de %qE qui attend une valeur dans la plage [%wd, %wd]"
@@ -37064,7 +37069,7 @@ msgstr "passage de %qT à l'argument %d de %qE mais sa forme %qT n'accepte pas d
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "définition dupliquée de %qs"
@@ -37105,7 +37110,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "le type SVE %qT n'a pas un alignement défini"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr "les variables de type %qT ne peuvent pas avoir une durée de stockage limitée au thread"
@@ -37192,323 +37197,323 @@ msgstr "vous pouvez activer SVE en utilisant l'option %<-march%> sur la ligne de
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "l'argument de type %qT requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "le type SVE %qT ne peut pas être passé en argument à une fonction sans prototype"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 13.1"
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 9.1"
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "les appels à des fonctions de type %qT requièrent l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "sondes de pile pour les trames SVE"
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "fanion inconnu passé à %<-moverride=%s%> (%s)"
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr "chaîne %qs mal formée"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "format invalide pour %<sve_width%>"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr "valeur invalide pour %<sve_width%>: %d"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "chaîne d'ajustement manquante dans l'option (%s)"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "option d'ajustement inconnue (%s)"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "%<-mstack-protector-guard=global%> et %<-mstack-protector-guard-offset=%qs%> incompatibles"
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "%<-mstack-protector-guard-offset%> et %<-mstack-protector-guard-reg%> doivent être utilisés tous les deux avec %<-mstack-protector-guard=sysreg%>"
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr "spécifie un registre système avec une chaîne de courte longueur"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs n'est pas un décalage valide dans %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr "%<-fsanitize=shadow-call-stack%> requiert %<-ffixed-x18%>"
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "seules les valeurs 12 (4 ko) et 16 (64 ko) sont supportées pour la taille de garde. La valeur %d donnée (%llu ko) est hors limites"
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "la taille %<%d%> de la sécurité anti-collision de la pile doit être égale à l'intervalle de sondage %<%d%>"
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "nom de processeur manquant dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "modificateur de fonctionnalité %qs invalide dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "argument invalide donné à %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr "%qs doit être seul pour %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "argument %<%s%> invalide pour %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "nom d'architecture manquant dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "valeur %qs inconnue pour %<-march%>"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "vouliez-vous utiliser %<-mcpu=%s%> ?"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "modificateur de fonctionnalité %qs invalide dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "nom de processeur manquant dans %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "valeur %qs inconnue pour %<-mtune%>"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "l'option %<-mcpu=%s%> est en conflit avec l'option %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "l'assembleur ne supporte pas %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "la signature de l'adresse de retour n'est supportée qu'avec %<-mabi=lp64%>"
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "modèle de code %qs avec %<-f%s%>"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode ilp32"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom %qs invalide dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "modificateur de fonctionnalité %s invalide avec la valeur %qs dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom %qs invalide dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "modificateur de fonctionnalité %qs invalide avec la valeur %qs dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "argument manquant dans le pragma ou l'attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "type de protection %qs invalide dans le pragma ou l'attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nom %qs invalide dans le pragma ou l'attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "valeur manquante dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target()%> est mal composé"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'accepte pas d'argument"
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'autorise pas de forme négative"
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s=%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "l'argument %<target%> de l'attribut n'est pas une chaîne"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr "l'extension arch %<%s%> devraient être préfixée par %<+%>"
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> est mal composé"
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "le passage de paramètre pour l'argument de type %qT avec des membres %<[[no_unique_address]]%> a changé dans %{GCC 10.1%}"
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "le passage par paramètre pour l'argument de type %qT quand C++17 est activé a changé pour correspondre à C++14 %{dans GCC 10.1%}"
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans %{GCC 12.1}%"
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "avenue %wd hors des limites %wd - %wd"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "simdlen %wd non supportée"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas les types de tailles mélangés pour les fonctions %<simd%>"
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas le type de retour %qT pour les fonctions %<simd%>"
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "type de retour %qT non supporté pour des fonctions %<simd%>"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas un argument de type %qT pour des fonctions %<simd%>"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "GCC ne supporte actuellement pas simdlen %wd pour le type %qT"
@@ -37693,13 +37698,13 @@ msgstr "l'argument de l'attribut %qE n'est pas « ilink » ni « firq »"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -37840,17 +37845,17 @@ msgstr "l'argument de l'attribut %qE est ignoré"
 msgid "%qE attribute only applies to variables"
 msgstr "l'attribut %qE ne s'applique qu'aux variables"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "les alternatives ne sont pas autorisées dans la sortie du fanion %<asm%>"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "sortie du fanion %<asm%> %qs inconnue"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "type invalide pour la sortie du fanion %<asm%>"
@@ -38057,7 +38062,7 @@ msgstr "le processeur cible ne supporte pas les instructions THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "le processeur cible ne supporte pas les accès non alignés"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "Cette architecture ne supporte pas les instructions de protection de branche"
@@ -38112,7 +38117,7 @@ msgstr "la frontière de la taille de la structure peut seulement être 8 ou 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC est incompatible avec %<-msingle-pic-base%>"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "le mode FDPIC n'est pas supporté en mode Thumb-1"
@@ -38218,7 +38223,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "argument de type %qT pas permis avec %<-mgeneral-regs-only%>"
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 7.1"
@@ -38268,32 +38273,32 @@ msgstr "l'accès à un stockage local au thread n'est actuellement pas supporté
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "incapable de calculer la position réelle des paramètres sur la pile"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Saut lointain thumb1 inattendu"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "pas de registre bas disponible pour dépiler les registres hauts"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "les routines du service d'interruption ne peuvent pas être codées en mode Thumb-1"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> pour Thumb-1"
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
@@ -38301,22 +38306,22 @@ msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "la sélection automatique du fpu n'est actuellement pas permise ici"
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "architecture invalide pour l'attribut ou le pragma cible %qs"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "attribut ou pragma cible %qs inconnu"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "fanions %<asm%> non supportés en mode thumb1"
@@ -38390,17 +38395,17 @@ msgstr "%<-fpie%> n'est pas supporté"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> n'est pas supporté"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "les attributs de fonction %qs et %qs sont mutuellement exclusifs"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la fonction avec l'attribut %qs ne peut pas avoir d'argument"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la fonction avec l'attribut %qs ne peut pas retourner une valeur"
@@ -38717,7 +38722,7 @@ msgstr "deuxième argument invalide pour la fonction interne"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "argument invalide pour la fonction interne"
@@ -39310,749 +39315,749 @@ msgstr "les versions de fonctions ne peuvent pas être marquées avec %<gnu_inli
 msgid "virtual function multiversioning not supported"
 msgstr "des versions multiples de fonctions virtuelles ne sont pas supportées"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "les versions multiples requièrent %<ifunc%> qui n'est pas supporté sur cette cible"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "le modèle de code %s ne supporte pas le mode PIC"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "l'argument de l'attribut %qs n'est pas une chaîne"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "l'argument %qs de l'attribut %qs est inconnu"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "la valeur %qs de l'attribut était déjà spécifiée dans l'attribut %qs"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "la valeur %qs de l'attribut est inconnue dans l'attribut %qs"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argument %qs erroné pour l'option %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "les plages de tailles de l'option %qs devraient être croissantes"
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "nom de stratégie %qs erroné spécifié pour l'option %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "le nom de stratégie %qs spécifié pour l'option %qs n'est pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignement %qs inconnu spécifié pour l'option %qs"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "la valeur maximale pour la dernière plage de taille de l'option %qs devrait être -1"
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "trop de plages de tailles spécifiées dans l'option %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "paramètre inconnu dans l'option %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "la psABI du MCU Intel n'est pas supportée dans le mode %s"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> est déprécié; utilisez plutôt %<-mtune=k8%> ou %<-mtune=generic%> selon ce qui est approprié"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> est déprécié; utilisez plutôt %<target(\"tune=k8\")%> ou %<target(\"tune=generic\")%> selon ce qui est approprié"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "option %<-mlam=%> : [u48|u57] pas supportée pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "le mode d'adresse %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> pas supporté avec l'ABI X32"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode x32"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> n'est pas supporté dans cette configuration"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "mode %i bits pas compilé"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "le processeur sélectionné ne supporte pas le jeu d'instructions x86-64"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "valeur %qs erronée pour l'option %<-march=%>"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "valeur %qs erronée pour l'attribut %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "valeur %qs erronée pour l'option %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "valeur %qs erronée pour l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> est ignoré avec la psABI du MCU Intel"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> n'est pas entre 0 et %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> n'est pas supporté pour cette cible"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> n'est pas entre %d et %d"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> n'est pas entre %d et 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> n'est pas implémenté pour %<-fPIC%>"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "jeu d'instructions SSE désactivé, l'arithmétique 387 est utilisée"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "jeu d'instructions 387 désactivé, l'arithmétique SSE est utilisée"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "le sondage de la pile requiert %<-maccumulate-outgoing-args%> pour être correcte"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "le sondage de la pile requiert %<target(\"accumulate-outgoing-args\")%> pour être correcte"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "le registre ebp fixé requiert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "le registre ebp fixé requiert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> n'est pas supporté en 32 bits en combinaison avec %<-fpic%>"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> n'est pas compatible avec SEH (gestionnaire d'exceptions structuré)"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> n%'est actuellement pas supporté avec SEH"
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "option inconnue pour %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs n'est pas un nombre valable dans %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs n'est pas un décalage valable dans %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs n'est pas un registre de base valable dans %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "les attributs d'interruption et nus sont incompatibles"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "seul le format de débogage DWARF est supporté pour les routines de service d'interruptions"
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service exception"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service d'interruption"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "les instructions %s ne sont pas autorisées dans la fonction avec l%'attribut %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm sont incompatibles"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs regparam et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante entière"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut %qE est plus grand que %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall sont incompatibles"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs stdcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs stdcall et fastcall sont incompatibles"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs stdcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs cdecl et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "l'attribut %qE est utilisé pour une méthode qui n'est pas une classe"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "l'attribut incompatible %qE est ignoré"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "l'attribut %qE est uniquement disponible en 32 bits"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "l'argument de l'attribut %qE n'est ni zéro ni un"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "les attributs %qs et %qs sont incompatibles"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante chaîne de caractères"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la routine de service d'interruption devrait avoir un pointeur comme premier argument"
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la routine de service d'interruption devrait avoir %qs comme deuxième argument"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la routine de service d'interruption ne peut avoir qu'un argument de type pointeur et un argument entier optionnel"
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "la routine de service d'interruption doit retourner %<void%>"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qD avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qT avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "X32 ne supporte pas l'attribut %<ms_abi%>"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "%<ms_hook_prologue%> n'est pas compatible avec les fonctions imbriquées"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "l'argument vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "le retour vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "l'argument vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "le retour vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "l'argument vectoriel SSE sans activer SSE modifie l'ABI"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "le retour vectoriel SSE sans activer SSE change l'ABI"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "l'argument vectoriel MMX sans activer MMX modifie l'ABI"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "le retour vectoriel MMX sans activer MMX change l'ABI"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un tableau flexible comme membre a changé dans GCC 4.4"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "l'ABI pour passer une union avec un %<long double%> a changé dans GCC 4.4"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un membre %<complex float%> a changé dans GCC 4.4"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "l'ABI pour passer des structures C avec des champs de bits de largeur zéro a changé dans GCC %{12.1%}"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "retour d'un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argument dans un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "retour d'un registre x87 alors que x87 est désactivé"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "appel de %qD avec la convention d'appel SSE sans avoir activé SSE/SSE2"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "ceci est un bogue de GCC qui peut être contourné en ajoutant l'attribut utilisé à la fonction appelée"
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "l'ABI pour passer des paramètres avec un alignement de %d octets a changé dans GCC 4.6"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "%<-mcall-ms2sysv-xlogues%> est incompatible avec %s"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "l'attribut %<ms_hook_prologue%> est incompatible avec %<-mfentry%> pour 32 bits"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "DRAP (Dynamic Realign Argument Pointer) n'est pas supporté dans une routine de service d'interruption. Ceci peut être contourné en évitant les fonctions avec un retour agrégé."
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "Le réalignement de pile n'est pas supporté avec %<__builtin_eh_return%>"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "les fonctions regparm imbriquées ne sont pas supportées avec %<__builtin_eh_return%>"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "%<-fsplit-stack%> ne supporte pas fastcall avec des fonctions imbriquées"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "%<-fsplit-stack%> ne supporte pas deux paramètres registres pour une fonction imbriquée"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "%<-fsplit-stack%> ne supporte pas trois paramètres registres"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr "modificateur %<V%> sur un registre non entier"
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "taille non supportée pour un registre entier"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "les registres étendus n'ont pas de moitié haute"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "taille d'opérande non supportée pour un registre étendu"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "opérande non entier utilise avec le code d'opérande %<z%>"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "l'ABI de passage de paramètres pour la classe vide %qT change avec %<-fabi-version=12%> (GCC 8)"
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "l'alignement des champs de %<_Atomic %T%> ont changé dans %{GCC 11.1%}"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "le profilage %<-mcmodel=large%> avec PIC n'est pas supporté"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modèle mémoire spécifique à l'architecture inconnu"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "%<HLE_ACQUIRE%> n'est pas utilisé avec le modèle mémoire %<ACQUIRE%> ou un autre plus contraignant"
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "%<HLE_RELEASE%> n'est pas utilisé avec le modèle mémoire %<RELEASE%> ou un autre plus contraignant"
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "type de retour %qT non supporté pour simd"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "type d'argument %qT non supporté pour simd"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> n'est pas compatible avec %<-mfpmath=387%>"
@@ -40397,7 +40402,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE redéclaré avec les attributs conflictuels %qs"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "l'attribut %qE requiert une chaîne comme argument"
@@ -41516,52 +41521,52 @@ msgstr "l'option %<#pragma riscv intrinsic%> %qs a besoin que l'extension « V
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "option %qs inconnue pour %<#pragma riscv intrinsic%>"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr "le type RVV %qT n'a pas de taille fixe"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "le type RVV %qT n'a pas un alignement défini"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "arithmétique sur un pointeur vers un type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr "les variables membre ne peuvent pas avoir le type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "les champs ne peuvent pas avoir le type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr "les éléments de tableau de peuvent pas avoir le type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "ne peut allouer des objets du type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "impossible de supprimer des objets du type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr "ne peut lever ou intercepter une exception sur le type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr "capture par copie du type RVV %qT"
@@ -41581,66 +41586,71 @@ msgstr "cette opération requiert l'extension de l'ISA RVV"
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "vous pouvez activer RVV en utilisant l'option %<-march%> sur la ligne de commande ou en utilisant l'attribut ou le pragma %<target%>"
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "l'ABI pour des structures aplaties avec un champ de bits d'une taille non nulle a changé dans GCC 10"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "l'argument de l'attribut %qE n'est pas %<\"user\"%>, %<\"supervisor\"%> ou %<\"machine\"%>"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> requiert %<-march%> pour incorporer l'extension %<M%>"
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "l'ABI demandée requiert %<-march%> pour incorporer l'extension %qc"
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e requiert l'ABI ilp32e"
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr "z*inx requiert l'ABI ilp32, ilp32e ou lp64"
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "l'ABI requiert %<-march=rv%d%>"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> doit être entre %d et %d"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "l'attribut RISC-V ELF %<-mriscv-attribute%> requiert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs n'est pas un registre de base valable dans %qs"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs n'est pas un nombre valide dans %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "la fonction %qs ne peut pas avoir un type d'interruption différent"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr "impossible d'allouer le registre vl pour %qs sur cette cible"
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, gcc-internal-format
@@ -42111,97 +42121,97 @@ msgstr "%qs est déprécié et recommandé dans aucune circonstance"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs est un type opaque et vous ne pouvez pas le remplacer avec d'autres valeurs"
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code 64 bits pour cette ABI"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option %qs"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<long double%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "l'utilisation des types booléens dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans %qs"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "l'utilisation de %<long%> dans les types Altivec est obsolète; utilisez %<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<long long%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<double%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "processeur %qs invalide pour %s\"%s\"%s"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s n'est pas permis"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s est invalide"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> désactive %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "l'attribut %<target_clones%> requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Des versions multiples de fonctions virtuelles ne sont pas supportées"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "le résultat de l'instruction xxspltidp n'est pas défini pour des valeurs d'entrée sous-normales"
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "le type %<__vector_quad%> requiert l'option %qs"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "le type %<__vector_pair%> requiert l'option %qs"
@@ -43596,7 +43606,7 @@ msgstr "impossible de mettre un objet avec un champ volatile dans un registre"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "%<const %qD%> non initialisé est invalide en C++"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
@@ -43781,7 +43791,7 @@ msgstr "classe de stockage spécifiée pour le paramètre %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "classe de stockage spécifiée pour le paramètre sans nom"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "classe de stockage spécifiée pour un typename"
@@ -43950,7 +43960,7 @@ msgstr "nom de type déclaré comme une fonction retournant un tableau"
 msgid "function definition has qualified void return type"
 msgstr "la définition de la fonction a un type de retour « void » qualifié"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "les qualificatifs de type sont ignorés sur le type retourné par la fonction"
@@ -44077,7 +44087,7 @@ msgstr "le C ISO interdit les fonctions de type volatile ou constante"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un membre d'une structure ou d'une union ne peut pas avoir de type modifié par une variable"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variable ou champ %qE déclaré « void »"
@@ -44278,7 +44288,7 @@ msgstr "définir le type dans l'expression %qs est invalide en C++"
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qT est défini dans l'initialiseur de l'objet sous-spécifié"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la déclaration ne déclare rien du tout"
@@ -44328,7 +44338,7 @@ msgstr "la structure n'a aucun membre nommé"
 msgid "struct has no members"
 msgstr "la structure n'a aucun membre"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "tableau flexible comme membre de l'union"
@@ -44373,7 +44383,7 @@ msgstr "redéclaration de %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr "%<enum%> déclaré avec mais défini sans type sous-jacent fixe"
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "le mode spécifié est trop petit pour les valeurs énumérées"
@@ -44418,7 +44428,7 @@ msgstr "la valeur de l'énumération est en dehors de la plage de %qs"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "le C ISO restreint les valeurs de l'énumérateur à la plage d'un %<int%> avant C2X"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "la fonction à mettre en ligne %qD a reçu l'attribut %qs"
@@ -44448,7 +44458,7 @@ msgstr "aucun prototype précédent pour %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD a été utilisé sans prototype avant sa définition"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "aucune déclaration précédente pour %qD"
@@ -44563,12 +44573,12 @@ msgstr "l'argument %qD ne concorde pas avec le prototype interne"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "le paramètre %qD est défini mais pas utilisé"
@@ -46580,7 +46590,7 @@ msgstr "pas assez de boucles parfaitement imbriquées"
 msgid "collapsed loops not perfectly nested"
 msgstr "boucles coalescées imparfaitement imbriquées"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable d'itération %qD ne devrait pas être « firstprivate »"
@@ -46710,12 +46720,12 @@ msgstr "%<match%> attendu"
 msgid "variant %qD is not a function"
 msgstr "le variant %qD n'est pas une fonction"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "le variant %qD et la base %qD ont des types incompatibles"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "le variant %qD est interne"
@@ -46976,7 +46986,7 @@ msgstr "utilisation invalide de l'expression void"
 msgid "invalid use of flexible array member"
 msgstr "utilisation invalide d'un membre qui est un tableau flexible"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "utilisation invalide d'un tableau sans borne spécifiée"
@@ -47925,12 +47935,12 @@ msgstr "l'initialiseur de %<constexpr%> pour un type réel est de type complexe"
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr "l'initialiseur de %<constexpr%> pour un type en virgule flottante binaire est de type décimal"
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisation d'un membre de tableau flexible"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "impossible d'initialiser un tableau de %qT depuis une chaîne de caractères littérale avec un tableau de type %qT"
@@ -47971,7 +47981,7 @@ msgstr "un élément de l'initialisation n'est pas évaluable lors du chargement
 msgid "invalid initializer"
 msgstr "initialisation invalide"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "type de vecteur opaque ne peut être initialisé"
@@ -47986,8 +47996,8 @@ msgstr "groupe d'accolades superflu à la fin de l'initialisation"
 msgid "braces around scalar initializer"
 msgstr "accolades autour d'une initialisation d'un scalaire"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisation d'un membre de tableau flexible dans un contexte imbriqué"
@@ -48077,7 +48087,7 @@ msgstr "trop d'éléments dans l'initialisation de la structure"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "initialisation par position de champs dans une %<struct%> qui est déclarée avec l'attribut %<designated_init%>"
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "initialisation non statique d'un membre de tableau flexible"
@@ -49420,7 +49430,7 @@ msgstr "pas de %<operator %s%> adapté pour %qT"
 msgid "%q#D is private within this context"
 msgstr "%q#D est privé dans ce contexte"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "déclaré privé ici"
@@ -49430,7 +49440,7 @@ msgstr "déclaré privé ici"
 msgid "%q#D is protected within this context"
 msgstr "%q#D est protégé dans ce contexte"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "déclaré protégé ici"
@@ -49445,7 +49455,7 @@ msgstr "%q#D est inaccessible dans ce contexte"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "passage de NULL pour l'argument non pointeur %P de %qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, gcc-internal-format
 msgid "  declared here"
@@ -49774,7 +49784,7 @@ msgstr "pas de fonction concordante pour l'appel à %<%T::%s%E(%A)%#V%>"
 msgid "call to non-function %qD"
 msgstr "appel à la non fonction %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le constructeur %<%T::%D%> directement"
@@ -50344,7 +50354,7 @@ msgstr "membre tableau flexible %qD dans %q#T par ailleurs vide"
 msgid "next member %q#D declared here"
 msgstr "membre %q#D suivant déclaré ici"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redéfinition de %q#T"
@@ -50466,7 +50476,7 @@ msgstr "type invalide pour le paramètre %d de la fonction %<constexpr%> %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "les lambdas ne sont implicitement %<constexpr%> qu'à partir du C++17"
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les destructeurs %<constexpr%> sont uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
@@ -50535,7 +50545,7 @@ msgstr "%qE est évalué à « faux »"
 msgid "failed %<assume%> attribute assumption"
 msgstr "la supposition de l'attribut %<assume%> a échoué"
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -50582,7 +50592,7 @@ msgstr "%qT est une classe de base ambigüe du type dynamique %qT de son opéran
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "le type dynamique %qT de son opérande n'a pas une classe de base publique %qT non ambigüe"
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -50706,7 +50716,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "déréférencement d'un pointeur nul dans %qE"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -50805,7 +50815,7 @@ msgstr "%qs accès à un octet non initialisé à l'offset %d"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs ne peut pas être évalué de manière constante car l'argument ne sait pas être interprété"
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -50881,7 +50891,7 @@ msgstr "changement du membre actif d'une union de %qD à %qD"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "changement du membre actif d'une union de %qD à %qD durant l'initialisation"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -50947,189 +50957,189 @@ msgstr "le contrôle passe au travers de la définition de %qD avec une durée d
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "le contrôle passe au travers de la définition de %qD avec une durée de stockage statique"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporaire du type %qT non littéral dans une expression constante"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "un %<reinterpret_cast%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversion depuis le type pointeur %qT vers le type arithmétique %qT dans une expression constante"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "le transtypage depuis %qT n'est pas permis"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE n'est pas une expression constante tant que la classe %qT est encore incomplète"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "l'expression %qE n'est pas une expression constante"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "le prédicat du contrat est faux dans une expression constante"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "template-id %qE inattendu"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "un concept de fonction doit être appelé"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "l'adresse d'un appel à %qs n'est pas une expression constante"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "l'expression %qE du sous-type %s est inattendue"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE n'est pas une expression constante car il fait référence aux sous-objets mutables de %qT"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE n'est pas une expression constante car il fait référence à une variable incomplètement initialisée"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE n'est pas une expression constante car il fait référence à un résultat de %<operator new%>"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE n'est pas une expression constante car le stockage alloué n'a pas été désalloué"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "l'évaluation immédiate retourne l'adresse de la fonction immédiate %qD"
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversion l-valeur vers r-valeur d'une l-valeur volatile %qE avec le type %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la capture lambda de %qE n'est pas une expression constante"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "car il est utilisé comme gl-valeur"
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> d'un entier vers un pointeur"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "prendre l'adresse avec address-of d'un objet %qE qui est local au thread ou a un stockage automatique n'est pas une expression constante"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "utilisation de %<this%> dans une expression constante"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "expression lambda dans une expression constante avant C++17"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "l'expression new n'est pas une expression constante avant C++20"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "les fonctions virtuelles ne peuvent pas être %<constexpr%> avant C++20"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "l'expression %<typeid%> n'est pas une expression constante car %qE est un type polymorphique"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "transtypage vers le type non entier %qT dans une expression constante"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD défini %<thread_local%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD défini %<static%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "la division par zéro n'est pas une expression constante"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "aucune des branches de %<if%> est une expression constante"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "initialisation d'un tableau non constant"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "la définition d'une étiquette dans une fonction %<constexpr%> est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattendu"
@@ -51703,7 +51713,7 @@ msgstr "le type de « promise » %qT pour la coroutine déclare à la fois %<r
 msgid "%<return_void%> declared here"
 msgstr "%<return_void%> déclaré ici"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "pas de membre nommé %qE dans %qT"
@@ -51795,7 +51805,7 @@ msgstr "l'argument de direction de %<__builtin_core_promise%> doit être une con
 msgid "no suspend point info for %qD"
 msgstr "aucune information du point de suspension pour %qD"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr "%qE est fourni par %qT mais il n'est pas utilisable avec la fonction ayant la signature %qD"
@@ -51815,23 +51825,23 @@ msgstr "les expressions temporisables ne sont pas permises dans les gestionnaire
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "les tableaux de longueur variable ne sont pas encore supportés dans les coroutines"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr "%qE est fourni par %qT mais %qE n'est pas marqué avec %<throw()%> ou %<noexcept%>"
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr "%qE est marqué avec %<throw()%> ou %<noexcep%> mais aucun %<get_return_object_on_allocation_failure%> utilisable est fourni par %qT"
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr "%qE est fourni par %qT mais %<std::nothrow%> n'est pas trouvé"
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "impossible d'initialiser un objet retourné de type %qT avec une r-valeur de type %<void%>"
@@ -52311,7 +52321,7 @@ msgstr "par rapport à la déclaration précédente de %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redéclaration de %qD diffère de %qs dans la déclaration précédente"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "déclaration précédente de %qD"
@@ -52711,2275 +52721,2275 @@ msgstr "%qD est une fonction, pas un type"
 msgid "%q#T is not a class"
 msgstr "%q#T n'est pas une classe"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "pas de patron de classe nommé %q#T dans %q#T"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "pas de type nommé %q#T dans %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la recherche de %qT dans %qT est ambigüe"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un patron de classe"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nomme %q#D qui n'est pas un type"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "les paramètres du patron ne correspondent pas au patron %qD"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> n'est pas une puissance de deux"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr "%<--param destructive-interference-size=%d%> est plus petit que %d"
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> est plus petit que %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr "%<--param constructive-interference-size=%d%> est plus petit que %d"
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> est plus grand que %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données publiques non statiques"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "cette flexibilité est dépréciée et sera supprimée"
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "struct anonyme avec des classes de base"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un destructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un opérateur d'affectation par copie n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoré dans la déclaration de %q#T"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "l'attribut pour %q#T doit suivre le mot-clé %qs"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "types multiples dans une déclaration"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redéclaration du type interne C++ %qT"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> peut seulement être spécifié pour des déclarations de variables ou de fonctions"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nom de type manquant dans la déclaration typedef"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "le C++ ISO interdit les structures anonymes"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> peut seulement être spécifié à l'intérieur d'une classe"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> peut seulement être spécifié pour des constructeurs"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "une classe de stockage peut seulement être spécifiée pour des objets et des fonctions"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> a été ignoré dans cette déclaration"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs ne peut pas être utilisé pour des déclarations de types"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoré dans l'instanciation explicite de %q#T"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "aucun attribut peut être appliqué à une instanciation explicite"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "les attributs sont ignorés s'ils sont appliqués à la classe de type %qT en dehors de la définition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "attributs ignorés car ils sont appliqués au type dépendent %qT sans déclaration associée"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD est initialisé (utilisez plutôt %qs)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la déclaration de %q#D est %<extern%> et est initialisée"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la définition de %q#D est marquée %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D n'est pas un membre de donnée statique de %q#T"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "la déclaration du patron non membre de %qD"
 
 # le message ci-dessous est la suite de celui juste ci-dessus
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ne correspond pas à la déclaration du patron membre ici"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "le C++ ISO ne permet pas que %<%T::%D%> soit défini comme %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "initialisation en double de %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la déclaration de %q#D en dehors de la classe n'est pas une définition"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr "la déclaration externe avec la portée bloc %q#D n'est pas permise dans le domaine du module"
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD défini %<thread_local%> dans la fonction %qs est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD défini %<static%> dans la fonction %qs est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D a un initialiseur mais a un type incomplet"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "les éléments du tableau %q#D ont un type incomplet"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "l'agrégat %q#D a un type incomplet et ne peut être défini"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD est déclaré comme référence mais n'est pas initialisé"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nom utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nom %qD utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "les initialisations par désignation non triviales ne sont pas supportées"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "le champ désigné par l'indicateur C99 %qE n'est pas une expression constante entière"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "l'initialisation n'a pu déterminer la taille de %qD"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "taille de tableau manquante dans %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "tableau %qD de taille zéro"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "la taille de stockage de %qD n'est pas connue"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "la taille de stockage de %qD n'est pas constante"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la variable en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la fonction statique en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "vous pouvez contourner cela en enlevant l'initialiseur"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "%<const %D%> non initialisé"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variable %qD non initialisée dans une fonction %<constexpr%>"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "variable %qD non initialisée dans un contexte %<constexpr%>"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T n'a pas de constructeur par défaut fourni par l'utilisateur"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "le constructeur n'est pas défini par l'utilisateur car le constructeur par défaut est explicitement demandé dans le corps de la classe"
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "et le constructeur implicitement défini n'initialise pas %q#D"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "type %qT invalide pour initialiser un vecteur de type %qT"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "l'initialisation de %qT doit être entre accolades"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> utilisé dans une initialisation par désignation dans le style GNU pour la classe %qT"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT n'a pas de membre de données non statique nommé %qD"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD n'est pas un membre direct de %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "initialisation invalide pour %q#D"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "le champ désigné par l'indicateur C99 %qE est hors de l'initialisation de l'agrégat"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "trop d'éléments d'initialisation pour %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "trop d'accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades manquantes autour de l'initialisation pour %qT"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "la liaison structurée à le type incomplet %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "les éléments du tableau %q#T ont un type incomplet"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "littéral composé de taille variable"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D a un type incomplet"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "l'objet scalaire %qD requiert un élément dans l'initialisation"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98, %qD doit être initialisé par un constructeur et non par %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "le tableau %qD est initialisé par la chaîne littérale entre parenthèses %qE"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initialisation invalide pour un membre statique avec constructeur"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique %qD"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique pas en ligne %qD"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(une initialisation en dehors de la classe est requise)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "la référence %qD est initialisée avec elle-même"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "n'a pu trouver la déclaration du variant"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> sur le constructeur %qD"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> sur le destructeur %qD"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> sur %qD par défaut"
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> sur %qD supprimé"
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> sur %qD virtuel"
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "affectation (pas une initialisation) dans la déclaration"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "le C++17 ISO n'autorise pas le spécificateur de classe de stockage %<register%>"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "spécificateur de classe de stockage %<register%> utilisé"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la déclaration de %q#D n'est pas initialisée"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "l'initialisation pour %<decltype(auto) %D%> a un type fonction (avez-vous oublié les %<()%> ?)"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "le type déduit %qT pour %qD est incomplet"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "le concept de variable n'a pas d'initialisation"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "masque la déclaration précédente du type de %q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> peut uniquement être appliqué à une variable avec une durée de stockage statique ou au niveau du thread"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la fonction %q#D est initialisée comme une variable"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une structure anonyme comme membre"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une union anonyme comme membre"
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "impossible de décomposer le membre inaccessible %qD de %qT"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: lui et sa classe de base %qT ont des membres de données non statiques"
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: ses classes de base %qT et %qT ont des membres de données non statiques"
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "la liaison structurée fait référence au type incomplet %qT"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "impossible de décomposer le tableau de longueur variable %qT"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u nom fourni pour la liaison structurée"
 msgstr[1] "%u noms fournis pour la liaison structurée"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "seulement %u nom fourni pour la liaison structurée"
 msgstr[1] "seulement %u noms fournis pour la liaison structurée"
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "alors que %qT se décompose en %wu élément"
 msgstr[1] "alors que %qT se décompose en %wu éléments"
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "impossible de décomposer le vecteur de longueur variable %qT"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> n'est pas une expression constante entière"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "alors que %qT se décompose en %E éléments"
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr "%<std::tuple_element<%u, %T>::type%> est %<void%>"
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dans l'initialisation de la variable de liaison structurée %qD"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "impossible de décomposer le type union %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "impossible de décomposer le type %qT qui n'est ni une classe ni un tableau"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "impossible de décomposer le type de fermeture lambda %qT"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "la liaison structurée fait référence au type de classe incomplet %qT"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "impossible de décomposer le type de classe %qT sans membre de donnée non statique"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "la variable non locale %qD déclarée %<__thread%> a besoin d'une initialisation dynamique"
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "la variable non locale %qD déclarée %<__thread%> a un destructeur non trivial"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> en C++11 permet l'initialisation et la destruction dynamique"
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "l'initialisation n'a pu déterminer la taille de %qT"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "taille du tableau manquante dans %qT"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "tableau %qT de taille zéro"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "le destructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "le constructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD est déclaré comme une variable %<virtual%>"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de variable"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD déclaré comme un paramètre %<virtual%>"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD déclaré comme un paramètre %<inline%>"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de paramètre"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD déclaré comme un type %<virtual%>"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD déclaré comme un type %<inline%>"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de type"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD déclaré comme un champ %<virtual%>"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD déclaré comme un champ %<inline%>"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de champ"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D déclaré comme un ami"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D déclaré avec une spécification d'exception"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la définition de %qD n'est pas dans l'espace de noms incluant %qT"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la fonction membre statique %q#D est déclarée avec des qualificatifs de type"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "le concept %q#D est déclaré avec des paramètres de fonction"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "le concept %q#D est déclaré avec un type de retour déduit"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "le concept %q#D a le type de retour %qT qui n'est pas %<bool%>"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "le concept %qD n'a pas de définition"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "un concept de fonction ne peut pas être contraint"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "contraintes sur une fonction sans patron"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "définition de la spécialisation explicite %qD dans la déclaration amie"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "utilisation invalide du template-id %qD dans la déclaration du patron primaire"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "les arguments par défaut ne sont pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> n'est pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "la déclaration amie de %qD spécifie des arguments par défaut et n%'est pas une définition"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "ne peut déclarer %<::main%> comme étant un patron"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "ne peut déclarer %<::main%> comme étant à mettre en ligne"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "ne peut déclarer %<::main%> comme étant %qs"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "ne peut déclarer %<::main%> comme étant static"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "le guide de déduction %qD doit être déclaré dans la même portée que %qT"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "le guide de déduction %qD doit avoir le même accès que %qT"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "le guide de déduction %qD ne peut pas avoir un corps de fonction"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "opérateur littéral avec une classe de liaison C"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD a une liste d'arguments invalide"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "le suffixe entier %qs est masqué par l'implémentation"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "le suffixe en virgule flottante %qs est masqué par l'implémentation"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "les suffixes d'opérateurs littéraux qui ne sont pas précédés par %<_%> sont réservés pour une standardisation future"
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD doit être une fonction non membre"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> doit retourner %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "définition de %qD déclaré implicitement"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "définition de %qD explicitement par défaut"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicitement par défaut ici"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "pas de fonction membre %q#D déclarée dans la classe %qT"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "ne peut déclarer %<::main%> comme variable globale"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "une variable qui n'est pas un patron ne peut pas avoir %<concept%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "le concept doit être défini au niveau de l'espace de noms"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "un concept doit avoir le type %<bool%>"
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "un concept variable ne peut pas être contraint"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D d'un type incomplet"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> est requis pour l'initialisation intra-classe du membre de donnée statique %q#D d'un type non entier"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D du type non littéral"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "initialisation intra-classe invalide du membre de donnée statique du type non entier %qT"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "le C++ ISO interdit l'initialisation intra-classe du membre statique non constant %qD"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "le C++ ISO interdit l'initialisation du membre constant %qD du type non entier %qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "la taille du tableau %qD a le type non entier %qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "la taille du tableau a le type non entier %qT"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "la taille du tableau %qD n'est pas une expression constante de type entier"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "la taille du tableau n'est pas une expression constante entière"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "le C++ ISO interdit le tableau de taille zéro %qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "le C++ ISO interdit le tableau de taille zéro"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "le C++ ISO interdit le tableau de taille variable %qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "le C++ ISO interdit le tableau de taille variable"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "le tableau de taille variable %qD est utilisé"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "le tableau de taille variable est utilisé"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "débordement dans la dimension du tableau"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD est déclaré comme tableau de type à remplacer dans un patron %qT"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "création d'un tableau de type à remplacer dans un patron %qT"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "déclaration de %qD comme un tableau de « void »"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "création d'un tableau « void »"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "déclaration de %qD comme un tableau de fonctions"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "création d'un tableau de fonctions"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "déclaration de %qD comme un tableau de références"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "création d'un tableau de références"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "déclaration de %qD comme un tableau de fonctions membres"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "création d'un tableau de fonctions membres"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration de %qD comme tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "le tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "tableau de taille variable de %<auto%>"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la spécification d'un type retourné pour un constructeur est invalide"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un constructeur"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la spécification d'un type retourné pour un destructeur est invalide"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un destructeur"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "type de retour spécifié pour %<operator %T%>"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration de %<operator %T%>"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "type de retour spécifié pour le guide de déduction"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration du guide de déduction"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "paramètre de patron %qT, qui est lui-même un patron, dans la déclaration du guide de déduction"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> dans la déclaration du guide de déduction"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variable non nommée ou champ déclaré void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variable ou champ déclaré void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "spécificateur %<inline%> invalide pour la variable %qD déclarée au niveau du bloc"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les variables « inline » sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT en tant que type plutôt qu'un simple %<decltype(auto)%>"
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> ne peut pas être qualifié avec CV"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "utilisation invalide du nom qualifié %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T n'est pas une classe ou un espace de noms"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "déclaration de %qE comme non fonction"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "déclaration de %qE comme non membre"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "declarator-id manquant; utilisation du mot réservé %qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la définition de fonction ne déclare aucun paramètre"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "déclaration de %qD comme non fonction"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "déclaration de %qD comme %<typedef%>"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "déclaration de %qD comme paramètre"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "%qs et %qs spécifiés tous les deux"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs ne peut pas apparaître dans une déclaration typedef"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "au plus un seul spécificateur %<constinit%> ou %<constexpr%> peut être utilisé"
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "au moins deux types de données dans la déclaration de %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C++ ISO n'accepte pas qu'un simple %<complex%> signifie %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "le C++ ISO interdit la déclaration de %qs sans type"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> n'est pas supporté par la cible"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "le C++ ISO ne supporte pas %<__int%d%> pour %qs"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> et %<unsigned%> spécifiés ensemble"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> et %<short%> spécifiés ensemble"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs spécifié avec %qT"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "%qs spécifié avec %qD"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs spécifié avec %<decltype%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs spécifié avec %<typeof%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "« complex » invalide pour %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "liste d'arguments de patron manquante après %qE ; pour la déduction, le type à remplacer doit être suivi d'un simple declarator-id"
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "le membre %qD ne peut pas être déclaré à la fois %<virtual%> et %<static%>"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "le membre %qD peut être déclaré à la fois %<virtual%> et %<constexpr%> uniquement avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "la déclaration typedef est invalide dans la déclaration du paramètre"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs du patron"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "un paramètre ne peut pas être déclaré %qs"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> en dehors de la déclaration de classe"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "la déclaration d'une liaison structurée ne peut pas être %qs"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les déclarations de liaisons structurées peuvent être %qs uniquement en %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "la liaison structurée qualifiée avec %<volatile%> est dépréciée"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le %<auto%> du C++98"
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le type %qT"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "le type doit être un %<auto%> qualifié avec CV ou une référence à un %<auto%> qualifié avec CV"
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "une déclaration de liaison structurée ne peut pas avoir la contrainte %<auto%> de type %qT"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "classes de stockage multiples dans la déclaration de %qs"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "classe de stockage spécifiée pour %qs"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fonction imbriquée %qs déclarée %<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la déclaration de %qs hors de toute fonction spécifie %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs dans le champ de la fonction est implicitement déclaré auto et déclaré %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spécificateurs de classe de stockage invalides dans les déclarations de fonctions amies"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribut ignoré"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un attribut qui appartient à un spécificateur de type est ignoré"
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "parenthèses inutiles dans la déclaration de %qs"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "retirez les parenthèses"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "clause « requires » sur le type de retour"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la fonction %qs utilise le spécificateur de type %<auto%> sans type de retour à la fin"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "le type de retour déduit est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "une fonction virtuelle ne peut pas avoir un type de retour déduit"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %qT comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %<decltype(auto)%> comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "utilisation invalide de %<decltype(auto)%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "type de classe %qD déduit dans le type de retour de la fonction"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "le guide de déduction pour %qT doit avoir un type de retour à la fin"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "le type de retour %qT à la fin du guide de déduction n'est pas une spécialisation de %qT"
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "le type de retour à la fin est uniquement disponible avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "la fonction %qs avec le type de retour à la fin n'est pas déclarée avec le spécificateur de type %<auto%>"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "une fonction de conversion ne peut pas avoir de type de retour à la fin"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "le type de retour qualifié avec %<volatile%> est déprécié"
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs déclaré comme une fonction retournant une fonction"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs déclaré comme une fonction retournant un tableau"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "le type de retour %<constinit%> pour une fonction n'est pas permis"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "le destructeur ne peut être une fonction membre statique"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "le constructeur ne peut être une fonction membre statique"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "les constructeurs ne peuvent pas être déclarés %<virtual%>"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "les fonctions virtuelles ne peuvent pas être amies"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la déclaration amie n'est pas dans la définition de la classe"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "ne peut définir la fonction amie %qs dans une définition de classe locale"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "la définition de la fonction amie %qs ne peut pas avoir son nom qualifié avec %<::%>"
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "la définition de la fonction amie %qs ne pas avoir son nom qualifié avec %<%D::%>"
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destructeurs ne peuvent pas avoir de paramètre"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ne peut déclarer un pointeur vers %q#T"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "ne peut déclarer une référence vers %q#T"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ne peut déclarer un pointeur vers le membre %q#T"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "ne peut déclarer une référence vers le type de fonction qualifié %qT"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ne peut déclarer un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "ne peut déclarer une référence vers %q#T qui n'est pas un typedef ou un argument vers un type d'un patron"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD utilisé comme un déclarateur"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "les fonctions membres sont implicitement amies de leur classe"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "qualification %<%T::%> additionnelle sur le membre %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "ne peut définir la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "ne peut déclarer la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "ne peut déclarer le membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "le non paramètre %qs ne peut pas être un paquet de paramètres"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "les membres de données ne peuvent pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "le paramètre ne peut pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> en dehors de la déclaration de la classe"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> dans une déclaration amie"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "seuls les déclarations de constructeurs et les opérateurs de conversion peuvent être %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "le non membre %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "le membre non objet %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la fonction %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la référence %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef ne peut pas être une définition de fonction"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef ne peut pas être une définition de fonction membre"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> n'est pas autorisé dans une déclaration de synonyme"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef déclaré %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "clause « requires » sur un typedef"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "le nom du typedef ne peut pas être un nom de spécificateur imbriqué"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "le C++ ISO interdit le type imbriqué %qD avec le même nom que la classe englobante"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> spécifié pour la déclaration d'une classe amie"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "les paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d. %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "tentative de rendre amie la classe %qT au niveau de la portée globale"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "qualificatifs invalides sur un type de fonction non membre"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "clause « requires » sur type-id"
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "déclaration abstraite %qT utilisée comme déclaration"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "clause « requires » dans la déclaration du type non fonction %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "ne peut utiliser %<::%> dans la déclaration d'un paramètre"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ne peut déclarer un paramètre avec %<decltype(auto)%>"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr "liste d'arguments de patron manquante après %qE ; type à remplacer pour le patron non permis dans le paramètre"
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "ou utilisez %<auto%> pour le patron de fonction abrégé"
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "le paramètre %<auto%> n'est pas permis dans ce contexte"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "paramètre déclaré %<auto%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "utilisation invalide du nom de patron %qE sans liste d'arguments"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "membre de donnée non statique déclaré avec %qT comme type à remplacer"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "le C++ ISO interdit le membre tableau flexible %qs"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "le C++ ISO interdit les tableaux flexibles comme membres"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "utilisation invalide de %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "déclaration de la fonction %qD dans un contexte invalide"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fonction %qD déclarée %<virtual%> à l'intérieur d'une union"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD ne peut pas être déclaré %<virtual%> puisqu'il est toujours statique"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie du destructeur %qD"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "déclaration de %qD comme membre de %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "un destructeur ne peut pas être %qs"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie pour le constructeur %qD"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "un constructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "un concept ne peut être une fonction membre"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD ne peut pas être %qs"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "spécialisation du patron de variable %qD déclaré comme une fonction"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "le patron de variable a été déclaré ici"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "le champ %qD a le type incomplet %qT"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "le nom %qT a un type incomplet"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "le champ sans nom n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "un attribut qui appartient à une déclaration amie qui n'est pas une définition est ignorée"
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "membre de donnée statique %qE déclaré %qs"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "le membre statique %<constexpr%> %qD doit avoir une initialisation"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "le membre de donnée non statique %qE est déclaré %qs"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la classe de stockage %<auto%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la classe de stockage %<register%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la classe de stockage %<__thread%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la classe de stockage %<thread_local%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "le spécificateur de type « virt-specifier » sur %qs n'est pas permis en dehors d'une définition de classe"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<static%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<inline%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "fonction non classe virtuelle %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs défini en dehors d'un contexte de classe"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs déclaré en dehors d'un contexte de classe"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "ne peut déclarer la fonction membre %qD comme ayant une classe de liaison statique"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "ne peut déclarer une fonction statique à l'intérieur d'une autre fonction"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> ne peut pas être utilisé lors de la définition (contrairement à la déclaration) d'un membre de donnée statique"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "membre statique %qD déclaré %<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "ne peut explicitement déclarer le membre %q#D comme ayant une classe de liaison externe"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la déclaration de la variable %<constexpr%> %qD n'est pas une définition"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "une variable ne peut pas être déclarée %<consteval%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisé et déclaré %<extern%>"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs a, à la fois, %<extern%> et une initialisation"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "l'argument par défaut %qE utilise %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "l'argument par défaut %qE utilise la variable locale %qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "utilisation invalide du type %qT qualifié CV dans la déclaration du paramètre"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "utilisation invalide du type %<void%> dans la déclaration du paramètre"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "le paramètre qualifié avec %<volatile%> est obsolète"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "le paramètre %qD est incorrectement déclaré comme type de méthode"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut un pointeur vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut une référence vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructeur invalide; vous vouliez probablement utiliser %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD ne peut pas être déclaré dans un espace de noms"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD ne peut pas être déclaré statique"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD doit être une fonction membre non statique"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD doit être une fonction membre"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%qD peut être une fonction membre statique uniquement avec %<-std=c++23%> ou %<-std=gnu++23%>"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD doit être soit une fonction membre non statique ou une fonction non membre"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD doit avoir un argument de type classe ou énuméré"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "le C++ ISO interdit la surcharge de %<operator ?:%>"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD ne doit pas avoir un nombre variables d'arguments"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD doit avoir zéro ou un argument"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD doit avoir un ou deux arguments"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qD suffixé doit avoir %<int%> comme argument"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qD suffixé doit avoir %<int%> comme second argument"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD ne doit avoir aucun argument"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD doit avoir exactement un argument"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD doit avoir exactement deux arguments"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD ne peut avoir d'arguments par défaut"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversion de %qT vers %<void%> n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "%qD défini par l'usager évalue toujours les 2 arguments"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "%qD préfixé devrait retourner %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "%qD suffixé devrait retourner %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD devrait retourner par valeur"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "utilisation du paramètre du type de patron %qT après %qs"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "utilisation de la spécialisation du patron d'alias %qT après %qs"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "utilisation du nom de typedef %qD après %qs"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD a une déclaration précédente ici"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT référé en tant que %qs"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT a une déclaration précédente ici"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "il est fait référence à %qT comme un enum"
@@ -54991,110 +55001,110 @@ msgstr "il est fait référence à %qT comme un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argument du patron requis pour %<%s %T%>"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la référence à %qD est ambiguë"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "le patron de classe %qD est redéclaré comme un non patron"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT n'est pas un patron"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "vous voulez peut-être ajouter %<%T::%> explicitement"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "utilisation de l'enum %q#D sans déclaration précédente"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redéclaration de %qT sous une forme qui n'est pas un patron"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "ne peut déclarer %qD dans un module différent"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "l'union dérivée %qT est invalide"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT est défini avec des bases directes multiples"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT est défini avec des bases virtuelles directes"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "le type de base %qT n'est pas un « struct » ou une « class »"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "type récursif %qT non défini"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "le type de base dupliqué %qT est invalide"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "non concordance entre un enum simple et un enum fortement typé pour %q#T"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "définition précédente ici"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "désaccord dans le type sous-jacent de l'enum %q#T"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "types sous-jacents différents dans l'enum %q#T"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "impossible de définir %qD dans un module différent"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "le type sous-jacent %qT de %qT doit être un type entier"
@@ -55103,83 +55113,83 @@ msgstr "le type sous-jacent %qT de %qT doit être un type entier"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "aucun type entier ne peut représenter toutes les valeurs de l'énumération pour %qT"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "les valeurs énumérées de %qD doivent être de type entier ou une énumération simple (donc, pas fortement typée)"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "la valeur de l'énumération pour %qD n'est pas une constante entière"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<unsigned long%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<long%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "débordement dans les valeurs de l'énumération à %qD"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "la valeur de l'énumération %qE est en dehors de la plage du type sous-jacent %qT"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "définition multiple de %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "le type retourné %q#T est incomplet"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> devrait retourner une référence à %<*this%>"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction retournant %qT"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "seul un type de retour %<auto%> évident peut être déduit en %<void%>"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "« return » manquant dans une fonction %<constexpr%> devant retourner une valeur"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD est déjà défini dans la classe %qT"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "en utilisant %qs"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "utilisation de %qD avant la déduction de %<auto%>"
@@ -56028,7 +56038,7 @@ msgstr "le type %qT n'est pas une base directe ou virtuelle de %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "le type %qT n'est pas une base directe de %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "le tableau doit être initialisé avec une initialisation entre accolades"
@@ -57082,7 +57092,7 @@ msgstr "déclaration « using » pour un non membre au niveau de la portée de
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> avec la portée énumérée %q#T uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT n'est pas une classe, un espace de noms ou une énumération"
@@ -57828,7 +57838,7 @@ msgstr "les types ne peuvent pas être définis dans une expression %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_addressof%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_launder%>"
@@ -58537,12 +58547,12 @@ msgstr "seuls les constructeurs prennent des initialisions membres"
 msgid "cannot expand initializer for member %qD"
 msgstr "impossible de développer l'initialisation du membre %qD"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "l'initialisation en mémoire pour %qD suit la délégation du constructeur"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "la délégation du constructeur suit l'initialisation en mémoire pour %qD"
@@ -59141,7 +59151,7 @@ msgstr "arguments de patron manquants après %qE"
 msgid "%qT not permitted in template argument"
 msgstr "%qT pas permis dans un argument de patron"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -60002,7 +60012,7 @@ msgstr "%<[[omp::directive(%s)]]%> doit être le seul attribut spécifié dans u
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "clause %<ordered%> avec un paramètre sur une boucle %<for%> basée sur une portée"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable d'itération %qD ne devrait pas être une réduction"
@@ -61009,7 +61019,7 @@ msgstr "type non patron %qT utilisé comme un patron"
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "échec de la contrainte du patron pour %qD"
@@ -61102,276 +61112,276 @@ msgstr "fonction retournant un tableau"
 msgid "function returning a function"
 msgstr "fonction retournant une fonction"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence vers void"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formation d'un pointeur vers le type de référence %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formation d'une référence vers le type de référence %qT"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formation d'un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formation d'une référence vers le type de fonction qualifié %qT"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe %qT"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le type de référence au membre %qT"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de type void"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "création d'un tableau de %qT"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD est instancié pour un paquet vide"
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT n'est pas un type class, struct ou union"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT est résolu en %qT qui n'est pas un type d'énumération"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT est résolu en %qT qui n'est pas un type de classe"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "utilisation de %qs dans le patron"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "le nom dépendant %qE est analysé comme un non type, mais son instanciation produit un type"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utilisez %<typename %E%> si un type est désiré"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "l'initialiseur pour %q#D est développé en une liste vide d'expressions"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "utilisation du champ %qD invalide"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide de l'expression d'expansion d'un paquet"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "utilisez %<...%> pour dérouler le paquet d'arguments"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "initialisation vide dans l'initialisation par capture de la fonction lambda"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD n'a pas été déclaré dans cette portée et aucune déclaration a été trouvée par le recherche dépendant des arguments au point d'instanciation"
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "les déclarations dans la base dépendante %qT ne sont pas trouvées par une recherche non qualifiée"
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "utilisez plutôt %<this->%D%>"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "utilisez plutôt %<%T::%D%>"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD déclaré ici, plus loin dans l'unité de traduction"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "nombre erroné d'arguments pour l'attribut %<assume%>"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT n'est pas une classe ou un espace de noms"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD n'est pas une classe ou un espace de noms"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT est/utilise un type anonyme"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "l'argument du patron pour %qD utilise le type local %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT est un type modifié par une variable"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "l'expression intégrale %qE n'est pas une constante"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instancier %qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciation de patron ambiguë pour %q#T"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciation de patron ambiguë pour %q#D"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciation explicite du non patron %q#D"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instanciation explicite du concept de variable %q#D"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciation explicite du concept de fonction %q#D"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD n'est pas un membre de données statique d'un patron de classe"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "aucun patron correspondant trouvé pour %qD"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "le type %qT pour l'instanciation explicite %qD ne correspond pas au type déclaré %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciation explicite de %q#D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciation explicite dupliquée pour %q#D"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "le C++ ISO 1998 interdit l'utilisation de %<extern%> sur des instanciations explicites"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage %qD appliquée à l'instanciation du patron"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciation explicite du patron non classe %qD"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciation explicite du type non patron %qT"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciation explicite de %q#T avant la définition de patron"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "le C++ ISO interdit l'utilisation de %qE sur des instanciations explicites"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciation explicite dupliquée de %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "la spécification d'exception %qD dépend d'elle-même"
@@ -61383,163 +61393,163 @@ msgstr "la spécification d'exception %qD dépend d'elle-même"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciation explicite de %qD mais pas de définition disponible"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum de %d lors de l'instanciation de %q+D, peut-être via la génération de la table virtuelle (utilisez %<-ftemplate-depth=%> pour augmenter le maximum)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les paramètres de patrons non typés du type classe déduit sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT n'est pas un type valide pour un paramètre non type du patron car il n'est pas structurel"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les paramètres de patrons non typés du type classe sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "le paramètre non type du patron est invalide"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T n'est pas un type valide pour un paramètre non type du patron"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "le mot-clé %<template%> n'est pas permis dans declarator-id"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "un concept ne peut être contraint"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "le concept %qE n'est pas dans la portée de l'espace de noms"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "le concept %qE a plusieurs listes de paramètres de patrons"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la déduction à partir d'une liste d'initialisation entre accolades requiert %<#include <initializer_list>%>"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "le patron %qT ne peut être déduit et il est utilisé sans arguments de patron"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "la déduction du patron synonyme est uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "utilisez directement %qD à la place"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "impossible de déduire les arguments du patron pour l'initialisation par copie de %qT car il n'a pas de guides de déduction non explicites ou de constructeur déclaré par l'utilisateur"
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "impossible de déduire les arguments du patron de %qT car il n'a pas de guides de déduction viables"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "la déduction des arguments du patron de classe a échoué:"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "les guides de déduction explicites ne sont pas pris en compte pour l'initialisation par copie"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "la déduction de l'argument du patron de classe pour %qT a échoué : guide de déduction explicite sélectionné dans l'initialisation par copie de liste"
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "guide de déduction explicite déclaré ici"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT peut ne pas avoir l'intention de supporter la déduction d'argument pour un patron de classe"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "ajoutez un guide de déduction pour supprimer cet avertissement"
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "l'initialisation par liste directe de %<auto%> requiert exactement un élément"
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "pour la déduction de %<std::initializer_list%>, utilisez l'initialisation par liste copiée (c-à-d ajoutez %<=%> avant le %<{%>)"
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "impossible de déduire le type de retour de la lambda à partir de %qE"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "impossible de déduire %qT à partir de %qE"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "les contraintes sur le type à remplacer ne sont pas satisfaites"
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "l'initialisation déduite ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "le type retourné déduit ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "le type déduit pour l'expression ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "utilisation invalide de %qT dans un argument de patron"
@@ -61850,7 +61860,7 @@ msgstr "spécification de classe de base invalide"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "impossible de capturer le membre %qD d'une union anonyme"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD n'est pas capturé"
@@ -62259,27 +62269,27 @@ msgstr "%<__builtin_is_corresponding_member%> a besoin de deux arguments"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr "l'argument de %<__builtin_is_corresponding_member%> n'est pas un pointeur vers un membre"
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qD n'est pas un patron de classe ou un alias"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "l'opérande de l'expression fold n'a aucun paquet de paramètres non déroulé"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "les deux arguments dans le fold binaire ont des paquets de paramètres non déroulés"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "aucun paquet de paramètres non déroulés dans le fold binaire"
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
@@ -62287,22 +62297,22 @@ msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "%<__builtin_bit_cast%> a le type de destination %qT qui est un type tableau"
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%> a le type de destination %qT qui n'est pas trivialement copiable"
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%> a le type source %qT qui n'est pas trivialement copiable"
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "%<__builtin_bit_cast%> a la taille source %qE qui n'est pas égale à la taille du type destination %qE"
@@ -63534,220 +63544,220 @@ msgstr "déclaration anticipée de %q#T"
 msgid "declaration of %q#T"
 msgstr "déclaration de %q#T"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qD a un type incomplet"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "utilisation invalide du type incomplet %q#T"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "utilisation invalide de la fonction membre %qD (avez-vous oublié le %<()%> ?)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "utilisation invalide du membre %qD (avez-vous oublié le %<&%> ?)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "utilisation invalide du type à remplacer %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "utilisation invalide du paramètre de patron %qT qui est un type"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "utilisation invalide du paramètre de patron %qT qui est un patron"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "utilisation invalide de l'expansion d'un paquet %qT"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "utilisation invalide du type dépendant %qT"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "utilisation invalide de la liste d'initialisation entre accolades"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "adresse de la fonction surchargée sans information contextuelle de type"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "fonction surchargée sans information contextuelle de type"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "information contextuelle insuffisante pour déterminer le type"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "syntaxe de constructeur utilisée mais aucun constructeur déclaré pour le type %qT"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "la variable %<constinit%> %qD n'a pas une initialisation constante"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "la conversion réductrice de %qE depuis %qH vers %qI est mal formée en C++11"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "conversion réductrice de %qE depuis %qH vers %qI"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "l'expression a une valeur constante mais elle n'est pas une expression constante du C++"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "la chaîne d'initialisation pour %qT est trop longue"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr "l'initialisation d'une classe de base du type %qT résulte en un découpage d'objet"
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "enlever %<{ }%> autour d'un initialiseur"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "impossible d'initialiser l'agrégat du type %qT avec un littéral composé"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initialisation manquante pour le membre %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "le membre %qD est une référence non initialisée"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "membre %qD avec des champs de référence non initialisés"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "l'ordre du désignateur pour le champ %qD ne correspond pas à l'ordre de la déclaration dans %qT"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "pas de champ %qD trouvé dans l'union initialisée"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valeur d'index au lieu d'un nom de champ dans l'initialisation de l'union"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "délégation de pointeur circulaire détectée"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "l'opérande de base de %<->%> a un type non pointeur %qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "le résultat de %<operator->()%> est un non pointeur"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "l'opérande de base de %<->%> n'est pas un pointeur"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE ne peut pas être utilisé comme pointeur de membre puisqu'il est de type %qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "ne peut appliquer le pointeur membre %qE à %qE lequel est d'un type non classe %qT"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "le pointeur vers le type membre %qT est incompatible avec le type d'objet %qT"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une r-valeur"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur avant C++20"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "transtypage fonctionnel vers le type tableau %qT"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "%<auto(x)%> ne peut être contraint"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto(x)%> est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "l'initialisation par valeur du type référence est invalide"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "appel à la fonction %qD qui génère une exception du type incomplet %q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "appel à une fonction qui génère une exception du type incomplet %q#T"
@@ -64683,7 +64693,7 @@ msgstr "La constante littérale BOZ à %L ne peut pas être un argument effectif
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Les arguments de %qs à %L et %L ne peuvent pas être tous les deux des constantes littérales BOZ"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Utilisation invalide de la constant littérale BOZ à %L"
@@ -65776,12 +65786,12 @@ msgstr "Chaîne d'initialisation inutilisée à %L car la variable a une longueu
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "La chaine d'initialisation à %L a été tronquée pour tenir dans la variable (%ld/%ld)"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "L'index de départ de la sous-chaîne à %L est plus petit que un"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "L'index de fin de la sous-chaîne à %L excède la longueur de la chaîne"
@@ -65962,7 +65972,7 @@ msgstr "Mauvaise spécification INTENT à %C"
 msgid "deferred type parameter at %C"
 msgstr "paramètre de type différé à %C"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Expression INTEGER scalaire attendue à %L"
@@ -67973,7 +67983,7 @@ msgstr "L'intrinsèque transformationnel %qs à %L n'est pas permis dans une exp
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Évaluation d'une expression d'initialisation non standard à %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "La fonction %qs dans l'expression d'initialisation à %L doit être une fonction intrinsèque"
@@ -68244,7 +68254,7 @@ msgstr "Désaccord d'interface dans l'affectation du pointeur de procédure à %
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Interface explicite requise pour le composant %qs à %L: %s"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Interface explicite requise pour %qs à %L: %s"
@@ -68362,7 +68372,7 @@ msgstr "Affectation à un pointeur contigu depuis une cible non contigüe à %L"
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Le pointeur à %L dans l'affectation de pointeur pourrait vivre plus longtemps que la cible pointée"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "La cible de l'initialisation de pointeur à %L ne doit pas être ALLOCATABLE"
@@ -68372,7 +68382,7 @@ msgstr "La cible de l'initialisation de pointeur à %L ne doit pas être ALLOCAT
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "La cible de l'initialisation du pointeur à %L ne doit pas avoir l'attribut TARGET"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "La cible de l'initialisation du pointeur à %L doit avoir l'attribut SAVE"
@@ -68503,7 +68513,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Identifiant illégal dans copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -68719,12 +68729,12 @@ msgstr "Le premier argument de l'affectation définie à %L doit être INTENT(OU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'affection définie à %L doit être INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le premier argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
@@ -68834,562 +68844,562 @@ msgstr "Rang non concordant entre l'argument effectif à %L et l'argument effect
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Rang non concordant entre l'argument effectif à %L et l'argument effectif à %L (rang %d et rang %d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Argument de procédure invalide à %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Interface non concordante dans la procédure muette %qs à %L: %s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "L'argument effectif au pointeur contigus du muet %qs à %L doit être simplement contigu"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Désaccord de type entre l'argument effectif à %L et l'argument effectif à %L (%s/%s)."
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Type non concordant dans l'argument %qs à %L; passé %s à %s"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "L'argument effectif du type tacite à %L requiert que l'argument muet %qs soit d'un type tacite"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "L'argument effectif du type tacite à %L correspondant à l'argument muet de rang tacite %qs doit être d'une forme tacite ou de rang tacite"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "L'argument effectif de %qs à %L doit être polymorphique"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "L'argument effectif de %qs à %L doit avoir le même type déclaré"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "L'argument effectif de %qs à %L doit être polymorphique illimité puisque l'argument de format est un pointeur ou une entité polymorphique illimité allouable [F2008: 12.5.2.5]"
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "L'argument effectif de %qs à %L doit être un co-tableau"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Co-rang non concordant dans l'argument %qs à %L (%d et %d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "L'argument effectif de %qs à %L doit être simplement contigu ou un élément vers un tel tableau"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Argument effectif vers le muet %qs non INTENT(INOUT) à %L qui est LOCK_TYPE ou a un composant LOCK_TYPE"
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Argument effectif vers le muet %qs non INTENT(INOUT) à %L qui est EVENT_TYPE ou a un composant EVENT_TYPE"
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "L'argument muet %qs doit être un pointeur, un tableau de forme tacite ou de rang tacite sans attribut CONTIGUOUS – car l'argument effectif à %L n'est pas simplement contigu et les deux sont ASYNCHRONOUS ou VOLATILE"
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Passage d'un co-tableau à %L pour l'argument %qs allouable, non co-tableau, muet INTENT(OUT)"
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Passage d'un co-tableau à %L pour l'argument %qs allouable, non co-tableau et muet qui est invalide si le statut d'allocation est modifié"
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Scalaire polymorphique passé à l'argument tableau muet %qs à %L"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Un élément d'un tableau de forme tacite ou pointeur comme argument effectif à %L ne peut pas correspondre à l'argument effectif à %L"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Un élément d'un tableau de forme tacite ou pointeur est passé à l'argument tableau muet %qs à %L"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Extension: Argument effectif scalaire du sous-type pas par défaut, du sous-type non C_CHAR avec un argument muet tableau %qs à %L"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Argument effectif scalaire CHARACTER avec un argument muet tableau %qs à %L"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "L'argument mot-clé %qs à %L est invalide dans une fonction instruction"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "L'argument mot-clé %qs à %L n'est pas dans une procédure, vouliez-vous employer %qs ?"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "L'argument mot-clé %qs à %L n'est pas dans une procédure"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "L'argument mot-clé %qs à %L est déjà associé à un autre argument effectif"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Plus d'arguments effectifs que d'arguments formels dans l'appel de la procédure à %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Spécificateur de retour alternatif manquant dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Spécificateur de retour alternatif inattendu dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "NULL() intrinsèque inattendu à %L pour le muet %qs"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Pointeur null à %L pour un muet non pointeur %qs"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr "L'argument effectif à %L pour le muet de type tacite a des paramètres de type ou est de type dérivé avec une liaison à un type ou des procédures FINAL"
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Désaccord dans la longueur de CHARACTER (%ld/%ld) entre l'argument effectif et l'argument muet pointeur ou allouable %qs à %L"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Désaccord dans la longueur de CHARACTER (%ld/%ld) entre l'argument effectif et l'argument muet de forme tacite %qs à %L"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "L'argument effectif à %L pour l'argument muet allouable ou pointeur %qs doit avoir un paramètre de type différé si et uniquement si le muet en a un"
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "La longueur de CHARACTER de l'argument effectif est plus court que celui de l'argument muet %qs (%lu/%lu) à %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "L'argument effectif contient trop peu d'éléments pour l'argument muet %qs (%lu/%lu) à %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Pointeur de procédure attendu pour l'argument %qs à %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Procédure attendue pour l'argument %qs à %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "L'argument effectif pour %qs ne peut pas être un tableau de taille tacite à %L"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr "Argument effectif vers le muet de rang tacite INTENT(OUT) %qs à %L ne peut pas être de taille inconnue"
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "L'argument effectif pour %qs à %L doit être un pointeur"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Argument effectif non pointeur à %L vers le muet pointeur %qs"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr "L'argument effectif pour %qs à %L doit être un pointeur ou une cible valide pour le pointeur muet dans l'instruction d'affectation d'un pointeur"
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Argument effectif co-indexé à %L vers le muet pointeur %qs"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "L'argument effectif co-indexé à %L vers le muet allouable %qs requiert INTENT(IN)"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "L'argument effectif co-indexé ASYNCHRONOUS ou VOLATILE à %L requiert que le muet %qs n'ait ni ASYNCHRONOUS ni VOLATILE"
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "L'argument effectif co-indexé à %L avec un composant ultimement allouable pour le muet %qs requiert soit VALUE ou INTENT(IN)"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "L'argument effectif qui est un tableau de CLASS pour %qs doit être un tableau complet à %L"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "L'argument effectif pour %qs doit être ALLOCATABLE à %L"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "L'argument effectif qui est une section de tableau avec des indices de vecteur à %L est incompatible avec l'attribut INTENT(OUT), INTENT(INOUT), VOLATILE ou ASYNCHRONOUS de l'argument muet %qs"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif de forme tacite à %L est incompatible avec l'argument muet de forme non tacite %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif qui est une section de tableau à %L est incompatible avec l'argument muet de forme non tacite %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif qui est un tableau de pointeurs à %L requiert un argument muet de forme tacite ou un tableau de pointeurs %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Spécification de retour alternatif manquant dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Argument effectif manquant pour l'argument %qs à %L"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Mauvais code de composant"
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Liste non concordante"
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): donnée corrompue"
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Le même argument effectif est associé avec l'argument INTENT(%s) %qs et l'argument INTENT(%s) %qs à %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Liste non concordante"
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "L'argument de procédure à %L est local dans une procédure PURE et a l'attribut POINTER"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "L'argument effectif co-indexé à %L dans une procédure PURE est passé à un argument INTENT(%s)"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "L'argument effectif co-indexé à %L dans une procédure PURE est passé à un argument muet de type POINTER"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "L'argument effectif polymorphique co-indexé à %L est passé à l'argument muet polymorphique %qs"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "La procédure %qs appelée à %L n'est pas explicitement déclarée, vouliez-vous employer %qs ?"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "La procédure %qs appelée à %L n'est pas explicitement déclarée"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Procédure %qs appelée avec une interface implicite à %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "L'objet pointeur %qs à %L doit avoir une interface de fonction explicite ou être déclaré comme un tableau"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "L'objet allouable %qs à %L doit avoir une interface de fonction explicite ou être déclaré comme un tableau"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "La fonction allouable %qs à %L doit avoir une interface de fonction explicite"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Interface explicite requise pour l'argument polymorphique à %L"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "L'argument mot-clé requiert une interface explicite pour la procédure %qs à %L"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "L'argument de type tacite %s à %L requiert une interface explicite"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "L'argument effectif de LOCK_TYPE ou avec un composant LOCK_TYPE à %L requiert une interface explicite pour la procédure %qs"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "L'argument effectif de EVENT_TYPE ou avec un composant EVENT_TYPE à %L requiert une interface explicite pour la procédure %qs"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "Argument MOLD requis pour NULL à %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "Passer l'intrinsèque NULL comme argument effectif à %L requiert une interface explicite"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Un argument de rang tacite requiert une interface explicite à %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Composant pointeur de procédure %qs appelé avec une interface implicite à %L"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "L'argument mot-clé requiert une interface explicite pour le composant pointeur de procédure %qs à %L"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= est requis dans l'argument NULL() à %L: Ambigüité entre les fonctions spécifiées %s et %s"
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Impossible de trouver le symbole %qs"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "L'entité %qs à %L est déjà présente dans l'interface"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Mauvais type d'interface"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Ne peut écraser GENERIC %qs à %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs à %L redéfini une liaison de procédure déclarée NON_OVERRRIDABLE"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs à %L ne doit pas être DEFERRED car il redéfini une liaison non DEFERRED"
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs à %L redéfini une procédure PURE et doit aussi être PURE"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs à %L redéfini une procédure ELEMENTAL et doit aussi être ELEMENTAL"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs à %L redéfini une procédure non ELEMENTAL et ne doit pas être ELEMENTAL non plus"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs à %L redéfini une SUBROUTINE et doit aussi être une SUBROUTINE"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs à %L redéfini une FUNCTION et doit aussi être une FUNCTION"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Résultat non concordant pour la redéfinition de la procédure %qs à %L: %s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs à %L redéfini une procédure PUBLIC et ne doit pas être PRIVATE"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "L'argument muet %qs de %qs à %L devrait être nommé %qs pour correspondre à l'argument équivalent de la procédure redéfinie"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Argument non concordant pour la procédure redéfinissante %qs à %L: %s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs à %L doit avoir le même nombre d'arguments formels que la procédure redéfinie"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs à %L redéfini une liaison NOPASS et doit aussi être NOPASS"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs à %L redéfini une liaison PASS et doit aussi être PASS"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "L'argument muet %qs de type objet passé à %L doit être à la même position que l'argument muet de type objet passé à la procédure redéfinie"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "L'argument muet DTIO à %L doit être du type %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "L'argument muet DTIO à %L doit avoir KIND = %d"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "L'argument muet DTIO à %L doit être un scalaire"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "L'argument muet DTIO à %L doit être ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "L'argument caractère DTIO à %L doit avoir une longueur tacite"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "L'argument muet DTIO à %L doit avoir INTENT %s"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Le retour alternatif à %L n'est pas permis dans une procédure DTIO"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "La procédure DTIO %qs à %L doit être une sous-routine"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Trop peu d'arguments muets dans la procédure DTIO %qs à %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Trop d'arguments muets dans la procédure DTIO %qs à %L"
@@ -69573,7 +69583,7 @@ msgstr "Conversion de %s vers %s à %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Impossible de convertir %s en %s à %L"
@@ -70124,7 +70134,7 @@ msgstr "NAMELIST %qs dans l'instruction READ à %L contient le symbole %qs qui n
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
@@ -70691,7 +70701,7 @@ msgstr "Le code STOP à %L doit être un caractère par défaut avec KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Le code STOP à %L doit être un entier par défaut avec KIND=%d"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "Le spécificateur QUIET à %L doit être un scalaire LOGICAL"
@@ -72548,8 +72558,8 @@ msgstr "Le paramètre de la clause ORDERED est plus petit que COLLAPSE à %L"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "la clause ORDER ne doit pas être utilisée avec ORDERED à %L"
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause IF à %L requiert une expression LOGICAL scalaire"
@@ -74521,713 +74531,723 @@ msgstr "La procédure de module %qs avec une valeur de caractère à %L ne peut
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "La fonction interne %qs avec une valeur de caractère à %L ne peut pas avoir une longueur tacite"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "La fonction %s à %L a des entrées avec des spécifications de tableau non concordantes"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "La fonction %s à %L a l'entrée %s avec des caractéristiques non concordantes"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "La fonction %s à %L a des entrées qui retournent des variables de longueurs de chaînes différentes"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Le résultat de FUNCTION %s ne peut pas être un tableau dans FUNCTION %s à %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Le résultat de ENTRY %s ne peut pas être un tableau dans FUNCTION %s à %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Le résultat de FUNCTION %s ne peut pas être un POINTER dans FUNCTION %s à %L"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Le résultat de ENTRY %s ne peut pas être un POINTER dans FUNCTION %s à %L"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Le résultat de FUNCTION %s ne peut pas être ALLOCATABLE dans FUNCTION %s à %L"
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Le résultat de ENTRY %s ne peut pas être ALLOCATABLE dans FUNCTION %s à %L"
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Le résultat de FUNCTION %s ne peut pas être du type %s dans FUNCTION %s à %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Le résultat de ENTRY %s ne peut pas être du type %s dans FUNCTION %s à %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "L'entité globale %qs à %L ne peut pas apparaître dans un bloc COMMON à %L"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "L'entité globale %qs à %L ne peut pas apparaître dans un bloc COMMON"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr "Bloc COMMON à %L"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "La variable %qs à %L est dans COMMON mais seule l'initialisation dans BLOCK DATA est permise"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "La variable %qs à %L est initialisée dans un COMMON blanc mais l'initialisation est uniquement permise dans des communs nommés"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr "%qs à %L ne peut pas apparaître dans COMMON [F2008:C5100]"
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "La variable %qs, d'un type dérivé, dans COMMON à %L n'a ni l'attribut SEQUENCE ni l'attribut BIND(C)"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "La variable %qs, d'un type dérivé, dans COMMON à %L a un composant ultime qui est allouable"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "La variable %qs, d'un type dérivé, dans COMMON à %L ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr "En Fortran 2003, le bloc COMMON %qs à %L est un identificateur global et doit donc avoir le même nom de liaison que le bloc COMMON similairement nommé à %L: %s vs %s"
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "Le bloc COMMON %qs à %L utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr "Fortran 2008: Le bloc COMMON %qs avec l'étiquette de liaison à %L partage l'identificateur avec l'entité de bloc non COMMON globale à %L"
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "Le bloc COMMON à %L avec le label de liaison %qs utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "Le bloc COMMON %qs à %L est utilisé comme PARAMETER à %L"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "Le bloc COMMON %qs à %L ne peut pas avoir d'attribut EXTERNAL"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "Le bloc COMMON %qs à %L est aussi une procédure intrinsèque"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "Le bloc COMMON %qs à %L qui est aussi un résultat de fonction"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "Le bloc COMMON %qs à %L qui est aussi une procédure globale"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr "Le paramètre KIND %qs dans le constructeur PDT à %C n'a pas de valeur"
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "Le rang de l'élément dans le constructeur de structure à %L ne correspond pas à celui du composant (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "L'élément dans le constructeur de structure à %L, pour le composant pointeur %qs, est %s mais il devrait être %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Longueurs de caractères inégales (%wd/%wd) pour le composant pointeur %qs dans le constructeur à %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "Le NULL dans le constructeur de structure à %L est appliqué au composant %qs qui n'est ni un POINTER ni ALLOCATABLE"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "Désaccord d'interface pour le composant pointeur de procédure %qs dans le constructeur de structure à %L: %s"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "Mauvaise spécification de tableau du composant %qs référencé dans le constructeur de structure à %L"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "La forme du composant %qs dans le constructeur de structure à %L diffère de la forme du composant déclaré pour la dimension %d (%ld/%ld)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "L'élément dans le constructeur de structure à %L pour le composant pointeur %qs devrait être un POINTER ou un TARGET"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Expression invalide dans le constructeur de structure pour le composant pointeur %qs à %L dans une procédure PURE"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "La limite supérieure dans la dernière dimension doit apparaître dans la référence du tableau de taille tacite %qs à %L"
 
 # %qs est le nom d'une procédure d'où le féminin
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "%qs à %L est ambigüe"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "La procédure GENERIC %qs n'est pas permise comme argument effectif à %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Le type spécifié pour la fonction intrinsèque %qs à %L est ignoré"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "La sous-routine intrinsèque %qs à %L n'aura point de spécificateur de type"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%qs déclaré INTRINSIC à %L n'existe pas"
 
 # %s est une chaîne non traduite telle que "available since Fortran 77".
 # voir bugs #38573 et #52279 à ce sujet.
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "L'intrinsèque %qs déclaré INTRINSIC à %L n'est pas disponible avec les paramètres standard actuels mais est %s. Utilisez l'option %<-std=*%> appropriée ou activez %<-fall-intrinsics%> de manière à pouvoir l'utiliser."
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "La procédure non RECURSIVE %qs à %L semble s'appeler elle-même récursivement. Déclarez là RECURSIVE ou utilisez %<-frecursive%>"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "L'étiquette %d référencée à %L n'est jamais définie"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Le type dérivé %qs est utilisé comme argument effectif à %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "La fonction-instruction %qs à %L n'est pas permise comme argument effectif"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "L'intrinsèque %qs à %L n'est pas permis comme argument effectif"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Procédure interne %qs utilisée comme argument effectif à %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "La procédure ELEMENTAL non INTRINSIC %qs n'est pas permise comme argument effectif à %L"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Impossible de trouver une procédure INTRINSIC spécifique pour la référence %qs à %L"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Le symbole %qs à %L est ambigu"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "L'argument par valeur à %L n'est pas un type numérique"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "L'argument par valeur à %L ne peut pas être un tableau ou une section de tableau"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "L'argument par valeur à %L n'est pas permis dans ce contexte"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Passer la procédure interne à %L par position n'est pas permis"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Le composant pointeur de procédure ELEMENTAL %qs n'est pas permis comme argument effectif à %L"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Argument effectif co-indexé à %L avec un composant pointeur ultime"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "%qs à %L est un tableau et est OPTIONAL; s'il n'est pas présent, il ne peut pas être l'argument effectif d'une procédure ELEMENTAL à moins qu'il y ait un argument non optionnel avec le même rang (Fortran 2018, 15.5.2.12)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "L'argument effectif à %L pour le muet INTENT(%s) %qs de la sous-routine ELEMENTAL %qs est un scalaire mais un autre argument effectif est un tableau"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Désaccord dans le type de retour de la fonction %qs à %L (%s/%s)"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Non concordance de l'interface dans la procédure globale %qs à %L: %s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Il n'y a pas de fonction spécifique pour la fonction générique %qs à %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "La fonction générique %qs à %L n'est pas cohérente avec l'interface intrinsèque spécifique"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La fonction %qs à %L est INTRINSIC mais elle est incompatible avec un intrinsèque"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Impossible de résoudre la fonction spécifique %qs à %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr "Déclaration explicite manquante avec l'attribut EXTERNAL pour le symbole %qs à %L"
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT, vouliez-vous employer %qs ?"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT"
 
 # %s à la fin est le texte non traduit "mask" ou "block"
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Référence à la fonction impure %qs à %L à l'intérieur d'un FORALL %s"
 
 # %s à la fin est le texte non traduit "mask" ou "block"
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Référence à la fonction impure %qs à %L à l'intérieur d'un DO CONCURRENT %s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Référence à la fonction impure %qs à %L dans une procédure PURE"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Rebut inattendu après %qs à %L"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs à %L n'est pas une fonction"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs ne doit pas être référencée à %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr "ABSTRACT INTERFACE %qs à %L ne doit pas avoir un résultat d'une longueur de caractères tacite (F2008: C418)"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "La fonction %qs est déclarée CHARACTER(*) et ne peut pas être utilisée à %L car elle n'est pas un argument muet"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): mauvais type de fonction"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr "Une constante littérale BOZ à %L ne peut pas apparaître comme un argument effectif dans une référence de fonction"
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "La fonction %qs non ELEMENTAL définie par l'utilisateur à %L n'est pas permise dans la construction WORKSHARE"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs à %L ne peut pas être appelé récursivement car la fonction %qs n'est pas RECURSIVE"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "La fonction %qs à %L ne peut pas être appelée récursivement car elle n'est pas RECURSIVE"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "L'utilisation de la fonction %qs à %L est obsolète"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "L'appel de sous-routine à %qs dans le bloc FORALL à %L n'est pas PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "L'appel de sous-routine à %qs dans le bloc DO CONCURRENT à %L n'est pas PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "L'appel de sous-routine à %qs à %L n'est pas PURE"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Il n'y a pas de sous-routine spécifique pour le générique %qs à %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "La sous-routine générique %qs à %L n'est pas cohérente avec l'interface de sous-routine intrinsèque"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La sous-routine %qs à %L est INTRINSIC mais elle n'est pas compatible avec un intrinsèque"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Impossible de résoudre la sous-routine spécifique %qs à %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs à %L a un type, ce qui n'est pas cohérent avec l'appel CALL à %L"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs à %L ne peut pas être appelé récursivement car la sous-routine %qs n'est pas RECURSIVE"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs à %L ne peut pas être appelée récursivement car elle n'est pas RECURSIVE"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): mauvais type de fonction"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "L'utilisation de la sous-routine %qs à %L est obsolète"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Les formes pour les opérandes à %L et %L ne sont pas conformes"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Mauvais intrinsèque"
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "La fonction impure %qs à %L pourrait ne pas être évaluée"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "La fonction impure à %L pourrait ne pas être évaluée"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "La constante littérale BOZ à %L ne peut pas être un opérande de l'opérateur unaire %qs"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Les opérandes à %L et %L ne peuvent pas apparaître comme opérandes de l'opérateur binaire %qs"
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "La constante littérale BOZ près de %L ne peut pas apparaître comme opérande d'un opérateur relationnel"
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "Comparaison égalitaire pour %s à %L"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "Comparaison inégalitaire pour %s à %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Mauvais intrinsèque"
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la co-dimension %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la co-dimension %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Pas nul illégal à %L"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Mauvaise référence de tableau"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "La limite supérieure la plus à droite de la section du tableau de taille tacite n'est pas spécifiée à %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord de rang dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord du rang du co-index dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Le co-index de la co-dimension %d doit être un scalaire à %L"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "L'index de tableau à %L doit être scalaire"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "L'index de tableau à %L doit être du type INTEGER, on a trouvé %s"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "Index de tableau REAL à %L"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "L'argument dim à %L doit être scalaire"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "L'argument dim à %L doit être du type INTEGER"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Référence de tableau invalide dans une entité qui n'est pas un tableau à %L"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): « as » inutilisé(1)"
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): « as » inutilisé(2)"
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "L'index de tableau à %L est un tableau de rang %d"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "L'index de départ de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "L'index de départ de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "L'index de fin de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "L'index de fin de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "L'index de fin de la sous-chaîne à %L est trop grand"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Mauvaise référence de tableau"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut POINTER à %L"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut ALLOCATABLE à %L"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Deux références de parties (ou plus) avec un rang non nul ne peuvent pas être spécifiées à %L"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Deux specs de tableau"
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK peut uniquement être utilisée comme argument effectif"
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "La variable de type tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -75236,12 +75256,12 @@ msgstr "La variable de type tacite %s à %L peut uniquement être utilisée comm
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de type tacite %s à %L comme argument effectif à une fonction de requête sera le premier argument"
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "La variable de rang tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -75250,296 +75270,296 @@ msgstr "La variable de rang tacite %s à %L peut uniquement être utilisée comm
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de rang tacite %s à %L comme argument effectif à une fonction intrinsèque sera le premier argument"
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de type tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de rang tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs, utilisée dans une expression de spécification, est référencée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs est utilisée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Sous-objet polymorphique d'un objet co-indexé à %L"
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objet co-indexé avec un sous-composant allouable polymorphique à %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "L'utilisation de la variable %qs à %L est obsolète"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs à %L est associé à l'hôte à %L dans une procédure contenue avec une procédure interne du même nom"
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Erreur dans l'appel avec type lié à %L"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "L'objet passé à %L doit être scalaire"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de composant pointeur de procédure à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de procédure liée au type à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "L'objet de base pour l'appel de procédure liée au type NOPASS à %L doit être scalaire"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Aucune liaison spécifique correspondante pour l'appel à GENERIC %qs à %L"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs à %L devrait être une SUBROUTINE"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs à %L devrait être une FUNCTION"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Mauvais type d'expression"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s à %L doit être un scalaire"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s à %L doit être un entier"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s à %L doit être INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "L'expression de pas dans la boucle DO à %L ne peut pas être zéro"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "La boucle DO à %L sera exécutée zéro fois"
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde"
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde vers le bas"
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Le nom d'index FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "L'expression de départ de FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "L'expression de fin de FORALL à %L doit être un INTEGER scalaire"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "L'expression de pas de FORALL à %L doit être un %s scalaire"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "L'expression de pas de FORALL à %L ne peut pas être zéro"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "L'index %qs de FORALL ne peut pas apparaître dans une spécification de triplet à %L"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "L'objet allouable à %L doit être ALLOCATABLE ou un POINTER"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objet allouable co-indexé à %L"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "L'expression source à %L doit être scalaire ou avoir le même rang que l'objet allouable à %L"
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "L'expression source à %L et l'objet allouable à %L doivent avoir la même forme"
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Le type de l'entité à %L a un type incompatible avec l'expression source à %L"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "L'objet allouable à %L et l'expression source à %L auront le même paramètre de sous-type"
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type LOCK_TYPE ni un composant LOCK_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type EVENT_TYPE ni un composant EVENT_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "L'allocation de %s du type de base ABSTRACT à %L requiert une spécification de type ou une expression source"
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "L'allocation de %s à %L avec la spécification de type requiert la même longueur de caractères dans le paramètre que dans la déclaration"
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spécification de tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Une spécification de tableau ou une expression SOURCE= avec une valeur tableau est requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spécification de co-tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de co-tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure à %L"
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure 1 à %L"
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs ne doit pas apparaître dans la spécification de tableau à %L dans la même instruction ALLOCATE où il est lui-même alloué"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%<*%> attendu dans la spécification du co-index dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat à %L doit être une variable INTEGER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG à %L est inutile sans la balise STAT"
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "La variable ERRMSG à %L sera une variable CHARACTER du scalaire par défaut"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "L'objet alloué à %L apparaît aussi à %L"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
@@ -75548,284 +75568,284 @@ msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "L'étiquette CASE à %L chevauche l'étiquette CASE à %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "L'expression dans l'instruction CASE à %L doit être du type %s"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "L'expression dans l'instruction CASE à %L doit être du sous-type %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "L'expression dans l'instruction CASE à %L doit être scalaire"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "L'expression de sélection dans le GOTO calculé à %L doit être une expression entière scalaire"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "L'argument de l'instruction SELECT à %L ne peut pas être %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "L'argument de l'expression SELECT à %L doit être une expression scalaire"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "L'expression dans l'instruction CASE à %L n'est pas dans la plage de %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Le DEFAULT CASE à %L ne peut pas être suivi par un second DEFAULT CASE à %L"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Une plage logique n'est pas permise dans l'instruction CASE à %L"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "La valeur logique constante est répétée dans l'instruction CASE à %L"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La spécification d'étendue à %L ne peut jamais correspondre à quoi que ce soit"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Le bloc SELECT CASE logique à %L a plus de deux cas"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "L'entité associante %qs à %L est un pointeur de procédure"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Le type dérivé %qs ne peut pas être utilisé comme une variable à %L"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "L'entité associante %qs à %L est un nom de procédure"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "L'expression de sélecteur associant à %L donne une procédure"
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Le sélecteur à %L ne peut pas NULL()"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Le sélecteur à %L n'a pas de type"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Le nom associé %qs à %L est utilisé comme tableau"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "Le sélecteur CLASS à %L a besoin d'un temporaire qui n'est pas encore implémenté"
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Le sélecteur sera polymorphique dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Le sélecteur à %L ne doit pas être co-indexé"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS à %L chevauche TYPE IS à %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Le type dérivé %qs à %L doit être extensible"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Le type dérivé %qs à %L doit être une extension de %qs"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Type intrinsèque %qs inattendu à %L"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La spécification de type à %L doit spécifier que chaque paramètre de type de longueur est tacite"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloc CLASS IS en double dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT à %L est répété à %L"
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) à %L est répété à %L"
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) à %L est répété à %L"
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) à %L ne peut pas être utilisé avec un pointeur ou un sélecteur allouable à %L"
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexte invalide pour l'intrinsèque NULL () à %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "La procédure DTIO %s à %L doit être récursive"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas être polymorphique à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants POINTER à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants de pointeur de procédure"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants ALLOCATABLE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "L'élément de transfert de données à %L ne peut pas être une référence complète à un tableau de taille tacite"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable verrou à %L doit être un scalaire de type LOCK_TYPE"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable d'événement à %L doit être un scalaire de type EVENT_TYPE"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau ou co-indexé"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau mais pas co-indexé"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "L'argument STAT= à %L doit être une variable INTEGER scalaire"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "L'argument ERRMSG= à %L doit être une variable CHARACTER scalaire"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "L'argument ACQUIRED_LOCK= à %L doit être une variable LOGICAL scalaire"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "L'argument UNTIL_COUNT= à %L doit être une expression INTEGER scalaire"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "L'argument imageset à %L doit être une expression scalaire ou INTEGER de rang 1"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "L'argument imageset à %L doit être entre 1 et num_images()"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "L'instruction à %L n'est pas une instruction cible valable pour l'instruction de branchement à %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Le branchement à %L peut conduire à une boucle infinie"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction CRITICAL pour l'étiquette à %L"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'étiquette à %L"
@@ -75833,207 +75853,207 @@ msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'é
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "L'étiquette à %L n'est pas dans le même bloc que l'instruction GOTO à %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Le masque WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "La cible de l'affectation WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Affectation définie par l'utilisateur non ELEMENTAL dans WHERE à %L"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Instruction non supportée à l'intérieur de WHERE à %L"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Affectation à une variable d'index FORALL à %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Le FORALL avec l'index %qs n'est pas utilisé dans le membre de gauche de l'affectation à %L et, par conséquent, pourrait causer de multiples affectations à cet objet"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Construction FORALL à %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Le nom d'index de FORALL à %L doit être une variable scalaire de type entier"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Une construction de boucle FORALL extérieure a déjà un index avec ce nom à %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "La clause WHERE/ELSEWHERE à %L requiert un tableau LOGICAL"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Mauvais type de bloc"
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "L'expression CHARACTER sera tronquée dans l'affectation (%ld/%ld) à %L"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "L'expression co-indexée à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "Dans un sous-programme pure, un argument fictif INTENT(IN) ne sera point utilisé comme l'expression à %L d'une instruction d'affectation intrinsèque dans laquelle la variable est d'un type dérivé si le type dérivé a un composant pointeur à n'importe quel niveau de la sélection du composant."
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Affectation à une variable co-indexée à %L dans une procédure PURE"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "L'affectation à un co-tableau polymorphique à %L n'est pas permise"
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Affectation à une variable polymorphique allouable à %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "L'affectation à une variable polymorphique allouable à %L requiert %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "La variable non allouable ne doit pas être polymorphique dans l'affectation intrinsèque à %L – vérifiez qu'il existe une sous-routine spécifique correspondante pour l'opérateur %<=%>"
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable co-indexée ne doit pas avoir un composant ultimement allouable dans l'affectation à %L"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "À FAIRE: la/les affectation(s) liée(s) au type à %L n'ont pas été réalisées car des références multiples à des parties de tableaux apparaîtraient dans des expressions intermédiaires."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Affectation à une procédure pointeur à %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Le résultat de la fonction dans le membre de gauche de l'affectation à %L doit avoir l'attribut pointeur."
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "L'argument TEAM de %qs à %L doit être une expression scalaire de type TEAM_TYPE"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "L'argument TEAM NUMBER pour FROM TEAM à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "L'instruction ASSIGNED GOTO à %L requiert une variable INTEGER scalaire"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Une étiquette cible n'a pas été affectée à la variable %qs à %L"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "L'instruction RETURN alternatif à %L requiert un spécificateur de retour SCALAR-INTEGER"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Assignation intrinsèque attendue dans OMP WORKSHARE à %L"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "L'instruction ASSIGN à %L requiert une variable scalaire INTEGER par défaut"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL invalide à %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "L'instruction IF arithmétique à %L requiert une expression scalaire REAL ou INTEGER"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Pas d'expression dans le DO WHILE"
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condition de sortie de la boucle DO WHILE à %L doit être une expression LOGICAL scalaire"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause de masque FORALL à %L requiert une expression scalaire LOGICAL"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mauvais code d'instruction"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "L'utilisation du paramètre %qs déclaré à %L est obsolète"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La variable %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L du module %qs"
@@ -76041,986 +76061,986 @@ msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L uti
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La procédure %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longueur de chaîne à %L est trop grande"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le tableau allouable %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "L'objet scalaire %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le pointeur tableau %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Le tableau %qs à %L ne peut pas avoir une forme différée"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Le type %qs de la variable CLASS %qs à %L n'est pas extensible"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS %qs à %L doit être muette, allouable ou pointeur"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Le type %qs ne peut pas être associé à un hôte à %L car il est bloqué par un objet incompatible du même nom déclaré à %L"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "SAVE implicite pour la variable module %qs à %L, nécessaire à cause de l'initialisation par défaut"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "L'entité %qs à %L a un paramètre de type différé et requiert soit l'attribut POINTER ou ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Le tableau %qs à %L du module ou du programme principal doit avoir une forme constante"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "L'entité avec une longueur de caractère tacite à %L doit être un argument muet ou un PARAMETER"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs à %L doit avoir une longueur de caractère constante dans ce contexte"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON %qs à %L doit avoir une longueur de caractère constante"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "L'allouable %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "L'externe %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Le muet %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "L'intrinsèque %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Le résultat de fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Le tableau automatique %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s à %L"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La fonction-instruction %qs avec une valeur de caractère à %L doit avoir une longueur constante"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs est d'un type PRIVATE et ne peut pas être un argument muet de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "La procédure %qs dans l'interface PUBLIC %qs à %L prend des arguments muets de %qs qui est PRIVATE"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "L'objet externe %qs à %L ne peut pas avoir d'initialisation"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La fonction ELEMENTAL %qs à %L doit avoir un résultat scalaire"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La fonction-instruction %qs à %L ne peut pas avoir l'attribut pointeur ou allouable"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un tableau"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un pointeur"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être pure"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être récursive"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fonction CHARACTER(*) %qs à %L"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Le pointeur de procédure %qs à %L ne sera point élémental"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "La procédure muette %qs à %L ne sera point élémentale"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable résultat %qs de la fonction à %L de la fonction élémentale %qs n'aura point l'attribut ALLOCATABLE ou POINTER"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut SAVE dans %qs à %L"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut INTENT dans %qs à %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut RESULT dans %qs à %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "L'attribut EXTERNAL est en conflit avec l'attribut FUNCTION dans %qs à %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Le résultat du pointeur de procédure %qs à %L n'a pas d'attribut pointeur"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut ELEMENTAL entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut PURE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut RECURSIVE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s entre la déclaration MODULE PROCEDURE dans MODULE %qs et la déclaration à %L dans (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "L'interface de %qs à %L doit être explicite"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "La procédure FINAL %qs à %L n'est pas une SUBROUTINE"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "La procédure FINAL à %L doit avoir exactement un argument"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "L'argument de la procédure FINAL à %L doit être du type %qs"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr "La procédure FINAL à %L avec un argument de rang tacite doit être le seul finaliseur avec le même genre/type (F2018: C790)"
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être un POINTER"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être OPTIONAL"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être INTENT(OUT)"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "La procédure FINAL non scalaire à %L devrait avoir un argument de forme tacite"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "La procédure FINAL %qs déclarée à %L a le même rang (%d) que %qs"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Seules des procédures FINAL tableaux déclarées pour le type dérivé %qs à %L, une scalaire est également suggérée à moins qu'un finaliseur de rang tacite a été déclaré"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs et %qs ne peuvent pas être FUNCTION/SUBROUTINE mixte pour GENERIC %qs à %L"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs et %qs pour GENERIC %qs à %L sont ambigus"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Liaison spécifique %qs non définie comme cible du GENERIC %qs à %L"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs à %L doit cibler une liaison spécifique, %qs est GENERIC aussi"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs à %L ne peut écraser la liaison spécifique avec le même nom"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "L'opérateur lié au type à %L ne peut pas être NOPASS"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs doit être une procédure de module ou une procédure externe avec une interface explicite à %L"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "La procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "La procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argument muet passé comme objet non polymorphique de %qs à %L"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "L'argument muet de type objet passé de %qs à %L doit être scalaire"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être POINTER"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant de %qs"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant hérité de %qs"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Le type dérivé %qs déclaré à %L doit être ABSTRACT car %qs est DEFERRED et pas redéfini"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Le composant co-tableau %qs à %L doit être allouable avec une forme différée"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Le composant %qs à %L ayant TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Le composant %qs à %L avec le composant co-tableau sera un scalaire non pointeur, non allouable"
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Le composant %qs à %L a l'attribut CONTIGUOUS mais n'est pas un pointeur de tableau"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Le composant %qs du type BIND(C) à %L doit avoir la longueur un"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Le composant pointeur de procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Le composant pointeur de procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être scalaire"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas avoir l'attribut POINTER"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Le composant %qs de %qs à %L a le même nom qu'une procédure liée au type héritée"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longueur de caractère du composant %qs doit être une expression de spécification constante à %L"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "L'expression de longueur de caractère du composent %qs à %L doit être du type INTEGER et non %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Le composant caractère %qs de %qs à %L avec une longueur différée doit être POINTER ou ALLOCATABLE"
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "le composant %qs est un type PRIVATE et ne peut pas être un composant de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Le composant polymorphique %s à %L dans le type %s SEQUENCE ou BIND(C)"
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Le composant %s du type SEQUENCE déclaré à %L n'a pas l'attribut SEQUENCE"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initialisations conflictuelles dans l'union à %L et %L"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Puisque l'extension du type %qs à %L a un composant co-tableau, le type parent %qs en aura un aussi"
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Le type dérivé non extensible %qs à %L ne peut pas être ABSTRACT"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Le type paramétrisé %qs n'a pas de composant correspondant au paramètre %qs à %L"
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Nom générique %qs de la fonction %qs à %L étant le même nom que le type dérivé à %L"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Le type dérivé %qs à %L n'a pas été déclaré"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %L n'est pas permis"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme tacite dans la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Objet NAMELIST %qs avec une longueur de caractère non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a été déclaré PRIVATE et ne peut pas être membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE associés à USE et ne peut pas être membre de la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE et ne peut pas être un membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut NAMELIST dans %qs à %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Le tableau paramètre %qs à %L ne peut pas être automatique ou de forme différée"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Le PARAMETER %qs implicitement typé à %L ne concorde pas avec le type IMPLICIT ultérieur"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Type dérivé incompatible dans PARAMETER à %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "La variable CLASS %qs à %L ne peut pas avoir l'attribut PARAMETER"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "L'objet %qs à %L a un paramètre LEN différé %qs et n'est ni allouable ni un pointeur"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "L'objet AUTOMATIC %qs à %L ne doit pas avoir l'attribut SAVE ou être une variable déclarée dans le programme principal, un module ou un sous-module(F08/C513)"
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "L'objet %qs à %L avec des paramètres de type ASSUMED doit être fictif ou un sélecteur SELECT TYPE(F08/4.2)"
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Désolé, les composants allouables/pointeurs dans des co-tableaux de types polymorphiques (CLASS) à %L ne sont pas supportés"
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr "%<omp_all_memory%>, déclaré à %L, peut uniquement être utilisé dans la clause OpenMP DEPEND"
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "L'attribut PROTECTED est en conflit avec l'attribut EXTERNAL à %L"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut PROTECTED à %L"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs à %L a l'attribut CONTIGUOUS mais il n'est pas un pointeur de tableau ou un tableau de forme tacite ou de rang tacite"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Mauvaise spécification pour le tableau de taille tacite à %L"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Le tableau de taille tacite à %L doit être un argument muet"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Le tableau de forme tacite à %L doit être un argument muet"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Le tableau de rang tacite à %L doit être un argument muet"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Le tableau de rang tacite à %L ne peut pas avoir les attributs VALUE ou CODIMENSION"
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Le symbole à %L n'est pas une variable MUETTE"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs à %L ne peut pas avoir l'attribut VALUE car ce n'est pas un argument muet"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable muette caractère %qs à %L avec l'attribut VALUE doit avoir une longueur constante"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable muette caractère %qs, interopérable avec le C, à %L avec l'attribut VALUE doit avoir la longueur un"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Le type dérivé %qs à %L est du type %qs qui n'a pas été défini"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera un argument muet"
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera du type TYPE(*) ou d'un type intrinsèque numérique"
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera soit un scalaire ou un tableau de taille tacite"
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Le type tacite de la variable %s à %L est uniquement permis pour des variables muettes"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de type tacite %s à %L ne sera point un tableau de forme explicite"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable %qs à %L ne peut pas être BIND(C) car elle n'est ni un bloc COMMON ni déclarée au niveau du module"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable BIND(C) %qs à %L doit avoir la longueur un"
 
 # %s est soit « parameter » ou « variable » sans traduction
 # voir bug #80195
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs à %L du type dérivé PRIVATE %qs"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s à %L du type EVENT_TYPE ou avec un sous-composant du type EVENT_TYPE doit être un co-tableau"
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "L'argument muet INTENT(OUT) %qs à %L est ASSUMED SIZE et, par conséquent, ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est LOCK_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est EVENT_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Le résultat %qs de la fonction à %L ne sera point un co-tableau et n'aura point un composant co-tableau"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable %qs à %L du TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable %qs à %L avec un composant co-tableau doit être un scalaire non pointeur, non allouable qui n'est pas un co-tableau"
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable %qs à %L est un co-tableau qui n'est pas ALLOCATABLE, SAVE ni un argument muet"
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable co-tableau %qs à %L n'aura pas de co-dimensions avec une forme différée"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable co-tableau allouable %qs à %L doit avoir une forme différée"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable %qs à %L est INTENT(OUT) et ne peut donc pas être un co-tableau allouable ou avoir des composants co-tableaux"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "La variable muette co-tableau %qs à %L n'est pas permise dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Argument muet LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Variable résultat LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La liste de noms %qs ne peut pas être un argument de la sous-routine ou de la fonction à %L"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Le threadprivate à %L n'est pas sauvegardé avec SAVE"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "La variable !$OMP DECLARE TARGET %qs à %L n'est pas sauvegardée avec SAVE"
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Entité définissable attendue près de %L"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "L'élément BLOCK DATA %qs à %L doit être dans COMMON"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Le tableau DATA %qs à %L doit être spécifié dans une déclaration précédente"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir un co-index"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "L'élément DATA %qs à %L est un pointeur et doit donc être un tableau à part entière"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "L'objet DATA près de %L a l'attribut pointeur et la valeur DATA correspondante n'est pas une cible de donnée initiale valable"
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir l'attribut ALLOCATABLE"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Section de tableau non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "L'instruction DATA à %L a plus de variables que de valeurs"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le début de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "La fin de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le pas de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "le pas de la boucle DO implicite à %L ne sera point zéro"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "L'instruction DATA à %L a plus de valeurs que de variables"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "L'étiquette %d à %L est définie mais non utilisée"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "L'étiquette %d à %L est définie mais ne peut pas être utilisée"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L doit avoir l'attribut SEQUENCE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L ne peut pas avoir des composants ALLOCATABLE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de type dérivé %qs à %L avec une initialisation par défaut ne peut pas être dans une EQUIVALENCE avec une variable dans COMMON"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L avec un ou des composants pointeurs ne peut pas être dans un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Erreur de syntaxe dans l'instruction EQUIVALENCE à %L"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Soit aucun ou tous les objets dans l'ensemble EQUIVALENCE à %L aura l'attribut PROTECTED"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Le membre %qs du bloc COMMON à %L ne peut pas être un objet EQUIVALENCE dans la procédure pure %qs"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nommée %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Le tableau %qs à %L avec des limites non constantes ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Le composant de structure %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La sous-chaîne à %L a une longueur zéro"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Référence à elle-même dans l'expression de longueur de caractère pour %qs à %L"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fonction PUBLIC %qs à %L du type PRIVATE %qs"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "La procédure opérateur utilisateur %qs à %L doit être une FUNCTION"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "La procédure opérateur utilisateur %qs à %L ne peut pas être une longueur de caractère tacite"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "La procédure opérateur utilisateur %qs à %L doit avoir au moins un argument"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Le premier argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Le deuxième argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "L'interface opérateur à %L doit avoir, au plus, deux arguments"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "La procédure contenue %qs à %L d'une procédure PURE doit aussi être PURE"
@@ -77914,7 +77934,7 @@ msgstr "Initialisations inégales et se chevauchant dans EQUIVALENCE à %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Initialisations inégales et se chevauchant dans EQUIVALENCE à %C"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr "Le constructeur de structure à %C a été finalisé. Cette fonctionnalité a été enlevée par f08/0011. Utilisez -std=f2018 ou -std=gnu pour éliminer la finalisation."
@@ -77926,12 +77946,12 @@ msgstr "Le constructeur de structure à %C a été finalisé. Cette fonctionnali
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Le nombre d'éléments dans le constructeur du tableau à %L requiert une augmentation de la limite supérieure permise %d. Voyez l'option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Création d'un temporaire pour le tableau à %L dans l'argument %qs"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "mauvais type d'expression durant le parcours (%d)"
@@ -78023,81 +78043,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr "Le tableau %qs à %L est plus grand que la limite définie par %<-fmax-stack-var-size=%>, il est déplacé de la pile vers la zone de stockage statique. Ceci rend la procédure non sûr lorsqu'elle est appelée récursivement ou simultanément depuis plusieurs threads. Envisagez d'augmenter la limite de %<-fmax-stack-var-size=%> (ou d'utiliser %<-frecursive%> qui implique %<-fmax-stack-var-size%>) – ou changez le code pour utiliser un tableau ALLOCATABLE. Si la variable n'est jamais accédée de manière concurrentielle, cet avertissement peut être ignoré et la variable pourrait aussi être déclarée avec l'attribut SAVE."
 
 #: fortran/trans-decl.cc:1795
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "%s à %C n'a pas de type par défaut"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variable intrinsèque qui n'est pas une procédure"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "La valeur de retour de la fonction %qs à %L n'est pas définie"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Paramètre de type différé pas encore supporté"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Le backend decl pour la variable de module %qs existe déjà"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "La variable de module PRIVATE %qs inutilisée est déclarée à %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "Le symbole %qs à %L a l'attribut WEAK mais c'est un argument muet"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "Le symbole %qs à %L a l'attribut WEAK mais il est une variable locale"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "L'argument muet %qs à %L a été déclaré INTENT(OUT) mais n'a pas reçu de valeur"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "L'argument muet %qs d'un type dérivé à %L a été déclaré INTENT(OUT) mais n'a pas reçu de valeur et n'a pas d'initialisation par défaut"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argument muet %qs inutilisé à %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "La variable de module %qs est inutilisée mais elle a été importée explicitement à %L"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Variable %qs inutilisée déclarée à %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Paramètre %qs inutilisé déclaré à %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Le paramètre %qs est inutilisé mais il a été importé explicitement à %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "La valeur de retour %qs de la fonction %qs est déclarée à %L mais ne reçoit pas de valeur"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Désolé, !$ACC DECLARE à %L n'est pas permis dans une construction BLOCK"
@@ -78112,27 +78137,27 @@ msgstr "Impossible de calculer la longueur du tableau de caractères à %L."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Du code pour réallouer la variable allouable à %L va être ajouté"
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un objet polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un composant polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Op intrinsèque inconnue"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Fonction de liste d'arguments inconnue à %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Si le remappage des limites est spécifié à %L, la cible du pointeur ne sera point NULL"
@@ -79931,6 +79956,9 @@ msgstr "la valeur de retour de type %qT est ignorée, ceci doit être utilisé"
 msgid "unused name %qE"
 msgstr "paramètre %qE inutilisé"
 
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "taille d'opérande invalide pour le code d'opérande « Z »"
+
 #~ msgid "Implement DIP25: Sealed references."
 #~ msgstr "Implémenter DIP25: Références scellées."
 
diff --git a/gcc/po/hr.po b/gcc/po/hr.po
index a6768e94428..cca99421d04 100644
--- a/gcc/po/hr.po
+++ b/gcc/po/hr.po
@@ -6,10 +6,10 @@
 # Božidar Putanec <bozidarp@yahoo.com>, 2022, 2023.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 13.1-b20230409\n"
+"Project-Id-Version: gcc 13.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
-"PO-Revision-Date: 2023-04-14 20:12-0700\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
+"PO-Revision-Date: 2023-04-27 12:03-0700\n"
 "Last-Translator: Božidar Putanec <bozidarp@yahoo.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
 "Language: hr\n"
@@ -18,7 +18,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
-"X-Generator: Lokalize 22.12.3\n"
+"X-Generator: Poedit 3.2.2\n"
 "X-Poedit-Basepath: ../sources/gcc-12-20220213\n"
 "X-Poedit-Bookmarks: 13750,0,-1,-1,-1,-1,-1,-1,-1,-1\n"
 "X-Poedit-SearchPath-0: .\n"
@@ -41,7 +41,7 @@ msgstr "redefinirana vanjska ‘inline’ funkcija nije kvalificirana za ‘inli
 
 #: cif-code.def:56
 msgid "function not inlinable"
-msgstr "funkcija nije nije ‘inlinable’"
+msgstr "funkcija nije ‘inlinable’"
 
 #: cif-code.def:60
 msgid "function body can be overwritten at link time"
@@ -210,7 +210,7 @@ msgstr "Greška"
 
 #: fortran/gfc-diagnostic.def:36
 msgid "sorry, unimplemented"
-msgstr "nije implementirano: "
+msgstr "nije implementirano:"
 
 #: fortran/gfc-diagnostic.def:37
 msgid "Warning"
@@ -3998,7 +3998,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -4129,7 +4129,7 @@ msgstr ""
 #: m2/lang.opt:235
 #, no-c-format
 msgid "generate a shared library from the module"
-msgstr "generira zajedničku (dijeljenu) biblioteku iz modula."
+msgstr "generira zajedničku (dijeljenu) biblioteku iz modula"
 
 #: m2/lang.opt:239
 #, no-c-format
@@ -7641,6 +7641,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Podržava AMX-COMPLEX ugrađene funkcije i generiranje koda."
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -7940,7 +7945,7 @@ msgstr ""
 #: config/nvptx/nvptx.opt:28
 #, no-c-format
 msgid "Ignored, but preserved for backward compatibility.  Only 64-bit ABI is supported."
-msgstr "Zanemareno, ali zadržano radi kompatibilnost. Samo 64-bit ABI je podržan"
+msgstr "Zanemareno, ali zadržano radi kompatibilnosti. Podržan je samo 64-bit ABI."
 
 #: config/nvptx/nvptx.opt:33
 #, no-c-format
@@ -13423,7 +13428,7 @@ msgstr "omogući statičku analizu prolaza"
 #: common.opt:1080
 #, no-c-format
 msgid "Select what to sanitize."
-msgstr "odaberite što treba počistiti."
+msgstr "odaberite što treba počistiti"
 
 #: common.opt:1084
 #, no-c-format
@@ -13453,7 +13458,7 @@ msgstr "taj šalter je zastario; koristite -fsanitize-recover= instead"
 #: common.opt:1114
 #, no-c-format
 msgid "Use traps instead of diagnostics of undefined behavior sanitizers."
-msgstr "Koristi klopku umjesto dezinfektora nedefiniranog ponašanja"
+msgstr "koristi klopku umjesto dezinfektora nedefiniranog ponašanja"
 
 #: common.opt:1124
 #, no-c-format
@@ -13528,7 +13533,7 @@ msgstr "taj šalter je zastario; nemojte ga koristiti"
 #: common.opt:1201
 #, no-c-format
 msgid "Check the return value of new in C++."
-msgstr "provjeri vraćenu vrijdnost operatora ‘new’ u C++"
+msgstr "provjeri vraćenu vrijednost operatora ‘new’ u C++"
 
 #: common.opt:1205 common.opt:1209
 #, no-c-format
@@ -17168,12 +17173,12 @@ msgstr "operand ‘%%l’ nije oznaka"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18253,63 +18258,63 @@ msgstr "Ova opcija nije dokumentirana."
 msgid "Uses of this option are diagnosed."
 msgstr "Upotreba ove opcije je dijagnosticirana."
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr "Isto kao %s%s (ili, u negiranom obliku, %s%s)."
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr "Isto kao %s%s."
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr "Isto kao %s."
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s je identično s %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr "[dostupno u "
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[zadano]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr "%llu bajta"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[omogućeno]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[onemogućeno]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Nisu pronađene opcije sa željenim svojstvima\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Nijedan nije nađen. Koristite --help=%s za ispis *all* opcija koje podržava %s front-end sučelje.\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Sve opcije sa željenim svojstvima su već prikazane\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -18318,47 +18323,47 @@ msgstr ""
 "  Znani valjani argument za %s opciju:\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Sljedeće opcije su specifične za cilj"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Sljedeće opcije upravljaju porukama upozorenja kompajlera"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Sljedeće opcije upravljaju s optimizacijama"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Sljedeće opcije su neovisne o jeziku"
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr "Sljedeće opcije upravljaju s parametrima"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Sljedeće opcije su posebne samo za jezik "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Sljedeće opcije podržava jezik "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Sljedeće opcije nisu dokumentirane"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Sljedeće opcije uzimaju odvojene argumente"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Sljedeće opcije uzimaju spojene argumente"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Sljedeće opcije se odnose na jezik"
 
@@ -18743,72 +18748,72 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "nepodržani operand za kȏd ‘%c’"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "nevaljani operand za ‘%%%c’"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr "nevaljana vektorska konstanta"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "nekompatibilan operand registra za ‘%%%c’"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "nema operanda"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "nevaljana konstanta"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "nevaljani operand"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "nevaljani prefiks operanda ‘%%%c’"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "nevaljani način adresiranja"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ne mogu se kombinirati GNU i SVE vektori u binarnoj operaciji"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "‘%%&’ je upotrebljen bez ikakve dinamičke TLS referencije"
@@ -18825,18 +18830,18 @@ msgid "invalid %%r value"
 msgstr "nevaljana %%r vrijednos"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "nevaljana %%R vrijednost"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "nevaljana %%N vrijednost"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "nevaljana %%P vrijednost"
@@ -18866,7 +18871,7 @@ msgstr "nevaljana %%M vrijednost"
 msgid "invalid %%U value"
 msgstr "nevaljana %%U vrijednost"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "nevaljana %%s vrijednost"
@@ -18876,7 +18881,7 @@ msgstr "nevaljana %%s vrijednost"
 msgid "invalid %%C value"
 msgstr "nevaljana %%C vrijednost"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "nevaljana %%E vrijednost"
@@ -18889,7 +18894,7 @@ msgstr "nepoznata relokacija unspec"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "nevaljani %%xn kȏd"
@@ -18972,35 +18977,35 @@ msgstr "nevaljani UNSPEC kao operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "neprepoznata pretpostavljena konstanta"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "nevaljai operand pomaka (shift)"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "predviđena Thumb instrukcija"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "predviđena instrukcija u uvjetnoj sekvenciji"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Nepodržani operand za kȏd ‘%c’"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19009,26 +19014,26 @@ msgstr "Nepodržani operand za kȏd ‘%c’"
 msgid "invalid operand for code '%c'"
 msgstr "nevaljani operand za kȏd ‘%c’"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "instrukcija nije nikada izvršena"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "zastarjela Maverick format kȏd ‘%c’"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "nevaljana konverzija od tipa %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "nevaljana konverzija u tip %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "nelegalna operacija na tipu %<bfloat16_t%>"
 
@@ -19393,97 +19398,97 @@ msgstr ""
 msgid "Expected register or constant integer."
 msgstr ""
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr ""
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "nevaljana veličina operanda za operand kȏd ‘O’"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "nevaljana veličina operanda za operand kȏd ‘z’"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, c-format
-msgid "invalid operand type used with operand code 'Z'"
-msgstr "nevaljani tip operanda korišten s operandom kȏda ‘Z’"
+msgid "invalid operand type used with operand code '%c'"
+msgstr "nevaljani tip operanda korišten s operandom kȏda ‘%c’"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "nevaljana veličina operanda za operand kȏd ‘Z’"
+msgid "invalid operand size for operand code '%c'"
+msgstr "nevaljana veličina operanda za operand kȏd ‘%c’"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand nije kȏd uvjeta, nevaljani operand kȏd ‘Y’"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand nije kȏd uvjeta, nevaljani operand kȏd ‘D’"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand nije kȏd uvjeta, nevaljani operand kȏd ‘%c’"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand nije pokretljiva (offsettable) referencija memorije, nevaljani operand kȏd ‘H’"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand nije cijeli broj, nevaljani operand kȏd ‘K’"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand nije određeni cijeli broj, nevaljani operand kȏd ‘r’"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand nije cijeli broj, nevaljani operand kȏd ‘R’"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand nije određeni cijeli broj, nevaljani operand kȏd ‘R’"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "nevaljani operand kȏd ‘%c’"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "nevaljano ograničenje za operand"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, c-format
 msgid "invalid vector immediate"
 msgstr "nevaljana vektorska konstanta"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "nepoznati insn način"
 
@@ -19514,7 +19519,7 @@ msgstr ""
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -19559,8 +19564,8 @@ msgstr ""
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr ""
@@ -19592,7 +19597,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr ""
 
@@ -19750,7 +19755,7 @@ msgstr ""
 msgid "unsupported memory expression:"
 msgstr ""
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, c-format
 msgid "invalid vector operand"
 msgstr "nevaljani vektorski operand"
@@ -19802,143 +19807,143 @@ msgstr ""
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, c-format
 msgid "invalid %%A value"
 msgstr "nevaljana %%A vrijednost"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "nevaljana %%e vrijednost"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "nevaljani %%t kȏd"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "nevaljana %%V vrijednost"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "nevaljani %%z kȏd"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr ""
 
@@ -20193,7 +20198,7 @@ msgstr ""
 
 #: c/c-objc-common.cc:193
 msgid "{erroneous}"
-msgstr "pogrešan"
+msgstr "{pogrešan}"
 
 #: c/c-objc-common.cc:234
 msgid "aka"
@@ -20395,7 +20400,7 @@ msgstr ""
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -20854,7 +20859,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -21012,11 +21017,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr ""
 
@@ -21024,199 +21029,199 @@ msgstr ""
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr ""
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr ""
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr ""
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr ""
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr ""
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr ""
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr ""
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr ""
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr ""
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr ""
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr ""
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -21229,27 +21234,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22117,7 +22122,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -22488,7 +22493,7 @@ msgstr ""
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -22585,10 +22590,10 @@ msgstr ""
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -22725,7 +22730,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -22962,7 +22967,7 @@ msgstr ""
 #: cfgexpand.cc:3005
 #, gcc-internal-format
 msgid "the value of the stack pointer after an %<asm%> statement must be the same as it was before the statement"
-msgstr "Vrijednost pokazivača stȏga nakon naredbe %<asm%> mora biti ista kao prije naredbe"
+msgstr "vrijednost pokazivača stȏga nakon naredbe %<asm%> mora biti ista kao prije naredbe"
 
 #: cfgexpand.cc:3075
 #, gcc-internal-format
@@ -24557,7 +24562,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25326,7 +25331,7 @@ msgstr "funkcija vraća adresu lokalne varijable"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26457,14 +26462,14 @@ msgstr ""
 msgid "using a dangling pointer to %qD"
 msgstr ""
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -26509,7 +26514,7 @@ msgstr ""
 msgid "call to %qD"
 msgstr ""
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr ""
@@ -27592,7 +27597,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr ""
@@ -28550,7 +28555,7 @@ msgstr ""
 msgid "command-line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr ""
@@ -28590,12 +28595,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -28750,7 +28755,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr ""
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "%<-fsanitize-trap=%s%> nije podržan"
@@ -28790,182 +28795,182 @@ msgstr ""
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr ""
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr ""
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr ""
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr ""
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr ""
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr ""
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr ""
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr ""
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr ""
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr ""
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr ""
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr ""
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr ""
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr ""
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr ""
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr ""
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr ""
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -29638,187 +29643,187 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "simbol funkcije nije funkcija"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr ""
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr ""
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr ""
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "krivi poredak u asm čvoru %i"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -31487,27 +31492,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -32323,7 +32328,7 @@ msgstr ""
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr ""
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -34409,7 +34414,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36085,7 +36090,7 @@ msgstr ""
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -36116,15 +36121,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr ""
@@ -36209,48 +36214,48 @@ msgstr ""
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -36734,13 +36739,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -36979,7 +36984,7 @@ msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr ""
@@ -37020,7 +37025,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -37107,323 +37112,323 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "nepoznata tuning opcija (%s)"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -37608,13 +37613,13 @@ msgstr ""
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -37755,17 +37760,17 @@ msgstr ""
 msgid "%qE attribute only applies to variables"
 msgstr ""
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
@@ -37972,7 +37977,7 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr ""
@@ -38027,7 +38032,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
@@ -38133,7 +38138,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -38183,32 +38188,32 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -38216,22 +38221,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr ""
@@ -38305,17 +38310,17 @@ msgstr ""
 msgid "%<-fPIE%> is not supported"
 msgstr ""
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
@@ -38629,7 +38634,7 @@ msgstr ""
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr ""
@@ -38974,12 +38979,12 @@ msgstr "nije moguće otvoriti ‘%s’"
 #: config/gcn/mkoffload.cc:1129 config/nvptx/mkoffload.cc:730
 #, gcc-internal-format
 msgid "cannot open omp_requires file %qs"
-msgstr "Nije moguće otvoriti ‘omp_requires’ datoteku %qs"
+msgstr "nije moguće otvoriti ‘omp_requires’ datoteku %qs"
 
 #: config/gcn/mkoffload.cc:1133 config/nvptx/mkoffload.cc:734
 #, gcc-internal-format
 msgid "cannot read omp_requires file %qs"
-msgstr "Nije moguće čitati ‘omp_requires’ datoteku %qs"
+msgstr "nije moguće čitati ‘omp_requires’ datoteku %qs"
 
 #: config/gcn/mkoffload.cc:1139
 #, gcc-internal-format
@@ -39222,749 +39227,749 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr ""
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr ""
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr ""
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr ""
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -40309,7 +40314,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -41428,52 +41433,52 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -41493,66 +41498,71 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr "nije moguće dodijeliti vl registar za %qs na ovoom cilju"
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, gcc-internal-format
@@ -42022,97 +42032,97 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -43507,7 +43517,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -43692,7 +43702,7 @@ msgstr ""
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -43861,7 +43871,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -43988,7 +43998,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -44188,7 +44198,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr ""
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -44238,7 +44248,7 @@ msgstr ""
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -44283,7 +44293,7 @@ msgstr ""
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -44328,7 +44338,7 @@ msgstr ""
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr ""
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
@@ -44358,7 +44368,7 @@ msgstr ""
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
@@ -44473,12 +44483,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -46490,7 +46500,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
@@ -46620,12 +46630,12 @@ msgstr "očekivano je %<match%>"
 msgid "variant %qD is not a function"
 msgstr ""
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr ""
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -46886,7 +46896,7 @@ msgstr ""
 msgid "invalid use of flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr ""
@@ -47835,12 +47845,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -47881,7 +47891,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -47896,8 +47906,8 @@ msgstr ""
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -47987,7 +47997,7 @@ msgstr ""
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -49330,7 +49340,7 @@ msgstr ""
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
@@ -49340,7 +49350,7 @@ msgstr ""
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
@@ -49355,7 +49365,7 @@ msgstr ""
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, gcc-internal-format
 msgid "  declared here"
@@ -49684,7 +49694,7 @@ msgstr ""
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -50253,7 +50263,7 @@ msgstr ""
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
@@ -50374,7 +50384,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -50443,7 +50453,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -50490,7 +50500,7 @@ msgstr ""
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -50614,7 +50624,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -50713,7 +50723,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -50789,7 +50799,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -50855,189 +50865,189 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr ""
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -51207,12 +51217,12 @@ msgstr "  %qT nije moguće dodijeliti kopiju pomoću ‘nothrow’"
 #: cp/constraint.cc:3684 cp/constraint.cc:3779
 #, gcc-internal-format
 msgid "  %qT is not nothrow default constructible"
-msgstr "%qT se ne može sagraditi prema zadanim postavkama s ‘nothrow’"
+msgstr "  %qT se ne može sagraditi prema zadanim postavkama s ‘nothrow’"
 
 #: cp/constraint.cc:3687
 #, gcc-internal-format
 msgid "  %qT is not nothrow copy constructible"
-msgstr "%qT se ne može konstruirati kopiranjem s ‘nothrow’"
+msgstr "  %qT se ne može konstruirati kopiranjem s ‘nothrow’"
 
 #: cp/constraint.cc:3690
 #, gcc-internal-format
@@ -51347,7 +51357,7 @@ msgstr "  %qT nema upotrebljiv zadani konstruktor"
 #: cp/constraint.cc:3769
 #, gcc-internal-format
 msgid "  %qT is not constructible from %qE"
-msgstr "%qT se ne može konstruirati iz %qE"
+msgstr "  %qT se ne može konstruirati iz %qE"
 
 #: cp/constraint.cc:3775
 #, gcc-internal-format
@@ -51610,7 +51620,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr ""
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr ""
@@ -51702,7 +51712,7 @@ msgstr ""
 msgid "no suspend point info for %qD"
 msgstr ""
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -51722,23 +51732,23 @@ msgstr "‘await’ izraz nije dopušten u rukovateljima (handlers)"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -52218,7 +52228,7 @@ msgstr ""
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr ""
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr ""
@@ -52618,604 +52628,604 @@ msgstr ""
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr ""
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr ""
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr ""
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr ""
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr ""
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr ""
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -53223,7 +53233,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -53231,7 +53241,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -53239,1656 +53249,1656 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr ""
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "deduction guide %qD mora imati isti pristup kao %qT"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr ""
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr ""
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr ""
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr ""
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr ""
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr ""
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr ""
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr ""
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs opseg funkcije je implicitno auto i deklariran kao %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr ""
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD ne može bit %qs"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr ""
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD mora biti član funkcije"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr ""
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -54900,110 +54910,110 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr ""
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr ""
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -55012,82 +55022,82 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "koristimo %qs"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -55936,7 +55946,7 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -56986,7 +56996,7 @@ msgstr ""
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr ""
@@ -57731,7 +57741,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr ""
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr ""
@@ -58440,12 +58450,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -59043,7 +59053,7 @@ msgstr ""
 msgid "%qT not permitted in template argument"
 msgstr ""
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -59903,7 +59913,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
@@ -60913,7 +60923,7 @@ msgstr ""
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
@@ -61006,276 +61016,276 @@ msgstr "funkcija vraća polje"
 msgid "function returning a function"
 msgstr "funkcija vraća funkciju"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr ""
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr ""
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -61287,163 +61297,163 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr ""
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr ""
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr ""
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr ""
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "ograničenja rezerviranog mjesta nisu zadovoljena"
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "izvedeni povratni tip ne zadovoljava ograničenja rezerviranog mjesta"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "izvedeni povratni tip ne zadovoljava ograničenja rezerviranog mjesta"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "izvedeni povratni tip ne zadovoljava ograničenja rezerviranog mjesta"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -61754,7 +61764,7 @@ msgstr ""
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -62162,27 +62172,27 @@ msgstr ""
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr ""
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -62190,22 +62200,22 @@ msgstr ""
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -63437,220 +63447,220 @@ msgstr ""
 msgid "declaration of %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr ""
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr ""
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr ""
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr ""
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr ""
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr ""
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr ""
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr ""
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr ""
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -64586,7 +64596,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -65679,12 +65689,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -65865,7 +65875,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -67876,7 +67886,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -68147,7 +68157,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -68265,7 +68275,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
@@ -68275,7 +68285,7 @@ msgstr ""
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
@@ -68406,7 +68416,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -68622,12 +68632,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -68737,562 +68747,562 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr ""
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Isti stvarni argument pridružen s INTENT(%s) argumentom %qs i INTENT(%s) argumentom %qs na %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr ""
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -69476,7 +69486,7 @@ msgstr ""
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
@@ -70027,7 +70037,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -70594,7 +70604,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -72104,7 +72114,7 @@ msgstr ""
 #: fortran/openmp.cc:5690
 #, gcc-internal-format
 msgid "expected %<(%> at %C"
-msgstr "Očekivano je %<(%> kod %C"
+msgstr "očekivano je %<(%> kod %C"
 
 #: fortran/openmp.cc:5388
 #, gcc-internal-format, gfc-internal-format
@@ -72120,7 +72130,7 @@ msgstr ""
 #: fortran/openmp.cc:5699
 #, gcc-internal-format
 msgid "expected %<)%> at %C"
-msgstr "Očekivano je %<)%> kod %C"
+msgstr "očekivano je %<)%> kod %C"
 
 #: fortran/openmp.cc:5408
 #, gcc-internal-format, gfc-internal-format
@@ -72447,8 +72457,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -74413,708 +74423,718 @@ msgstr ""
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr ""
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr ""
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr ""
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr ""
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr ""
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr ""
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75123,12 +75143,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75137,293 +75157,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs se ne smije pojaviti u specifikaciji polja pri %L u istoj ALLOCATE izjavi gdje je i sam dodijeljen"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -75432,284 +75452,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -75717,207 +75737,207 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -75925,984 +75945,984 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr ""
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -77794,7 +77814,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -77806,12 +77826,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -77903,81 +77923,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "%s pri %C nema zadani tip (vrstu)"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -77992,27 +78017,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -78472,7 +78497,7 @@ msgstr "nekoliko prevladavajućih definicija za %qE"
 #: lto/lto-symtab.cc:492
 #, gcc-internal-format
 msgid "%qD has already been defined"
-msgstr "%qD bio je već definiran "
+msgstr "%qD već je bio definiran"
 
 #: lto/lto-symtab.cc:494
 #, gcc-internal-format
@@ -78507,7 +78532,7 @@ msgstr "%qD je već ranije ovdje deklariran"
 #: lto/lto-symtab.cc:760
 #, gcc-internal-format
 msgid "code may be misoptimized unless %<-fno-strict-aliasing%> is used"
-msgstr "Kôd može biti pogrešno optimiziran osim ako se ne koristi %<-fno-strict-aliasing%>"
+msgstr "kôd može biti pogrešno optimiziran osim ako se ne koristi %<-fno-strict-aliasing%>"
 
 #: lto/lto-symtab.cc:846
 #, gcc-internal-format
@@ -79810,6 +79835,9 @@ msgstr ""
 msgid "unused name %qE"
 msgstr ""
 
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "nevaljana veličina operanda za operand kȏd ‘Z’"
+
 #~ msgid "-gz=zlib is not supported in this configuration"
 #~ msgstr "-gz=zlib nije podržan u ovoj konfiguraciji"
 
diff --git a/gcc/po/id.po b/gcc/po/id.po
index 9068b6b3396..4245b14f210 100644
--- a/gcc/po/id.po
+++ b/gcc/po/id.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -4484,7 +4484,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -8513,6 +8513,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support AES built-in functions and code generation"
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Dukung fungsi dalam dan pembuatan kode AES"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy, no-c-format
 #| msgid "Assume code will be linked by GNU ld"
@@ -19218,12 +19224,12 @@ msgstr "'%%l' operan bukan sebuah label"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "konstanta pecahan disalah gunakan"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -20432,65 +20438,65 @@ msgstr "Switch ini kurang dokumentasi"
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr ""
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, fuzzy, c-format
 #| msgid "(%s %s %s %s %s"
 msgid "%s  Same as %s."
 msgstr "(%s %s %s %s %s"
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr ""
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[aktif]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[non-aktif]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Tidak ada pilihan dengan karakteristik yang diinginkan ditemukan\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, fuzzy, c-format
 #| msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Tidak ditemukan apapun. Gunakan --help=%s untuk menunjukan *seluruh* pilihan yang didukung oleh %s front-end\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Seluruh pilihan dengan karakteristik yang diinginkan telah ditampilkan\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "no arguments for spec function"
 msgid ""
@@ -20498,49 +20504,49 @@ msgid ""
 "   "
 msgstr "tidak ada argumen untuk spesifikasi fungsi"
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Pilihan berikut adalah target spesifik"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Pilihan berikut mengontrol pesan peringatan kompiler"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Pilihan berikut mengontrol optimisasi"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Pilihan berikut adalah independen terhadap bahasa pemrograman"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options control optimizations"
 msgid "The following options control parameters"
 msgstr "Pilihan berikut mengontrol optimisasi"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Pilihan berikut hanya spesifik terhadap bahasa "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Pilihan berikut tidak didukung oleh bahasa "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Pilihan berikut tidak terdokumentasi"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Pilihan berikut mengambil argumen terpisah"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Pilihan berikut mengambil argumen tergabung"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Pilihan berikut adalah berhubungan dengan bahasa"
 
@@ -20937,82 +20943,82 @@ msgstr "pemodifikasi panjang dalam format strfmon"
 msgid "<command-line>"
 msgstr "<baris-perintah>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "punctuation %qc tidak valid dalam batasan"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "hilang operan"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "insn tidak valid:"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "operan %%d tidak valid"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "alamat tidak valid"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -21029,18 +21035,18 @@ msgid "invalid %%r value"
 msgstr "nilai %%r tidak valid"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "nilai %%R tidak valid"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
@@ -21070,7 +21076,7 @@ msgstr "nilai %%M tidak valid"
 msgid "invalid %%U value"
 msgstr "nilai %%U tidak valid"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
@@ -21080,7 +21086,7 @@ msgstr "nilai %%s tidak valid"
 msgid "invalid %%C value"
 msgstr "nilai %%C tidak valid"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
@@ -21093,7 +21099,7 @@ msgstr "relokasi unspek tidak diketahui"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "kode %%xn tidak valid"
@@ -21183,36 +21189,36 @@ msgstr "UNSPEC tidak valid sebagai operan"
 msgid "unrecognized supposed constant"
 msgstr "konstanta yang diharapkan tidak dikenal"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "operan shift tidak valid"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruksi Thumb terprediksi"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruksi terprediksi dalam urutan berkondisi"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -21221,30 +21227,30 @@ msgstr "operan tidak valid untuk kode '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "instruksi tidak pernah dijalankan"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -21628,111 +21634,111 @@ msgstr "insn tidak valid:"
 msgid "Expected register or constant integer."
 msgstr "akumulator bukan sebuah konstanta integer"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "penggunaan tidak valid dari %<restrict%>"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "predikat pengontrol tidak valid"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "mode insn tidak diketahui"
 
@@ -21764,7 +21770,7 @@ msgstr "operasi di %<__fpreg%> tidak valid"
 msgid "invalid %%P operand"
 msgstr "operan %%P tidak valid"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -21813,8 +21819,8 @@ msgstr "'%%%c' bukan sebuah awalan operan yang valid"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "penggunaan dari '%%%c' tidak valid"
@@ -21846,7 +21852,7 @@ msgid "post-increment address is not a register"
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -22020,7 +22026,7 @@ msgstr "kombinasi tidak didukung: %s"
 msgid "unsupported memory expression:"
 msgstr "diduga ekspresi integer"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid vector operand"
@@ -22081,158 +22087,158 @@ msgstr ""
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "nilai %%D tidak valid"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -22740,7 +22746,7 @@ msgstr "kandidat 1:"
 msgid "  after user-defined conversion:"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -23287,7 +23293,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Driving:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -23451,11 +23457,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "Diimplikasikan END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "assignment"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "assignmen penunjuk"
 
@@ -23463,249 +23469,249 @@ msgstr "assignmen penunjuk"
 msgid "simple IF"
 msgstr "IF sederhana"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "prosedur elemental"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "assignmen penunjuk"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "argumen tidak cocok"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "argumen tidak cocok"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 #| msgid "array assignment"
 msgid "coarray argument"
 msgstr "penempatan array"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 #, fuzzy
 #| msgid "elemental procedure"
 msgid "bind(c) procedure"
 msgstr "prosedur elemental"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator numerik unary '%s' di %%L adalah %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operan binari numerik '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operan dari string operator konkatenasi di %%L adalah %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator logikal '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operan dari operator .not. di %%L adalah %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "kuantitas KOMPLEKS tidak dapat dibandingkan di %L"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logikal di %%L harus dibandingkan dengan %s daripada %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator perbandingan '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tingkat tidak konsisten untuk operator di %%L dan %%L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 #, fuzzy
 #| msgid "%qD is not a variable"
 msgid "iterator variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ekspresi sebagai operan tidak valid"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALOKASIKAN "
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALOKASIKAN "
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -23719,29 +23725,29 @@ msgstr "Pajang KARAKTER berbeda (%d/%d) dalam konstruktor array di %L"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, fuzzy, c-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, fuzzy, c-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -24781,7 +24787,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax hanya didukung untuk RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Sintaks error dalam pernyataan %s di %C"
@@ -25205,7 +25211,7 @@ msgstr "%qE atribut konflik dengan atribut %s"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -25310,10 +25316,10 @@ msgstr "tipe atribut diabaikan setelah tipe telah didefinisikan"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -25458,7 +25464,7 @@ msgstr "tidak dapat menemukan berkas untuk class %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "ofset diluar dari jangkauan dari konstanta string"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -27439,7 +27445,7 @@ msgstr "konstanta titik-tetap besar secara implisit dipotong ke tipe titik-tetap
 msgid "comparison is always %d due to width of bit-field"
 msgstr "perbandingan selalu %d karena lebar dari bit-field"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan pemeriksaan jangkauan"
@@ -28295,7 +28301,7 @@ msgstr "fungsi mengembalikan alamat dari variabel lokal"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -29443,14 +29449,14 @@ msgstr "mengasumsikan penunjuk ke anggota %qD"
 msgid "using a dangling pointer to %qD"
 msgstr "mode pointer tidak valid %qs"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -29498,7 +29504,7 @@ msgstr ""
 msgid "call to %qD"
 msgstr "  dalam panggilan ke %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -30626,7 +30632,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in call statement"
 msgid "invalid jump function in LTO stream"
@@ -31649,7 +31655,7 @@ msgstr "Lakukan optimisasi cross-jumping"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "pilihan baris perintah %qs tidak didukung dalam konfigurasi ini"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
@@ -31695,13 +31701,13 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr "pilihan baris perintah \"%s\" tidak dikenal"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -31874,7 +31880,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-falign-loops=%d tidak didukung"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-loops=%d is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -31917,203 +31923,203 @@ msgstr "pelacakan variabel diminta, tetapi tidak berguna kecuali menghasilkan in
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "pelacakan variabel diminta, tetapi tidak didukung oleh format debug ini"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition tidak bekerja dalam arsitektur ini"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition tidak bekerja dalam arsitektur ini"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition tidak bekerja dalam arsitektur ini"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "tidak dikenal include_flags 0x%x dilewatkan ke print_specific_help"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 #| msgid "warning: unrecognized argument to --help= option: %.*s\n"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "peringatan: argumen tidak dikenal ke pilihan --help=: %.*s\n"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "warning: unrecognized argument to --help= option: %.*s\n"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "peringatan: argumen tidak dikenal ke pilihan --help=: %.*s\n"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "%qs atribut direktif diabaikan"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr ""
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid alignment for %<#pragma align%>, ignoring"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "alignmen tidak valid untuk %<#pragma align%>, abaikan"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "jumlah dari argumen ke fungsi %<va_start%> salah"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, fuzzy, gcc-internal-format
 #| msgid "warning: --help argument %.*s is ambiguous, please be more specific\n"
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "warning: --help argumen %.*s adalah ambigu, mohon lebih spesifik\n"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "warning: unrecognized argument to --help= option: %.*s\n"
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "peringatan: argumen tidak dikenal ke pilihan --help=: %.*s\n"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "alignmen struktur harus berupa kelipatan kecil dari dua, bukan %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 #| msgid "unknown stack check parameter \"%s\""
 msgid "unknown stack check parameter %qs"
 msgstr "tidak diketahui parameter pemeriksaan stack \"%s\""
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "warning: unrecognized argument to --help= option: %.*s\n"
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "peringatan: argumen tidak dikenal ke pilihan --help=: %.*s\n"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "target sistem tidak mendukung keluaran debug"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "format debug \"%s\" konflik dengan pemilihan sebelumnya"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "tingkat keluaran debug \"%s\" tidak dikenal"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "tingkat keluaran debug %s terlalu tinggi"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized btf debug output level %qs"
 msgstr "tingkat keluaran debug \"%s\" tidak dikenal"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "memperoleh batas maksimum ukuran berkas core: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "menset batas maksimum ukuran berkas core ke: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "pilihan debuggin gcc: %c tidak dikenal"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: No option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: Tidak ada pilihan -%s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -32840,199 +32846,199 @@ msgstr "kode thunk umum gagal untuk metoda %q#D yang menggunakan %<...%>"
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D diubah namanya setelah direferensikan dalam perakitan"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "function symbol is not function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "node has invalid order %i"
 msgstr "kompleks tidak valid untuk %qs"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "titik tidak ditemukan dalam cgraph_hash"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "dipanggil objek %qE bukan sebuah fungsi"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%J definisi fungsi gaya-lama"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr ""
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "Set the default symbol visibility"
 msgid "symver is not exported with default visibility"
 msgstr "Set simbol visibility baku"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "implisit deklarasi dari fungsi %qE"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa gagal"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "mode pointer tidak valid %qs"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has function type"
 msgid "variable %q+D part of alias cycle"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -34843,27 +34849,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr "pilihan target spesifik tidak cocok"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -35748,7 +35754,7 @@ msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE atribut hanya memiliki efek dalam objek publik"
@@ -38040,7 +38046,7 @@ msgstr "tidak didukung bukan-standar pemotongan dari string literals"
 msgid "traditional C rejects string constant concatenation"
 msgstr "tradisional C menolak pemotongan konstanta string"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -39862,7 +39868,7 @@ msgstr "terlalu banyak berkas masukan"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -39896,15 +39902,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -39997,55 +40003,55 @@ msgstr "-mcpu=%s tidak valid"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "-mcpu=%s memiliki revisi silikon tidak valid"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops%s is obsolete, use -falign-loops%s"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "%salign-loops%s sudah ditinggalkan, gunakan -falign-loops%s"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-jumps%s is obsolete, use -falign-jumps%s"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "%salign-jumps%s sudah ditinggalkan, gunakan -falign-jumps%s"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-functions%s is obsolete, use -falign-functions%s"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "%salign-functions%s sudah ditinggalkan, gunakan -falign-functions%s"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "%sbranch-cost=%d%s is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s tidak berada diantara 0 dan 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -40576,14 +40582,14 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "-fdirectives-only tidak kompatibel dengan -Wunused_macros"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -40854,7 +40860,7 @@ msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebua
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "duplicate definition of %qs"
@@ -40902,7 +40908,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "tipe %q+D tidak memiliki ukuran yang diketahui"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -40998,346 +41004,346 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code for the counting ISA extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Keluarkan kode untuk menghitung ekstensi ISA"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "%qs atribut diabaikan"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid format for %<sve_width%>"
 msgstr "operasi di %<__fpreg%> tidak valid"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%H value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "nilai %%H tidak valid"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "fungsi spesifikasi '%s' tidak diketahui"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length"
 msgstr "Spesifikasikan pengurutan alokasi register"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "argumen ke %<__builtin_frame_address%> tidak valid"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "argumen ke %<__builtin_frame_address%> tidak valid"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-march%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "pilihan -mcpu=%s konflik dengan pilihan -march="
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s tidak mendukung %s"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "salah bentuk %<#pragma init%>"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -41542,13 +41548,13 @@ msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -41705,17 +41711,17 @@ msgstr "%qE atribut diabaikan"
 msgid "%qE attribute only applies to variables"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for %<asm%> flag output"
@@ -41939,7 +41945,7 @@ msgstr "target CPU tidak mendukung instruksi THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "target CPU tidak mendukung kode ARM"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -42002,7 +42008,7 @@ msgstr "ukuran batas struktur hanya dapat diset ke %s"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC tidak kompatibel dengan -msingle-pic-base"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -42117,7 +42123,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -42171,34 +42177,34 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "tidak dapat menghitung lokasi ril dari parameter terstack"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Tidak terduga akhir dari modul"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "tidak ada register bawah yang tersedia unruk popping register atas"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -42207,24 +42213,24 @@ msgstr "tipe vektori tidak valid untuk atribut %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "nama register: %s tidak dikenal"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -42310,19 +42316,19 @@ msgstr "-pipe tidak didukung"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe tidak didukung"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G dan -static adalah mutually exclusive"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -42678,7 +42684,7 @@ msgstr "argumen ke fungsi bawaan tidak valid"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "argumen ke fungsi bawaan tidak valid"
@@ -43343,755 +43349,755 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "model kode %s tidak mendukung kode PIC"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "atribut SEQUENCE di %C telah dispesifikasikan dalam pernyataan TIPE"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s atribut dari '%s' konflik dengan %s atribut di %L"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "terlalu banyak argumen ke fungsi %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "nama register tidak dispesifikasikan untuk %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= tidak didukung di sistem 32 bit"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mgp64%> used with a 32-bit ABI"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mgp64%> digunakan dengan sebuah ABI 32 bit"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bit mode tidak terkompile"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU yang anda pilih tidak mendukung set instruksi x86-64"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "nilai buruk %qs untuk pilihan -mcpu"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "nilai (%s) buruk untuk pilihan %sarch=%s %s"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %<%s%> for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "nilai %<%s%> buruk untuk pilihan -mtune="
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "nilai (%s) buruk untuk %stune=%s %s"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_return_address%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "argumen ke %<__builtin_return_address%> tidak valid"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%sregparm%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d tidak berada diantara %d dan 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "set instruksi SSE non-aktif, menggunakan 387 aritmetik"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "set instruksi 387 non-aktif, menggunakan aritmetik SSE"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "mengabaikan pilihan tidak dikenal %q.*s dalam %<-fdump-%s%>"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qT dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "tidak mendukung multilib"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "argumen vektor SSE tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE vektor kembali tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "argumen vektor MMX tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX vektor kembali tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan struct dengan sebuah anggota array flexible telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 #, fuzzy
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "register SSE kembali dengan SSE tidak aktif"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumen register SSE dengan SSE tidak aktif"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 register kembali dengan x87 tidak aktif"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr ""
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
@@ -44099,81 +44105,81 @@ msgstr "%s tidak didukung untuk fungsi nested"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "register extended tidak memiliki setengah tinggi"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 #, fuzzy
 #| msgid "the mangling of %<va_list%> has changed in GCC 4.4"
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "mangling dari %<va_list%> telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "unknown architecture specific memory model"
 msgstr "Arsitektur '%s' tidak dikenal"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "argumen yang tidak digunakan dalam $-gaya format"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -44559,7 +44565,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -45775,59 +45781,59 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "sampah diakhir dari %<#pragma reset_options%>"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "type %q+D does not have a known size"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "tipe %q+D tidak memiliki ukuran yang diketahui"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "type %q+D does not have a known size"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "tipe %q+D tidak memiliki ukuran yang diketahui"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not of type %qT"
 msgid "fields cannot have RVV type %qT"
 msgstr "%qE bukan dari tipe %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "tidak dapat mengalokasikan sebuah objek dari tipe abstrak %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "tidak dapat mengalokasikan sebuah objek dari tipe abstrak %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -45848,71 +45854,76 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -46430,106 +46441,106 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "tipe abstrak tidak valid %qT untuk %qE"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -48068,7 +48079,7 @@ msgstr "tidak dapat meletakan objek dengan bagian volatile kedalam register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "tidak terinisialisasi const %qD"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -48272,7 +48283,7 @@ msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
@@ -48468,7 +48479,7 @@ msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 msgid "function definition has qualified void return type"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
@@ -48612,7 +48623,7 @@ msgstr "ISO C melarang tipe fungsi const atau volatile"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "sebuah anggota dari sebuah struktur atau union tidak dapat memiliki sebuah tipe variabel termodifikasi"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel atau field %qE dideklarasikan void"
@@ -48831,7 +48842,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr "field %qE tidak dikenal dispesifikasikan dalam penginisialisasi"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
@@ -48883,7 +48894,7 @@ msgstr "struct tidak memiliki anggota bernama"
 msgid "struct has no members"
 msgstr "struct tidak memiliki anggota"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -48932,7 +48943,7 @@ msgstr "redeklarasi dari %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -48983,7 +48994,7 @@ msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -49017,7 +49028,7 @@ msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -49146,12 +49157,12 @@ msgstr "argumen %qD tidak cocok dengan prototipe bawaan"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -51366,7 +51377,7 @@ msgstr "tidak cukup secara sempurna nested loops"
 msgid "collapsed loops not perfectly nested"
 msgstr "collapsed loops tidak secara sempurna nested"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
@@ -51509,13 +51520,13 @@ msgstr "diduga %<{%>"
 msgid "variant %qD is not a function"
 msgstr "%q+D bukan sebuah fungsi,"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -51794,7 +51805,7 @@ msgstr "penggunaan tidak valid dari ekspresi void"
 msgid "invalid use of flexible array member"
 msgstr "penggunaan tidak valid dari anggota array fleksibel"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "penggunaan tidak valid dari array dengan batasan tidak terspesifikasikan"
@@ -52836,12 +52847,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -52883,7 +52894,7 @@ msgstr "elemen penginisialisasi tidak dapat dihitung di waktu load"
 msgid "invalid initializer"
 msgstr "penginisialisasi tidak valid"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
@@ -52898,8 +52909,8 @@ msgstr "kelebihan grup kurung diakhir dari penginisialisasi"
 msgid "braces around scalar initializer"
 msgstr "kurung disekitar penginisialisasi skalar"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inisialisasi dari anggota array fleksibel dalam sebuah konteks bertelur"
@@ -52993,7 +53004,7 @@ msgstr "kelebihan elemen dalam struktur penginisialisasi"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inisialisasi tidak statis dari sebuah anggota array fleksibel"
@@ -54471,7 +54482,7 @@ msgstr "tidak cocok %<operator %s%> untuk %qT"
 msgid "%q#D is private within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
@@ -54483,7 +54494,7 @@ msgstr "%q+D dideklarasikan disini"
 msgid "%q#D is protected within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
@@ -54500,7 +54511,7 @@ msgstr "%q+#D tidak dapat diakses"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "melewatkan koson ke argumen bukan penunjuk %P dari %qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -54874,7 +54885,7 @@ msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -55514,7 +55525,7 @@ msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
@@ -55643,7 +55654,7 @@ msgstr "tipe kembali abstrak tidak valid untuk fungsi %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -55717,7 +55728,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -55768,7 +55779,7 @@ msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -55908,7 +55919,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "dereferensi penunjuk %<void *%>"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -56013,7 +56024,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -56101,7 +56112,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
@@ -56171,214 +56182,214 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "tipe tidak lengkap %qT tidak diijinkan"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "contract predicate is false in constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 #| msgid "non-function in gimple call"
 msgid "function concept must be called"
 msgstr "bukan fungsi dalam panggilan gimple"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "diduga ekspresi"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -57022,7 +57033,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "no member named %qE in %qT"
@@ -57129,7 +57140,7 @@ msgstr "argumen ketiga ke %<__builtin_prefetch%> harus berupa sebuah konstan"
 msgid "no suspend point info for %qD"
 msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -57152,23 +57163,23 @@ msgstr "penunjuk tidak diijinkan sebagai nilai case"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -57715,7 +57726,7 @@ msgstr "dari deklarasi sebelumnya %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -58176,662 +58187,662 @@ msgstr "%qD bukan sebuah template fungsi"
 msgid "%q#T is not a class"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named %q#T in %q#T"
 msgid "no type named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah class template"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah tipe"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "parameter template tidak cocok dengan template"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "alignmen yang diminta bukan kelipatan dari 2"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "anonymous struct tidak didalam tipe bernama"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan konstruktor tidak diijinkan dalam kumpulan anonymous"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam kumpulan anoymous"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan operator penempatan salin tidak diperbolehkan dalam kumpulan anonymous"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "atribut untuk %q+#T harus mengikuti kata kunci %qs"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "multiple tipe dalam satu deklarasi"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ menghambat struct anonymous"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> hanya dapat dispesifikasikan didalam sebuah kelas"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> hanya dapat dispesifikasikan untuk konstruktor"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> telah diabaikan dalam deklarasi ini"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qs cannot be used for type declarations"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe kelas %qT diluar dari definisi"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe dependen %qT tanpa sebuah deklarasi yang berasosiasi"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan decltype)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarasi dari %q#D memiliki %<extern%> dan terinisialisasi"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tidak mengijinkan %<%T::%D%> untuk didefinisikan sebagai %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "duplikasi inisialisasi dari %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabel %q#D memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "kumpulan %q#D memiliki tipe tidak lengkap dan tidak dapat didefinisikan"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nama digunakan dalam sebuah gaya GNU diperuntukan penginisialisasi untuk sebuah array"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "bukan trivial designated penginisialisasi tidak didukung"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  anda dapat memperbaiki ini dengan menghapus penginisialisasi"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "tidak terinisialisasi const %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%J anggota tidak terinisialisasi %qD dengan %<const%> tipe %qT"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipe tidak valid %qT sebagai penginisialisasi untuk sebuah vektor dari tipe %qT"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "terlalu banyak penginisialisasi untuk %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elemen dari array %q#T memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ukuran-variabel compound literals"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "objek skalar %qD membutuhkan satu elemen dalam penginisialisasi"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "dalam C++98 %qD harus diinisialisasi dengan konstruktor, bukan dengan %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "array %qD diinisialisasi dengan tanda kurung string literal %qE"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "penginisialisasi tidak valid untuk anggota statis  dengan konstruktor"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(diluar dari kelas inisialisasi dibutuhkan)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "parameter %qD dinisialisasi"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarasi dari %q#D tidak memiliki penginisialisasi"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "membayangi tipe deklarasi sebelumnya dari %q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "fungsi %q#D telah dinisialisasi seperti sebuah variabel"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  tidak dapat menggunakan obsolete binding di %q+D karena ini memiliki sebuah desktruktor"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT adalah sebuah dasar tidak dapat diakses dari %qT"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "%u name provided for structured binding"
@@ -58839,1840 +58850,1840 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%Hpenginisialisasi disediakan untuk fungsi"
 msgstr[1] "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "tidak dapat menguraikan alamat"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "tidak dapat menjalankan %<offsetof%> ke anggota data statis %qD"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "desktruktor untuk alien kelas %qT tidak dapat berupa sebuah anggota"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktor untuk alien kelas %qT tidak dapt berupa sebuah anggota"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D dideklarasikan dengan spesifikasi eksepsi"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definisi dari %qD tidak dalam namespace melingkupi %qT"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "anggota fungsi statis %q#D dideklarasikan dengan tipe pengkualifikasi"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "metoda Java %qD memiliki tipe kembali %qT bukan Java"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD bukan sebuah fungsi template"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "mendifinisikan eksplisit spesialisasi %qD dalam deklarasi friend"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "penggunaan tidak valid dari template-id %qD dalam deklarasi dari primary template"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "Binding di %C harus memiliki akses sama seperti telah didefinisikan binding '%s'"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "literal operator with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> harus kembali %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "bukan %q#D anggota fungsi dideklarasikan dalam kelas %qT"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "strong using only meaningful at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "strong using hanya berarti di lingkup namespace"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ melarang inisialisasi dari anggota constant %qD dari bukan integral tipe %qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "ukuran dari array %qD memiliki tipe bukan integral %qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ melarang array dengan variabel panjang %qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ melarang array dengan variabel panjang"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "array dengan panjang bervariabel  %qD digunakan"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "overflow dalam dimensi array"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "spesifikasi tipe kembali untuk konstruktor tidak valid"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "tipe kembali yang dispesifikasikan untuk %<operator %T%>"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variabel tidak bernama atau field dideklarasikan void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "deklarasi dari %qD sebagai bukan anggota"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "id pendeklarasi hilang; menggunaka kata reserved %qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "definisi fungsi tidak mendeklarasikan parameter"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "missing type-name in typedef-declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dua atau lebih tipe data dalam deklarasi dari %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ melarang deklarasi dari %qs dengan tidak ada tipe"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs tidak didukung oleh target ini"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ 1998 does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> dan %<unsigned%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> dan %<short%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qD"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "kompleks tidak valid untuk %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "type deklarasi tidak valid dalam parameter deklarasi"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level deklarasi dari %qs menspesifikasikan %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "lingkup-fungsi %qs secara implisit auto dan dideklarasikan %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spesifikasi kelas penyimpanan tidak valid dalam deklarasi fungsi friend"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Diduga parenthesis kiri"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function uses %<auto%> type specifier without late return type"
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs fungsi menggunakan penspesifikasi tipe %<auto%> tanpa tipe kembali late"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type not declared with %<auto%> type specifier"
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs fungsi dengan tipe kembali late tidak dideklarasikan dengan penspesifikasi tipe %<auto%>"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> fungsi mengembalikan nilai bukan-void"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "tidak dapat mendefinisikan fungsi friend %qs dalam sebuah definisi lokal kelas"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktor mungkin tidak memiliki parameter"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T, yang bukan sebuah typedef atau sebuah argumen tipe template"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD digunakan sebagai sebuah pendeklarasi"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "anggota fungsi secara implisit friends dari kelasnya"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra kualifikasi %<%T::%> di anggota %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member %<%T::%s%> within %qT"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "bukan parameter %qs tidak dapat menjadi parameter pack"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "anggota member tidak boleh memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "typedef may not be a member function definition"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%H%<[*]%> tidak diijinkan selain dalam sebuah deklarasi"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "typedef declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ melarang tipe nested %qD dengan nama sama seperti kelas yang melingkupi"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "deklarasi friend membutuhkan kunci kelas, i.e. %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "deklarasi friend membutuhkan class-key, i.e. %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "mencoba untuk membuat kelas %qT sebuah friend dari lingkup global"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "kualifier tidak valid di tipe fungsi bukan anggota"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "deklarasi abstrak %qT digunakan sebagai deklarasi"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "tidak dapat mendeklarasikan parameter %q+D untuk menjadi tipe abstrak %qT"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "%Hpenggunaan tidak vlaid dari nama template %qE tanpa sebuah daftar argumen"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "penggunaan tidak valid dari %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "deklarasi dari C fungsi %q#D konflik dengan"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fungsi %qD dideklarasikan virtual didalam sebuah union"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD tidak dapat dideklarasikan virtual, karena itu selalu statis"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "a destructor cannot be %qs"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "diduga kualifikasi nama dalam deklarasi friend untuk konstruktor %qD"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "a constructor cannot be %<concept%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "tidak dapat membuka %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "field %qD memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "kelas penyimpanan %<auto%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "kelas penyimpanan %<register%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> dispesifikasikan tidak valid untuk fungsi %qs dideklarasikan diluar lingkup global"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual bukan kelas fungsi %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 #| msgid "%qs defined in a non-class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "tidak dapat mendeklarasikan anggota fungsi %qD untuk memiliki linkage statis"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "tidak dapat mendeklarasikan fungsi statis didalam fungsi lainnya"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> mungkin tidak digunakan ketika mendefinisikan (terbalik untuk deklarasi) sebuah anggota data statis"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "tidak dapat secara eksplisit mendeklarasikan anggota %q#D untuk memiliki extern linkage"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "konstruktor tidak valid; anda mungkin bermaksud %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD tidak boleh dideklarasikan sebagai statis"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD harus baik sebuah anggota fungsi tidak statis atau bukan anggota fungsi"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD harus memiliki sebuah argumen dari kelas atau tipe enumerasi"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ melarang overloading operator ?:"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD harus mengambil baik nol atau satu argumen"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD harus mengambil baik satu atau dua argumen"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumennya"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumen keduanya"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD harus mengambil secara tepat satu argumen"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD seharusnya kembali dengan nilai"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "menggunakan typedef-name %qD setelah %qs"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT direferensikan sebagai enum"
@@ -60684,115 +60695,115 @@ msgstr "%qT direferensikan sebagai enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "penggunaan dari enum %q#D tanpa deklarasi sebelumnya"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeklarasi dari %qT sebagai bukan-template"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "tidak dapat mendeklarasikan %qD untuk menjadi sebuah tipe bit-field"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union turunan %qT tidak valid"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "tipe base %qT gagal untuk menjadi sebuah struct atau tipe kelas"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipe rekursif %qT tidak terdefinisi"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "duplikasi tipe dasar %qT tidak valid"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -60802,90 +60813,90 @@ msgstr "tipe yang digaris bawahi %<%T%> dari %<%T%> harus berupa sebuah tipe int
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "tidak ada tipe integral yang dapat merepresentasikan seluruh dari nilai enumerasi untuk %qT"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow dalam nilai enumerasi di %qD"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD telah didefinisikan dalam kelas %qT"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "using %qs"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -61826,7 +61837,7 @@ msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
@@ -62958,7 +62969,7 @@ msgstr "using-declaration untuk bukan-anggota di class scope"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -63807,7 +63818,7 @@ msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -64601,13 +64612,13 @@ msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 msgid "cannot expand initializer for member %qD"
 msgstr "%Htidak dapat mengekspand penginisialisasi untuk anggota %<%D%>"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -65289,7 +65300,7 @@ msgstr "hilang target makefile setelah %qs"
 msgid "%qT not permitted in template argument"
 msgstr "%Hparse error dalam daftar argumen template"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
@@ -66280,7 +66291,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
@@ -67392,7 +67403,7 @@ msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
@@ -67494,294 +67505,294 @@ msgstr "fungsi mengembalikan sebuah array"
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in comparison expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "operan tidak valid dalam ekspresi perbandingan"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "jumlah dari argumen salah dispesifikasikan untuk atribut %qs"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -67794,183 +67805,183 @@ msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bukan sebuah namespace"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "definisi dari %q#T didalam daftar parameter template"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "fungsi tidak dipertimbangkan untuk inlining"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 #| msgid "explicit qualification in declaration of %qD"
 msgid "explicit deduction guide declared here"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -68309,7 +68320,7 @@ msgstr "spesifikasi kelas dasar tidak valid"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
@@ -68764,30 +68775,30 @@ msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a class or namespace"
 msgid "%qD is not a class or alias template"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -68796,22 +68807,22 @@ msgstr "argumen ke %<__builtin_return_address%> tidak didukung"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -70191,243 +70202,243 @@ msgstr "deklarasi dari %q#D"
 msgid "declaration of %q#T"
 msgstr "deklarasi dari %q#D"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of incomplete type %q#T"
 msgstr "penggunaan tidak valid dari typedef tidak lengkap %qD"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "penggunaan tidak valid dari anggota %q+D dalam anggota fungsi statis"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of placeholder %qT"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of template type parameter %qT"
 msgstr "penggunaan tidak valid dari typedef tidak lengkap %qD"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "invalid use of template template parameter %qT"
 msgstr "argumen baku tidak valid untuk sebuah parameter template template"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of pack expansion expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of dependent type %qT"
 msgstr "penggunaan tidak valid dari typedef tidak lengkap %qD"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array must be initialized with a brace-enclosed initializer"
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "sintaks konstruktor digunakan, tetapi tidak ada konstruktor dideklarasikan untuk tipe %qT"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 #| msgid "interface %qs does not have valid constant string layout"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "antar-muka %qs tidak memiliki layout konstanta string yang valid"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "inisialisasi-string untuk array dari karakter terlalu panjang"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "kurung disekitar penginisialisasi skalar"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "tidak dapat menginisialisasi kumpulan dari tipe %qT dengan sebuah kompound literal"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "prototipe untuk %q#D tidak cocok dengan kelas apapun %qT"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "tidak ada field %qD ditemukan dalam union sedang diinisialisasi"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "nilai indeks daripada nama field dalam union penginisialisasi"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "operan dasar dari %<->%> memiliki tipe bukan penunjuk %qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "hasil dari %<operator->()%> menghasilkan hasil bukan penunjuk"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "operan dasar dari %<->%> bukan sebuah penunjuk"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE tidak dapat digunakan sebagai sebuah anggota penunjuk, karena ini adalah tipe %qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "tidak dapat mengaplikasikan anggota penunjuk %qE ke %qE, yang dari tipe bukan class %qT"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "invalid value-initialization of reference type"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi yang melemparkan tipe tidak lengkap %q#T"
@@ -71451,7 +71462,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -72684,12 +72695,12 @@ msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Indeks awal substring di %L lebih kecil dari satu"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Indeks akhir substring di %L melebihi panjang string"
@@ -72892,7 +72903,7 @@ msgstr "Spesifikasi INTENT buruk di %C"
 msgid "deferred type parameter at %C"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -75097,7 +75108,7 @@ msgstr "intrinsik transformational '%s' di %L tidak diijinkan dalam sebuah ekspr
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Ekstensi: Evaluasi dari ekspresi inisialisasi ekpresi tidak baku di %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic or a specification function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -75405,7 +75416,7 @@ msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -75531,7 +75542,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
@@ -75543,7 +75554,7 @@ msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
@@ -75683,7 +75694,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -75918,12 +75929,12 @@ msgstr "Argumen pertama dari penempatan yang didefinisikan di %L harus berupa IN
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
@@ -76048,637 +76059,637 @@ msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) argumen aktual di %L mungkin menginterferensi dengan argumen aktual di %L."
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Tipe tidak cocok dalam argumen '%s' di %L; dilewatkan %s ke %s"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tipe yang sama"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Argumen kata-kunci '%s' di %L telah berasosiasi dengan argumen aktual lain"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Lebih aktual daripada formal argumen dalam pemanggilan prosedur di %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Hilang alternatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Tidak terduga alternaatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan penunjuk atau dapat dialokasikan argumen dummy '%s' di %L"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan diasumsikan-bentuk argumen dummy '%s' di %L"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Panjang karakter dari argumen aktual lebih pendek dari argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Diduga sebuah prosedur penunjuk untuk argumen '%s' di %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktual argumen untuk '%s' tidak dapat diasumsikan array berukuran di %L"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktual argumen untuk '%s' harus DAPAT DIALOKASIKAN di %L"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT) or VOLATILE attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Daerah array aktual argumen dengan vektor subscript di %L adalah tidak kompatibel dengan INTENT(OUT), INTENT(INOUT) atau VOLATILE atribut dari argumen dummy'%s'"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Daerah array aktual argumen di %L adalah tidak kompatibel dengan tidak-diasumsikanbentuk dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Penunjuk array aktual argumen di %L membutuhkan sebuah bentuk diasumsikan ataupenunjuk array dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Hilang alternatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Hilang aktual argumen untuk argumen '%s' di %L"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Aktual argumen sama berasosiasi dengan INTENT(%s) argumen '%s' dan INTENT(%s) argumen '%s' di %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan memiliki atribut PENUNJUK"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Otomatis panjang fungsi karakter '%s' di %L harus memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Simbol '%s' di %L telah memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D teraliasi ke simbol tidak terdefinisi %qs"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiti '%s' di %C telah ada dalam sebuah antar-muka"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Tidak dapat overwrite GENERIC '%s' di %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' di %L overrides sebuah prosedur binding dideklarasikan NON_OVERRIDABLE"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' di %L overrides sebuah prosedur PURE dan juga harus berupa PURE"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' di %L overrides sebuah prosedur ELEMENTAL dan juga harus berupa ELEMENTAL"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' di %L overrides sebuah prosedur bukan ELEMENTAL dan tidak harus berupa ELEMENTAL juga"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' di %L overrides sebuah SUBROUTINE dan juga harus berupa sebuah SUBROUTINE"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' di %L overrides sebuah FUNGSI dan juga harus berupa sebuah FUNGSI"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' di %L overrides sebuah prosedur PUBLIK dah tidak harus berupa PRIVATE"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Argumen dummy '%s' dari '%s' di %L seharusnya bernama '%s' untuk mencocokan dengan argumen yang berhubungan dengan prosedur overridden"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' di %L harus memiliki jumlah sama dari argumen formal seperti prosedur overridden"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' di %L overrides sebuah binding NOPASS dan juga harus berupa NOPASS"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' di %L overrides sebuah pengikatan dengan PASS dan juga harus berupa PASS"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Argumen dummy objek yang dilewatkan dari '%s' di %L harus berada di posisi yang sama sebagai argumen dumy objek yang dilewatkan dari prosedur overridden"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s tag di %L harus berupa tipe %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Nilai-karakter fungsi internal '%s' di %L tidak boleh dengan panjang diasumsikan"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "pernyataan DATA di %C tidak diperbolehkan dalam sebuah prosedur PURE"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Terlalu banyak argumen dalam panggilan ke '%s' di %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -76886,7 +76897,7 @@ msgstr "Konversi dari %s ke %s di %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -77513,7 +77524,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -78147,7 +78158,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -80181,8 +80192,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
@@ -82341,800 +82352,812 @@ msgstr "Nilai-karakter fungsi internal '%s' di %L tidak boleh dengan panjang dia
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Nilai-karakter fungsi internal '%s' di %L tidak boleh dengan panjang diasumsikan"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "Fungsi %s di %L memiliki masukan dengan spesifikasi array tidak cocok"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function %s at %L has entries with mismatched array specifications"
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "Fungsi %s di %L memiliki masukan dengan spesifikasi array tidak cocok"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Function %s at %L with entries returning variables of different string lengths"
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "Ekstensi: Fungsi %s di %L dengan masukan mengembalikan variabel dari panjang string berbeda"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be an array in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Hasil FUNGSI %s tidak dapat berupa sebuah array dalam FUNGSI %s di %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be an array in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Hasil MASUKAN %s tidak dapat berupa sebuah array dalam FUNGSI %s di %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Hasil FUNGSI %s tidak dapat berupa sebuah PENUNJUK dalam FUNGSI %s di %L"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Hasil MASUKAN %s tidak dapat berupa sebuah PENUNJUK dalam FUNGSI %s di %L"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Hasil FUNGSI %s tidak dapat berupa sebuah PENUNJUK dalam FUNGSI %s di %L"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Hasil MASUKAN %s tidak dapat berupa sebuah PENUNJUK dalam FUNGSI %s di %L"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be of type %s in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Hasil FUNGSI %s tidak dapat tipe %s dalam FUNGSI %s di %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be of type %s in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Hasil MASUKAN %s tidak dapat tipe %s dalam FUNGSI %s di %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a DO block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "pernnyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok DO"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a DO block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "pernnyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok DO"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "COMMON block /%s/ not found at %C"
 msgid "COMMON block at %L"
 msgstr "blok COMMON /%s/  tidak ditemukan di %C"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "Variabel '%s' di %L adalah dalam COMMON tetapi hanya dalam inisialisasi BLOK DATA yang diperbolehkan"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized variable '%s' at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "variabel terinisialisasi '%s' di %L adalah dalam sebuah kosong COMMON tetapi inisialisasi hanya diperbolehkan dalam blok umum bernama"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "Tipe variabel turunan '%s' dalam COMMON di %L memiliki bukan SEQUENCE ataupun atribut BIND(C)"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' in COMMON at %L has an ultimate component that is allocatable"
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "Tipe variabel turunan '%s' dalam COMMON di %L memiliki sebuah komponen ultimate yang dapat dialokasikan"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' in COMMON at %L may not have default initializer"
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "Tipe variabel turunan '%s' dalam COMMOND di %L tidak boleh memiliki penginisialisasi baku"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "blok COMMON '%s' di %L digunakan sebagai PARAMETER di %L"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "blok COMMON '%s' di %L digunakan sebagai PARAMETER di %L"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L is also an intrinsic procedure"
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "blok COMMON '%s' di %L juga sebuah prosedur intrinsik"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: COMMON block '%s' at %L that is also a function result"
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "Fortran 2003: blok common '%s' di %L yang juga sebuah hasil fungsi"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: COMMON block '%s' at %L that is also a global procedure"
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "Fortran 2003: blok COMMON '%s' di %L yang juga sebuah prosedur global"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The rank of the element in the derived type constructor at %L does not match that of the component (%d/%d)"
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "Tingkat dari elemen dalam tipe konstruktor turunan di %L tidak cocok dengan komponen (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "Elemen dalam tipe konstruktor turunan di %L, untuk komponen penunjuk '%s', adalah %s tetapi seharusnya berupa %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, fuzzy, gcc-internal-format
 #| msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Panjang karakter tidak sama (%ld/%ld) dalam %s di %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, fuzzy, gcc-internal-format
 #| msgid "The NULL in the derived type constructor at %L is being applied to component '%s', which is neither a POINTER nor ALLOCATABLE"
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "NULL dalam tipe konstruktor turunan di %L, sedang diaplikasikan untuk komponen '%s', yang bukan sebuah PENUNJUK atau sebuah ALLOCATABLE"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %C!"
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "Terlalu banyak komponen dalam struktur konstruktor di %C!"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %C!"
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "Terlalu banyak komponen dalam struktur konstruktor di %C!"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 #| msgid "The rank of the element in the derived type constructor at %L does not match that of the component (%d/%d)"
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "Tingkat dari elemen dalam tipe konstruktor turunan di %L tidak cocok dengan komponen (%d/%d)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s' should be a POINTER or a TARGET"
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "Elemen dalam tipe konstruktor turunan di %L, untuk komponen penunjuk '%s' seharusnya berupa sebuah PENUNJUK atau sebuah TARGET"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Elemen dalam tipe konstruktor turunan di %L, untuk komponen penunjuk '%s', adalah %s tetapi seharusnya berupa %s"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, fuzzy, gcc-internal-format
 #| msgid "The upper bound in the last dimension must appear in the reference to the assumed size array '%s' at %L"
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "Batas atas dalam dimensi terakhir harus muncul dalam referensi ke ukuran array yang diasumsikan '%s' di %L"
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%qs at %L is ambiguous"
 msgstr "'%s' di %L adalah ambigu"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "prosedur UMUM '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, fuzzy, gcc-internal-format
 #| msgid "Type specified for intrinsic function '%s' at %L is ignored"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Tipe dispesifikasikan untuk fungsi intrinsik '%s' di %L diabaikan"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared INTRINSIC at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "'%s' dideklarasikan INTRINSIC di %L tidak ada"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, fuzzy, gcc-internal-format
 #| msgid "The intrinsic '%s' declared INTRINSIC at %L is not available in the current standard settings but %s.  Use an appropriate -std=* option or enable -fall-intrinsics in order to use it."
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Intrinsik '%s' dideklarasikan INTRINSIC di %L tidak tersedia dalam konfigurasi baku sekarang tetapi %s. Gunakan sebuah pilihan -std=* yang sesuai atau aktifkan -fall-intrinsics untuk menggunakan itu."
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, fuzzy, gcc-internal-format
 #| msgid "Non-RECURSIVE procedure '%s' at %L is possibly calling itself recursively.  Declare it RECURSIVE or use -frecursive"
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Label %d direferensikan di %L tidak pernah terdefinisi"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Prosedur internal '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsik '%s' di %L tidak diperbolehkan sebagai sebuah argumen aktual"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Prosedur internal '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL bukan INTRINSIK prosedur '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to find a specific INTRINSIC procedure for the reference '%s' at %L"
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Tidak dapat menemukan sebuah prosedur INTRINSIK spesifik untuk referensi '%s' di %L"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Simbol '%s' di %L adalah ambigu"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Argumen dengan nilai di %L adalah bukan tipe numerik"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Melewati prosedur internal di %L dengan lokasi tidak diperbolehkan"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL bukan INTRINSIK prosedur '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "'%s' di %L adalah sebuah array dan OPSIONAL; JIKA INI HILANG, ini tidak dapat berupa argumen aktual dari sebual prosedur ELEMENTAL kecuali disana ada sebuah tidak pilihanonal argumen dengan tingkat sama (12.4.1.5)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Argumen aktual di %L untuk INTENT(%s) dummy '%s' dari subroutine ELEMENTAL '%s' adalah sebuah skalar, tetapi argumen aktual lain adalah sebuah array"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Disana tidak ada fungsi spesifik untuk umum '%s' di %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Fungsi umum '%s' di %L tidak konsisten dengan sebuah antar-muka spesifik intrinsik."
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Fungsi '%s' di %L adalah INTRINSIK tetapi tidak kompatibel dengan sebuah intrinsik"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Tidak dapat meresolf fungsi spesifik '%s'di %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "referensi ke fungsi bukan-PURE '%s' di %L didalam sebuah FORALL %s"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "referensi ke fungsi bukan-PURE '%s' di %L didalam sebuah FORALL %s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Tidak dapat menulis ke internal berkas satuan '%s' di %C didalam prosedur PURE"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "'%s' di %L bukan sebuah fungsi"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ANTAR-MUKA ABSTRAK '%s' tidak boleh direferensikan di %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Fungsi '%s' adalah dideklarasikan KARAKTER(*) dan tidak dapat digunakan di %L karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Fungsi bukan-ELEMENTAL definisi pengguna '%s' di %L tidak diperbolehkan dalam WORKSHAREkonstruksi"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "MASUKAN '%s' di %L tidak dapat dipanggil secara rekursif, karena fungsi '%s' tidak REKURSIF"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Fungsi '%s' di %L tidak dapat dipanggil secara rekursif, karena ini bukan REKURSIF"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Using function %qs at %L is deprecated"
 msgstr "Pernyataan fungsi di %L adalah rekursif"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' dalam blok FORALL di %L tidak PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' dalam blok FORALL di %L tidak PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' di %L bukan PURE"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Disana tidak ada subroutine spesifik untuk umum '%s' di %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Subroutine umum '%s' di %L tidak konsisten dengan sebuah anta-muka subroutine intrinsik"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Subroutine '%s' di %L adalah INTRINSIK tetapi tidak kompatibel dengan sebuah intrinsik"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Tidak dapat meresolf subroutine spesifik '%s' di %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' di %L memiliki sebuah tipe, yang tidak konsisten dengan CALL di %L"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "MASUKAN '%s' di %L tidak dapat dipanggil secara rekursif, karena subroutine '%s' tidak REKURSIF"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE '%s' di %L tidak dapat dipanggil secara rekursif, karena ini bukan REKURSIF"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Bentuk untuk operan di %L dan %L tidak konformant"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Shape specification at %L cannot be negative"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Spesifikasi bentuk di %L tidak dapat negatif"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tidak legal stride dari nol di %L"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Jangkauan paling kanan ats dari daerah ukuran array yang diasumsikan tidak dispesifikasikan di %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Indeks array di %L harus berupa skalar"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Indeks array di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ekstensi: indeks array RIL di %L"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of array reference at %C"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Format dari referensi array tidak valid di %C"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Indeks array di %L adalah sebuah array dari tingkat %d"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Indeks awal substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Indeks awal substring di %L harus berupa skalar"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Indeks akhir substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut PENUNJUK di %L"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut DAPAT DIALOKASIKAN di %L"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Dua atau lebih referensi bagian dengan tingkat bukan-nol tidak boleh dispesifikasikan di %L"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -83144,12 +83167,12 @@ msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -83159,314 +83182,314 @@ msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s', digunakan dalam sebuah ekspresi spesifikasi, direferensikan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s' digunakan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "instance variabel %qs dideklarasikan %s"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Argumen '%s' dari prosedur elemental di %L harus berupa skalar"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Tidak ditemukan pengikatan spesifik yang cocok untuk panggilan ke GENERIC '%s' di %L"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' di %L seharusnya berupa sebuah SUBROUTINE"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' di %L seharusnya berupa sebuah FUNGSI"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s di %L harus berupa sebuah skalar"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "%s at %L must be integer"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s di %L harus berupa INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL akhir ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL stride ekspresi di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL indeks '%s' mungkin tidak muncul dalam spesifikasi triplet di %L"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Ekspresi dalam pernyataan ALOKASI di %L harus berupa DAPAT DIALOKASIKAN atau sebuah PENUNJUK"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' tidak boleh muncul dalam spesifikasi array di %L dalam pernyataan ALOKASI yang sama dimana ini sendiri dialokasikan"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -83475,310 +83498,310 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "KASUS BAKU di %L tidak dapat diikuti oleh sebuah KASUS BAKU kedua di %L"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Jangkauan logikal dalam pernyataan CASE di %L tidak diperbolehkan"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "nilai logikan konstan dalam pernyataan CASE diulang di %L"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Spesifikasi jangkauan di %L tidak pernah cocok"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logikal SELECT CASE blok di %L memiliki lebih dari dua kasus"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Nama '%s' tidak dapat digunakan sebagai sebuah operator terdefinisi di %C"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "Selector at %L must not be coindexed"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Elemen pemindahan data di %L tidak dapat berupa sebuah referensi lengkap ke sebuah array yang ukurannya diasumsikan"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Pernyataan di %L bukan sebuah pernyataan pencabangan target yang valid untuk sebuah pernyataan percabangan di %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Cabang di %L bisa menyebabkan sebuah loop tak terhingga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -83786,217 +83809,217 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "DIMANA mask di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "penempatan target WHERE di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "penempatan bukan-ELEMEN didefinisikan-pengguna dalam WHERE di %L"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Pernyataan didalam WHERE di %L tidak didukung"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL dengan indeks '%s' tidak digunakan di sisi kiri dari penempatan di %L dan jadi mungkin menyebabkan penempatan berulang di objek ini"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Sebuah konstruks FORALL luar telah memiliki sebuah indeks dengan nama ini %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE clause di %L membutuhkan sebuah array LOGIKAL"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Pernyataan RETURN alternatif di %L membutuhkan sebuah SKALAR-INTEGER return penspesifikasi"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Diduga ekspresi inisialisasi dalam CASE di %C"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Pernyataan aritmetik IF di %L membutuhkan sebuah ekspresi numerik"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Kondisi keluar dari loop DO WHILE di %L harus berupa sebuah ekspresi skalar LOGIKAL"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL mask clause di %L membutuhkan sebuah ekspresi LOGIKAL"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -84004,7 +84027,7 @@ msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -84012,1110 +84035,1110 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Objek skalar '%s' di %L mungkin tidak dapat DIALOKASIKAN"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Tipe '%s' tidak dapat host assosiasi di %L karena ini diblok dengan sebuah objek tidak kompatibel dari nama sama yang dideklarasikan di %L"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul atau array aplikasi utama '%s' di %L harus memiliki bentuk konstan"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entity dengan panjang karakter diasumsikan di %L harus berupa sebuah argumen dummy atau sebuah PARAMETER"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsik '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Hasil fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Array otomatis '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "dalam %s, di %s:%d"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Pernyataan fungsi nilai-karakter '%s' di %L harus memiliki panjang konstant"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah argumen dummy dari '%s', yang mana ini adalah PUBLIK di %L"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Prosedur '%s' dalam antar-muka PUBLIK '%s' di %L memakai argumen dummy dari '%s' dimana ini adalah PRIVATE"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Fungsi ELEMEN '%s' di %L harus memiliki sebuah hasil skalar"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-array"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat rekursif"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Prosedur dummy '%s' di %C tidak dapat memiliki sebuah antar-muka umum"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut SAVE dalam '%s' di %L"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "Prosedur FINAL '%s' di %L bukan sebuah SUBROUTINE"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Prosedur FINAL di %L harus memiliki tepat satu argumen"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa tipe '%s'"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "argumen dari prosedur FINAL di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argumen dari prosedur FINAL di %L tidak boleh berupa OPSIONAL"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa INTENT(OUT)"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Prosedur FINAL bukan skalar di %L seharusnya memiliki diasumsikan argumen bentuk"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "prosedur FINAL '%s' dideklarasikan di %L memiliki tingkat yang sama (%d) seperti '%s'"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Hanya array prosedur FINAL dideklarasikan untuk tipe turunan '%s' didefinisikan di %L, disarankan juga skalar satu"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' dan '%s' tidak dapat dicampurkan FUNCTION/SUBROUTINE untuk GENERIC '%s' di %L"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' dan '%s' untuk GENERIC '%s' di %L adalah ambigu"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Tidak terdefinisi pengikatan spesifik '%s' sebagai target dari GENERIC '%s' di %L"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' di %L harus target sebuah pengikatan spesifik, '%s' adalah GENERIC, juga"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC '%s' di %L tidak dapat overwrite pengikatan spesifik dengan nama sama"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' harus berupa sebuah prosedur modul atau sebuah prosedur eksternal dengan sebuah antar-muka eksplisit di %L"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic entities are not yet implemented, non-polymorphic passed-object dummy argument of '%s' at %L accepted"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "entiti polymorphic belum diimplementasikan, bukan polymorphic objek argumen dummy dilewatkan dari '%s' di %L diterima"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama seperti sebuah komponen turunan dari '%s'"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumen dari ICHAR di %L harus berupa panjang satu"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Panjang karakter dari komponen '%s' butuh untuk menjadi sebuah ekspresi spesifikasi konstan di %L"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Ekspresi di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: Komponen '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah komponen dari '%s', yang mana adalah PUBLIK di %L"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponen %s dari tipe URUTAN dideklarasikan di %L tidak dapat memiliki atribut URUTAN"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%H%qE belum pernah dideklarasikan"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Panjang karakter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -86085,7 +86108,7 @@ msgstr "Overlapping tidak sama penginisialisasi dalam EKUIVALEN di %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Overlapping tidak sama penginisialisasi dalam EKUIVALEN di %L"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -86098,13 +86121,13 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Jumlah dari elemen dalam konstruktor array di %L membutuhkan sebuah peningkatan dari batas atas %d yang diijinkan. Lihat pilihan -fmax-array-constructor"
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Membuat array sementara di %L untuk argumen '%s'"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipe ekspresi buruk selama walk (%d)"
@@ -86208,94 +86231,100 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY '%s' at %L has no IMPLICIT type"
+msgid "%s at %C has no default type"
+msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variabel instrinsic yang bukan sebuah prosedur"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return value of function %qs at %L not set"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "backend deklarasi untuk variabel modul %s telah ada"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Dummy argumen '%s' di %L telah dideklarasikan INTENT(OUT) tetapi belum diset"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Dummy argumen '%s' di %L telah dideklarasikan INTENT(OUT) tetapi belum diset"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 #| msgid "Unused dummy argument '%s' at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argumen dummy tidak digunakan '%s' di %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "Return value '%s' of function '%s' declared at %L not set"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Nilai kembali dari fungsi '%s' dideklarasikan di %L tidak diset"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -86310,27 +86339,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Instrinsik op tidak diketahui"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Daftar fungsi argumen tidak diketahui di %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
diff --git a/gcc/po/ja.po b/gcc/po/ja.po
index 464a05d5069..a20d2a983c5 100644
--- a/gcc/po/ja.po
+++ b/gcc/po/ja.po
@@ -21,7 +21,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2021-05-11 22:47+0900\n"
 "Last-Translator: Hiroshi Takekawa <sian@big.or.jp>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -4036,7 +4036,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7681,6 +7681,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "AES 組み込み関数とコード生成をサポートする"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17220,12 +17225,12 @@ msgstr "'%%l' 被演算子が label ではありません"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "浮動小数定数を使い損ねました"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18290,64 +18295,64 @@ msgstr "このオプションに説明がありません"
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr ""
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.cc:1732
+#: opts.cc:1733
 #, fuzzy
 msgid "[available in "
 msgstr "STAT 変数"
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[デフォルト]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[有効]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[無効]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -18356,47 +18361,47 @@ msgstr ""
 "  %s オプションの有効な引数は以下の通り:\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "このオプションはターゲット固有のものです"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "次のオプションはコンパイラの警告メッセージを制御します"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "次のオプションは最適化を制御します"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "次のオプションは言語に依存しないものです"
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr "次のオプションはパラメータを制御します"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "次のオプションはこの言語固有のものです"
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "次のオプションはこの言語でサポートされているものです"
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "次のオプションは文書化されていません"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "次のオプションは分離した引数を取ります"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "次のオプションは結合した引数を取ります"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "次のオプションは言語に関係したものです"
 
@@ -18780,72 +18785,72 @@ msgstr "strfmon 書式の長さ修飾子"
 msgid "<command-line>"
 msgstr "<コマンドライン>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr "無効なベクトル定数です"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "被演算子がありません"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "無効な定数"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "無効な被演算子です"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "無効なアドレスモードです"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "GNU と SVE ベクタの二項演算はできません"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "局所動的 TLS 参照無しで '%%&' が使用されました"
@@ -18862,18 +18867,18 @@ msgid "invalid %%r value"
 msgstr "無効な %%r 値"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "無効な %%R 値"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
@@ -18903,7 +18908,7 @@ msgstr "無効な %%M 値"
 msgid "invalid %%U value"
 msgstr "無効な %%U 値"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
@@ -18913,7 +18918,7 @@ msgstr "無効な %%s 値"
 msgid "invalid %%C value"
 msgstr "無効な %%C 値"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
@@ -18926,7 +18931,7 @@ msgstr ""
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無効な %%xn コード"
@@ -19009,35 +19014,35 @@ msgstr "被演算子として無効な UNSPEC です"
 msgid "unrecognized supposed constant"
 msgstr "認識できない定数のようなもの"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "無効なシフト被演算子"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "述語付き Thumb 命令"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "条件シーケンスにある述語付き命令"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19046,26 +19051,26 @@ msgstr "コード '%c' に対する無効な被演算子です"
 msgid "invalid operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "命令は決して実行されません"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<bfloat16_t%> からの無効な変換です"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "%<bfloat16_t%> への無効な変換です"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19430,97 +19435,97 @@ msgstr "無効な浮動小数点定数です"
 msgid "Expected register or constant integer."
 msgstr "インターフェースまたはインターフェースへのポインタが予期されます"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "'%s' の誤った用法です"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "無効な型の使用法です"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "演算子に対する無効な制約です"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, c-format
 msgid "invalid vector immediate"
 msgstr "無効なベクトル直接表記"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "不明な命令モード"
 
@@ -19551,7 +19556,7 @@ msgstr "%<__fpreg%> に関する無効な操作です"
 msgid "invalid %%P operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -19596,8 +19601,8 @@ msgstr "'%%%c' は有効な被演算子接頭辞ではありません"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "'%%%c' の無効な使用法です"
@@ -19629,7 +19634,7 @@ msgid "post-increment address is not a register"
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -19787,7 +19792,7 @@ msgstr "サポートされていない定数アドレス:"
 msgid "unsupported memory expression:"
 msgstr "固定小数変換内で無効な型です"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "無効な %%P 被演算子です"
@@ -19845,147 +19850,147 @@ msgstr "リトルエンディアンモードでコードを生成する"
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "誤った 128 ビット move"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, c-format
 msgid "invalid %%A value"
 msgstr "無効な %%A 値"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "無効な %%D 値です"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "無効な %%e 値"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "無効な %%t 値"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "無効な %%V 値"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "無効な %%z 値"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "32 ビット乗算命令を有効にする"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "%<__vector_quad%> からの無効な変換です"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "%<__vector_quad%> への無効な変換です"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "%<__fpreg%> への無効な変換です"
@@ -20455,7 +20460,7 @@ msgstr "候補:"
 msgid "  after user-defined conversion:"
 msgstr "利用者定義命令を有効にする"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
@@ -20938,7 +20943,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -21110,11 +21115,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "代入"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 #, fuzzy
 msgid "pointer assignment"
 msgstr "代入"
@@ -21123,211 +21128,211 @@ msgstr "代入"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 msgid "allocatable argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "十分な引数がありません"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 msgid "optional argument"
 msgstr "無効な PHI 引数です"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 msgid "pointer argument"
 msgstr "代入"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 msgid "target argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 msgid "value argument"
 msgstr "無効な PHI 引数です"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 msgid "volatile argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 msgid "coarray argument"
 msgstr "配列代入"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "<不明な演算子>"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "<不明な演算子>"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE オブジェクト"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr "ALLOCATE オブジェクト"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr "STAT 変数"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr "ERRMSG 変数"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -21340,27 +21345,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22258,7 +22263,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax は RTP PIC 用にのみサポートされています"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
@@ -22635,7 +22640,7 @@ msgstr "%qE 属性は %s 属性と競合します"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -22732,10 +22737,10 @@ msgstr "型が既に定義されているため型属性が無視されました
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -22868,7 +22873,7 @@ msgstr "クラス %s 用のファイルを見つけられません。"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "オフセットが定数文字列の境界の外にあります"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qD はここで宣言されています"
@@ -24705,7 +24710,7 @@ msgstr "大きな固定小数定数が暗黙的に固定整数型に切り詰め
 msgid "comparison is always %d due to width of bit-field"
 msgstr "ビットフィールド幅のため、比較が常に %d になります"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25475,7 +25480,7 @@ msgstr "関数が局所変数のアドレスを返します"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26584,14 +26589,14 @@ msgstr "メンバ %qD へのポインタと見なしています"
 msgid "using a dangling pointer to %qD"
 msgstr "無効なポインタモード %qs です"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -26637,7 +26642,7 @@ msgstr "非関数 %qD の呼び出しです"
 msgid "call to %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
@@ -27690,7 +27695,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "call 文内で無効な関数です"
@@ -28650,7 +28655,7 @@ msgstr "ジャンプをまたがった最適化を行う"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "コマンドラインオプション %qs はこの設定ではサポートされていません"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "%qs への引数がありません"
@@ -28690,12 +28695,12 @@ msgstr "-mcorea と -mcoreb は併用できません"
 msgid "unrecognized argument in option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
@@ -28851,7 +28856,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-falign-loops=%d はサポートされていません"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "-falign-loops=%d はサポートされていません"
@@ -28891,183 +28896,183 @@ msgstr "変数追跡が要求されましたが、デバッグ情報を生成し
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "変数追跡が要求されましたが、このデバッグ形式ではサポートされていません"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では動作しません"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では巻き戻し (unwind) 情報をサポートしません"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では動作しません"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, fuzzy, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "print_specific_help へ認識できない include_flags 0x%x が渡されました"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "%qE 属性指示が無視されました"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, fuzzy, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "--help 引数 %q.*s は曖昧です。より特定してください"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "構造体の整列は %d ではなく、小さな二の累乗でなければいけません"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "不明なスタック検査パラメータ \"%s\" です"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
 # 規格に合わせて DWARF と大文字で表記する
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "DWARF バージョン %d はサポートされていません"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "ターゲットシステムはデバッグ出力をサポートしていません"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "デバッグ形式 \"%s\" は前の選択と競合しています"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "認識できないでバッグ出力レベル \"%s\" です"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "デバッグ出力レベル %s は高すぎます"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "認識できないでバッグ出力レベル \"%s\" です"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "コアファイルサイズ最大制限を取得しています: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "コアファイルサイズ制限を最大へ設定しています: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "認識できない gcc デバッグオプションです: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: オプション -%s はありません"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "%qs は前処理の有効なオプションではありません"
@@ -29752,187 +29757,187 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%qE は変数にのみ適用できます"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "メソッド '%s' はクラス内に見つかりません"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "古いスタイルの関数定義です"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "古いスタイルの関数定義です"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr "%qD は %qs として宣言されていて、暗黙的にデフォルトの可視性になります"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "関数 %qE の暗黙的な宣言です"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, fuzzy, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa に失敗しました"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "無効なポインタモード %qs です"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "関数 %qD が変数として再宣言されました"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "変数 %q+D が設定されましたが使用されていません"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -31590,27 +31595,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -32433,7 +32438,7 @@ msgstr "%qE 属性は %qT が既に定義されているため無視されます
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE 属性は公開オブジェクトに関してのみ効果があります"
@@ -34524,7 +34529,7 @@ msgstr "サポートされていない非標準の文字列リテラルの連結
 msgid "traditional C rejects string constant concatenation"
 msgstr "伝統的な C では文字列定数の連結を拒否します"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36193,7 +36198,7 @@ msgstr "入力ファイルが多すぎます"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "-mfpu 用の不明な値 %s です"
@@ -36224,15 +36229,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "認識できないオプション %<-%s%> です"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
@@ -36317,48 +36322,48 @@ msgstr "-mcpu=%s が無効です"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "%salign-loops%s は廃止予定です。-falign-loops%s を使用してください"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "%salign-jumps%s は廃止予定です。-falign-jumps%s を使用してください"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "%salign-functions%s は廃止予定です。-falign-functions%s を使用してください"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s が 0 と 5 の間ではありません"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> は現在のところ GNU/Linux 上でのみサポートされています"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
@@ -36845,13 +36850,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "RTP PIC は Thumb では使用できません"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -37118,7 +37123,7 @@ msgstr "passing argument %d 番目の %qE の引数を渡すときにポイン
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "重複した初期化子"
@@ -37160,7 +37165,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, fuzzy, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
@@ -37248,324 +37253,324 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "%qs 属性が無視されました"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "無効な #pragma %s です"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr "無効な %%h 値"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "不明な spec 関数 %qs です"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, fuzzy, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "multilib はサポートしません"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "間違った形式の %<#pragma init%> です"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "-shared オプションは VAX ELF 用には現在はサポートされていません"
@@ -37750,13 +37755,13 @@ msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありま
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -37897,17 +37902,17 @@ msgstr "%qE 属性は無視されました"
 msgid "%qE attribute only applies to variables"
 msgstr "%qE は変数にのみ適用できます"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "無効な被演算子出力コード"
@@ -38115,7 +38120,7 @@ msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 msgid "target CPU does not support unaligned accesses"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -38171,7 +38176,7 @@ msgstr "構造体サイズ境界は %s にのみ設定できます"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC は -msingle-pic-base と併用できません"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
@@ -38280,7 +38285,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -38330,32 +38335,32 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "スタックに積まれた仮引数の実際の位置を計算できません"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高位レジスタを pop する為に使用できる低位レジスタがありません"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
@@ -38363,22 +38368,22 @@ msgstr "%qs 属性用の無効なベクトル型です"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "target 属性または pragma が SPE ABI を変更します"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
@@ -38452,17 +38457,17 @@ msgstr "-fpic はサポートされていません"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC はサポートされていません"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-pedantic と -traditional とは相互排他的です"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "割り込み関数は引数無しでなければいけません"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "関数が __fp16 型を返しません"
@@ -38782,7 +38787,7 @@ msgstr "組み込み関数への無効な引数です"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "組み込み関数への無効な引数です"
@@ -39382,751 +39387,751 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "コードモデル %s は PIC モードをサポートしません"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "弱い参照属性は別名属性より前に出現しなければいけません"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "レジスタ名が %q+D 用に指定されていません"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs にクラス名が指定されていません"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "不明なレジスタ名です: %s"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-mg でのプロファイルはサポートされていません"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i ビットモードが使用できるようにコンパイルされていません"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "選択した CPU は x86-64 命令セットをサポートしていません"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "ret 命令は実装されていません"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 命令セットが無効になっています。 387 数値演算を使用します"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 命令セットが無効になっています。SSE 数値演算を使用します"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qT を呼び出しています<"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "multilib はサポートしません"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "可変長配列メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "long double を持つ共用体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 #, fuzzy
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタを戻して (return) います"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタ引数があります"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 が無効な状態で x87 レジスタを戻して (return) います"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "ms_hook_prologue 属性は 32 ビット用の -mfentry と併用できません"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "init_priority 属性はこのプラットフォームではサポートされていません"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "このコンパイラ設定では %<-fsplit-stack%> はサポートされていません"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "このコンパイラ設定では %<-fsplit-stack%> はサポートされていません"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "このコンパイラ設定では %<-fsplit-stack%> はサポートされていません"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "-mno-fentry は SEH と互換性がありません"
@@ -40482,7 +40487,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE が競合する %qs 属性付きで再宣言されました"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
@@ -41608,53 +41613,53 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "不明な #pragma GCC coprocessor %E です"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr "%q#D 用のプロトタイプがクラス %qT 内のどれとも一致しません"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, fuzzy, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "%s を開けません"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
@@ -41674,66 +41679,71 @@ msgstr "ビットフィールド命令を使用しない"
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, fuzzy, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "割り込み関数は引数無しでなければいけません"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -42205,98 +42215,98 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
@@ -43719,7 +43729,7 @@ msgstr "volatile フィールドがあるオブジェクトをレジスタに配
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -43906,7 +43916,7 @@ msgstr "仮引数 %qE 用に記憶域クラスが指定されました"
 msgid "storage class specified for unnamed parameter"
 msgstr "無名仮引数用に記憶域クラスが指定されました"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "型名用に記憶域クラスが指定されました"
@@ -44075,7 +44085,7 @@ msgstr "型名は配列を返す関数として定義されています"
 msgid "function definition has qualified void return type"
 msgstr "関数定義が void 戻り型の修飾子を持っています"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
@@ -44202,7 +44212,7 @@ msgstr "ISO C は const や volatile の関数型を禁止しています"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "構造体または共用体のメンバは可変型を持つことは出来ません"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "変数またはフィールド %qE が void と宣言されています"
@@ -44404,7 +44414,7 @@ msgstr "%qs 式内での型定義は C++ では無効です"
 msgid "%qT defined in underspecified object initializer"
 msgstr "ISO C90 は初期化用に副オブジェクトを指定することを禁止してます"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "宣言が何も宣言していません"
@@ -44454,7 +44464,7 @@ msgstr "構造体に名前付きメンバがありません"
 msgid "struct has no members"
 msgstr "構造体にメンバがありません"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "共用体に可変配列メンバがあります"
@@ -44499,7 +44509,7 @@ msgstr "%<enum %E%> の再定義です"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "指定したモードは列挙値用には小さすぎます"
@@ -44546,7 +44556,7 @@ msgstr "%qE 用の列挙値が整数定数ではありません"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
@@ -44576,7 +44586,7 @@ msgstr "前に %qD 用のプロトタイプがありません"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD がプロトタイプ無しで、定義される前に使用されました"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "前に %qD 用の定義がありません"
@@ -44691,12 +44701,12 @@ msgstr "引数 %qD が組み込みプロトタイプと一致しません"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "仮引数 %qD が設定されましたが使用されません"
@@ -46719,7 +46729,7 @@ msgstr "ループが完全な入れ子になっていません"
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
@@ -46849,12 +46859,12 @@ msgstr "%<catch%> が予期されます"
 msgid "variant %qD is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s と -msdata=%s は併用できません"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47117,7 +47127,7 @@ msgstr "void 式の無効な使用法です"
 msgid "invalid use of flexible array member"
 msgstr "可変配列メンバの無効な使用法です"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "境界が指定されていない配列の無効な使用法です"
@@ -48069,12 +48079,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "可変配列メンバを初期化しています"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "互換性のないポインタ型からの初期化です"
@@ -48115,7 +48125,7 @@ msgstr "初期化子の要素がロード時に計算出来ません"
 msgid "invalid initializer"
 msgstr "無効な初期化子です"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
@@ -48130,8 +48140,8 @@ msgstr "初期化子の終わりに余分なブレースのグループ"
 msgid "braces around scalar initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "入れ子になったコンテキスト内で可変配列メンバを初期化しています"
@@ -48221,7 +48231,7 @@ msgstr "構造体初期化子内の要素が多すぎます"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -49571,7 +49581,7 @@ msgstr "%<operator %s%> は %qT 用としては適切ではありません"
 msgid "%q#D is private within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "ここで宣言されています"
@@ -49581,7 +49591,7 @@ msgstr "ここで宣言されています"
 msgid "%q#D is protected within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "ここで宣言されています"
@@ -49596,7 +49606,7 @@ msgstr "%q+#D はアクセス出来ません"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
@@ -49936,7 +49946,7 @@ msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
@@ -50509,7 +50519,7 @@ msgstr "構造体に可変配列メンバ以外のメンバがありません"
 msgid "next member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
@@ -50631,7 +50641,7 @@ msgstr "関数 `%s' に対して不適切な保存クラス"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
@@ -50700,7 +50710,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -50747,7 +50757,7 @@ msgstr "%s に `%s' という名前のメンバはありません"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -50872,7 +50882,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -50971,7 +50981,7 @@ msgstr "初期化子を欠いています"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -51047,7 +51057,7 @@ msgstr "NaN から整数への変換です"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -51114,189 +51124,189 @@ msgstr "%q+D が再定義されました"
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "%q+D が再定義されました"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "%<template%> が予期されます"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "`%s' はその定義の前にプロトタイプなしで使われました"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "仮想関数は friend にできません"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
@@ -51884,7 +51894,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%qD はここで定義されています"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "不明な型名 %qE です"
@@ -51980,7 +51990,7 @@ msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけ
 msgid "no suspend point info for %qD"
 msgstr "前に %qD 用のプロトタイプがありません"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -52002,23 +52012,23 @@ msgstr "case の値としてポインタは許可されていません"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "参照を参照として宣言できません"
@@ -52506,7 +52516,7 @@ msgstr "前方での `%s' の宣言"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "使用している宣言 %q+D は前に使用している宣言と競合しています"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "前方での `%s' の宣言"
@@ -52909,2273 +52919,2273 @@ msgstr "%qD は関数テンプレートではありません"
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "不明な型名 %qE です"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr ""
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "仮引数 `%s' の型が宣言されていません"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求された整列が 2 の累乗ではありません"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "無名構造体が名前つき型の中にありません"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一つの宣言に複数の型があります"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typdef 宣言で型名を欠いています"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "`%s' の宣言で型がデフォルトの `int' とされました"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef `%s' が初期化されました"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "重複した初期化子"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "変数 `%s' には初期化子がありますが、不完全型です"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "仮引数 `%s' は不完全型です"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "自明でないラベルのついた初期化子です"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "初期化された変数 %q+D は dllimport とマークされています"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無効なビット列初期化子です"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無効な初期化子です"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "入力ファイルが多すぎます"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C89 は複合リテラルを禁じます"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "`%s' は不完全型です"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pramga が括弧で囲まれた文字列リテラルを受け取りました"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(クラス外での初期化を必要とします)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "仮引数 %qD が初期化されます"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "関数 `%s' が変数であるかのように初期化されました"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs が構造体フィールド用に指定されています"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java メソッド %qD が非 Java 戻り型 %qT を持ちます"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "共用体を透過的にできません"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qD はテンプレート関数ではありません"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' は `int' を返さなければなりません"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D が再定義されました"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "配列の次元がオーバーフローしました"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名変数やフィールドが void と宣言されました"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "変数またはフィールドが void と宣言されました"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "関数の定義が `register' と宣言されました"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ では型の無い %qs の宣言を禁止しています"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> と %<unsigned%> が %qs に対して両方指定されています"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> および %<short%> が %qs に対して両方指定されています"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex は %qs に対しては無効です"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "仮引数宣言の中の typedef 宣言は無効です"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "仮引数 %qs に対して記憶域クラスタ指定されています"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "無効な宣言です"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, fuzzy, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "ネストした関数 `%s' は `extern' に宣言されました"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "`%s' のトップレベルの宣言が `auto' を指定します"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<restrict%> の誤った使用法です"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "`%s' は配列を返す関数として宣言されています"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, fuzzy, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "デストラクタは仮引数を取りません"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "メンバ関数は暗黙的にそのクラスの friend です"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static `%s' を mutable として宣言できません"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "クラス宣言の外側で virtual 指定しています"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, fuzzy, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "クラス `%s' を大域スコープの friend にしようとしています"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, fuzzy, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "無効な用法の of %%d, %%x, 又は %%X"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%s を開けません"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "領域 `%s' は不完全な型です"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "仮引数が不完全型です"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "関数を inline にできません"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `register' は無効です"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual な非クラス関数 `%s'"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "他の関数内で static 関数を宣言できません"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, fuzzy, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "`%s' が初期化されるところで、`extern' 宣言されました"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, fuzzy, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -55187,111 +55197,111 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "事前の宣言なしの大域関数に関して警告する"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "%qD をビットフィールド型として宣言できません"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "型修飾子 `%s' は struct や class の後には使えません"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複した case の値"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "作成時と使用時でエンディアンが異なります"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "述語は識別子でなければなりません"
@@ -55300,82 +55310,82 @@ msgstr "述語は識別子でなければなりません"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "列挙値がオーバーフロー"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
@@ -56224,7 +56234,7 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -57281,7 +57291,7 @@ msgstr ""
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%s=%s は数値ではありません"
@@ -58024,7 +58034,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
@@ -58734,12 +58744,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "メンバ `%s' に対する無効な初期値"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -59337,7 +59347,7 @@ msgstr "`%s' の引数として無効な型"
 msgid "%qT not permitted in template argument"
 msgstr "合っていない引数です"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -60197,7 +60207,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
@@ -61202,7 +61212,7 @@ msgstr ""
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "内部一貫性がありません"
@@ -61295,278 +61305,278 @@ msgstr "関数が集合体を返しています"
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "%qE 属性用に間違った数の引数が指定されました"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -61578,163 +61588,163 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "`%s' の宣言は仮引数リストのシンボルを覆い隠します"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "spec %qs が無効です"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "間接関数 %q+D は弱い参照として宣言できません"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "不完全な typedef `%s' の使用は不適切です"
@@ -62045,7 +62055,7 @@ msgstr "無効な宣言です"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -62454,27 +62464,27 @@ msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "%<__builtin_return_address%> へのサポートされていない引数です"
@@ -62482,22 +62492,22 @@ msgstr "%<__builtin_return_address%> へのサポートされていない引数
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -63740,222 +63750,222 @@ msgstr "`%s' が再宣言されました"
 msgid "declaration of %q#T"
 msgstr "`%s' が再宣言されました"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "`%s' は不完全型です"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "void 式の不適切な使用"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "%<restrict%> の誤った使用法です"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "関数を inline にできません"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "char の配列にとって初期化子文字列が長すぎます"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "レコードや共用体にフィールド名がない初期化子です"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "union 初期化子がフィールド名ではなくインデックス値になっています"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "循環ポインタの代表を検出しました"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, fuzzy, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "`operator->()'の結果が非ポインタの結果をもたらします"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
@@ -64906,7 +64916,7 @@ msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無効なビット列初期化子です"
@@ -65999,12 +66009,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -66185,7 +66195,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "引数の型が異なります"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -68196,7 +68206,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
@@ -68467,7 +68477,7 @@ msgstr "代入として無効な左辺値です"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -68585,7 +68595,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
@@ -68595,7 +68605,7 @@ msgstr ""
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
@@ -68726,7 +68736,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -68942,12 +68952,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -69057,562 +69067,562 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "%q+D が未定義シンボル %qE の別名となっています"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "引数は定数でなければいけません"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
@@ -69796,7 +69806,7 @@ msgstr "NaN から整数への変換です"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "値をベクトルには変換できません"
@@ -70347,7 +70357,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -70914,7 +70924,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -72772,8 +72782,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -74741,708 +74751,718 @@ msgstr ""
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr ""
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "インスタンス変数の仕様が一貫していません"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "インスタンス変数の仕様が一貫していません"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "非メンバ `%s' を `mutable' とは宣言できません"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "非メンバ `%s' を `mutable' とは宣言できません"
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr ""
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "%qE は廃止されました"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "%qE は廃止されました"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared と mdll とは共存できません"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "無効な参照型です"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "要求されたアラインメントが大きすぎます"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75451,12 +75471,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75465,293 +75485,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE は廃止されました"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "式文が無効です"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -75760,284 +75780,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -76045,207 +76065,207 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "引数は定数でなければいけません"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -76253,984 +76273,984 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s 内、位置 %s:%d"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD は既に定義されています"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "式文が無効です"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -78122,7 +78142,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -78134,12 +78154,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -78231,81 +78251,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "仮引数 %u が void 型を持っています"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "フォーマットへの引数が多すぎます"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -78320,27 +78345,27 @@ msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -80166,6 +80191,10 @@ msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値
 msgid "unused name %qE"
 msgstr "仮引数 %q+D が未使用です"
 
+#, fuzzy
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
+
 #, fuzzy
 #~ msgid "invalid conversion from type %<* __vector_quad%>"
 #~ msgstr "%<__fpreg%> からの無効な変換です"
diff --git a/gcc/po/nl.po b/gcc/po/nl.po
index 0cfe6983f1e..c2c49012dac 100644
--- a/gcc/po/nl.po
+++ b/gcc/po/nl.po
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -4079,7 +4079,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7738,6 +7738,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "ingebouwde functie %qs is niet geïmplementeerd"
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17312,12 +17317,12 @@ msgstr "operand van '%%l' is geen label"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "floating-point constante verkeerd gebruikt"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18358,63 +18363,63 @@ msgstr "Deze optie heeft geen documentatie"
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr ""
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr ""
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[ingeschakeld]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[uitgeschakeld]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "no arguments for spec function"
 msgid ""
@@ -18422,56 +18427,56 @@ msgid ""
 "   "
 msgstr "geen argumenten voor spec-functie"
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "De volgende opties zijn afhankelijk van het doelsysteem"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "De volgende opties beheren waarschuwingsboodschappen van de compiler"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "De volgende opties beheren optimalisaties"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "De volgende opties zijn taalafhankelijk"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options control optimizations"
 msgid "The following options control parameters"
 msgstr "De volgende opties beheren optimalisaties"
 
 # Zou een format spec moeten hebben voor de taalnaam...
-#: opts.cc:1976
+#: opts.cc:1977
 #, fuzzy
 msgid "The following options are specific to just the language "
 msgstr "De volgende opties enkel van toepassing voor de taal "
 
 # Zou een format spec moeten hebben voor de taalnaam...
 # Of beter "voor de taal "?
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "De volgende opties worden ondersteund door de taal "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "De volgende opties zijn niet gedocumenteerd"
 
-#: opts.cc:1991
+#: opts.cc:1992
 #, fuzzy
 msgid "The following options take separate arguments"
 msgstr "De volgende opties zijn niet gedocumenteerd"
 
-#: opts.cc:1993
+#: opts.cc:1994
 #, fuzzy
 msgid "The following options take joined arguments"
 msgstr "De volgende opties zijn niet gedocumenteerd"
 
 # Betere vertaling?
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "De volgende opties hebben iets met een taal te maken"
 
@@ -18867,77 +18872,77 @@ msgstr "lengte-modifier in strfmon-formaat"
 msgid "<command-line>"
 msgstr "<opdrachtregel>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "invalid operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "operand ontbreekt"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "ongeldige operand"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ongeldige operandprefix '%%%c'"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ongeldige adresseringsmodus"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ongeldige operanden in binaire bewerking"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -18954,18 +18959,18 @@ msgid "invalid %%r value"
 msgstr "ongeldige waarde voor %%r"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "ongeldige waarde voor %%R"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
@@ -18995,7 +19000,7 @@ msgstr "ongeldige waarde voor %%M"
 msgid "invalid %%U value"
 msgstr "ongeldige waarde voor %%U"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
@@ -19005,7 +19010,7 @@ msgstr "ongeldige waarde voor %%s"
 msgid "invalid %%C value"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
@@ -19019,7 +19024,7 @@ msgstr "onbekende 'unspec' relocatie"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ongeldige code voor %%xn"
@@ -19104,36 +19109,36 @@ msgstr "ongeldige UNSPEC als operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "vermoedelijke constante niet herkend"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "ongeldige shift-operand"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "Thumb-instructie met predicaat"
 
 # mja. snappen wie snappen kan ^^
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19142,29 +19147,29 @@ msgstr "ongeldige operand voor code '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "instructie wordt nooit uitgevoerd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19542,99 +19547,99 @@ msgstr "ongeldige constante"
 msgid "Expected register or constant integer."
 msgstr "accumulator is geen integer-constante"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ongeldige UNSPEC als operand"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ongeldige operand voor '%c'"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ongeldige constraints voor operand"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Ongeldig token in expressie"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "onbekende insn-modus"
 
@@ -19665,7 +19670,7 @@ msgstr "ongeldige bewerking met %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -19711,8 +19716,8 @@ msgstr "'%%%c' is geen geldige operand-prefix"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ongeldig gebruik van '%%%c'"
@@ -19747,7 +19752,7 @@ msgid "post-increment address is not a register"
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -19911,7 +19916,7 @@ msgstr "niet-ondersteunde versie"
 msgid "unsupported memory expression:"
 msgstr "ongeldige waarheidsexpressie"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "ongeldige operand voor %%P"
@@ -19969,156 +19974,156 @@ msgstr "case-label niet in een switch-statement"
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "ongeldige waarde voor %%D"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -20599,7 +20604,7 @@ msgstr "kandidaat 1:"
 msgid "  after user-defined conversion:"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -21106,7 +21111,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -21275,12 +21280,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 #, fuzzy
 msgid "assignment"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 #, fuzzy
 msgid "pointer assignment"
 msgstr "ongeldige lvalue in toewijzing"
@@ -21289,213 +21294,213 @@ msgstr "ongeldige lvalue in toewijzing"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 msgid "allocatable argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 msgid "optional argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 msgid "pointer argument"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 msgid "target argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 msgid "value argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 msgid "volatile argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 msgid "coarray argument"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 #, fuzzy
 msgid "iterator variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -21508,27 +21513,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22456,7 +22461,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s voor %qs"
@@ -22842,7 +22847,7 @@ msgstr "attribuut %qE botst met attribuut %s"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -22939,10 +22944,10 @@ msgstr ""
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -23079,7 +23084,7 @@ msgstr "kan %s niet vinden"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "offset buiten de grenzen van een constante string"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -24935,7 +24940,7 @@ msgstr "grote integer impliciet afgekapt naar 'unsigned' type"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vergelijking is altijd %d vanwege breedte van bit-veld"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25715,7 +25720,7 @@ msgstr "functie geeft adres van lokale variabele terug"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26840,14 +26845,14 @@ msgstr "herhaald lid %qs"
 msgid "using a dangling pointer to %qD"
 msgstr "%qs is geen geldige pointer-modus"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -26892,7 +26897,7 @@ msgstr "impliciete declaratie van functie %qE"
 msgid "call to %qD"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr "adres van globale registervariabele %qs gevraagd"
@@ -27968,7 +27973,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "ongeldige opslagklasse voor functie %qs"
@@ -28941,7 +28946,7 @@ msgstr "(dicht bij initialisatie van %qs)"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "opdrachtregeloptie %qs wordt niet ondersteund door deze configuratie"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "ontbrekend argument bij %qs"
@@ -28983,13 +28988,13 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr "niet-herkend argument bij optie %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
@@ -29149,7 +29154,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
@@ -29189,191 +29194,191 @@ msgstr ""
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "niet-herkend argument bij optie '--fsanitize=': %q.*s"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "niet-herkend argument bij optie '--fsanitize=': %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute directive ignored"
 msgid "%qs attribute directive ignored"
 msgstr "attribuut-commando %qE wordt genegeerd"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "niet-herkend argument bij optie '--help=': %q.*s"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "niet-herkend argument bij optie '--help=': %q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "Alignment moet een kleine macht van twee zijn, en niet %d, in #pragma pack"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "niet-herkend argument bij optie '--help=': %q.*s"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, fuzzy, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized debug output level %qs"
 msgstr "niet-herkende registernaam %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized btf debug output level %qs"
 msgstr "niet-herkende registernaam %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr ""
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -30051,189 +30056,189 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "Ongeldige optie %qs"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "opgeroepen object is geen functie"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "opgeroepen object is geen functie"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, fuzzy, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "impliciete declaratie van functie %qE"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "%qs is geen geldige pointer-modus"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -31921,27 +31926,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -32771,7 +32776,7 @@ msgstr "attribuut %qE wordt genegeerd omdat %qT reeds gedefinieerd is"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "attribuut %qE wordt genegeerd omdat %qT reeds gedefinieerd is"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -34933,7 +34938,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionele C verwerpt het aaneenplakken van stringconstantes"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36634,7 +36639,7 @@ msgstr "te veel invoerbestanden"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "slechte waarde (%s) voor optie -mcpu"
@@ -36666,16 +36671,16 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -36767,50 +36772,50 @@ msgstr "spec '%s' is ongeldig"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malign-jumps=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d ligt niet tussen 0 en 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -37303,13 +37308,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "case-selector niet compatibel met label"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "herhalings-aantal is geen integerconstante"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, fuzzy, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr "Alignment moet een kleine macht van twee zijn, en niet %d, in #pragma pack"
@@ -37547,7 +37552,7 @@ msgstr "%s maakt integer van pointer zonder een cast"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "%Jherdefinitie van %qD"
@@ -37588,7 +37593,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "%qs is geen bestand, pipe of tty"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -37678,328 +37683,328 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "attribuut %qs wordt genegeerd"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%H value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Ongeldige optie voor floating-point emulatie: -mfpe-%s"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "onbekende spec-functie '%s'"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "beginwaarde ontbreekt"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "ondersteunt geen multilib"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "misvormde #pragma pack"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "misvormde #pragma weak"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "niet-ondersteunde versie"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "De -shared optie wordt op het ogenblik niet ondersteund voor VAX ELF."
@@ -38187,13 +38192,13 @@ msgstr "het argument van %<asm%> is geen constante string"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -38341,17 +38346,17 @@ msgstr "attribuut %qE wordt genegeerd"
 msgid "%qE attribute only applies to variables"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -38560,7 +38565,7 @@ msgstr "doel-CPU ondersteunt geen interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
@@ -38617,7 +38622,7 @@ msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
@@ -38724,7 +38729,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -38779,32 +38784,32 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "ongeldige operand van %s"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ongeldig type-argument %qs"
@@ -38812,24 +38817,24 @@ msgstr "ongeldig type-argument %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ongeldig vector-type voor attribuut %qs"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "rommel aan einde van #pragma %s"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
@@ -38903,17 +38908,17 @@ msgstr "-pipe wordt niet ondersteund"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G en -static sluiten elkaar uit"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "functie %qs kan geen waarde teruggeven"
@@ -39239,7 +39244,7 @@ msgstr "ongeldig argument voor %<__builtin_return_address%>"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
@@ -39847,762 +39852,762 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, fuzzy, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, fuzzy, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attribuut %qE vereist een string-constante als argument"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "de '-%c' moet een argument hebben"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "herdefinitie van %<union %s%>"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -40954,7 +40959,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -42104,54 +42109,54 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "rommel aan einde van %<#pragma reset_options%>"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "%qs is geen bestand, pipe of tty"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "cast geeft functie-type op"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -42171,66 +42176,71 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "het argument van %<asm%> is geen constante string"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -42706,97 +42716,97 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
@@ -44233,7 +44243,7 @@ msgstr "een object met een volatile veld kan niet in een register geplaatst word
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ongeïnitialiseerde const %qD is ongeldig in C++"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -44419,7 +44429,7 @@ msgstr "opslagklasse opgegeven voor parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "opslagklasse opgegeven voor typenaam"
@@ -44589,7 +44599,7 @@ msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 msgid "function definition has qualified void return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
@@ -44717,7 +44727,7 @@ msgstr "ISO C verbiedt %<const%> of %<volatile%> functie-types"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabele of veld %qs als void gedeclareerd"
@@ -44917,7 +44927,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "declaratie declareert niets"
@@ -44967,7 +44977,7 @@ msgstr "struct heeft geen benoemde leden"
 msgid "struct has no members"
 msgstr "struct heeft geen leden"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jflexibel array-lid in union"
@@ -45012,7 +45022,7 @@ msgstr "herdeclaratie van %<enum %qs%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -45062,7 +45072,7 @@ msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
@@ -45092,7 +45102,7 @@ msgstr "%Jgeen eerder prototype voor %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%Jgeen eerdere declaratie voor %qD"
@@ -45207,12 +45217,12 @@ msgstr "argument %qs komt niet overeen met prototype"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -47251,7 +47261,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
@@ -47381,12 +47391,12 @@ msgstr "ongeldige operand van %s"
 msgid "variant %qD is not a function"
 msgstr "%qs is meestal een functie"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47647,7 +47657,7 @@ msgstr "ongeldig gebruik van een void-expressie"
 msgid "invalid use of flexible array member"
 msgstr "ongeldig gebruik van flexibel array-lid"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "ongeldig gebruik van een array zonder opgegeven grenzen"
@@ -48623,12 +48633,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisatie van flexibel array-lid"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -48669,7 +48679,7 @@ msgstr "beginwaarde-element kan niet berekend worden tijdens het laden"
 msgid "invalid initializer"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -48684,8 +48694,8 @@ msgstr "extra accolade-groep aan einde van beginwaarde"
 msgid "braces around scalar initializer"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisatie van flexibel array-lid in een geneste context"
@@ -48777,7 +48787,7 @@ msgstr "overtollige elementen in beginwaarde van struct"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "niet-statische initialisatie van flexibel array-lid"
@@ -50139,7 +50149,7 @@ msgstr ""
 msgid "%q#D is private within this context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -50149,7 +50159,7 @@ msgstr "%qs tevoren hier gedeclareerd"
 msgid "%q#D is protected within this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -50164,7 +50174,7 @@ msgstr "%s is niet addresseerbaar"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
@@ -50505,7 +50515,7 @@ msgstr "Teveel argumenten in oproep van %qs"
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -51078,7 +51088,7 @@ msgstr "%Jflexibel array-lid in overigens lege struct"
 msgid "next member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
@@ -51199,7 +51209,7 @@ msgstr "ongeldige opslagklasse voor functie %qs"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -51268,7 +51278,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -51315,7 +51325,7 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -51440,7 +51450,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -51539,7 +51549,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -51615,7 +51625,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -51681,190 +51691,190 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "ongeldige beginwaarde"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "functie kan niet inline gemaakt worden"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
@@ -52445,7 +52455,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%Jeerder hier gebruikt"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "union heeft geen lid dat %qs heet"
@@ -52539,7 +52549,7 @@ msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 msgid "no suspend point info for %qD"
 msgstr "%Jgeen eerder prototype voor %qD"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -52560,23 +52570,23 @@ msgstr "pointers zijn niet toegestaan als case-waarden"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "ongeldige registernaam voor %qs"
@@ -53063,7 +53073,7 @@ msgstr "eerdere declaratie van %qs"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "eerdere declaratie van %qs"
@@ -53464,2285 +53474,2285 @@ msgstr "%qs is geen iterator"
 msgid "%q#T is not a class"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nutteloos sleutelwoord of typenaam in lege declaratie"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabele %qs heeft beginwaarde, maar een onvolledig type"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ongeïnitialiseerde const %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ongeldige beginwaarde"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "ongeldige beginwaarde voor veld %qs"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C90 verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%Jherdeclaratie van enum %qD"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "typedef %qs krijgt beginwaarde alsof het een variabele is"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "dereferentie van pointer naar onvolledig type"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "opslagklasse opgegeven voor structure-veld %qs"
 msgstr[1] "opslagklasse opgegeven voor structure-veld %qs"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "herhaald lid %qs"
 
 # Betere vertaling voor 'decompose'?
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan adres niet ontleden"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "teruggeeftype is onvolledig"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, fuzzy, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "a function concept cannot be constrained"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qs is meestal een functie"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Ongeldige optie %qs"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ verbiedt lid-declaraties zonder leden"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "zowel 'signed' als 'unsigned' opgegeven voor %qs"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "zowel 'long' als 'short' opgegeven voor %qs"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuut wordt genegeerd"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> functie geeft niet-void waarde terug"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "cast geeft functie-type op"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "In functie %qs"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "open %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "ongeldig type-argument %qs"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -55754,110 +55764,110 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "cast geeft functie-type op"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qs is geen typedef of ingebouwd type"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "herhaalde case-waarde"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
@@ -55866,83 +55876,83 @@ msgstr "grootte van array %qs is van een niet-integer type"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow in enumeratiewaarden"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -56793,7 +56803,7 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -57859,7 +57869,7 @@ msgstr ""
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qs is geen iterator"
@@ -58606,7 +58616,7 @@ msgstr "types in voorwaardelijke expressie komen niet overeen"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -59317,12 +59327,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -59926,7 +59936,7 @@ msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 msgid "%qT not permitted in template argument"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -60788,7 +60798,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
@@ -61801,7 +61811,7 @@ msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "herdeclaratie van %qs"
@@ -61896,280 +61906,280 @@ msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "verkeerd aantal argumenten opgegeven voor attribuut %qE"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#qS"
 msgstr "%s %qs"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "impliciete declaratie van functie %qs"
@@ -62181,165 +62191,165 @@ msgstr "impliciete declaratie van functie %qs"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "de declaratie van %qs verbergt een symbool uit de parameterlijst"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "functie wordt niet als kandidaat voor inlining beschouwd"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "%Jeerder hier gebruikt"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ongeldig type-argument %qs"
@@ -62652,7 +62662,7 @@ msgstr "ongeldige linker operand van %s"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
@@ -63064,27 +63074,27 @@ msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -63093,22 +63103,22 @@ msgstr "niet-ondersteund argument voor %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -64373,224 +64383,224 @@ msgstr "herdeclaratie van %qs"
 msgid "declaration of %q#T"
 msgstr "herdeclaratie van %qs"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "beginwaarde-string voor array van chars is te lang"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "dubbele beginwaarde"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
@@ -65536,7 +65546,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%s voor %qs"
@@ -66712,12 +66722,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -66902,7 +66912,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -68919,7 +68929,7 @@ msgstr "overflow in constante expressie"
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "ongeldige waarheidsexpressie"
@@ -69191,7 +69201,7 @@ msgstr "Te veel argumenten voor %s op %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
@@ -69309,7 +69319,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
@@ -69319,7 +69329,7 @@ msgstr "(dicht bij initialisatie van %qs)"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(dicht bij initialisatie van %qs)"
@@ -69452,7 +69462,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -69669,12 +69679,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -69784,562 +69794,562 @@ msgstr "Te veel argumenten voor %s op %L"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "te veel argumenten voor %s %q+#D"
@@ -70523,7 +70533,7 @@ msgstr "ongeldige registernaam voor %qs"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
@@ -71078,7 +71088,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -71647,7 +71657,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
@@ -73508,8 +73518,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -75478,714 +75488,724 @@ msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr ""
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr ""
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr ""
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, fuzzy, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "%qs is meestal een functie"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "%qs is meestal een functie"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "naar label %s gerefereerd buiten enige functie"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs is meestal een functie"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "-shared en -mdll zijn niet compatibel"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
 # Ongeldig soort wat?
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of array reference at %C"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Ongeldige vorm van arrayverwijzing op %C"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -76194,12 +76214,12 @@ msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -76208,293 +76228,293 @@ msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -76503,287 +76523,287 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%<defined%> zonder een naam"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -76791,209 +76811,209 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "In functie %qs"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -77001,990 +77021,990 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "String-lengte bij %L is te groot"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -78881,7 +78901,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -78893,12 +78913,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -78991,81 +79011,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "object van variabele lengte mag geen beginwaarde krijgen"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -79080,27 +79105,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "onbekende machine-modus %qs"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -81002,6 +81027,10 @@ msgstr "ongeldige macronaam %<%.*s%>"
 #~ msgid "options enabled: "
 #~ msgstr "ingeschakelde opties: "
 
+#, fuzzy
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "ongeldige operand voor code '%c'"
+
 #, fuzzy
 #~ msgid "invalid %%L code"
 #~ msgstr "ongeldige code voor %%xn"
diff --git a/gcc/po/ru.po b/gcc/po/ru.po
index 598499d803b..26518afe3b4 100644
--- a/gcc/po/ru.po
+++ b/gcc/po/ru.po
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 9.1-b20190414\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2019-05-04 12:10+0300\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@d07.ru>\n"
@@ -4116,7 +4116,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7854,6 +7854,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support XOP built-in functions and code generation."
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Включить поддержку внутренних функций и генерацию команд XOP."
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17606,12 +17612,12 @@ msgstr "операнд '%%l' не является меткой"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "некорректное использование плавающей константы"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18824,72 +18830,72 @@ msgstr "Этот ключ не документирован"
 msgid "Uses of this option are diagnosed."
 msgstr "При использовании этого ключа выдается предупреждение"
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
 #
-#: opts.cc:1656
+#: opts.cc:1657
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s%s."
 msgstr "(%s  Аналог %s."
 
 #
-#: opts.cc:1661
+#: opts.cc:1662
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s."
 msgstr "(%s  Аналог %s."
 
 #
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "(%s  Аналог %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 #, fuzzy
 #| msgid "variable"
 msgid "[available in "
 msgstr "переменная"
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[по умолчанию]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[включено]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[выключено]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Не найдены ключи с требуемыми характеристиками\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 " Ничего не найдено.  --help=%s выводит *все* ключи, поддерживаемые для языка %s.\n"
 "\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Все ключи с требуемыми характеристиками уже выведены\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "invalid argument to built-in function %s"
 msgid ""
@@ -18897,49 +18903,49 @@ msgid ""
 "   "
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Следующие ключи не зависят от целевой архитектуры"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Следующие ключи контролируют предупреждения компилятора"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Следующие ключи контролируют оптимизацию"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Следующие ключи не зависят от входного языка"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options control optimizations"
 msgid "The following options control parameters"
 msgstr "Следующие ключи контролируют оптимизацию"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Следующие ключи зависят только от языка "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Следующие ключи поддерживаются языком "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Следующие ключи не документированы"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Следующие ключи принимают раздельные аргументы"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Следующие ключи принимают объединенные аргументы"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Следующие ключи относятся к исходному языку"
 
@@ -19331,75 +19337,75 @@ msgstr "модификатор размера в формате strfmon"
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "недопустимый операнд для кода '%%%c'"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "отсутствует операнд"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "недопустимая константа"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "некорректный операнд"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "некорректный префикс операнда '%%%c'"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "неверные операнды в бинарной операции"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' использовано без локальной динамической TLS ссылки"
@@ -19416,18 +19422,18 @@ msgid "invalid %%r value"
 msgstr "некорректное значение %%r"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "некорректное значение %%R"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
@@ -19457,7 +19463,7 @@ msgstr "некорректное значение %%M"
 msgid "invalid %%U value"
 msgstr "некорректное значение %%U"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
@@ -19467,7 +19473,7 @@ msgstr "некорректное значение %%s"
 msgid "invalid %%C value"
 msgstr "некорректное значение %%C"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
@@ -19480,7 +19486,7 @@ msgstr "некорректное unspec-перемещение"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "некорректный код %%xn"
@@ -19563,35 +19569,35 @@ msgstr "некорректный операнд UNSPEC: %d"
 msgid "unrecognized supposed constant"
 msgstr "неопознанная константа"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "некорректный оператор сдвига"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикативная инструкция для архитектуры Thumb"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикативная инструкция в условной последовательности"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Неподдерживаемый операнд для кода '%c'"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19600,30 +19606,30 @@ msgstr "Неподдерживаемый операнд для кода '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "инструкция никогда не выполняется"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "устаревший код формата Maverick '%c'"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19997,97 +20003,99 @@ msgstr "недопустимая константа"
 msgid "Expected register or constant integer."
 msgstr "Ожидался интерфейс или указатель на интерфейс"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "некорректный операнд UNSPEC"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "недопустимое использование регистра '%s'>"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "некорректное использование флага вывода в asm"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "недопустимый размер операнда для кода 'O'"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "недопустимый размер операнда для кода 'z'"
 
-#: config/i386/i386.cc:13283
-#, c-format
-msgid "invalid operand type used with operand code 'Z'"
+#: config/i386/i386.cc:13290
+#, fuzzy, c-format
+#| msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "недопустимый тип операнда для кода 'Z'"
 
-#: config/i386/i386.cc:13288
-#, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "недопустимый размер операнда для кода 'Z'"
+#: config/i386/i386.cc:13295
+#, fuzzy, c-format
+#| msgid "invalid operand size for operand code 'O'"
+msgid "invalid operand size for operand code '%c'"
+msgstr "недопустимый размер операнда для кода 'O'"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд не является кодом условия, неверный код операнда 'D'"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд не является кодом условия, неверный код операнда '%c'"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд не является ссылкой на память со смещением, неверный код операнда 'H'"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "операнд не является кодом условия, неверный код операнда 'K'"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "операнд не является специфическим целым, неверный код операнда 'r'"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "операнд не является целым, неверный код операнда 'R'"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд не является специфическим целым, неверный код операнда 'R'"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "некорректные ограничения для операнда"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, c-format
 msgid "invalid vector immediate"
 msgstr ""
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "некорректный режим инструкции"
 
@@ -20118,7 +20126,7 @@ msgstr "некорректный операнд для %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -20163,8 +20171,8 @@ msgstr "'%%%c' не является корректным префиксом о
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "недопустимое использование '%%%c'"
@@ -20196,7 +20204,7 @@ msgid "post-increment address is not a register"
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -20365,7 +20373,7 @@ msgstr "неподдерживаемая комбинация: %s"
 msgid "unsupported memory expression:"
 msgstr "неподдерживаемое преобразование с фиксированной точкой"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -20432,155 +20440,155 @@ msgstr "ключ -mquad-memory не поддерживается для обра
 msgid "bad move"
 msgstr "некорректная пересылка"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "некорректная 128-битная пересылка"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "неверное значение для кода %%D"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "некорректное %%e значение"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректное значение %%y, попробуйте использовать ограничитель 'Z'"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Включить использование инструкций IEEE 128-битной плавающей точки."
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr "Не удалось сгенерировать дополнительное значение для синтеза"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Не удалось сгенерировать смещение загрузки/сохранения для синтеза"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "Некорректный GPR синтез"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -21048,7 +21056,7 @@ msgstr "кандидат 1:"
 msgid "  after user-defined conversion:"
 msgstr "Включить определяемые пользователем инструкции."
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат"
@@ -21535,7 +21543,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Движущий:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "фактический аргумент для INTENT = OUT/INOUT"
 
@@ -21707,11 +21715,11 @@ msgstr "блочный IF"
 msgid "implied END DO"
 msgstr "предписанный END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "присваивание"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "присваивание указателя"
 
@@ -21719,200 +21727,200 @@ msgstr "присваивание указателя"
 msgid "simple IF"
 msgstr "простой IF"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "элементная процедура"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr "размещаемый аргумент"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr "асинхронный аргумент"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "необязательный аргумент"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr "аргумент-указатель"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr "целевой аргумент"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr "value аргумент"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr "volatile аргумент"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr "assumed-shape аргумент"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr "assumed-rank аргумент"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr "coarray аргумент"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr "аргумент параметризованного производного типа"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr "полиморфный аргумент"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr "атрибут NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr "аргумент предполагаемого типа"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr "результат-массив"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr "указательный или размещаемый результат"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr "результат с неконстантной character длиной"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr "процедура bind(c)"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Некорректный контекст для NULL() указателя в %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Операнд унарного числового оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды бинарного числового оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнды оператора конкатенации строк в %%L есть %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды логического оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX величины не могут сравниваться в %L"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логические в %%L должны сравниваться посредством %s вместо %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды оператора сравнения %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "Unknown operator %%<%s%%> at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Неизвестный оператор %%<%s%%> в %%L"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Неизвестный оператор %%<%s%%> в %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Операнд пользовательского оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды пользовательского оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Противоречивые ранги для оператора в %%L и %%L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "Переменная цикла"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr "Переменная итератора"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr "Начальное выражение в DO цикле"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr "Конечное выражение в DO цикле"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr "Шаговое выражение в DO цикле"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE объект"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr "ALLOCATE объект"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr "STAT переменная"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr "ERRMSG переменная"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr "элемент в READ"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK переменная"
 
@@ -21925,27 +21933,27 @@ msgstr "Разные CHARACTER длины (%ld/%ld) в конструкторе
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Целочисленное переполнение при вычислении объема памяти для размещения"
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки не соответствует декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки меньше декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Цель переотображения ранга слишком мала (%ld < %ld)"
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr "Присваивание скаляра неразмещенному массиву"
 
@@ -22835,7 +22843,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax поддерживается только для RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "синтаксическая ошибка в %s операторе в %C"
@@ -23227,7 +23235,7 @@ msgstr ""
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -23326,10 +23334,10 @@ msgstr "атрибуты типов игнорируются, если тип у
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -23469,7 +23477,7 @@ msgstr "ошибка чтения профиля функции из %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "смещение %qwi вне границ константной строки"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -25392,7 +25400,7 @@ msgstr "большая константа с фиксированной точк
 msgid "comparison is always %d due to width of bit-field"
 msgstr "при данной ширине битового поля результат сравнения - всегда %d"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "предполагается, что при упрощении проверки диапазона не произошло переполнение"
@@ -26214,7 +26222,7 @@ msgstr "функция возвращает адрес локальной пер
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -27506,14 +27514,14 @@ msgstr "предполагается указатель на элемент %qD"
 msgid "using a dangling pointer to %qD"
 msgstr "неизвестная машинный режим %qs для указателя"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD объявлено здесь"
@@ -27563,7 +27571,7 @@ msgstr "в вызове встроенной функции размещения
 msgid "call to %qD"
 msgstr "  в вызове %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %qD returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -28708,7 +28716,7 @@ msgstr "во входном файле отсутствует информаци
 msgid "IPA modref summary is missing in input file"
 msgstr "во входном файле отсутствует информация о межпроцедурных inline-подстановках"
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid jump function in LTO stream"
@@ -29731,7 +29739,7 @@ msgstr "Выполнить оптимизацию кода вокруг кома
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "ключ %qs для этой конфигурации не поддерживается"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "отсутствует аргумент для %qs"
@@ -29774,12 +29782,12 @@ msgstr "FPX fast и compact опции не могут задаваться вм
 msgid "unrecognized argument in option %qs"
 msgstr "некорректный аргумент ключа %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %qs: %s; имелось в виду %qs?"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "допустимые аргументы %qs: %s"
@@ -29947,7 +29955,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr ""
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "-fpie is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -29990,201 +29998,201 @@ msgstr "отслеживание переменных бесполезно бе
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "запрошено отслеживание переменных, но оно не поддерживается этого формата отладочной информации"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "присваивания с отслеживанием переменных влияют на селективное планирование"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr ""
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr ""
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "неопознанный include_flags 0x%x передан print_specific_help"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "неопознанный аргумент для -f%ssanitize%s= опции: %q.*s; имелось в виду %qs?"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "неопознанный аргумент для -f%ssanitize%s= опции: %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute directive ignored"
 msgid "%qs attribute directive ignored"
 msgstr "директива описания атрибута %qE проигнорирована"
 
 #
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument of -mcpu: %s"
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "неопознанный аргумент для -mcpu: %s"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect number of arguments to function %qE"
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "неправильное число аргументов в вызове функции %qE"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malign-loops=%d не между 0 и %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, fuzzy, gcc-internal-format
 #| msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "аргумент --help %q.*s неоднозначен, требуется уточнение"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "неизвестный аргумент ключа --help=: %q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "выравнивание структуры должно быть небольшой степенью двойки, а не %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "неизвестный параметр проверки стека %qs"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, fuzzy, gcc-internal-format
 #| msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr "%<-gdwarf%s%> двусмысленна; используйте %<-gdwarf-%s%> для DWARF версии или %<-gdwarf -g%s%> для уровня отладки"
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "dwarf version %d is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "версия dwarf %d не поддерживается"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "неизвестный аргумент ключа --help=: %q.*s"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "целевая платформа не поддерживает вывод отладочной информации"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "отладочный формат %qs противоречит предыдущему выбору"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "неопознанный уровень вывода отладочной информации %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "уровень вывода отладочной информации %qs слишком высок"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized debug output level %qs"
 msgid "unrecognized btf debug output level %qs"
 msgstr "неопознанный уровень вывода отладочной информации %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "исходный максимальный размер core-файла: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "установлен максимальный размер core-файла: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "некорректный ключ отладки: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "неопознанная опция командной строки %<-%s%>; имелось в виду %<-%s%>?"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: ключа -%s не существует"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
@@ -30918,196 +30926,196 @@ msgstr "ошибка в обобщенном thunk-коде для метода
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "функциональный символ не есть функция"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
 #
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "символ переменной не есть переменная"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "узел имеет неизвестный тип"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD has invalid argument list"
 msgid "node has invalid order %i"
 msgstr "%qD имеет некорректный список аргументов"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "узел не найден node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "узел отличается от node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "хэш-список ассемблерного имени поврежден"
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "не найден узел в symtab assembler name hash"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "испорчен двусвязный список ассемблерных имен"
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "узел имеет body_removed, но является определением"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "узел проанализирован, но это не определение"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "узел есть синоним, но не неявный синоним"
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "узел является синонимом, но не определением"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "узел есть weakref, но не transparent_alias"
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "узел есть transparent_alias, но не синоним"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not implicit alias"
 msgid "node is symver but not alias"
 msgstr "узел есть синоним, но не неявный синоним"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "Set the default symbol visibility"
 msgid "symver is not exported with default visibility"
 msgstr "Установить видимость символов по умолчанию"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "узел в списке same_comdat_group, но не имеет comdat_group"
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group список через разные группы"
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "смешение разных типов символа в одной comdat группе не поддерживается"
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "только один узел в comdat группе"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group не является циклическим списком"
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "на comdat-local символ ссылается %s извне его comdat"
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit_section flag is set but section isn't"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "implicit_section флаг установлен, а секция нет"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Установлена и секция, и comdat группа"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's section differs"
 msgid "Alias and target%'s section differs"
 msgstr "синоним и секция цели различаются"
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's comdat groups differs"
 msgid "Alias and target%'s comdat groups differs"
 msgstr "синоним и comdat группа цели различаются"
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, fuzzy, gcc-internal-format
 #| msgid "Transparent alias and target's assembler names differs"
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "Прозрачный синоним и ассемблерные имена цели различаются"
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Связанные в цепочку прозрачные синонимы"
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "ошибка symtab_node::verify"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "неизвестная машинный режим %qs для указателя"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Два символа с одной comdat_group не связаны посредством same_comdat_group списка."
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "функция %q+D является частью цикла алиасов"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "переменная %q+D входит в цикл алиасов"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "секция синонима %q+D должна соответствовать его цели"
@@ -32922,27 +32930,27 @@ msgstr "машинно независимый встроенный код вне
 msgid "target specific builtin not available"
 msgstr "специфическая для целевой платформы встроенная функция недоступна"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "векторная операция будет выполнена по частям"
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "векторная операция будет выполнена параллельно"
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "векторная операция будет выполнена при помощи одной скалярной операции"
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "векторное условие будет расширено по частям"
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "векторная операция перемешивания будет выполнена по частям"
@@ -33848,7 +33856,7 @@ msgstr "атрибут %qE игнорируется, поскольку %qT уж
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "атрибут %qE игнорируется, поскольку %qT уже определен"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE атрибут действует только в public-объектах"
@@ -36093,7 +36101,7 @@ msgstr "неподдерживаемая нестандартная конкат
 msgid "traditional C rejects string constant concatenation"
 msgstr "традиционный Си не поддерживает конкатенацию строковых констант"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37858,7 +37866,7 @@ msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%qE указатель; имелось в виду использовать %<->%>?"
 
 #
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -37893,15 +37901,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "неопознанный ключ -fenable"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "допустимые аргументы: %s; имелось в виду %qs?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr ""
@@ -37992,55 +38000,55 @@ msgstr "недопустимый параметр -mcpu=%s"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "-mcpu=%s имеет некорректную кремниевую версию"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops is obsolete, use -falign-loops"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops устарело, используйте -falign-loops"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d не между 0 и %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malign-jumps устаревший ключ, используйте -falign-jumps"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps=%d is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d не между 0 и %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions is obsolete, use -falign-functions"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions устаревший ключ, используйте -falign-functions"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d не между 0 и %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d не между 0 и 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> в настоящее время поддерживается только на GNU/Linux"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
@@ -38583,14 +38591,14 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "%qs несовместим с %s %s"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a pointer to a constant size type"
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "аргумент %d для %qE должен быть указателем на тип константного размера"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
@@ -38864,7 +38872,7 @@ msgstr "при передаче аргумента %d %qE указатель п
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate definition of '%s'"
 msgid "duplicate definition of %qs"
@@ -38912,7 +38920,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "тип %qT не имеет известный размер"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored because %qT is already defined"
 msgid "variables of type %qT cannot have thread-local storage duration"
@@ -39014,361 +39022,361 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "аргумент decltype должен быть выражением"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Использовать расширения SPE ABI."
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, fuzzy, gcc-internal-format
 #| msgid "unknown flag passed in -moverride=%s (%s)"
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "неизвестный флаг переданный в -moverride=%s (%s)"
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "атрибут %qs проигнорирован"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for %<sve_width%>"
 msgstr "некорректный формат %s"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "некорректное значение %%h"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "строка настройки отсутствует в опции (%s)"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "неизвестная опция настройки (%s)"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length"
 msgstr "Порядок выделения регистров"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "отсутствует имя процессора в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "некорректный модификатор возможности в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%qs некорректный аргумент для -mcpu="
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "отсутствует имя архитектуры в %<-march=%s%>"
 
 #
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "неизвестное значение %qs для -march"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in %<-mcpu=%s%>"
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "отсутствует имя процессора в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "некорректный модификатор возможности в %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "отсутствует имя процессора в %<-mtune=%s%>"
 
 #
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "неизвестное значение %qs для -mtune"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "ключ -mcpu=%s несовместим с ключом -march=%s"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support %<-mfp32%>"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "архитектура %qs не поддерживает %<-mfp32%>"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "модель кода %qs с -f%s"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "некорректное значение (%qs) для %<target(\"arch=\")%> атрибута"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "некорректный модификатор возможности в %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "некорректный модификатор возможности в %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "некорректное значение (%qs) для %<target(\"tune=\")%> атрибута"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент атрибута %<target%> не строка"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "проход %wd вне диапазона %wd - %wd"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
 msgstr "неподдерживаемая simdlen %d"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -39573,13 +39581,13 @@ msgstr ""
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -39725,19 +39733,19 @@ msgstr ""
 msgid "%qE attribute only applies to variables"
 msgstr "%qE атрибут применим только к переменным"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, fuzzy, gcc-internal-format
 #| msgid "alternatives not allowed in asm flag output"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "альтернативы не допускается в выводе ассемблерного флага"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 #| msgid "unknown asm flag output %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "неизвестный вывод ассемблерного флага %qs"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for asm flag output"
 msgid "invalid type for %<asm%> flag output"
@@ -39963,7 +39971,7 @@ msgstr "целевой процессор не поддерживает кома
 msgid "target CPU does not support unaligned accesses"
 msgstr "целевой процессор не поддерживает невыровненные доступы"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -40024,7 +40032,7 @@ msgstr "граница размера структуры может быть т
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "позиционно-независимый RTP несовместим с -msingle-pic-base"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -40141,7 +40149,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
@@ -40193,34 +40201,34 @@ msgstr "доступ к локальной памяти потока в наст
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd вне диапазона %wd - %wd"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "невозможно вычислить фактическое положение параметра в стеке"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Неожиданный thumb1 далекий переход"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нет свободных low-регистров для выталкивания high-регистров"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific для Thumb-1"
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -40228,22 +40236,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "auto fpu выбор в настоящее время здесь не допускается"
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -40322,17 +40330,17 @@ msgstr "-fpie не поддерживается"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE не поддерживается"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs функция не может иметь аргументы"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs функция не может возвращать значение"
@@ -40674,7 +40682,7 @@ msgstr "некорректный аргумент встроенной функ
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "некорректный аргумент встроенной функции"
@@ -41328,726 +41336,726 @@ msgstr "версии функции не могут быть помечены к
 msgid "virtual function multiversioning not supported"
 msgstr "мультиверсионность виртуальной функции не поддерживается"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 #| msgid "multiversioning needs ifunc which is not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "мультиверсионность требует ifunc, что не поддерживается на этой платформе"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель кода %s не поддерживает PIC режим"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "аргумент атрибута %qE не является строковой константой"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "attribute(target(\"%s\")) неизвестен"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "SEQUENCE атрибут в %C уже специфицирован в TYPE операторе"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Атрибут %s %qs конфликтует с атрибутом %s в %L"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "некорректный аргумент %qs для опции %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "диапазоны размера в опции %qs следует увеличить"
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "некорректное имя стратегии %qs задано для опции %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "имя стратегии %qs заданное для опции %qs не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "неизвестное выравнивание %qs задано для опции %qs"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "максимальное значение для диапазона последнего размера должно быть -1 для опции %qs"
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "слишком много диапазонов размера задано в опции %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI не поддерживается в %s режиме"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> устарело; используйте вместо этого соответственно %<-mtune=k8%> или %<-mtune=generic%>"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> устарело; используйте вместо этого соответственно %<target(\"tune=k8\")%> или %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mcmodel= не поддерживается на 32-битных системах"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "адресный режим %qs не поддерживается в %s-битном режиме"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> не поддерживается, используется =2"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "транзакционная память не поддерживается с %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "транзакционная память не поддерживается с %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fcheck-pointer-bounds%> is not supported with %<-fsanitize=bounds%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-fcheck-pointer-bounds%> не поддерживается с %<-fsanitize=bounds%>"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel не поддерживается в этой конфигурации"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битный режим не компилируется в"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<intel%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<intel%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "заданный процессор не поддерживает набор команд x86-64"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "некорректное значение (%qs) для ключа %<-march=%>"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "некорректное значение (%qs) для %<target(\"arch=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<-march=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "допустимые аргументы для %<-march=%> ключа: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-mtune=%> switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "некорректное значение (%qs) для ключа %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "некорректное значение (%qs) для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<-mtune=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "допустимые аргументы для %<-mtune=%> ключа: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm игнорируется для Intel MCU psABI"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d не между 0 и %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary не поддерживается для этой целевой платформы"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d не между %d и 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount не реализовано для -fPIC"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> используется без SSE включения"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> используется без SSE включения"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "набор команд SSE отменен, используется арифметика 387"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "набор команд 387 отменен, используется арифметика SSE"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "опробование стека требует %<-maccumulate-outgoing-args%> для корректной работы"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "опробование стека требует %<target(\"accumulate-outgoing-args\")%> для корректной работы"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "фиксированный ebp регистр требует %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "фиксированный ebp регистр требует %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry не поддерживается для 32 бит в комбинации с -fpic"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "неизвестная опция для -mrecip=%s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не есть допустимое число в -mstack-protector-guard-offset"
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не есть допустимое смещение в -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs не есть допустимый базовый регистр в -mstack-protector-guard-reg"
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, fuzzy, gcc-internal-format
 #| msgid "Only DWARF debug format is supported for interrupt service routine."
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Только отладочный формат DWARF поддерживается для программы обслуживания прерываний."
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s инструкции не допускаются в функции с no_caller_saved_registers атрибутом"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты regparam и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты cdecl и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE используется для неклассового метода"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qE допустим только для 32 бит"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибуты ms_abi и sysv_abi несовместимы"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргументом атрибута %qE должна быть строковая константа"
 
 #
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "программа обслуживания прерываний должна иметь указатель первым аргументом"
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "программа обслуживания прерываний должна иметь беззнаковый %sint вторым аргументом"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "программа обслуживания прерываний может иметь только указательный аргумент и необязательный целочисленный аргумент"
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
 msgstr "программа обслуживания прерываний не может иметь не-void возвращаемое значение"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qT с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "X32 does not support ms_abi attribute"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "X32 не поддерживает ms_abi атрибут"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ms_hook_prologue несовместим с вложенной функцией"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F векторный аргумент без включения AVX512F изменяет ABI"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F векторный возврат без включения AVX512F изменяет ABI"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX векторный возврат без включения AVX изменяет ABI"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE векторный аргумент без включения SSE изменяет ABI"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "результат - вектор SSE без включения SSE изменяет ABI"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "возврат вектора MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом flexible array изменен в GCC 4.4"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "ABI для передачи объединения с long double изменен в GCC 4.4"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 #, fuzzy
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE регистровый возврат с выключенным SSE"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE регистровый аргумент с выключенным SSE"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 регистровый возврат с выключенным x87"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "вызов %qD с SSE соглашением о вызовах без включения SSE/SSE2"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "это ошибка GCC, которую можно обойти добавлением атрибута used для вызываемой функции"
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not compatible with %qD"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "%qD не совместим с %qD"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "атрибут ms_hook_prologue несовместим с -mfentry для 32 бит"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "%qE атрибут не поддерживается на данной платформе"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support fastcall with nested function"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "-fsplit-stack не поддерживает fastcall с вложенной функцией"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
@@ -42055,84 +42063,84 @@ msgstr "-fsplit-stack не поддерживает 2-регистровые п
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 3 register parameters"
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported size for integer register"
 msgid "%<V%> modifier on non-integer register"
 msgstr "неподдерживаемый размер для целочисленного регистра"
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "неподдерживаемый размер для целочисленного регистра"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "расширенные регистры не имеют верхних половин"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "некорректный размер операнда для расширенного регистра"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 #| msgid "non-integer operand used with operand code 'z'"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "нецелый операнд использован с кодом операнда 'z'"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 #, fuzzy
 #| msgid "the mangling of %<va_list%> has changed in GCC 4.4"
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "разборка %<va_list%> изменилась в GCC 4.4"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "-mcmodel= не поддерживается на 32-битных системах"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "HLE_ACQUIRE не использовано с ACQUIRE или более сильной моделью памяти"
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "HLE_RELEASE не использовано с RELEASE или более сильной моделью памяти"
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 #| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -42515,7 +42523,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "повторная декларация %qE с конфликтующими атрибутами %qs"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE атрибут требует строковый аргумент"
@@ -43736,60 +43744,60 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "неизвестная модель '#pragma extern_model' '%s'"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "тип %qT не имеет известный размер"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "тип %qT не имеет известный размер"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "арифметическая операция над указателем на неполный тип"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type %qT"
 msgid "fields cannot have RVV type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 #| msgid "function parameters cannot have __fp16 type"
 msgid "array elements cannot have RVV type %qT"
 msgstr "параметры функции не могут иметь тип __fp16"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "невозможно разместить объект абстрактного типа %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "невозможно разместить объект абстрактного типа %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "невозможно разместить объект абстрактного типа %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 #| msgid "capture by copy of incomplete type %qT"
 msgid "capture by copy of RVV type %qT"
@@ -43812,73 +43820,78 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv требует -march, чтобы понять %<M%> расширение"
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "запрошенный ABI требует -march, чтобы понять %qc расширение"
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI требует -march=rv%d"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs функция не может иметь аргументы"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -44385,100 +44398,100 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование %<long double%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование типов boolean в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование %<complex%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "использование типов decimal floating point в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование %<long%> в типах AltiVec не рекомендуется; используйте %<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
 #
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "мультиверсионность виртуальной функции не поддерживается"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -45983,7 +45996,7 @@ msgstr "некорректная попытка разместить в реги
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неинициализированная константа %qD не допускается в C++"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D в declare target директиве не имеет отображаемого типа"
@@ -46173,7 +46186,7 @@ msgstr "класс хранения в декларации параметра %
 msgid "storage class specified for unnamed parameter"
 msgstr "класс хранения задан для неименованного параметра"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "класс хранения задан для имени типа"
@@ -46342,7 +46355,7 @@ msgstr "имя типа объявлено как функция, возвращ
 msgid "function definition has qualified void return type"
 msgstr "в определении функции задан квалифицированный void-тип возвращаемого значения"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
@@ -46469,7 +46482,7 @@ msgstr "в ISO C функции с квалификаторами const и volat
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "элемент структуры или объединения не может иметь переменно модифицируемый тип"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "переменная или поле %qE объявлено void"
@@ -46673,7 +46686,7 @@ msgstr "определение типа в выражении %qs некорре
 msgid "%qT defined in underspecified object initializer"
 msgstr "неизвестное поле %qE в инициализаторе"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларация ничего не описывает"
@@ -46723,7 +46736,7 @@ msgstr "структура не содержит именованных элем
 msgid "struct has no members"
 msgstr "структура не содержит элементов"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "регулируемый элемент-массив в объединении"
@@ -46769,7 +46782,7 @@ msgstr "повторная декларация %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -46819,7 +46832,7 @@ msgstr "в ISO C значения перечислимого типа огран
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -46850,7 +46863,7 @@ msgstr "прототип для %qD не был предварительно о
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD использована без прототипа, до её определению"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "отсутствует предварительная декларация %qD"
@@ -46966,12 +46979,12 @@ msgstr "аргумент %qD не соответствует встроенно
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не соответствует прототипу"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметру %qD присвоено значение, но он не использован"
@@ -49088,7 +49101,7 @@ msgstr "недостаточно аккуратно вложенные цикл
 msgid "collapsed loops not perfectly nested"
 msgstr "сливаемые циклы не являются идеально вложенными"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "итерационная переменная %qD не должна быть firstprivate"
@@ -49235,13 +49248,13 @@ msgstr "ожидалось %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "%qs в %L не есть функция"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -49522,7 +49535,7 @@ msgstr "неправильное использование void-выражен
 msgid "invalid use of flexible array member"
 msgstr "неправильное использование регулируемого элемента-массива в структуре"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "неправильное использование массива с неопределенными границами"
@@ -50504,12 +50517,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "инициализация регулируемого элемента-массива"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -50550,7 +50563,7 @@ msgstr "инициализирующий элемент не может быть
 msgid "invalid initializer"
 msgstr "неверный инициализатор"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "вектор скрытого типа не может быть инициализирован"
@@ -50565,8 +50578,8 @@ msgstr "избыточные фигурные скобки в конце ини
 msgid "braces around scalar initializer"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "инициализация элемента регулируемого элемента-массива во вложенном контексте"
@@ -50657,7 +50670,7 @@ msgstr "избыточные элементы в инициализаторе с
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "позиционная инициализация поля в %<struct%> декларированной с %<designated_init%> атрибутом"
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "не статическая инициализация регулируемого элемента-массива в структуре"
@@ -52079,7 +52092,7 @@ msgstr "нет подходящего %<operator %s%> для %qT"
 msgid "%q#D is private within this context"
 msgstr "%q#D private в данном контексте"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "декларировано private здесь"
@@ -52089,7 +52102,7 @@ msgstr "декларировано private здесь"
 msgid "%q#D is protected within this context"
 msgstr "%q#D protected в данном контексте"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "декларировано protected здесь"
@@ -52104,7 +52117,7 @@ msgstr "%q#D недоступно в данном контексте"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "передача NULL в неуказательный аргумент %P в %qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid " declared here"
@@ -52446,7 +52459,7 @@ msgstr ""
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "невозможно вызвать конструктор %<%T::%D%> непосредственно"
@@ -53037,7 +53050,7 @@ msgstr "элемент регулируемого массива %qD в друг
 msgid "next member %q#D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
@@ -53161,7 +53174,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -53233,7 +53246,7 @@ msgstr "самосравнение всегда дает false"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -53285,7 +53298,7 @@ msgstr "  %qT является неоднозначным базовым кла
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -53419,7 +53432,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "доступ по пустому указателю в %qE"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -53530,7 +53543,7 @@ msgstr "доступ к неинициализированному элемен
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -53611,7 +53624,7 @@ msgstr "Изменение значения в преобразовании из
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -53682,207 +53695,207 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "capture переменной  %qD с неавтоматическим сроком хранения"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 #| msgid "a reinterpret_cast is not a constant expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "reinterpret_cast не является константным выражением"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в константном выражении"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "%s\"%s\"%s не допускается"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на не полностью инициализированную переменную"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не является константным выражением"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не есть константное выражение"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 #| msgid "a reinterpret_cast is not a constant expression"
 msgid "contract predicate is false in constant expression"
 msgstr "reinterpret_cast не является константным выражением"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "ожидался template-id"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "внутренняя функция %qE должна вызываться напрямую"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "неожиданное выражение %qE вида %s"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на не полностью инициализированную переменную"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from integer to pointer"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast из целого в указатель"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of объекта %qE с поточно-локальным или автоматическим хранением не есть константное выражение"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "использование %<this%> в константном выражении"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "приведение к нецелочисленному типу %qT в константном выражении"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD декларирована %<thread_local%> я %<constexpr%> функции"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<static%> in %<constexpr%> function"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD декларирована %<static%> я %<constexpr%> функции"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не есть константное выражение"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<this%> in a constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "использование %<this%> в константном выражении"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "неконстантная инициализация массива"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "неожиданное AST вида %s"
@@ -54533,7 +54546,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%qD было объявлено здесь"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "no member named %qE in %qT"
@@ -54640,7 +54653,7 @@ msgstr "третий аргумент %<__builtin_prefetch%> должен быт
 msgid "no suspend point info for %qD"
 msgstr "прототип для %qD не был предварительно определен"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54663,23 +54676,23 @@ msgstr "в конструкции case нельзя употреблять ук
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "граница массив переменной длины неизвестна"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -55180,7 +55193,7 @@ msgstr "из предыдущей декларации %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "редекларация %qD отличается в %<constexpr%> от предыдущей декларации"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "предыдущая декларация %qD"
@@ -55609,621 +55622,621 @@ msgstr "%qD не является шаблоном функции"
 msgid "%q#T is not a class"
 msgstr "%q#T не является классом"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "шаблон класса с именем %q#T' отсутствует в %q#T"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нет имени типа %q#T в %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "просмотр %qT в %qT неоднозначен"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именует %q#T, который не является шаблоном класса"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> именует %q#T, который не является типом"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "параметры шаблона не соответствуют шаблону %qD"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-faligned-new=%d is not a power of two"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-faligned-new=%d не есть степень двойки"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "анонимная структура не внутри именованного типа"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с конструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с деструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с операцией присваивания-копирования недопустим в анонимном агрегатном типе"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибуты проигнорированы в декларации %q#T"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут для %q#T должен следовать за %qs ключевым словом"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "несколько типов в одной декларации"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "повторная декларация внутреннего типа C++ %qT"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "отсутствует имя типа в typedef-декларации"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "в ISO C++ анонимные структуры запрещены"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> может задаваться только для функций"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> может задаваться только для функций"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> может быть задан только внутри класса"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> может быть задан только для конструкторов"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "класс хранения может быть задан только для объектов и функций"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> в этой декларации отброшен"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> не может использоваться для деклараций типов"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут игнорируется в явной конкретизации %q#T"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "никакой атрибут не может применяться к явной конкретизации"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "игнорирование атрибутов примененных к классу %qT вне определения"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "игнорирование атрибутов примененных к зависимому типу %qT без ассоциированной декларации"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD инициализирован (используйте decltype взамен)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларация %q#D содержит %<extern%> и инициализирована"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "определение функции %q#D помечено %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D не есть статический элемент данных %q#T"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "non-member-template декларация %qD"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "не соответствует декларации элемента шаблона здесь"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ не разрешает определять %<%T::%D%> как %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "повторная инициализация %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "переменная %q#D инициализирована, хотя имеет неполный тип"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "элементы массива %q#D имеют неполный тип"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "агрегатный тип %q#D неполон и не может быть определён"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "переменная %qD декларирована как ссылка, но не инициализирована"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "имя использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "имя %qD использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривиально определенные инициализаторы не поддерживаются"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99 обозначение %qE не является целочисленным константным выражением"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "при инициализации не удалось определить размер %qD"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "не задан размер массива для %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "массив %qD имеет нулевой размер"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "размер памяти %qD неизвестен"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "размер памяти %qD не константа"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики inline переменной %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики статических данных inline функции %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "это можно обойти, удалив инициализатор"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неинициализированная константа %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неинициализированная переменная %qD в %<constexpr%> функции"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T не имеет предоставленный пользователем подразумеваемый конструктор"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "конструктор не является предоставленным пользователем, поскольку он явно подразумевался в теле класса"
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "и неявно определенный конструктор не инициализирует %q#D"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "некорректный тип %qT является инициализатором для вектора типа %qT"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "инициализатор для %qT должен быт заключен в фигурные скобки"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> использовано в определенном в GNU-стиле инициализаторе для класса %qT"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD не является элементом %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "некорректный инициализатор для %q#D"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 обозначение %qE вне инициализатора агрегата"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "избыточные элементы в инициализаторе для %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "элементы массива %q#T имеют неполный тип"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "составной литерал переменного размера"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D имеет неполный тип"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "в инициализаторе скалярного объекта %qD должен быть только один элемент"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "в C++98 %qD следует инициализировать при помощи конструктора, а не %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "массив %qD инициализируется строковой константой %qE, заключённой в скобки"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "инициализатор недопустим для статического элемента с конструктором"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для non-inline статического элемента %qD"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(запрошена инициализация вне класса)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "ссылка %qD инициализируется собой"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "повторная декларация перечислимого типа %q+D"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "использован %<register%> спецификатор класса хранения"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "декларация %q#D не имеет инициализатора"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "инициализатор для %<decltype(auto) %D%> имеет тип функции (вы забыли %<()%> ?)"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "переменная concept не имеет инициализатора"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "перекрытие предыдущей декларации %q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "атрибут %qE применим только к переменным в статической памяти"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функция %q#D инициализирована как переменная"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он содержит анонимный элемент структуры"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он имеет анонимный элемент объединения"
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: и он и его базовый класс %qT имеют нестатические элементы данных"
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: его базовые классы %qT и %qT имеют нестатические элементы данных"
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "невозможна декомпозиция массива переменной длины %qT"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -56231,7 +56244,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -56239,7 +56252,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -56247,1719 +56260,1719 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не является целочисленным константным выражением"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "невозможна декомпозиция типа объединения %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "невозможна декомпозиция non-array non-class типа %qT"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "невозможна декомпозиция типа lambda замыкания %qT"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT без нестатических элементов данных"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> требует динамической инициализации"
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> имеет нетривиальный деструктор"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> допускает динамическую инициализацию и уничтожение"
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "при инициализации не удалось определить размер %qT"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "не задан размер массива в %qT"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "нулевой размер массива %qT"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларирована как %<virtual%> переменная"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации переменной"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларирован как %<virtual%> параметр"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларирован как %<inline%> параметр"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации параметра"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларирован как %<virtual%> тип"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларирован как %<inline%> тип"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации типа"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларирован как %<virtual%> поле"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларирован как %<inline%> поле"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации поля"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларировано со спецификацией исключений"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "определение %qD вне пространства имён, объемлющего %qT"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статическая функция-член %q#D объявлена с квалификаторами типа"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "concept %q#D декларирован с параметрами функциями"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "concept %q#D декларирован с выведенным типом возврата"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "concept %q#D с non-%<bool%> типом возврата %qT"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "concept %qD не имеет определения"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "a function concept cannot be constrained"
 msgstr "функция не может быть инструментирована"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "определение явной специализации %qD в friend-декларации"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "некорректное использование идентификатора шаблона %qD в декларации первичного шаблона"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "не допускается использовать %<inline%> в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "недопустимая декларация %<::main%> как шаблона"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "руководство вывода %qD не должно иметь тело функции"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "литеральный оператор с C-привязкой"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD имеет некорректный список аргументов"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "целый суффикс %qs перекрыт реализацией"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %qs shadowed by implementation"
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "суффикс плавающей точки %qs перекрыт реализацией"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "суффиксы литеральных операторов без предшествующего %<_%> зарезервированы для будущей стандартизации"
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD должен быть не-элемент-функцией"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> должна возвращать %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "определение неявно декларированного %qD"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "определение явно подразумеваемого %q+D"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явно подразумевается здесь"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "нет элемента-функции %q#D в классе %qT"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "невозможно декларировать %<::main%> как глобальную переменную"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "non-template переменная не может быть %<concept%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "concept должен иметь тип %<bool%>"
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "variable concept has no initializer"
 msgid "a variable concept cannot be constrained"
 msgstr "переменная concept не имеет инициализатора"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "инициализация внутри класса статического элемента данных %q#D неполного типа"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> требуется для инициализации внутри класса статического элемента данных %q#D нецелого типа"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "инициализация внутри класса статического элемента данных %q#D нелитерального типа"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ запрещает инициализацию внутри класса неконстантного статического элемента %qD"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ запрещает инициализацию элемента-константы %qD нецелочисленного типа %qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "размер массива %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "размер массива имеет нецелочисленный тип %qT"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ запрещает массив нулевого размера %qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ запрещает массивы нулевого размера"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ запрещает массив переменного размера %qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ запрещает массивы переменного размера"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "используется массив переменного размера %qD"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "используется массив переменного размера"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "переполнение в размерности массива"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as array of %qT"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD декларировано как массив %qT"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "декларация %qD как массива void"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "создание массива void"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "декларация %qD как массива функций"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "создание массива функций"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "декларация %qD как массива ссылок"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "создание массива ссылок"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "декларация %qD как массива элементов-функций"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "создание массива элементов-функций"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "в многомерном массиве должны быть определены границы для всех размерностей, кроме первой"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "используется массив переменного размера"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в конструкторе"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "квалификаторы не допускаются в декларации конструктора"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в деструкторе"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "квалификаторы не допускаются в декларации деструктора"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "тип результата задан для %<operator %T%>"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "возвращаемый тип задан для руководства вывода"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "квалификаторы не допускаются в декларации руководства вывода"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier in declaration of deduction guide"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "decl-спецификатор в декларации руководства вывода"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "декларация безымянной переменной или поля с типом void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "декларация переменной или поля с типом void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> спецификатор некорректен для переменной %qD декларированной в контексте блока"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT как тип а не плоский %<decltype(auto)%>"
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "декларация %qD как не-элемента"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "декларатор отсутствует; используется зарезервированное слово %qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "определение функции не объявляет параметры"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларация %qD как %<typedef%>"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "декларация %qD как параметра"
 
 #
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "нет специфицированных классов"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> не может встречаться в typedef декларации"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или более типа в декларации имени %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ не поддерживает плоские %<complex%> означающие %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ запрещает декларации %qs без типа"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> не поддерживается этой целевой платформой"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не поддерживает %<__int%d%> для %qs"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> и %<unsigned%> одновременно заданы для %qs"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> и %<short%> одновременно заданы для %qs"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%qs использован с %qE"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qD"
 msgstr "%qs использован с %qE"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs указан с %<decltype%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs указан с %<typeof%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "спецификатор complex для %qs недопустим"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, fuzzy, gcc-internal-format
 #| msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "за типом заполнителя шаблона %qT должен следовать простой declarator-id"
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<static%>"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<constexpr%>"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-декларация не допускается в декларации параметров"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "класс хранения задан для параметра шаблона %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> вне декларации класса"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for structured binding declaration"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "некорректный инициализатор для структурированной связывающей декларации"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "тип должен быть cv-qualified %<auto%> или ссылкой на cv-qualified %<auto%>"
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "в декларации %qs задано более одного класса хранения"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "для %qs задан класс хранения"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "вложенная функция %qs объявлена %<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "имя %qs описано на верхнем уровне с классом хранения %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "имя %qs на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "класс хранения не допускается в декларации friend-функции"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "атрибут проигнорирован"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "атрибут, относящийся к спецификатору типа, игнорируется"
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Ожидалась открывающая скобка"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-клаузула для типа возврата"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs функция использует %<auto%> спецификатор типа без завершающего типа возврата"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "выведенный тип возврата доступен только с -std=c++14 или -std=gnu++14"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуальная функция не может иметь выведенный тип возврата"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "руководство вывода для %qT должно иметь завершающий тип возврата"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "хвостовой тип возврата %qT руководства вывода не есть специализация %qT"
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs функция с завершающим типом возврата не декларирована с %<auto%> спецификатором типа"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "функция преобразования не может иметь завершающий тип возврата"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<_Atomic%>-квалифицированный возвращаемый тип в %qD"
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функция с атрибутом noreturn возвращает не-void значение"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "деструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "конструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструкторы не могут быть декларированы %<virtual%>"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "невозможно определить friend-функцию %qs в определении локального класса"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструкторы не могут иметь параметров"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "недопустимая декларация указателя на элемент %q#T"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Недопустимо определять ссылку на %q#T, которая не будет определением типа или аргументом шаблона"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "элементы-функции неявно считаются friend-функциями своего класса"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "избыточная квалификация %<%T::%> элемента %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента %<%T::%s%> внутри %qT"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не может иметь модифицированный тип `%T"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> вне декларации класса"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> в friend декларации"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "только декларации конструкторов и операторов преобразования могут быть %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не объектного элемента %qs как %<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация статического %qs как %<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация константного %qs как %<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "ссылка %qs не может быть декларирована %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef декларирован %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-клаузула для typedef"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ запрещает определять вложенный тип %qD с тем же именем, что и объемлющий класс"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "в декларации friend-класса использован квалификатор %<inline%>"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "в friend-декларации требуется указание класса: %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "в friend-декларации требуется указание класса: %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "попытка сделать класс %qT \"другом\" глобальной области видимости"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "некорректные квалификаторы для типа функции, не являющейся элементом"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-клаузула для идентификатора типа"
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактный декларатор %qT использован в качестве декларатора"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-клаузула в декларации нефункционального типа %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "недопустимое использование %<::%> в декларации параметра"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "невозможно декларировать параметр с абстрактным типом %qT"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр декларирован %<auto%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "нестатический элемент данных декларирован с заполнителем %qT"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ запрещает элемент регулируемый массив %qs"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ запрещает элементы регулируемые массивы"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "декларация функции %qD в неверном контексте"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не может быть декларирована %<virtual%>, поскольку она всегда статическая"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для деструктора %qD"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для конструктора %qD"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "конструктор не может быть %<concept%>"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "ошибка открытия %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "специализация переменного шаблона %qD декларирована как функция"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "переменный шаблон декларирован здесь"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, fuzzy, gcc-internal-format
 #| msgid "an attribute that appertains to a type-specifier is ignored"
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "атрибут, относящийся к спецификатору типа, игнорируется"
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qE declared %<concept%>"
 msgid "static data member %qE declared %qs"
 msgstr "статический элемент данных %qE декларирован %<concept%>"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "некорректный класс хранения %<auto%> для функции %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "некорректный класс хранения %<register%> для функции %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "класс хранения %<thread_local%> недопустим для функции %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-спецификаторы в %qs не допускаются вне определения класса"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> спецификатор некорректен для функции %qs декларированной вне глобального контекста"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуальная функция %qs не является элементом класса"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs определен не в контексте класса"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs декларирован не в контексте класса"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "недопустимая декларация статического элемента-функции %qD"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "недопустимая декларация статической функции внутри другой функции"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "слово %<static%> недопустимо при определении (в отличие от объявления) статического элемента данных в классе"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "недопустимая явная extern-декларация элемента %q#D"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент по умолчанию %qE использует %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
 #
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "некорректное использование cv-квалифицированного типа %qT в декларации параметра"
 
 #
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "некорректное использование типа %<void%> в декларации параметра"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<_Atomic%>-квалифицированный параметр типа %qT для %q+D"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD включает указатель на массив с неизвестной границей %qT"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD включает ссылку на массив с неизвестной границей %qT"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "некорректный конструктор; возможно, вы имели в виду %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD можно не определять статической"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a member function"
 msgstr "%qD должен быть не-элемент-функцией"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD должен быть либо нестатическим элементом-функцией или функцией-не-элементом"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD должен иметь аргумент типа класс или перечислимого типа"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ не поддерживает перегрузку операции ?:"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "преобразование к void никогда не использует операцию преобразования типа"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "преобразование к ссылке на тот же тип никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "преобразование к тому же типу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к ссылке на базовый класс никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к базовому классу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксный %qD должен возвращать %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксный %qD должен возвращать %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD должен возвращать результат по значению"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "использование параметра шаблона %qT после %qs"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "использование синонима специализации шаблона %qT после %qs"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "использование typedef-имени %qD после %qs"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD ранее декларирован здесь"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "ссылка на %qT как на %qs"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT ранее декларирован здесь"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "ссылка на %qT как на enum"
@@ -57971,113 +57984,113 @@ msgstr "ссылка на %qT как на enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "для %<%s %T%> нужен аргумент-шаблон"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "шаблон функции %qD редекларирован как шаблон класса"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "возможно вы хотите явно добавить %<%T::%>"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "использование перечисления %q#D без предыдущей декларации"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторная декларация %qT как не-шаблона"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "недопустимая декларация %qD как битового поля"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "некорректный производный тип union %qT"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT определен с многими непосредственными базами"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT определен с непосредственной виртуальной базой"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовый тип %qT не является ни структурой, ни классом"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивный тип %qT не определён"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "некорректное дублирование базового типа %qT"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "scoped/unscoped рассогласование в enum %q#T"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "рассогласование основного типа в enum %q#T"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "отличающийся основной тип в enum %q#T"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "специализация %qD в другой namespace-области"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -58086,84 +58099,84 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ни один целочисленный тип не годится для представления всех значений перечислимого типа %qT"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "значение перечислимого типа для %qD должно иметь целочисленный или unscoped перечислимый тип"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<long%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переполнение в перечисляемых значениях для %qD"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "нет операторов возврата в функции возвращающей %qT"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "только плоский %<auto%> тип возврата может быть приведен к %<void%>"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD уже определена в классе %qT"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %qs"
 msgid "using %qs"
 msgstr "объемлющая %qs"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "использование %qD до приведения %<auto%>"
@@ -59055,7 +59068,7 @@ msgstr "тип %qT не является непосредственной или
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "массив должен быть инициализирован инициализатором в фигурных скобках"
@@ -60182,7 +60195,7 @@ msgstr "using-декларация для не-элемента внутри к
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -60963,7 +60976,7 @@ msgstr "типы нельзя определять в %<typeid%> выражен
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неверное число аргументов для %<__builtin_addressof%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неверное число аргументов для %<__builtin_launder%>"
@@ -61728,12 +61741,12 @@ msgstr "только конструкторы берут инициализат
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer для %qD следует за constructor delegation"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "constructor delegation следует за mem-initializer для %qD"
@@ -62365,7 +62378,7 @@ msgstr "отсутствуют аргументы шаблона после %qT"
 msgid "%qT not permitted in template argument"
 msgstr "отсутствуют аргументы шаблона"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -63262,7 +63275,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "итерационная переменная %qD не должна быть reduction"
@@ -64302,7 +64315,7 @@ msgstr "не-шаблонный тип %qT использован как шаб
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
@@ -64400,282 +64413,282 @@ msgstr "функция возвращает массив"
 msgid "function returning a function"
 msgstr "функция возвращает функцию"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "формирование указателя на ссылочный тип %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "формирование ссылки на ссылочный тип %qT"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "формирование указателя на квалифицированный тип функции %qT"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "формирование ссылки на квалифицированный тип функции %qT"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент типа void"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT разрешается в %qT, который не является перечислимым типом"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT разрешается в %qT, который не является классовым типом"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависимое имя %qE разбирается как не тип, но конкретизация дает тип"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "использование некорректного поля %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "используйте %<...%> для расширения argument pack"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "пустой инициализатор в lambda init-capture"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не декларирован в этом контексте, и не было найдено деклараций при зависимом от аргументов поиске в точке конкретизации"
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "декларации в зависимой базе %qT не найдены при неквалифицированном поиске"
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "используйте %<this->%D%>"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "используйте %<%T::%D%>"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD декларировано здесь, позднее в единице трансляции"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неверное число аргументов в вызове %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "для атрибута %qE задано неверное число аргументов"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT есть/использует неименованный тип"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблона для %qD использует локальный тип %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT есть переменно модифицированный тип"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначная конкретизация шаблона для %q#T"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначная конкретизация шаблона класса для %q#D"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация нешаблона %q#D"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of variable concept %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "специализация variable concept %q#D"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of function concept %qD"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "явная специализация function concept %qD"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явной конкретизации %qD не соответствует декларированному типу %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация %q#D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация %q#D"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация неклассового шаблона %qD"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -64687,175 +64700,175 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT не является пространством имен или unscoped enum"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "определение %q#T внутри списка параметров шаблона"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "неклассовый шаблон %qT использован без аргументов шаблона"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "используйте директиву #include"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "невозможно вывести аргументы шаблона для инициализации копированием %qT, поскольку он имеет неявное руководство вывода или декларированные пользователем конструкторы"
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "явные руководства вывода не рассматриваются для copy-инициализации"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "explicit deduction guide declared here"
 msgstr "в вызове функции %qD определенной здесь"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, fuzzy, gcc-internal-format
 #| msgid "class template argument deduction failed:"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization %<auto%> требует ровно один элемент"
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "для вывода к %<std::initializer_list%> используйте copy-list-initialization (то есть добавьте %<=%> перед %<{%>)"
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "не удается вывести возвращаемый тип lambda из %qE"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "ограничения заполнителя не удовлетворены"
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "выведенный инициализатор не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "выведенный тип возврата не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "выведенный тип выражения не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -65183,7 +65196,7 @@ msgstr "некорректная спецификация базового кл
 msgid "cannot capture member %qD of anonymous union"
 msgstr "невозможно захватить элемент %qD анонимного объединения"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захватывается"
@@ -65606,28 +65619,28 @@ msgstr "вызов %<__builtin_next_arg%> без аргумента"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE не является шаблоном класса"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "операнд выражения свертки не имеет нерасширенных пакетов параметров"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "оба аргумента в бинарной свертке имеют нерасширенные пакеты параметров"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "нет нерасширенных пакетов параметров в бинарной свертке"
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "неуказательный аргумент для %<__builtin_launder%>"
@@ -65635,22 +65648,22 @@ msgstr "неуказательный аргумент для %<__builtin_launder
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -66927,231 +66940,231 @@ msgstr "forward декларация %q#T"
 msgid "declaration of %q#T"
 msgstr "декларация %q#T"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qD имеет неполный тип"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "некорректное использование неполного типа %q#T"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "некорректное использование функции-элемента %qD (вы забыли %<()%> ?)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "некорректное использование элемента %qD (вы забыли %<&%>?)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "некорректное использование заполнителя %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "некорректное использование шаблона параметра типа %qT"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "некорректное использование шаблона параметра шаблона %qT"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of pack expansion expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "некорректное использование зависимого типа %qT"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "некорректное использование списка инициализатора в фигурных скобках"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "адрес перегруженной функции без контекстной информации о типе"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "перегруженная функция без контекстной информации о типе"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "недостаточно контекстной информации для определения типа"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "использован синтаксис конструктора для типа %qT, который не имеет конструкторов"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 #| msgid "interface %qE does not have valid constant string layout"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "интерфейс %qE не имеет корректной структуры константной строки"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 #| msgid "Warn about narrowing conversions within { } that are ill-formed in C++11."
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "Предупреждать о сужающих преобразованиях в { }, являющихся дефектными в C++11."
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "conversion from %q#T to %q#T"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "преобразование из %q#T в %q#T"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "слишком длинная строка инициализации для символьного массива"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "невозможно инициализировать агрегат типа %qT составным литералом"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "элемент %qD с неинициализированными ссылочными полями"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поле %qD не найдено в инициализируемом объединении"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значение индекса вместо имени поля в инициализаторе объединения"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "обнаружено циклическое делегирование указателей"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовый операнд %<->%> имеет неуказательный тип %qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> не является указателем"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовый операнд %<->%> не является указателем"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не может использоваться как элемент, поскольку имеет тип %qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "невозможно применить элементный указатель %qE к %qE, который имеет неклассовый тип %qT"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "указатель на элементный тип %qT несовместим с объектным типом %qT"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "тип указатель на элемент-функцию %qT требует rvalue"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member-function type %qT requires an lvalue"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "функциональное приведение к массивному типу %qT"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "функция не может быть инструментирована"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "некорректная инициализация значения ссылочного типа"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "вызов функции %qD, которая вызывает исключение неполного типа %q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "вызов функции, которая вызывает исключение неполного типа %q#T"
@@ -68153,7 +68166,7 @@ msgstr "Список имен %qs не может быть аргументом
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "%<I%> в %L и %<J%> в %L не могут обе быть BOZ литеральными константами"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid exponent-letter %<q%> in real-literal-constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -69275,12 +69288,12 @@ msgstr "Неиспользуемая инициализационная цепо
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Начальный индекс подстроки в %L меньше единицы"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Конечный индекс подстроки в %L превышает длину строки"
@@ -69463,7 +69476,7 @@ msgstr "Некорректная INTENT спецификация в %C"
 msgid "deferred type parameter at %C"
 msgstr "отложенный параметр типа в %C"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Скалярное INTEGER выражение ожидалось в %L"
@@ -71520,7 +71533,7 @@ msgstr "трансформационная встроенная функция %
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Вычисление нестандартного инициализационного выражения в %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "Функция %qs в инициализационном выражении в %L должна быть встроенной функцией"
@@ -71795,7 +71808,7 @@ msgstr "Несоответствие интерфейсов в присваив
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Явный интерфейс требуются для компонента %qs в %L: %s"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Явный интерфейс требуются для %qs в %L: %s"
@@ -71916,7 +71929,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Указатель в %L в присваивании указателя может пережить цель указателя"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Цель инициализации указателя в %L не должна быть ALLOCATABLE"
@@ -71926,7 +71939,7 @@ msgstr "Цель инициализации указателя в %L не дол
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Цель инициализации указателя в %L должна иметь TARGET атрибут"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Цель инициализации указателя в %L должна иметь SAVE атрибут"
@@ -72068,7 +72081,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Некорректный идентификатор в copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -72291,12 +72304,12 @@ msgstr "Первый аргумент определенного присваи
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Второй аргумент определенного присваивания в %L должен быть INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Первый аргумент интерфейса оператора в %L должен быть INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Второй аргумент интерфейса оператора в %L должен быть INTENT(IN)"
@@ -72409,574 +72422,574 @@ msgstr "Несоответствие рангов в аргументе %qs в %
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и ранг-%d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Некорректный аргумент процедуры в %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Несоответствие интерфейса в формальной процедуре %qs в %L: %s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Фактический аргумент для непрерывного указательного формального параметра %qs в %L должен быть просто непрерывным"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) фактические аргументы в %L могут противоречить фактическим аргументам в %L."
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Несоответствие типа в аргументе %qs в %L; передано %s в %s"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Фактический аргумент предполагаемого типа в %L требует, чтобы формальный аргумент %qs был предполагаемого типа"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "Фактический аргумент предполагаемого типа в %L требует, чтобы формальный аргумент %qs был предполагаемого типа"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Фактический аргумент для %qs в %L должен быть полиморфным"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Фактический аргумент для %qs в %L должен иметь тот же декларированный тип"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Фактический аргумент для %qs в %L должен быть неограниченно полиморфным, так как формальный аргумент есть указатель или размещаемая неограниченно полиморфная сущность [F2008: 12.5.2.5]"
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Фактический аргумент для %qs в %L должен быть комассивом"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Несоответствие корангов в аргументе %qs в %L (%d и %d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Фактический аргумент для %qs в %L должен быть просто непрерывным или элементом такого массива"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть LOCK_TYPE или имеет LOCK_TYPE компонент"
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть EVENT_TYPE или имеет EVENT_TYPE компонент"
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Формальный аргумент %qs должен быть указателем или массивом предполагаемой формы или ранга без CONTIGUOUS атрибута - поскольку фактический аргумент в %L не является просто непрерывным и оба являются ASYNCHRONOUS или VOLATILE"
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Передача комассива в %L в allocatable, noncoarray, INTENT(OUT) формальный аргумент %qs"
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Передача комассива в %L в allocatable, noncoarray формальный аргумент %qs, что некорректно, если статус размещения модифицирован"
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Полиморфный скаляр передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Расширение: Скалярный неподразумеваемого вида, не-C_CHAR-вида CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Скалярный CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Аргумент с ключевым словом %qs в %L не в процедуре"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Аргумент с ключевым словом %qs в %L уже ассоциирован с другим фактическим аргументом"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Больше фактических чем формальных аргументов в вызове процедуры в %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Отсутствует спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неожиданная спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Неожиданная NULL() встроенная функция в %L для формального параметра %qs"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Пустой указатель в %L в неуказательный формальный параметр %qs"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr "Фактический аргумент в %L для формального параметра предполагаемого типа имеет производный тип с type-bound или FINAL процедурами"
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и указательным или размещаемым формальным аргументом %qs в %L"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и формальным аргументом предполагаемой формы %qs в %L"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Фактический аргумент в %L в размещаемый или указательный формальный аргумент %qs должен иметь типовый параметр отложенной длины тогда и только тогда, когда таковой имеется у формального"
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Character длина фактического аргумента короче чем у формального аргумента %qs (%lu/%lu) в %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Фактический аргумент содержит слишком мало элементов для формального аргумента %qs (%lu/%lu) в %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Ожидался указатель на процедуру для аргумента %qs в %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Ожидалась процедура для аргумента %qs в %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Фактический аргумент для %qs не может быть массивом предполагаемого размера в %L"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть LOCK_TYPE или имеет LOCK_TYPE компонент"
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for %qs must be a pointer at %L"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Фактический аргумент для %qs должен быть указателем в %L"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Неуказательный фактический аргумент в %L в указательный формальный параметр %qs"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Коиндексированный фактический аргумент в %L в указательный формальный параметр %qs"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Коиндексированный фактический аргумент в %L в размещаемый формальный параметр %qs требует INTENT(IN)"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Коиндексированный ASYNCHRONOUS или VOLATILE фактический аргумент в %L требует, чтобы формальный параметр %qs не имел ни ASYNCHRONOUS ни VOLATILE"
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Коиндексированный фактический аргумент в %L с размещаемым окончательным компонентом для формального параметра %qs требует либо VALUE либо INTENT(IN)"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Фактический аргумент CLASS массив для %qs должен быть полным массивом в %L"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Фактический аргумент для %qs должен быть ALLOCATABLE в %L"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Фактический аргумент секция массива с векторными индексами в %L несовместим с INTENT(OUT), INTENT(INOUT), VOLATILE или ASYNCHRONOUS атрибутом формального аргумента %qs"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент предполагаемой формы в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент секция массива в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент pointer-array в %L требует assumed-shape или pointer-array формальный аргумент %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Отсутствует спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Отсутствует фактический аргумент для аргумента %qs в %L"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Некорректный код компонента"
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Несоответствие списка"
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): поврежденные данные"
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Один и тот же фактический аргумент ассоциирован с INTENT(%s) аргументом %qs и INTENT(%s) аргументом %qs в %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Несоответствие списка"
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Аргумент процедуры в %L локален в PURE процедуре и имеет POINTER атрибут"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Коиндексированный фактический аргумент в %L в процедуре PURE передан в аргумент INTENT(%s)"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Коиндексированный фактический аргумент в %L в PURE процедуре передан в POINTER формальный аргумент"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Коиндексированный полиморфный фактический аргумент в %L передан в полиморфный формальный аргумент %qs"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Процедура %qs вызванная в %L не декларирована явно"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Процедура %qs вызвана с неявным интерфейсом в %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Указательный объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Размещаемый объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Размещаемая функция %qs в %L должна иметь явный функциональный интерфейс"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Explicit interface required for component %qs at %L: %s"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Явный интерфейс требуются для компонента %qs в %L: %s"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Аргумент с ключевым словом требует явный интерфейс для процедуры %qs в %L"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Аргумент предполагаемого типа %s в %L требует явный интерфейс"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Фактический аргумент LOCK_TYPE или с LOCK_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Фактический аргумент EVENT_TYPE или с EVENT_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD аргумент в NULL требуется в %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "Аргумент предполагаемого типа %s в %L требует явный интерфейс"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Аргумент предполагаемого ранга требует явный интерфейс в %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Компонент указатель на процедуру %qs вызван с неявным интерфейсом в %L"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Аргумент с ключевым словом требует явный интерфейс для компонента указателя на процедуру %qs в %L"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= требуется в NULL() аргументе в %L: Неоднозначность между конкретными функциями %s и %s"
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Не удается найти символ %qs"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Сущность %qs в %L уже присутствует в интерфейсе"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Некорректный тип интерфейса"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC %qs at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Не удалось перебить GENERIC %qs в %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs в %L перебивает связывание процедуры декларированной NON_OVERRIDABLE"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs в %L не должно быть DEFERRED, поскольку это перебивает не-DEFERRED связывание"
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs в %L перебивает PURE процедуру и должна также быть PURE"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs в %L перебивает ELEMENTAL процедуру и должна также быть ELEMENTAL"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs в %L перебивает не-ELEMENTAL процедуру и не должна быть ELEMENTAL, также"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs в %L перебивает SUBROUTINE и должна также быть SUBROUTINE"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs в %L перебивает FUNCTION и должна также быть FUNCTION"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Несоответствие результатов для перебивающей процедуры %qs в %L: %s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs в %L перебивает PUBLIC процедуру и не должна быть PRIVATE"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Формальный аргумент %qs от %qs в %L должен именоваться %qs, чтобы подходить соответствующему аргументу перебиваемой процедуры"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Несоответствие аргументов для перебивающей процедуры %qs в %L: %s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs в %L должен иметь то же число формальных аргументов, что и перебиваемая процедура"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs в %L перебивает NOPASS связывание и должен также быть NOPASS"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs в %L перебивает связывание с PASS и должен также быть PASS"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Passed-object формальный аргумент от %qs в %L должен быть на той же позиции, что и passed-object формальный аргумент перебиваемой процедуры"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO формальный аргумент в %L должен быть типа %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO формальный аргумент в %L должен быть KIND = %d"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO формальный аргумент в %L должен быть скаляром"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO формальный аргумент в %L должен быть ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO формальный аргумент в %L должен иметь INTENT %s"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Альтернативный возврат в %L не допускается в DTIO процедуре"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO процедура %qs в %L должна быть подпрограммой"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Слишком мало формальных аргументов в DTIO процедуре %qs в %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Слишком много формальных аргументов в DTIO процедуре %qs в %L"
@@ -73170,7 +73183,7 @@ msgstr "Преобразование из %s в %s в %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -73759,7 +73772,7 @@ msgstr "NAMELIST %qs в READ операторе в %L содержит симв
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L является полиморфным и требует определенную процедуру ввода/вывода"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L с ALLOCATABLE или POINTER компонентами"
@@ -74353,7 +74366,7 @@ msgstr "STOP код в %L должен быть default character KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP код в %L должен быть default integer KIND=%d"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -76308,8 +76321,8 @@ msgstr "параметр ORDERED клаузулы меньше чем COLLAPSE 
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF клаузула в %L требует скалярное LOGICAL выражение"
@@ -78352,735 +78365,747 @@ msgstr "Процедура модуля с character значением %qs в %
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Внутренняя функция с character значением %qs в %L не должна быть предполагаемой длины"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "Функция %s в %L имеет входы с несоответствующими спецификациями массивов"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function %s at %L has entries with mismatched array specifications"
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "Функция %s в %L имеет входы с несоответствующими спецификациями массивов"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "Функция %s at %L с входами, возвращающими переменные с разными длинами строк"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be an array in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "FUNCTION результат %s не может быть массивом в FUNCTION %s в %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be an array in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "ENTRY результат %s не может быть массивом в FUNCTION %s в %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "FUNCTION результат %s не может быть POINTER в FUNCTION %s в %L"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "ENTRY результат %s не может быть POINTER в FUNCTION %s в %L"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "FUNCTION результат %s не может быть POINTER в FUNCTION %s в %L"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "ENTRY результат %s не может быть POINTER в FUNCTION %s в %L"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be of type %s in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "FUNCTION результат %s не может быть типа %s в FUNCTION %s в %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be of type %s in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "ENTRY результат %s не может быть типа %s в FUNCTION %s в %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "Символ %qs в %C уже в COMMON блоке"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "Символ %qs в %C уже в COMMON блоке"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "COMMON block /%s/ not found at %C"
 msgid "COMMON block at %L"
 msgstr "COMMON блок /%s/ не найден в %C"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "Переменная %qs в %L находится в COMMON, но допустима только инициализация в BLOCK DATA"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "Инициализированная переменная %qs в %L находится в безымянном COMMON, но инициализация допустима только в именованных common блоках"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, fuzzy, gcc-internal-format
 #| msgid "%qs in cannot appear in COMMON at %L [F2008:C5100]"
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr "%qs не может появляться в COMMON в %L [F2008:C5100]"
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "Переменная производного типа %qs в COMMON в %L не имеет ни SEQUENCE ни BIND(C) атрибута"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "Переменная производного типа %qs в COMMON в %L имеет окончательный компонент, который является размещаемым"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "Переменная производного типа %qs в COMMON в %L не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr "В Fortran 2003 COMMON %qs блок в %L есть глобальный идентификатор и должен поэтому иметь то же связывающее имя, что и одноименный COMMON блок в %L: %s против %s"
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "COMMON блок %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr "Fortran 2008: COMMON блок %qs со связывающей меткой в %L, разделяющий идентификатор с глобальной не-COMMON-блок сущностью в %L"
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "COMMON блок в %L со связывающей меткой %qs использует тот же глобальный идентификатор, что и сущность в %L"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "COMMON блок %qs в %L использован как PARAMETER в %L"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block %qs at %L can not have the EXTERNAL attribute"
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "COMMON блок %qs в %L не может иметь EXTERNAL атрибут"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "COMMON блок %qs в %L является также встроенной процедурой"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "COMMON блок %qs в %L, который является также результатом функции"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "COMMON блок %qs в %L, который является также глобальной процедурой"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr "У параметра KIND %qs в конструкторе PDT в %C отсутствует значение"
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "Ранг элемента в конструкторе структуры в %L не соответствует рангу компонента (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "Элемент в конструкторе структуры в %L для компонента указателя %qs есть %s, но должен быть %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, fuzzy, gcc-internal-format
 #| msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Неравные character длины (%ld/%ld) в %s в %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "NULL в конструкторе структуры в %L применяется к компоненту %qs, который не является ни POINTER ни ALLOCATABLE"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "Несоответствие интерфейса для компонента указателя на процедуру %qs в конструкторе структуры в %L: %s"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %L"
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "Слишком много компонентов в конструкторе структуры в %L"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 #| msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "Ранг элемента в конструкторе структуры в %L не соответствует рангу компонента (%d/%d)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "Элемент в конструкторе структуры в %L для компонента указателя %qs должен быть POINTER или TARGET"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Некорректное выражение в конструкторе структуры для компонента указателя %qs в %L в PURE процедуре"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "Верхняя граница в последнем измерении должна появляться в ссылке на массив предполагаемого размера %qs в %L"
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "%qs в %L неоднозначно"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC процедура %qs не допускается как фактический аргумент в %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Тип специфицированный для встроенной функции %qs в %L игнорируется"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Встроенная подпрограмма %qs в %L не должна иметь спецификатор типа"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%qs декларированная INTRINSIC в %L не существует"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Встроенная %qs декларированная INTRINSIC в %L недоступна в установках текущего стандарта кроме %s. Используйте подходящую %<-std=*%> опцию или включите %<-fall-intrinsics%>, чтобы использовать её."
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Не-RECURSIVE процедура %qs в %L возможно вызывает себя рекурсивно.  Объявите её RECURSIVE или используйте %<-frecursive%>"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Метка %d используемая в %L нигде не определяется"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is used as actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Внутренняя процедура %qs использована как фактический аргумент в %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Оператор функция %qs в %L не допускается в качестве фактического аргумента"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Встроенная %qs в %L не допускается в качестве фактического аргумента"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Внутренняя процедура %qs использована как фактический аргумент в %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL не-INTRINSIC процедура %qs не допускается в качестве фактического аргумента в %L"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Невозможно найти конкретную INTRINSIC процедуру для ссылки %qs в %L"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Символ %qs в %L неоднозначен"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Аргумент по значению в %L нечислового типа"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Аргумент по значению в %L не может быть массивом или секцией массива"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Аргумент по значению в %L не допускается в этом контексте"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Передача внутренней процедуры в %L по расположению не допускается"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Компонент указатель на ELEMENTAL процедуру %qs не допускается в качестве фактического аргумента в %L"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Коиндексированный фактический аргумент в %L с окончательным компонентом указателем"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "%qs в %L есть массив и OPTIONAL; ЕСЛИ ОН ОПУЩЕН, он не может быть фактическим аргументом ELEMENTAL процедуры кроме случая, когда есть обязательный аргумент того же ранга (12.4.1.5)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Фактический аргумент в %L для INTENT(%s) формального параметра %qs ELEMENTAL подпрограммы %qs есть скаляр, но другой фактический аргумент является массивом"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Несоответствие возвращаемого типа функции %qs в %L (%s/%s)"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Несоответствие интерфейса в глобальной процедуре %qs в %L: %s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Нет конкретной функции для generic %qs в %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generic функция %qs в %L несовместима с конкретным встроенным интерфейсом"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Функция %qs в %L есть INTRINSIC, но не является совместимой со встроенной"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Не удается разрешить конкретную функцию %qs в %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип. Может имелось в виду %qs?"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Ссылка на impure функцию %qs в %L внутри FORALL %s"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Ссылка на impure функцию %qs в %L внутри DO CONCURRENT %s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Ссылка на impure функцию %qs в %L внутри PURE процедуры"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after NOWAIT clause at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Неожиданный мусор после NOWAIT клаузулы в %C"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs в %L не есть функция"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs не должна фигурировать в %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Функция %qs декларирована CHARACTER(*) и не может использоваться в %L, поскольку это не формальный аргумент"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): некорректный тип функции"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Определенная пользователем не-ELEMENTAL функция %qs в %L не допускается в WORKSHARE конструкции"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs в %L не может вызываться рекурсивно, поскольку функция %qs не есть RECURSIVE"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Функция %qs в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is deprecated."
 msgid "Using function %qs at %L is deprecated"
 msgstr "внутренняя функция %qF устарела."
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Вызов подпрограммы %qs в FORALL блоке в %L не есть PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Вызов подпрограммы %qs в DO CONCURRENT блоке в %L не есть PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Вызов подпрограммы %qs в %L не есть PURE"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Нет конкретной подпрограммы для generic %qs в %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generic подпрограмма %qs в %L несовместима с интерфейсом встроенной подпрограммы"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Подпрограмма %qs в %L есть INTRINSIC, но несовместима со встроенной"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Не удается разрешить конкретную подпрограмму %qs в %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs в %L имеет тип, который несовместим с CALL в %L"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs в %L не может вызываться рекурсивно, поскольку подпрограмма %qs не есть RECURSIVE"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): некорректный тип функции"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is deprecated."
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "внутренняя функция %qF устарела."
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Формы для операндов в %L и %L не являются подобными"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Некорректная встроенная функция"
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение указатель"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "always_inline function might not be inlinable"
 msgid "Impure function at %L might not be evaluated"
 msgstr "always_inline функция, возможно, не годится для подстановки"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Аргумент по значению в %L не может быть массивом или секцией массива"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Некорректный вид для %s в %L"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Некорректный вид для %s в %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Некорректная встроенная функция"
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в коизмерении %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в коизмерении %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Некорректный нулевой шаг в %L"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Некорректная ссылка на массив"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Самая правая верхняя граница секции массива предполагаемой формы не задана в %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие коиндексных рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Коиндекс коразмерности %d должен быть скаляром в %L"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс массива в %L должен быть скаляром"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс массива в %L должен быть INTEGER типа, найдено %s"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL индекс массива в %L"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент dim в %L должен быть скаляром"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент dim в %L должен быть INTEGER типа"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of array reference at %C"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Некорректная форма ссылки на массив в %C"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): неиспользуемый as(1)"
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): неиспользуемый as(2)"
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс массива в %L является массивом ранга %d"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Начальный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Начальный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Конечный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Конечный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Конечный индекс подстроки в %L слишком велик"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Некорректная ссылка на массив"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь POINTER атрибут в %L"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь ALLOCATABLE атрибут в %L"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Две или больше частичные ссылки с ненулевым рангом не должны быть заданы в %L"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, fuzzy, gcc-internal-format
 #| msgid "expression_rank(): Two array specs"
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "expression_rank(): Две спецификации массива"
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом может использоваться только как фактический аргумент"
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Переменная предполагаемого типа %s в %L может использоваться только как фактический аргумент"
@@ -79089,12 +79114,12 @@ msgstr "Переменная предполагаемого типа %s в %L м
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Переменная предполагаемого типа %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Переменная предполагаемого ранга %s в %L может использоваться только как фактический аргумент"
@@ -79103,296 +79128,296 @@ msgstr "Переменная предполагаемого ранга %s в %L
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Переменная предполагаемого ранга %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Переменная предполагаемого типа %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Переменная предполагаемого ранга %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs, использованная в спецификационном выражении, фигурирует в %L до ENTRY оператора, в котором она является параметром"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs используется в %L до оператора ENTRY, в котором она является параметром"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Полиморфный подобъект коиндексированного объекта в %L"
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Коиндексированный объект с полиморфным размещаемым подкомпонентом в %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 #| msgid "%qs matching variant is deprecated."
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs соответствующий вариант устарел."
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Ошибка в спецификации типа в %L"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Передаваемый объект в %L должен быть скаляром"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова компонента указателя на процедуру в %L имеет ABSTRACT тип %qs'"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова type-bound процедуры в %L имеет ABSTRACT тип %qs"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Базовый объект для вызова NOPASS type-bound процедуры в %L должен быть скаляром"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Не найдено подходящего конкретного связывания для вызова GENERIC %qs в %L"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs в %L должна быть SUBROUTINE"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Некорректный тип выражения"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "'%s' в %L должна быть скаляром"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s в %L должен быть integer"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s в %L должна быть INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Шаговое выражение в DO цикле в %L не может быть нулевым"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO цикл в %L будет выполнен ноль раз"
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO цикл в %L является неопределенным, так как он переполняется"
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO цикл в %L является неопределенным, так как он теряет значимость"
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL стартовое выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL конечное выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL шаговое выражение в %L не может быть нулевым"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL индекс %qs не может появляться в спецификации триплета в %L"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object в %L должен быть ALLOCATABLE или POINTER"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Коиндексированный размещаемый объект в %L"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr в %L должно быть скалярным или иметь тот же ранг, что и allocate-object в %L"
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr в %L и allocate-object в %L должны иметь одинаковую форму"
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Тип сущности в %L есть тип несовместимый с source-expr в %L"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allocate-object в %L и source-expr в %L должны иметь одинаковый вид параметра типа"
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа EVENT_TYPE и не должно иметь EVENT_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Размещение %s ABSTRACT базового типа в %L требует type-spec или source-expr"
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Размещение %s в %L с type-spec требует того же character-length параметра, что и в декларации"
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Спецификация массива или SOURCE= выражение со значением массивом требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Спецификация комассива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация комассива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация массива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs не должно появляться в спецификации массива в %L в том же ALLOCATE операторе где оно само размещается"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Ожидалась '*' в спецификации коиндекса в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable в %L не должна быть %sd в том же %s операторе"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG в %L бесполезно без STAT тега"
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG переменная в %L должна быть стандартной скалярной CHARACTER переменной"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Переменная Errmsg в %L не должна быть %sd в том же операторе %s"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object в %L также появляется в %L"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object в %L есть подобъект объекта в %L"
@@ -79401,287 +79426,287 @@ msgstr "Allocate-object в %L есть подобъект объекта в %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Выражение в CASE операторе в %L должно быть типа %s"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Выражение в CASE операторе в %L должно быть вида %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Выражение в CASE операторе в %L должно быть скаляром"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Выражение выбора в вычисляемом GOTO операторе в %L должно быть скалярным integer выражением"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент SELECT оператора в %L не может быть %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент SELECT оператора в %L не может быть скалярным выражением"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Выражение в CASE операторе в %L не находится в диапазоне %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "За DEFAULT CASE в %L не может следовать второй DEFAULT CASE в %L"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логический диапазон в CASE операторе в %L не допускается"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Константное логическое значение в CASE операторе повторяется в %L"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Спецификации диапазона в %L невозможно найти соответствие"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Логический SELECT CASE блок в %L имеет более двух случаев"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Встроенная функция %qs в %L некорректна в присваивании указателя на процедуру"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs cannot be used as a variable at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Производный тип %qs не может быть использован как переменная в %C"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name %qs at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Селектор в %L не может быть NULL()"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Селектор в %L не имеет типа"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS селектор в %L требует временной переменной, которая пока не реализована"
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Селектор должен быть полиморфным в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Селектор в %L не должен быть коиндексирован"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS в %L перекрывается с TYPE IS в %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Производный тип %qs в %L должен быть расширением %qs"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неожиданный встроенный тип %qs в %L"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Спецификация типа в %L должна специфицировать, что каждый параметр длины типа является предполагаемым"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Двойной CLASS IS блок в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Некорректный контекст для NULL () встроенной в %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s процедура в %L должна быть рекурсивной"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может быть полиморфным, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Элемент передачи данных в %L не может иметь компоненты указатели на процедуру"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь ALLOCATABLE компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Элемент передачи данных в %L не может быть полной ссылкой на массив предполагаемого размера"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Event переменная в %L должна быть скаляром типа EVENT_TYPE"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом или коиндексированным"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом, но не коиндексированным"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG= аргумент в %L должна быть скалярной CHARACTER переменной"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK= аргумент в %L должна быть скалярной LOGICAL переменной"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT= аргумент в %L должен быть скалярным INTEGER выражением"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset аргумент в %L должен быть между 1 и num_images()"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Оператор в %L не есть корректный оператор цели перехода для оператора перехода в %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Переход в %L может вызвать зацикливание"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO оператор в %L покидает CRITICAL конструкцию для метки в %L"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO оператор в %L покидает DO CONCURRENT конструкцию для метки в %L"
@@ -79689,214 +79714,214 @@ msgstr "GOTO оператор в %L покидает DO CONCURRENT констр
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Метка в %L не находится в том же блоке, что GOTO оператор в %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE маска в %L имеет противоречивую форму"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE цель присваивания в %L имеет противоречивую форму"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL определенное пользователем присваивание в WHERE в %L"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподдерживаемый оператор внутри WHERE в %L"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Присваивание FORALL индексной переменной в %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL с индексом %qs не используется в левой части присваивания в %L и поэтому может вызвать множественное присваивание этому объекту"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "BLOCK конструкция в %C"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL имя индекса в %L должно быть скалярной переменной типа integer"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Внешняя FORALL конструкция уже имеет индекс с этим именем %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE клаузула в %L требует LOGICAL массив"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Некорректный тип блока"
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER выражение будет усечено в присваивании (%ld/%ld) в %L"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Коиндексированное выражение в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Присваивание коиндексированной переменной в %L в PURE процедуре"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Присваивание полиморфному комассиву в %L не допускается"
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Присваивание размещаемой полиморфной переменной в %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Присваивание размещаемой полиморфной переменной в %L требует %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, fuzzy, gcc-internal-format
 #| msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "Неразмещаемая переменная не должна быть полиморфной во встроенном присваивании в %L - проверьте, что имеется соответствующая конкретная подпрограмма для '=' оператора"
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Коиндексированная переменная не должна иметь размещаемых окончательных компонентов в присваивании в %L"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: type-bound определенные присваивания в %L не выполнены, так как несколько ссылок на части массива появятся в промежуточных выражениях."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Присваивание указателя на процедуру в %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Результат функции в левой части присваивания в %L должен иметь pointer атрибут."
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Аргумент SELECT оператора в %L не может быть скалярным выражением"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO оператор в %L требует INTEGER переменной"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Переменной %qs не присвоили целевую метку в %L"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternate RETURN оператор в %L требует SCALAR-INTEGER спецификатор возврата"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Ожидалось инициализационное выражение в CASE в %C"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN оператор в %L требует скалярную подразумеваемого INTEGER переменную"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Некорректный NULL в %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Оператор арифметического IF в %L требует скалярное REAL или INTEGER выражение"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Нет выражения в DO WHILE"
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Условие выхода из DO WHILE цикла в %L должно быть скалярным LOGICAL выражением"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL клаузула маски в %L требует скалярное LOGICAL выражение"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Некорректный код оператора"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %qs declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Неиспользуемый параметр %qs декларирован в %L"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Переменная %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Переменная %qs из модуля %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L из модуля %qs"
@@ -79904,995 +79929,995 @@ msgstr "Переменная %qs из модуля %qs со связывающе
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Процедура %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Длина строки в %L слишком велика"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Размещаемый массив %qs в %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скалярный объект %qs в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Указатель на массив %qs at %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Массив %qs at %L не может иметь отложенную форму"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Тип %qs CLASS переменной %qs at %L не является расширяемым"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS переменная %qs в %L должна быть формальным параметром, размещаемой или указателем"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %qs не может быть host ассоциированным в %L, поскольку он блокирован несовместимым объектом с тем же именем декларированным в %L"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Выведенный SAVE для переменной модуля %qs в %L необходим из-за подразумеваемой инициализации"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Сущность %qs в %L имеет параметр отложенного типа и требует либо POINTER либо ALLOCATABLE атрибут"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Массив из модуля или главной программы %qs в %L должен иметь константную форму"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Сущность с предполагаемой character длиной в %L должна быть формальным аргументом или PARAMETER"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs в %L должна иметь константную character длину в этом контексте"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON переменная %qs в %L должна иметь константную character длину"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Размещаемая %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Формальный параметр %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Встроенная %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Результат функции %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Автоматический массив %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s в %L"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Оператор функция с character значением %qs в %L должна иметь константную длину"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs имеет PRIVATE тип и не может быть формальным аргументом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Процедура %qs в PUBLIC интерфейсе %qs в %L берет формальные аргументы %qs, который PRIVATE"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Функция %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Внешний объект %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL функция %qs в %L должна иметь скалярный результат"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Оператор функция %qs в %L не может иметь pointer или allocatable атрибут"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение массив"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение указатель"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) функция %qs в %L не может быть pure"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) функция %qs в %L не может быть рекурсивной"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) функция %qs в %L"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Указатель на процедуру %qs в %L не должен быть элементным"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Формальная процедура %qs в %L не должна быть элементной"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Переменная результата функции %s в %L элементной функции %qs не должна иметь атрибут ALLOCATABLE или POINTER"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с SAVE атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с INTENT атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с RESULT атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL атрибут конфликтует с FUNCTION атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Результат указатель на процедуру %qs в %L оказался без pointer атрибута"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в ELEMENTAL атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в PURE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в RECURSIVE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s между MODULE PROCEDURE декларацией в MODULE %qs и декларацией в %L в (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 #| msgid "Interface %qs at %L must be explicit"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Интерфейс %qs в %L должен быть явным"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL процедура %qs в %L не есть SUBROUTINE"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL процедура в %L должна иметь ровно один аргумент"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент FINAL процедуры в %L должен быть типа %qs"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент FINAL процедуры в %L не должен быть POINTER"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент FINAL процедуры в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент FINAL процедуры в %L не должен быть OPTIONAL"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Аргумент FINAL процедуры в %L не должен быть INTENT(OUT)"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Нескалярная FINAL процедура в %L должна иметь аргумент предполагаемой формы"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL процедура %qs декларированная в %L имеет тот же ранг (%d), что и %qs"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Только массивные FINAL процедуры декларированные для производного типа %qs определенного в %L, предлагают также скалярный тип"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs и %qs не могут быть смешанными FUNCTION/SUBROUTINE для GENERIC %qs в %L"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs и %qs для GENERIC %qs в %L неоднозначны"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Неопределенное конкретное связывание %qs как цели GENERIC %qs в %L"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs в %L должен нацеливаться на конкретное связывание, %qs также GENERIC"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs в %L не может перебить конкретное связывание с тем же именем"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound оператор в %L не может быть NOPASS"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs должна быть процедурой модуля или внешней процедурой с явным интерфейсом в %L"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Процедура %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура %qs с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Неполиморфный passed-object формальный аргумент %qs в %L"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object формальный аргумент %qs в %L должен быть скаляром"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть POINTER"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и компонент %qs"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и унаследованный компонент %qs"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Производный тип %qs декларированный в %L должен быть ABSTRACT, поскольку %qs есть DEFERRED и не перебивается"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Комассивный компонент %qs в %L должен быть размещаемым с отложенной формой"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Компонент %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должен быть комассивом"
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Компонент %qs в %L с комассивным компонентом должен быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Компонент %qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Компонент %qs типа BIND(C) в %L должен иметь единичную длину"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Компонент указателя на процедуру %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Компонент указателя на процедуру %qs с PASS в %L должен иметь по крайней мере один аргумент"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть скаляром"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может иметь POINTER атрибут"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Компонент %qs от %qs в %L имеет то же имя, что и унаследованная type-bound процедура"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Character длина компонента %qs должна быть константным спецификационным выражением в %L"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Выражение в %L должно быть INTEGER типа, найдено %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Character компонент %qs от %qs в %L с отложенной длиной должен быть POINTER или ALLOCATABLE"
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "компонент %qs имеет PRIVATE тип и не может быть компонентом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Полиморфный компонент %s в %L в SEQUENCE или BIND(C) типе %s"
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонент %s SEQUENCE типа декларированный в %L не имеет SEQUENCE атрибут"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Конфликтующие инициализаторы в объединении в %L и %L"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Поскольку расширяющий тип %qs в %L имеет комассивный компонент, родительский тип %qs должен также иметь его"
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Нерасширяемый производный тип %qs в %L не должен быть ABSTRACT"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Generic имя %qs функции %qs в %L то же, что и имя производного типа в %L"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Массив предполагаемого размера %qs в списке имен %qs в %L не допускается"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с предполагаемой формой в списке имен %qs в %L"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с неконстантной формой в списке имен %qs в %L"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST объект %qs с неконстантной character длиной в списке имен %qs в %L"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs был декларирован PRIVATE и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет use-associated PRIVATE компоненты и не может быть членом списка имен %qs в %L"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter массив %qs at %L не может быть автоматическим или отложенной формы"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Неявно типизированный PARAMETER %qs в %L не соответствует более позднему IMPLICIT типу"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несовместимый производный тип в PARAMETER в %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS переменная %qs в %L не может иметь PARAMETER атрибут"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Простите, размещаемые/указательные компоненты в комассивах полиморфных (CLASS) типов в %L не поддерживаются"
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROTECTED атрибут конфликтует с EXTERNAL атрибутом в %L"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE атрибут конфликтует с PROTECTED атрибутом в %L"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив или массивом предполагаемой формы или предполагаемого ранга"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Массив предполагаемого размера в %L должен быть формальным аргументом"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Массив предполагаемого ранга в %L не может иметь VALUE или CODIMENSION атрибут"
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ в %L не является DUMMY переменной"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs в %L не может иметь VALUE атрибут, поскольку он не является формальным аргументом"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Character формальная переменная %qs в %L с VALUE атрибутом должна иметь константную длину"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C совместимая character формальная переменная %qs в %L с VALUE атрибутом должна иметь длину один"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Производный тип %qs в %L имеет тип %qs, который не был определен"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутов должна быть формальным аргументом"
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть типа TYPE(*) или числового встроенного типа"
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть или скаляром или массивом предполагаемого размера"
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Предполагаемый тип переменной %s в %L разрешен только для формальных переменных"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Переменная предполагаемого типа %s в %L не должна быть массивом явной формы"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Переменная %qs at %L не может быть BIND(C), поскольку она не COMMON блок и не декларирована на уровне модуля"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs в %L PRIVATE производного типа %qs"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) формальный аргумент %qs в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа EVENT_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Результат функции %qs в %L не должен быть комассивом или иметь комассивный компонент"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Переменная %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Переменная %qs в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром, который не есть комассив"
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Переменная %qs в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Комассивная переменная %qs в %L не должна иметь коизмерения с отложенной формой"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Размещаемая комассивная переменная %qs в %L должна иметь отложенную форму"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Переменная %qs в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная %qs в %L не допускается в BIND(C) процедуре %qs"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL формальная переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL результирующая переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Список имен %qs не может быть аргументом для подпрограммы или функции в %L"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не является SAVEd"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET переменная %qs в %L не есть SAVEd"
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Ожидается список именованных сущностей в %C"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA элемент %qs в %L должен быть в COMMON"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA массив %qs в %L должен быть указан в предыдущей декларации"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA элемент %qs в %L не может иметь коиндекс"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA элемент %qs в %L является указателем и поэтому должен быть полным массивом"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 #| msgid "Argument %qs of elemental procedure at %L cannot have the ALLOCATABLE attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Аргумент %qs элементной процедуры в %L не может иметь ALLOCATABLE атрибут"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA оператор в %L имеет больше переменных чем значений"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "начало implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "окончание implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA оператор в %L имеет больше значений чем переменных"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Метка %d в %L определена, но не используется"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Метка %d в %L определена, но не может быть использована"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L должна иметь SEQUENCE атрибут, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L не может иметь ALLOCATABLE компоненты, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Переменная производного типа %qs в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L с указательным(и) компонент(ами) не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксическая ошибка в EQUIVALENCE операторе в %L"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Все или никакие объекты в EQUIVALENCE установленной в %L должны иметь PROTECTED атрибут"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именованная константа %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Массив %qs at %L с неконстантными границами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонент структуры %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подстрока в %L имеет нулевую длину"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC функция %qs в %L PRIVATE типа %qs"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура пользовательского оператора %qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура пользовательского оператора %qs в %L не может быть предполагаемой character длиной"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура пользовательского оператора %qs в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Первый аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Второй аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Интерфейс оператора в %L должен иметь не более двух аргументов"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Внутренняя процедура %qs в %L PURE процедуры должна также быть PURE"
@@ -81800,7 +81825,7 @@ msgstr "Перекрывающиеся неравные инициализато
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Перекрывающиеся неравные инициализаторы в EQUIVALENCE в %C"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -81812,12 +81837,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Создание временного массива в %L для аргумента %qs"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Некорректный тип выражения при проходе (%d)"
@@ -81911,83 +81936,89 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Symbol %qs at %C has no IMPLICIT type"
+msgid "%s at %C has no default type"
+msgstr "Символ %qs в %C не имеет IMPLICIT тип"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "встроенная переменная, которая не является процедурой"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Возвращаемое значение функции %qs в %L не установлено"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Параметр отложенного типа пока не поддерживается"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "backend декларация для переменной модуля %qs уже существует"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Неиспользуемая PRIVATE переменная модуля %qs декларирована в %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "%qs в %L не может иметь VALUE атрибут, поскольку он не является формальным аргументом"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "Компонент %qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Формальный аргумент %qs в %L был декларирован INTENT(OUT), но не был установлен"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Формальный аргумент производного типа %qs в %L был декларирован INTENT(OUT), но не был установлен и не имеет подразумеваемого инициализатора"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Неиспользуемый формальный аргумент %qs в %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Неиспользуемая переменная модуля %qs, которая была явно импортирована в %L"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Неиспользуемая переменная %qs декларирована в %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Неиспользуемый параметр %qs декларирован в %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Неиспользуемый параметр %qs, который был явно импортирован в %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Возвращаемое значение %qs функции %qs декларированное в %L не установлено"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Извините, !$ACC DECLARE в %L не допускается в конструкции BLOCK"
@@ -82003,27 +82034,27 @@ msgstr "Не могу вычислить длину char массива в %L."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Код для переразмещения размещаемой переменной в %L будет добавлен"
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному объекту в %L не поддерживается"
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному компоненту в %L не поддерживается"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Неизвестная встроенная операция"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Неизвестная функция списка аргументов в %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -84024,6 +84055,9 @@ msgstr "неиспользуемый параметр %qD"
 #~ msgid "PIC register isn't set up"
 #~ msgstr "PIC-регистр не установлен"
 
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "недопустимый размер операнда для кода 'Z'"
+
 #~ msgid "__float128 and __ibm128 cannot be used in the same expression"
 #~ msgstr "__float128 и __ibm128 нельзя использовать в одном выражении"
 
diff --git a/gcc/po/sr.po b/gcc/po/sr.po
index 4b4c5ada2fc..3edf2f7d9ba 100644
--- a/gcc/po/sr.po
+++ b/gcc/po/sr.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -4459,7 +4459,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -8459,6 +8459,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Подржи уграђене ММИкс и ССЕ функције и стварање кôда"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy, no-c-format
 #| msgid "Assume code will be linked by GNU ld"
@@ -19091,12 +19097,12 @@ msgstr "операнд уз ‘%%l’ није етикета"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "лоша употреба реалне константе"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -20310,66 +20316,66 @@ msgstr "Овом прекидачу недостаје документациј
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr ""
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr ""
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, fuzzy, c-format
 #| msgid " bytes"
 msgid "%llu bytes"
 msgstr " бајтова"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr ""
 
-#: opts.cc:1812
+#: opts.cc:1813
 #, fuzzy
 #| msgid "GCSE disabled"
 msgid "[disabled]"
 msgstr "ГЦСЕ искључен"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "no arguments for spec function"
 msgid ""
@@ -20377,67 +20383,67 @@ msgid ""
 "   "
 msgstr "нема аргумената за функцију навода"
 
-#: opts.cc:1958
+#: opts.cc:1959
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are target specific"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1961
+#: opts.cc:1962
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options control compiler warning messages"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1964
+#: opts.cc:1965
 #, fuzzy
 #| msgid "Do the full register move optimization pass"
 msgid "The following options control optimizations"
 msgstr "Изврши потпуни пролаз оптимизације померањем регистара"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-independent"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options control parameters"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1976
+#: opts.cc:1977
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are specific to just the language "
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1978
+#: opts.cc:1979
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are supported by the language "
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1989
+#: opts.cc:1990
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are not documented"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1991
+#: opts.cc:1992
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take separate arguments"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:1993
+#: opts.cc:1994
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take joined arguments"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.cc:2005
+#: opts.cc:2006
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-related"
@@ -20848,80 +20854,80 @@ msgstr "модификатор дужине у формату strfmon"
 msgid "<command-line>"
 msgstr "<командна-линија>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "недостаје операнд"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "неисправна ија:"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "неисправан %%d операнд"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "неисправна адреса"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -20938,18 +20944,18 @@ msgid "invalid %%r value"
 msgstr "неисправна %%r вредност"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "неисправна %%R вредност"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
@@ -20979,7 +20985,7 @@ msgstr "неисправна %%M вредност"
 msgid "invalid %%U value"
 msgstr "неисправна %%U вредност"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
@@ -20989,7 +20995,7 @@ msgstr "неисправна %%s вредност"
 msgid "invalid %%C value"
 msgstr "неисправна %%C вредност"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
@@ -21002,7 +21008,7 @@ msgstr "непознато unspec релокације"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "неисправан %%xn кôд"
@@ -21092,36 +21098,36 @@ msgstr "неисправан УНСПЕЦ као операнд"
 msgid "unrecognized supposed constant"
 msgstr "непрепозната претпостављена константа"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "неисправан операнд помака"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикатна инструкција Тамба"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикатна инструкција у условном редоследу"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -21130,31 +21136,31 @@ msgstr "неисправан операнд за кôд ‘%c’"
 msgid "invalid operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "инструкција се никад не извршава"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -21538,112 +21544,112 @@ msgstr "неисправна ија:"
 msgid "Expected register or constant integer."
 msgstr "акумулатор није целобројна константа"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "неисправна употреба %<restrict%>"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "неисправна ограничења за операнд"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "непознат режим ије"
 
@@ -21675,7 +21681,7 @@ msgstr "неисправна операција на %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неисправан %%P операнд"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -21725,8 +21731,8 @@ msgstr "‘%s’ није исправно име класе"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -21759,7 +21765,7 @@ msgid "post-increment address is not a register"
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -21932,7 +21938,7 @@ msgstr "неподржана комбинација: %s"
 msgid "unsupported memory expression:"
 msgstr "очекиван је целобројни израз"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid vector operand"
@@ -21993,159 +21999,159 @@ msgstr ""
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "неисправна %%D вредност"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -22652,7 +22658,7 @@ msgstr "кандидат 1:"
 msgid "  after user-defined conversion:"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -23197,7 +23203,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Погон:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -23363,11 +23369,11 @@ msgstr "блоковско IF"
 msgid "implied END DO"
 msgstr "имплицитно END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "додела"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "додела показивача"
 
@@ -23375,250 +23381,250 @@ msgstr "додела показивача"
 msgid "simple IF"
 msgstr "једноставно IF"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 #, fuzzy
 #| msgid "elemental subroutine"
 msgid "elemental procedure"
 msgstr "елементални потпрограм"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "додела показивача"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Операнд унарног бројевног оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди бинарног бројевног оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнди оператора надовезивања ниски код %%L су %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди логичког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Операнд оператора .NOT. код %%L је %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Комплексне величине се не могу поредити код %L"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логичке код %%L морају бити поређене са %s уместо %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди оператора поређења ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr ""
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Операнд корисничког оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди корисничког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Изврши праћење променљивих"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "неисправан израз као операнд"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -23631,27 +23637,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 #, fuzzy
 #| msgid "assignment of read-only location"
 msgid "Assignment of scalar to unallocated array"
@@ -24685,7 +24691,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
@@ -25107,7 +25113,7 @@ msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -25212,10 +25218,10 @@ msgstr "атрибути типа игноришу се пошто је тип 
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -25366,7 +25372,7 @@ msgstr "не могу да нађем датотеку за класу %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "померај ван граница константне ниске"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -27352,7 +27358,7 @@ msgstr "велики целобројни имплицитно подсечен
 msgid "comparison is always %d due to width of bit-field"
 msgstr "поређење је увек %d услед ширине битског поља"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
@@ -28205,7 +28211,7 @@ msgstr "функција враћа адресу на локалну проме
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -29375,14 +29381,14 @@ msgstr "претпостављам показивач на члан %qD"
 msgid "using a dangling pointer to %qD"
 msgstr "неисправан режим показивача %qs"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -29430,7 +29436,7 @@ msgstr ""
 msgid "call to %qD"
 msgstr "  у позиву %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -30589,7 +30595,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid jump function in LTO stream"
@@ -31614,7 +31620,7 @@ msgstr "Изврши оптимизацију за укрштање скоков
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "опција командне линије %qs није подржана овом конфигурацијом"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
@@ -31660,13 +31666,13 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s"
@@ -31837,7 +31843,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "-fno-gnu89-inline is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -31880,198 +31886,198 @@ msgstr "праћење променљивих затражено, али бес
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "праћење променљивих затражено, али неподржано овим исправљачким фоматом"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition не ради на овој архитектури"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition не ради на овој архитектури"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition не ради на овој архитектури"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "атрибутска директива %qs игнорисана"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr ""
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr ""
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "равнање структуре мора бити мали степен двојке, не %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown stack check parameter %qs"
 msgstr "непознат машински режим %qs"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "циљни систем не подржава исправљачки излаз"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "исправљачки формат „%s“ коси се са претходним избором"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "непрепознат ниво исправљачког излаза „%s“"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "ниво исправљачког излаза %s је превисок"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized btf debug output level %qs"
 msgstr "непрепознат ниво исправљачког излаза „%s“"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "добављам ограничење највеће величине датотеке језгра: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "постављам ограничење највеће величине датотеке језгра: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "непрепозната исправљачка опција: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: No option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: нема опције -%s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -32799,199 +32805,199 @@ msgstr "генерички кôд смрза не пролази за метод
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D преименован пошто је поменут у асемблеру"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "function symbol is not function"
 msgstr "функција враћа функцију"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "node has invalid order %i"
 msgstr "complex неисправно за %qs"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "чвор није нађен у cgraph_hash"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "позвани објекат %qE није функција"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%Jстаровремска дефиниција функције"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr ""
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "Set the default symbol visibility"
 msgid "symver is not exported with default visibility"
 msgstr "Постави подразумевану видљивост симбола"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "имплицитна декларација функције %qE"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa није успело"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "неисправан режим показивача %qs"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has function type"
 msgid "variable %q+D part of alias cycle"
 msgstr "променљива %qD има функцијски тип"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -34834,27 +34840,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -35737,7 +35743,7 @@ msgstr "атрибут %qE се игнорише јер је %qT већ дефи
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "атрибут %qE се игнорише јер је %qT већ дефинисан"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "атрибут %qE има утицаја само у јавним објектима"
@@ -38035,7 +38041,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "традиционални Ц одбија надовезивање константних ниски"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -39892,7 +39898,7 @@ msgstr "превише улазних датотека"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -39926,16 +39932,16 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -40028,55 +40034,55 @@ msgstr "%qs није исправно за %qs"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops is obsolete, use -falign-loops"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops је застарело, користите -falign-loops"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malign-jumps је застарело, користите -falign-jumps"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions is obsolete, use -falign-functions"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions је застарело, користите -falign-functions"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d није између 0 и 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -40596,14 +40602,14 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -40876,7 +40882,7 @@ msgstr "прослеђивање аргумента %d од %qE прави це
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %qD"
 msgid "duplicate definition of %qs"
@@ -40924,7 +40930,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "тип %q+D нема познату величину"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -41019,344 +41025,344 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code for the counting ISA extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Емитуј кôд за бројачко ИСА проширење"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "атрибут %qs се игнорише"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid format for %<sve_width%>"
 msgstr "неисправна операција на %<__fpreg%>"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%H value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "неисправна %%H вредност"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "непозната функција навода ‘%s’"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length"
 msgstr "Одредите редослед резервисања регистара"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-march%>"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "прекидач -mcpu=%s коси се са -march="
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s не подржава %s"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "лоше формирано %<#pragma init%>"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "неподржана комбинација: %s"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -41561,13 +41567,13 @@ msgstr "аргумент атрибута %qs није „ilink1“ или „il
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -41723,17 +41729,17 @@ msgstr "атрибут %qE се игнорише"
 msgid "%qE attribute only applies to variables"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for %<asm%> flag output"
@@ -41956,7 +41962,7 @@ msgstr "циљни ЦПУ не подржава инструкције Тамб
 msgid "target CPU does not support unaligned accesses"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -42019,7 +42025,7 @@ msgstr "граница величине структура може бити п
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -42134,7 +42140,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -42188,34 +42194,34 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "не могу да срачунам стварну локацију параметра на стеку"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Неочекиван крај модула"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нема доступних ниских регистара за подизање високих регистара"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -42224,24 +42230,24 @@ msgstr "неисправан тип вектора за атрибут %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "непознато име регистра: %s"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -42327,19 +42333,19 @@ msgstr "-pipe није подржано"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe није подржано"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G и -static су међусобно искључиви"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -42695,7 +42701,7 @@ msgstr "неисправан аргумент за уграђену функци
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument to built-in function"
@@ -43363,743 +43369,743 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "Атрибут SEQUENCE код %C је већ наведен у наредби TYPE"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "превише аргумената за функцију %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "име регистра није наведено за %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "равнање се не може навести за %q+D"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= није подржано на 32-битним системима"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битни режим није укомпилован"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ЦПУ који сте изабрали не подржава скуп инструкција икс86-64"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d није између 0 и %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 #| msgid "-mrtd calling convention not supported in the 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "конвенција позивања -mrtd није подржана у 64-битном режиму"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "скуп ССЕ инструкција искључен, користим 387 аритметику"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "скуп 387 инструкција искључен, користим ССЕ аритметику"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "игноришем непознату опцију %q.*s у %<-fdump-%s%>"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-fstack-protector није подржано за овај циљ"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qT са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "не подржава вишебиб"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "ССЕ векторски аргумент без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "ССЕ векторско враћање без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "ССЕ враћање регистра уз искључене ССЕ"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "ССЕ регистарски аргумент уз искључене ССЕ"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "враћање из регистра x87 када је x87 искључено"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr ""
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
@@ -44107,80 +44113,80 @@ msgstr "%s није подржано за угњеждене функције"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 #| msgid "%s functions limited to %d register parameters"
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "%s функције ограничене на %d регистарских параметара"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "проширени регистри немају високе половине"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "модела кôда %<large%> још увек није подржан"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "unsupported argument type %qT for simd"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -44566,7 +44572,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -45786,59 +45792,59 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "type %q+D does not have a known size"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "тип %q+D нема познату величину"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "type %q+D does not have a known size"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "тип %q+D нема познату величину"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not of type %qT"
 msgid "fields cannot have RVV type %qT"
 msgstr "%qE није типа %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "не може се резервисати објекат апстрактног типа %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "не може се резервисати објекат апстрактног типа %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -45858,71 +45864,76 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "аргумент атрибута %qs није „ilink1“ или „ilink2“"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -46433,106 +46444,106 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "неисправан апстрактни тип %qT за %qE"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not initialized"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%qE није успостављено"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -48067,7 +48078,7 @@ msgstr "не могу да ставим објекат са непостојан
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неуспостављена константа %qD"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -48272,7 +48283,7 @@ msgstr "складишна класа наведена за параметар %
 msgid "storage class specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "складишна класа наведена за име типа"
@@ -48469,7 +48480,7 @@ msgstr "%qs декларисано као функција која враћа 
 msgid "function definition has qualified void return type"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
@@ -48613,7 +48624,7 @@ msgstr "ИСО Ц забрањује константне или непосто
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "члан структуре или уније не може имати променљиво измењив тип"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "променљива или поље %qE декларисано празним"
@@ -48832,7 +48843,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr "непознато поље %qE наведено у успостављачу"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларација ништа не декларише"
@@ -48884,7 +48895,7 @@ msgstr "структура нема именованих чланова"
 msgid "struct has no members"
 msgstr "структура нема чланова"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -48933,7 +48944,7 @@ msgstr "поновљена декларација %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -48984,7 +48995,7 @@ msgstr "ИСО Ц ограничава вредности набрајача н
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -49018,7 +49029,7 @@ msgstr "нема претходног прототипа за %q+D"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -49148,12 +49159,12 @@ msgstr "аргумент %qD не одговара уграђеном прото
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не одговара прототипу"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -51372,7 +51383,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
@@ -51513,13 +51524,13 @@ msgstr "очекивано је %<{%>"
 msgid "variant %qD is not a function"
 msgstr "%q+D није функција,"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -51798,7 +51809,7 @@ msgstr "неисправна употреба израза празног тип
 msgid "invalid use of flexible array member"
 msgstr "неисправна употреба флексибилног чланског низа"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "неисправна употреба низа са ненаведеним границама"
@@ -52846,12 +52857,12 @@ msgstr "успостављач за целобројну вредност је 
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "успостављање флексибилног чланског низа"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -52893,7 +52904,7 @@ msgstr "елемент успостављача се не може израчу
 msgid "invalid initializer"
 msgstr "неисправан успостављач"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозирни векторски типови не могу бити успостављени"
@@ -52908,8 +52919,8 @@ msgstr "сувишна група витичастих заграда на кр
 msgid "braces around scalar initializer"
 msgstr "витичасте заграде око скаларног успостављача"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "успостављање флексибилног чланског низа у угњежденом контексту"
@@ -53002,7 +53013,7 @@ msgstr "сувишни елементи у успостављачу структ
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "нестатичко успостављање флексибилног чланског низа"
@@ -54488,7 +54499,7 @@ msgstr "нема погодног %<operator %s%> за %qT"
 msgid "%q#D is private within this context"
 msgstr "у овом контексту"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
@@ -54500,7 +54511,7 @@ msgstr "%q+D декларисано овде"
 msgid "%q#D is protected within this context"
 msgstr "у овом контексту"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
@@ -54517,7 +54528,7 @@ msgstr "%q+#D није приступно"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "прослеђивање NULL непоказивачком аргументу %P од %qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -54891,7 +54902,7 @@ msgstr "нема одговарајуће функције за позив %<%T:
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -55530,7 +55541,7 @@ msgstr "%Jфлексибилан члански низ у иначе празн
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
@@ -55660,7 +55671,7 @@ msgstr "неисправан апстрактни повратни тип за 
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -55733,7 +55744,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -55785,7 +55796,7 @@ msgstr "%qT је двосмислена основа за %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -55924,7 +55935,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "разрешавање %<void *%> показивача"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -56029,7 +56040,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -56118,7 +56129,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
@@ -56188,210 +56199,210 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "Празан конструктор низа код %C није дозвољен"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "contract predicate is false in constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "очекиван је израз"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -57035,7 +57046,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "no member named %qE in %qT"
@@ -57142,7 +57153,7 @@ msgstr "трећи аргумент за %<__builtin_prefetch%> мора бит
 msgid "no suspend point info for %qD"
 msgstr "нема претходног прототипа за %q+D"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -57164,23 +57175,23 @@ msgstr "показивачи нису дозвољени као вредност
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -57727,7 +57738,7 @@ msgstr "од претходне декларације %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Декларација %qs заклања претходну декларацију етикете"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -58188,666 +58199,666 @@ msgstr "%qD није шаблон функције"
 msgid "%q#T is not a class"
 msgstr "%q#T није класа"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "нема шаблона класе по имену %q#T у %q#T"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именује %q#T, што није шаблон класе"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> именује %q#T, што није тип"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "захтевано равнање није степен двојке"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "анонимна структура није унутар именованог типа"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са конструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са деструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у анонимној скупини"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут за %q+#T мора пратити кључну реч %qs"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "вишеструки типови у једној декларацији"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "недостаје име типа у наредби typedef"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ИСО Ц++ забрањује анонимне структуре"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> може бити наведено само унутар класе"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> може бити наведено само за конструкторе"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ИСО Ц++ не дозвољава да %<%T::%D%> буде дефинисано као %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "удвостручено успостављање %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "променљива %q#D има успостављач али је непотпуног типа"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "скупина %q#D има непотпун тип и не може се дефинисати"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD декларисано као упућивач али није успостављено"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривијални утврђени успостављачи нису подржани"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  можете ово заобићи уклањањем успостављача"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неуспостављена константа %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%Jнеуспостављени члан %qD са %<const%> типом %qT"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "неисправан тип %qT као успостављач за вектор типа %qT"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "неисправан успостављач"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "превише успостављача за %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ИСО Ц 90 забрањује сложене дословне ниске"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "скаларни објекат %qD захтева један елемент у успостављачу"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD мора бити успостављен конструктором, не помоћу %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "низ %qD успостављен заграђеном константном ниском %qE"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "успостављач неисправан за статички члан са конструктором"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(потребно је успостављање изван класе)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "параметар %qD је успостављен"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "could not find variant declaration"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: рекурзивно позивање конструктора %qs"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "поновљена декларација набрајача %q+D"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "заклањање претходне декларације типа за %q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функција %q#D успостављена као променљива"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  не може се користити застарело везивање код %q+D јер има деструктор"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT је неприступачна основа за %qT"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare variable %q+D to be of abstract type %qT"
 msgid "cannot decompose variable length array %qT"
 msgstr "не може се декларисати променљива %q+D апстрактног типа %qT"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -58857,7 +58868,7 @@ msgstr[1] "успостављач дат за функцију"
 msgstr[2] "успостављач дат за функцију"
 msgstr[3] "успостављач дат за функцију"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -58866,7 +58877,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -58875,1825 +58886,1825 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "не могу да разложим адресу"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "не могу применити %<offsetof%> на статички члански податак %qD"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларисано са одредницом изузетака"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "дефиниција %qD није у именском простору који обухвата %qT"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статичка чланска функција %q#D декларисана са одредбама типа"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "јавански метод %qD има не-јавански повратни тип %qT"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD није шаблонска функција"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "дефиниција експлицитне специјализације %qD у декларацији пријатеља"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "неисправна употреба ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> није дозвољено у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "неисправан аргумент опције %qs"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> мора враћати %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "чланска функција %q#D није декларисана у класи %qT"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "strong using only meaningful at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "јако using има смисла само у досегу именског простора"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ИСО Ц++ забрањује успостављање чланске константе %qD неинтегралног типа %qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ИСО Ц++ забрањује низ променљиве величине %qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ИСО Ц++ забрањује низ променљиве величине"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "преливање у димензији низа"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD не декларише шаблонски тип"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "декларација %qs као низа празних"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "вишедимензиони низ мора имати границе за све димензије осим прве"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "навод повратног типа за конструктор није исправан"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "наведен повратни тип за %<operator %T%>"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "неименована променљива или поље декларисано празним"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "неисправна употреба одређеног имена %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "неисправна употреба одређеног имена %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "неисправна употреба одређеног имена %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "декларација %qD као не-члана"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "недостаје ид. декларатора; користи се резервисана реч %qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "дефиниција функције не декларише параметре"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларација %qD као %s"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "није наведена ниједна класа"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или више типова података у декларацији %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ИСО Ц++ забрањује декларацију %qs без типа"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs није подржано овим циљем"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> и %<unsigned%> наведени заједно за %qs"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> и %<short%> наведени заједно за %qs"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qD"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex неисправно за %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "декларација %qs на највишем нивоу наводи %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs досега функције имплицитно аутоматска и декларасина као %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама пријатељских функција"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Очекивана је лева заграда"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неисправна употреба %<restrict%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функција са %<noreturn%> враћа непразну вредност"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не може се дефинисати пријатељска функција %qs у дефиницији локалне класе"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не могу имати параметре"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ид. шаблона %qD употребљен као декларатор"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "чланске функције су имплицитно пријатељи својих класа"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "сувишна одредба %<%T::%> на члану %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "не може се дефинисати чланска функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "не може се декларисати функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не може се декларисати члан %<%T::%s%> унутар %qT"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "члански податак не може имати променљиво измењив тип %qT"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "константно %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a member function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ИСО Ц++ забрањује угњеждени тип %qD истог имена као и обухватајућа класа"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> наведено уз декларацију пријатељске класе"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "покушај да се класа %qT учини пријатељем глобалног досега"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "неисправне одредбе уз тип не-чланске функције"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "апстрактни декларатор %qT употребљен као декларација"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "не може се декларисати параметар %q+D апстрактног типа %qT"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "декларација Ц функције %q#D коси се са"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функција %qD декларисана виртуелном унутар уније"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не може бити декларисана виртуелном, јер је увек статичка"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "не могу да отворим %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поље %qD има непотпун тип"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "складишна класа %<auto%> неисправна за функцију %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "складишна класа %<register%> неисправна за функцију %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> неисправно наведено за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуелна не-класна функција %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in class %qs"
 msgid "%qs defined in a non-class scope"
 msgstr "Променљива %qs није дефинисана у класи %qs"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не може се декларисати статичка повезивост за чланску функцију %qD"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не може се декларисати статичка функција унутар друге функције"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бити употребљено при дефинисању (насупрот декларисања) статичког чланског податка"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не може се експлицитно декларисати спољашња повезивост за члан %q#D"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неисправан конструктор; вероватно сте мислили %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бити декларисано статичко"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD мора бити или нестатичка чланска функција или не-чланска функција"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD мора имати аргумент класног или набројивог типа"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ИСО Ц++ забрањује препуњавање оператора ?:"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD мора узимати ниједан или један аргумент"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD мора узимати један или два аргумента"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфиксно %qD мора узимати %<int%> као аргумент"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфиксно %qD мора узимати %<int%> као други аргумент"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD мора узимати тачно један аргумент"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксно %qD треба да враћа %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксно %qD треба да враћа %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD треба да враћа по вредност"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "употреба typedef-имена %qD после %qs"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D има претходну декларацију овде"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT се помиње као %qs"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T има претходну декларацију овде"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT се помиње као набрајање"
@@ -60705,115 +60716,115 @@ msgstr "%qT се помиње као набрајање"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "class template %qD redeclared as non-template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "употреба набрајања %q#D без претходне декларације"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "поновљена декларација %qT као не-шаблона"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "%qD се не може декларисати као тип битског поља"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "неисправна изведена унија %qT"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "тип основе %qT није класа или структура"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "недефинисан рекурзивни тип %qT"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "неисправан удвостручен тип основе %qT"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "underlying type %qT of %qT must be an integral type"
@@ -60823,91 +60834,91 @@ msgstr "Крејов показивач код %C мора бити целобр
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ниједан интегрални тип не може представљати све вредности набрајача за %qT"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "вредност набрајача за %qD није целобројна константа"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "преливање у вредностима набрајача код %qD"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD је већ дефинисано у класи %qT"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "Processing %s\n"
 msgid "using %qs"
 msgstr "Обрађујем %s\n"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -61828,7 +61839,7 @@ msgstr "тип %qT није непосредна или виртуелна ос
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
@@ -62961,7 +62972,7 @@ msgstr "декларација употребе за не-члан у досег
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -63790,7 +63801,7 @@ msgstr "не могу се дефинисати нови типови у пов
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неподржан аргумент за %<__builtin_frame_address%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -64553,13 +64564,13 @@ msgstr "само конструктори узимају успостављач
 msgid "cannot expand initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -65221,7 +65232,7 @@ msgstr "недостаје справљачки циљ после %qs"
 msgid "%qT not permitted in template argument"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
@@ -66183,7 +66194,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
@@ -67298,7 +67309,7 @@ msgstr "нешаблонски тип %qT употребљен као шабло
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
@@ -67397,299 +67408,299 @@ msgstr "функција враћа низ"
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "погрешан број аргумената наведне за атрибут %qs"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -67702,181 +67713,181 @@ msgstr "експлицитна специјализација %qD после п
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "непрозирни векторски типови не могу бити успостављени"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT није именски простор"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "дефиниција %q#T унутар листе шаблонских параметара"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "користите #include уместо тога"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функција се не разматра за уткивање"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 #| msgid "explicit qualification in declaration of %qD"
 msgid "explicit deduction guide declared here"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -68216,7 +68227,7 @@ msgstr "неисправан навод основне класе"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
@@ -68675,30 +68686,30 @@ msgstr "%<__builtin_next_arg%> позвано без аргумената"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a class or namespace"
 msgid "%qD is not a class or alias template"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -68707,22 +68718,22 @@ msgstr "неподржан аргумент за %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -70112,242 +70123,242 @@ msgstr "декларација %q#D"
 msgid "declaration of %q#T"
 msgstr "декларација %q#D"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of incomplete type %q#T"
 msgstr "неисправна употреба непотпуног typedef %qD"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "неисправна употреба члана %q+D у статичкој чланској функцији"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of placeholder %qT"
 msgstr "неисправна употреба %qD"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of template type parameter %qT"
 msgstr "неисправна употреба непотпуног typedef %qD"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "invalid use of template template parameter %qT"
 msgstr "неисправан подразумевани аргумент за шаблонски шаблонски параметар"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of dependent type %qT"
 msgstr "неисправна употреба непотпуног typedef %qD"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array must be initialized with a brace-enclosed initializer"
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "употребљена синтакса конструктора, али конструктор није декларисан за тип %qT"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD may not have been initialized"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "променљива %qD можда није успостављена"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "двосмислено претварање %qE из %qT у %qT"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "предугачка ниска успостављача за низ знакова"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "витичасте заграде око скаларног успостављача"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "скупина типа %qT не може се успостављати сложеном константном"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "прототип за %q#D не одговара ниједном у класи %qT"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поље %qD није нађено у унији која се успоставља"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "индексна вредност уместо имена поља у успостављачу уније"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "откривено кружно прослеђивање показивача"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "основни операнд за %<->%> непоказивачког је типа %qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> производи непоказивачки резултат"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "основни операнд за %<->%> није показивач"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE се не може користити као члански показивач, пошто је типа %qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "члански показивач %qE не може се применити на %qE, које је некласног типа %qT"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "позив функције која баца непотпун тип %q#T"
@@ -71369,7 +71380,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -72600,12 +72611,12 @@ msgstr "успостављачка ниска подсечена да одгов
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Индекс почетка подниске код %L је мањи од један"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Индекс краја подниске код %L премашује дужину ниске"
@@ -72808,7 +72819,7 @@ msgstr "Лоша одредница намере код %C"
 msgid "deferred type parameter at %C"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -75010,7 +75021,7 @@ msgstr "трансформационо сопствено ‘%s’ код %L н
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Проширење: Израчунавање нестандардног успостављачког израза код %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -75320,7 +75331,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -75448,7 +75459,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
@@ -75460,7 +75471,7 @@ msgstr "Успостављање показивача код %C захтева 
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
@@ -75597,7 +75608,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
@@ -75834,12 +75845,12 @@ msgstr "Први аргумент дефинисане доделе код %L м
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
@@ -75961,609 +75972,609 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Неисправан трећи аргумент у IBITS код %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог типа"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Кључна реч ‘%s’ код %L је већ придружена другом стварном аргументу"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Више стварних него формалних аргумената у позиву процедуре код %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Недостаје одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неочекивана одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L не може бити низ претпостављене величине"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити резервљив"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Недостаје одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Недостаје стварни аргумент за аргумент ‘%s’ код %L"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Исти стварни аргумент придружен намере-%s аргументу ‘%s’ и намере-%s аргументу ‘%s’ код %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и има атрибут показивача"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Аутоматска функција знаковне дужине ‘%s’ код %L мора имати експлицитно сучеље"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D удволичено са недефинисаним симболом %qs"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Ентитет ‘%s’ код %C је већ присутан у сучељу"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "Ознака %s код %L мора бити типа %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Унутрашња функција знаковне вредности ‘%s’ код %L не може бити претпостављене дужине"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Процедура ‘%s’ у %s код %L није ни функција ни потпрограм"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Превише аргумената у позиву ‘%s’ код %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -76767,7 +76778,7 @@ msgstr "Претварање из %s у %s код %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -77391,7 +77402,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -78026,7 +78037,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -80049,8 +80060,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
@@ -82188,796 +82199,808 @@ msgstr "Унутрашња функција знаковне вредности
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Унутрашња функција знаковне вредности ‘%s’ код %L не може бити претпостављене дужине"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure %s at %L has entries with mismatched array specifications"
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "Процедура %s код %L има уносе са неусаглашеним одредницама низа"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure %s at %L has entries with mismatched array specifications"
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "Процедура %s код %L има уносе са неусаглашеним одредницама низа"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be an array in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Резултат функције %s не може бити низ у функцији %s код %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be an array in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Улазни резултат %s не може бити низ у функцији %s код %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Резултат функције %s не може бити показивач у функцији %s код %L"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "Улазни резултат %s не може бити показивач у функцији %s код %L"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Резултат функције %s не може бити показивач у функцији %s код %L"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "Улазни резултат %s не може бити показивач у функцији %s код %L"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be of type %s in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Резултат функције %s не може бити типа %s у функцији %s код %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be of type %s in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "Улазни резултат %s не може бити типа %s у функцији %s код %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a DO block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DO"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a DO block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DO"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "COMMON block /%s/ not found at %C"
 msgid "COMMON block at %L"
 msgstr "Заједнички блок /%s/ није нађен код %C"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block /%s/ not found at %C"
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "Заједнички блок /%s/ није нађен код %C"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The rank of the element in the derived type constructor at %L does not match that of the component (%d/%d)"
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "Ранг елемента у конструктору изведеног типа код %L не одговара оном компоненте (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "Елемент у конструктору изведеног типа код %L, за показивачку компоненте ‘%s’, јесте %s а треба да буде %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s' should be a POINTER or a TARGET"
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "Елемент у конструктору изведеног типа код %L, за показивачку компоненту ‘%s’, треба да је показивач или циљ"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %C"
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "Превише компонената у конструктору структуре код %C"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %C"
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "Превише компонената у конструктору структуре код %C"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 #| msgid "The rank of the element in the derived type constructor at %L does not match that of the component (%d/%d)"
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "Ранг елемента у конструктору изведеног типа код %L не одговара оном компоненте (%d/%d)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s' should be a POINTER or a TARGET"
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "Елемент у конструктору изведеног типа код %L, за показивачку компоненту ‘%s’, треба да је показивач или циљ"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Елемент у конструктору изведеног типа код %L, за показивачку компоненте ‘%s’, јесте %s а треба да буде %s"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, fuzzy, gcc-internal-format
 #| msgid "The upper bound in the last dimension must appear in the reference to the assumed size array '%s' at %L."
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "Горња граница у последњој димензији мора се појавити у упућивачу на низ претпостављене величине ‘%s’ код %L."
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "%qs at %L is ambiguous"
 msgstr "Двосмислен симбол ‘%s’ код %L"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Генеричка несопствена процедура ‘%s’ није дозвољена као стварни аргумент код %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Наводилац алтернативног повратка није дозвољен у функцији ‘%s’ код %L"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "Сопствено код %L не постоји"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Етикета %d поменута код %L није дефинисана"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Сопствено ‘%s’ код %L није дозвољено као стварни аргумент"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Елементална несопствена процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to find a specific INTRINSIC procedure for the reference '%s' at %L"
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Не могу да нађем одређену сопствену процедуру за упућивач ‘%s’ код %L"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Двосмислен симбол ‘%s’ код %L"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Аргумент-по-вредности код %L није бројевног типа"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Аргумент-по-вредности код %L није дозвољен у овом контексту"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Није дозвољено прослеђивање унутрашње процедуре по локацији код %L"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Елементална несопствена процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optionalargument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "‘%s’ код %L је низ и опцион; ако недостаје, не може бити стварни аргумент елементалне процедуре, осим ако постоји не-опциони аргумент истог ранга (12.4.1.5)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 #| msgid "coverage mismatch for function %qs while reading counter %qs"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "неслагање покривача за функцију %qs у току читања бројача %qs"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Нема одређене функције за генеричко ‘%s’ код %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Генеричка функција ‘%s’ код %L није у складу са одређеним сопственим сучељем"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Функција ‘%s’ код %L је сопствена али није сагласна са сопственом"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Не могу да разрешим одређену функцију ‘%s’ код %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "упућивач на не-чисту функцију ‘%s’ код %L унутар FORALL %s"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "упућивач на не-чисту функцију ‘%s’ код %L унутар FORALL %s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Не могу да пишем у унутрашњу датотеку ‘%s’ код %C унутар чисте процедуре"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "‘%s’ код %L није функција"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Функција ‘%s’ декларисана је као CHARACTER(*) и не може бити употребљена код %L пошто није лажни аргумент"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Кориснички дефинисана неелементална функција ‘%s’ код %L није дозвољена у конструкцији WORKSHARE"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "Потпрограм ‘%s’ код %L не може позивати самог себе, пошто није рекурзиван"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Функција ‘%s’ код %L не може позивати саму себе, пошто није рекурзивна"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Using function %qs at %L is deprecated"
 msgstr "Наредбена функција код %L је рекурзивна"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ у блоку FORALL код %L није чист"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ у блоку FORALL код %L није чист"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ код %L није чист"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Нема одређеног потпрограма за генеричко ‘%s’ код %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Генерички потпрограм ‘%s’ код %L није у складу са сучељем сопственог потпрограма"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Потпрограм ‘%s’ код %L је сопствени али није сагласан са сопственим"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Не могу да разрешим одређени потпрограм ‘%s’ код %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "„%s“ код %L има тип који није у складу са позивом код %L"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, fuzzy, gcc-internal-format
 #| msgid "Call to ENTRY '%s' at %L is recursive, but subroutine '%s' is not declared as RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "Позив за унос ‘%s’ код %L јесте рекурзиван, али потпрограм ‘%s’ није декларисан као такав"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Потпрограм ‘%s’ код %L не може позивати самог себе, пошто није рекурзиван"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Облици операнада код %L и %L нису усагласиви"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Shape specification at %L cannot be negative"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Одредница облика код %L не може бити негативна"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Недозвољен нулти корак код %L"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Није наведена десна горња граница низа претпостављене величине код %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс низа код %L мора бити скалар"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс низа код %L мора бити целобројни"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Проширење: реални индекс низа код %L"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid array initializer for non-array type %qs"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Неисправан успостављач низа за ненизовни тип %qs"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс низа код %L је низ ранга %d"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Индекс почетка подниске код %L мора бити целобројни"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Индекс почетка подниске код %L мора бити скалар"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Индекс краја подниске код %L мора бити целобројни"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут показивача код %L"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут резервљивости код %L"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Два или више делимична упућивача са ненултим рангом не смеју бити наведени код %L"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -82987,12 +83010,12 @@ msgstr "Низ претпостављеног облика код %L мора б
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -83002,312 +83025,312 @@ msgstr "Низ претпостављеног облика код %L мора б
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s',used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’, употребљена у одредничком изразу, користи се код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’ употребљена је код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "променљива примерка %qs декларисана је %s"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Израз за крај у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Израз за корак у FORALL код %L мора бити скаларни %s"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Израз за корак у FORALL код %L не може бити нула"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Израз у наредби ALLOCATE код %L мора бити резервљив или показивач"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear an the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’ не може да се јави у одредници низа код %L у истој наредби резервисања где се и само резервише"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -83316,298 +83339,298 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Израз у наредби CASE код %L мора бити врста %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE код %L не може бити праћен другим DEFAULT CASE код %L"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логички опсег у наредби CASE код %L није дозвољен"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "константна логичка вредност у наредби CASE поновљена је код %L"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Одредница опсега код %L не може никако бити поклопљена"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Блок логичког SELECT CASE код %L има више од два случаја"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Име ‘%s’ се не може употребити као дефинисани оператор код %C"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати резервљиве компоненте"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент преноса података код %L не може бити пун упућивач на низ претпостављене величине"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Наредба код %L није исправна наредба циља гранања за наредбу гранања код %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -83615,12 +83638,12 @@ msgstr "Гранање код %L води у бесконачну петљу"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -83628,224 +83651,224 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Циљ доделе у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподржана наредба унутар WHERE код %L"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL са индексом ‘%s’ изазива више од једне доделе овом објекту код %L"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Спољашња конструкција FORALL већ има индекс са овим именом %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Одредба WHERE/ELSEWHERE код %L захтева логички низ"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Алтернативна наредба повратка код %L захтева скаларни целобројни наводилац повратка"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Очекиван је успостављачки израз у CASE код %C"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Аритметичко IF код %L захтева бројевни израз"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Излазни услов из петље DO WHILE код %L мора бити скаларни логички израз"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба маске у FORALL код %L захтева логички израз"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -83853,1091 +83876,1091 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "величина низа %qs је превелика"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Низ модула или главног програма ‘%s’ код %L мора имати константан облик"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Ентитет са претпостављеном знаковном дужином код %L мора бити лажни аргумент или параметар"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Резервљиво ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Аутоматски низ ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "у %s, код %s:%d"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "‘%s’ је приватног типа и не може бити лажни аргумент у ‘%s’, који је јаван код %L"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Елементална функција ‘%s’ код %L мора имати скаларни резултат"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
 # no-c-format
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити рекурзивна"
 
 # no-c-format
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити опциони"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Знаковна дужина компоненте ‘%s’ мора бити константан одреднички израз код %L."
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Израз код %L мора бити целобројног типа"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Компонента ‘%s’ је приватни тип и не може бити компонента у ‘%s’, која је јавна код %L"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонента %s типа SEQUENCE декларисаног код %L нема атрибут SEQUENCE"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD није декларисано"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -85907,7 +85930,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -85919,12 +85942,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "лош тип израза током хода (%d)"
@@ -86028,93 +86051,99 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY '%s' at %L has no IMPLICIT type"
+msgid "%s at %C has no default type"
+msgstr "Унос ‘%s’ код %L нема имплицитан тип"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "сопствена променљива која није процедура"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "Враћај вредности функција у регистрима ФПУа"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "декларација зачеља за модулску променљиву %s већ постоји"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Превише аргумената за %s код %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Враћај вредности функција у регистрима ФПУа"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -86129,27 +86158,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Непознат сопствени оператор"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Непозната функције листе аргумената код %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
diff --git a/gcc/po/sv.po b/gcc/po/sv.po
index e4fe1b5bbff..028cfec62be 100644
--- a/gcc/po/sv.po
+++ b/gcc/po/sv.po
@@ -27,10 +27,10 @@
 # thunk			snutt
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 13.1-b20230409\n"
+"Project-Id-Version: gcc 13.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
-"PO-Revision-Date: 2023-04-22 18:19+0200\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
+"PO-Revision-Date: 2023-04-27 10:10+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
@@ -4015,7 +4015,7 @@ msgstr "använd ISO-dialekten av Modula-2"
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr "ange biblioteksordningen, biblioteken kan anges med en kommaseparerad förkortning: log,min,pim,iso eller med katalognamn: m2log,m2min,m2pim,m2iso.\""
 
 #: m2/lang.opt:127
@@ -7659,6 +7659,11 @@ msgstr "Aktivera konservativ utrullning av små slingor."
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr "-mlam=[none|u48|u57] Instrumentera metadatapositioner användardatapekare."
 
+#: config/i386/i386.opt:1280
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Stöd inbyggda AMX-COMPLEX-funktioner och -kodgenerering."
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17187,12 +17192,12 @@ msgstr "'%%l'-operand är inte en etikett"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "flyttalskonstant felanvänd"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18271,63 +18276,63 @@ msgstr "Denna flagga saknar dokumentation."
 msgid "Uses of this option are diagnosed."
 msgstr "Användning av denna flagga diagnostiseras."
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr "Samma som %s%s (eller, i negerad form, %s%s)."
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr "Samma som %s%s."
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr "Samma som %s."
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  Samma som %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr "[tillgänglig i "
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[standard]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr "%llu byte"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[aktiverad]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[avslagen]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Det finns inga flaggor med de eftersökta egenskaperna\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Det fanns inga.  Använd --help=%s för att visa *alla* flaggorna som stödjs av framänden %s.\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Alla flaggor med de eftersökta egenskaperna har redan visats\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -18336,47 +18341,47 @@ msgstr ""
 "  Kända giltiga argument till flaggan %s:\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Följande flaggor är målberoende"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Följande flaggor styr kompilatorns varningsmeddelanden"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Följande flaggor styr optimeringar"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Följande flaggor är språkoberoende"
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr "Följande flaggor styr parametrar"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Följande flaggor är specifika för just språket "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Följande flaggor stödjs av språket "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Följande flaggor är inte dokumenterade"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Följande flaggor tar separata argument"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Följande flaggor tar sammanslagna argument"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Följande flaggor är språkrelaterade"
 
@@ -18760,72 +18765,72 @@ msgstr "längdmodifierare i strfmon-format"
 msgid "<command-line>"
 msgstr "<kommandorad>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ej stödd operand för kod ”%c”"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ogiltig operand för ”%%%c”"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr "ogiltig vektorkonstant"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "inkompatibla flyttals-/vektorregisteroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "inkompatibla registeroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "operand saknas"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "ogiltig konstant"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "ogiltig operand"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ogiltig operandprefix ”%%%c”"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "ogiltigt adressläge"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "det går inte att kombinera GNU- och SVE-vektorer i en binär operation"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "”%%&” använt utan någon lokal dynamisk TLS-referens"
@@ -18842,18 +18847,18 @@ msgid "invalid %%r value"
 msgstr "ogiltigt %%r-värde"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "ogiltigt %%R-värde"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
@@ -18883,7 +18888,7 @@ msgstr "ogiltigt %%M-värde"
 msgid "invalid %%U value"
 msgstr "ogiltigt %%U-värde"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
@@ -18893,7 +18898,7 @@ msgstr "ogiltigt %%s-värde"
 msgid "invalid %%C value"
 msgstr "ogiltigt %%C-värde"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
@@ -18906,7 +18911,7 @@ msgstr "okänd avspecifikation av omlokalisering"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ogiltig %%xn-kod"
@@ -18989,35 +18994,35 @@ msgstr "ogiltig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "okänd förmodad konstant"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "ogiltig skiftoperand"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "förutsade Thumb-instruktion"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "förutsade instruktion i villkorlig sekvens"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ej stödd operand för kod ”%c”"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19026,26 +19031,26 @@ msgstr "Ej stödd operand för kod ”%c”"
 msgid "invalid operand for code '%c'"
 msgstr "ogiltig operand för kod ”%c”"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktionen aldrig utförd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "föråldrad Maverick-formatkod ”%c”"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operationen är inte tillåten på typen %<bfloat16_t%>"
 
@@ -19410,97 +19415,97 @@ msgstr "ogiltig fp-konstant"
 msgid "Expected register or constant integer."
 msgstr "Register eller konstant heltal förväntades."
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ogiltig UNSPEC som operand"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "ogiltig användning av register ”%s”"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "felaktig användning av asm-flaggutdata"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ogiltig operandstorlek för operandkod ”O”"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ogiltig operandstorlek för operandkod ”z”"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, c-format
-msgid "invalid operand type used with operand code 'Z'"
-msgstr "ogiltig operandtyp vid operandkod ”Z”"
+msgid "invalid operand type used with operand code '%c'"
+msgstr "ogiltig operandtyp använd med operandkod ”%c”"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "ogiltig operandstorlek för operandkod ”Z”"
+msgid "invalid operand size for operand code '%c'"
+msgstr "ogiltig operandstorlek för operandkod ”%c”"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operanden är inte en villkorskod, ogiltig operandkod ”Y”"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”D”"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”%c”"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand är inte en justerbar minnesreferens, ogiltig operandkod ”H”"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”K”"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”r”"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ogiltig operandkod ”%c”"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ogiltig begränsning för operand"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ogiltig vektoromedelbar"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "okänt instruktionsläge"
 
@@ -19531,7 +19536,7 @@ msgstr "ogiltig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ogiltig %%P-operand"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -19576,8 +19581,8 @@ msgstr "%%%c är inte ett giltigt operandprefix"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "felaktig användning av ”%%%c”"
@@ -19609,7 +19614,7 @@ msgid "post-increment address is not a register"
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -19767,7 +19772,7 @@ msgstr "ej stödd konstant adress:"
 msgid "unsupported memory expression:"
 msgstr "ej stött minnesuttryck:"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, c-format
 msgid "invalid vector operand"
 msgstr "ogiltig vektoroperand"
@@ -19819,143 +19824,143 @@ msgstr "%<-mquad-memory%> är inte tillgängligt i läget med omvänd byteordnin
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, c-format
 msgid "invalid %%A value"
 msgstr "ogiltigt %%A-värde"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "ogiltigt %%D-värde"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "ogiltigt %%t-värde"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "ogiltigt %%V-värde"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "ogiltigt %%z-värde"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Felaktig blandning av IEEE 128-bitars och IBM 128-bitars flyttalstyper"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kan inte generera ladda/lagra-avstånd för sammanslagning"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ogiltig konvertering från typen %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ogiltig konvertering till typen %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ogiltig konvertering från typen %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ogiltig konvertering till typen %<__vector_pair%>"
 
@@ -20412,7 +20417,7 @@ msgstr "kandidat:"
 msgid "  after user-defined conversion:"
 msgstr "  efter användardefinierad konvertering:"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
@@ -20876,7 +20881,7 @@ msgstr "Vektorbindning stämmer inte för dimension 2 av vektorn (%ld/%ld)"
 msgid "Driving:"
 msgstr "Driver:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "aktuellt argument till INTENT = OUT/INOUT"
 
@@ -21034,11 +21039,11 @@ msgstr "block-IF"
 msgid "implied END DO"
 msgstr "implicerat END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "tilldelning"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "pekartilldelning"
 
@@ -21046,199 +21051,199 @@ msgstr "pekartilldelning"
 msgid "simple IF"
 msgstr "enkelt IF"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "elementär procedur"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr "allokerbart argument"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr "asynkront argument"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "valfritt argument"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr "pekarargument"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr "målargument"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr "värdeargument"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr "volatilt argument"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr "argument med antagen form"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr "argument med antagen ordning"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr "co-vektorargument"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr "parametriserat härlett typargument"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr "polymorft argument"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr "attributet NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr "argument med antagen typ"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr "vektorresultat"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr "pekare eller allokerbart resultat"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr "resultat med teckenlängd som inte är konstant"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr "bind(c)-procedur"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ogiltigt sammanhang för NULL()-pekare vid %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand till unär numerisk operator %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Oväntade entiteter av härledd typ i binär inbyggd numerisk operator %%<%s%%> vid %%L"
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operander till binär numerisk operator %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanderna till strängkonkateneringsoperatorn vid %%L är %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till logiska operatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand till operatorn .not. vid %%L är %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-kvantiteter kan inte jämföras vid %L"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logiska vid %%L måste jämföras med %s istället för %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till jämförelseoperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Okänd operator %%<%s%%> vid %%L; menade du %%<%s%%>?"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Okänd operator %%<%s%%> vid %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Inkonsistenta ordningar för operator vid %%L och %%L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "Slingvariabel"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr "iteratorvariabel"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr "Startuttryck i DO-slinga"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr "Slututtryck i DO-slinga"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr "Steguttryck i DO-slinga"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE-objekt"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr "ALLOCATE-objekt"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr "STAT-variabel"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr "ERRMSG-variabel"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr "objekt i READ"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK-variabel"
 
@@ -21251,27 +21256,27 @@ msgstr "Olika CHARACTER-längder (%ld/%ld) i vektorkonstruerare"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Heltalsspill vid beräkning av mängden minne att allokera"
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Värdet på PDT LEN-parametern ”%s” stämmer inte överens med det i attrappdeklarationen"
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd matchar inte den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd är kortare än den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Målet för återavbildning av ordning är för litet (%ld < %ld)"
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr "Tilldelning av skalär till en oallokerad vektor"
 
@@ -22139,7 +22144,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "%<-mrelax%> stödjs endast för RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfel i %s-sats vid %C"
@@ -22510,7 +22515,7 @@ msgstr "ignorerar attributet %qE eftersom det står i konflikt med attributet %q
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -22607,10 +22612,10 @@ msgstr "typattribut ignoreras efter att typen redan är definierad"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -22745,7 +22750,7 @@ msgstr "det går inte att läsa profilen från %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "index %qwi till en konstant sträng pekar utanför dess gränser"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE är deklarerad här"
@@ -24577,7 +24582,7 @@ msgstr "stor fixdecimalskonstant implicit trunkerad till fixdecimaltyp"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "jämförelsen är alltid %d på grund av bredd på bitfält"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "antar att teckenspill inte förekommer vid förenkling av intervalltest"
@@ -25346,7 +25351,7 @@ msgstr "funktionen returnerar adress till en lokal variabel"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26464,14 +26469,14 @@ msgstr "hängande pekare till %qD kan användas"
 msgid "using a dangling pointer to %qD"
 msgstr "använder en hängande pekare till %qD"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
@@ -26516,7 +26521,7 @@ msgstr "%qD anropad på en pekare skickad till en omallokeringsfunktion som inte
 msgid "call to %qD"
 msgstr "anrop till %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr "lagrar adressen till den lokala variabeln %qD i %qE"
@@ -27582,7 +27587,7 @@ msgstr "ipa-inline-sammanfattning saknas i indatafil"
 msgid "IPA modref summary is missing in input file"
 msgstr "IPA modref-sammanfattning saknas i indatafilen"
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "ogiltig hoppfunktion i LTO-ström"
@@ -28540,7 +28545,7 @@ msgstr "fel när optimeringsposter %qs stängdes"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "kommandoradsflaggan %qs stödjs inte av denna konfiguration"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "argument saknas till %qs"
@@ -28580,12 +28585,12 @@ msgstr "%qs är ömsesidigt uteslutande med %qs och kan inte användas tillsamma
 msgid "unrecognized argument in option %qs"
 msgstr "okänt argument till flaggan %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "giltiga argument till %qs är: %s; menade du %qs?"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "giltiga argument till %qs är: %s"
@@ -28740,7 +28745,7 @@ msgstr "%<-fsanitize=pointer-subtract%> måste kombineras med %<-fsanitize=addre
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "%<-fsanitize-recover=%s%> stödjs inte"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "%<-fsanitize-trap=%s%> stödjs inte"
@@ -28780,182 +28785,182 @@ msgstr "variabelspårning begärd, men oanvändbar om den inte felsökningsinfor
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "variabel spårning begärd, men stödjs inte av detta felsökningsformat"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments ändrar selektiv schemaläggning"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr "%<-Wstrict-flex-arrays%> ignoreras när %<-fstrict-flex-arrays%> inte är aktivt"
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> fungerar inte med undantag på denna arkitektur"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> stödjer inte upprullningsinformation på denna arkitektur"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> fungerar inte på denna arkitektur"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "okänd %<include_flags 0x%x%> skickade till %<print_specific_help%>"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr "flaggan %<-fsanitize=all%> är inte giltig"
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "okänt argument till flaggan %<-f%ssanitize%s=%>: %q.*s; menade du %qs?"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "okänt argument till flaggan %<-f%ssanitize%s=%>: %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "attributdirektivet %qs ignorerat"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "okänt argument till %<-fzero-call-used-regs=%>: %qs"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "ogiltigt argument till flaggan %<-falign-%s%>: %qs"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "felaktigt antal argument till flaggan %<-falign-%s%>: %qs"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "%<-falign-%s%> är inte mellan 0 och %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "ogiltigt argument till %<-fpatchable-function-entry%>"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "argumentet %q.*s till %<--help%> är tvetydigt, var mer precis"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "okänt argument till %<--help=%>-flagga: %q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr "argumentet ignoreras för %<-Wattributes=%>; använd %<-Wno-attributes=%> istället"
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr "avslutande %<,%> i argumenten till %<-Wno-attributes=%>"
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr "flaggan %<-foffload-abi%> kan anges endast för en avlastande kompilator"
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "postjustering måste vara två upphöjt till ett litet tal, inte %wu"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "okänd stackkontrollparameter %qs"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr "%<-gdwarf%s%> är tvetydigt; använd %<-gdwarf-%s%> för DWARF-version eller %<-gdwarf%> %<-g%s%> för felsökningsnivå"
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "dwarf-version %wu stödjs inte"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "okänt argument till flaggan %<-flto=%>: %qs"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "målsystemet stödjer inte felsökningsutdata"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "felsökningsformatet %qs står i konflikt med tidigare val"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "okänd felsökningsnivå %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "felsökningsnivå %qs är för hög"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "okänd btf-felsökningsnivå %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "när gräns för maximal storlek på core-fil hämtades: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "när gräns för maximal storlek på core-fil sattes: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "ej igenkänd felsökningsflagga för gcc: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "%<-W%serror=%s%>: ingen flagga %<-%s%>; menade du %<-%s%>?"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "%<-W%serror=%s%>: ingen flagga %<-%s%>"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "%<-Werror=%s%>: %<-%s%> är inte en flagga som styr varningar"
@@ -29634,187 +29639,187 @@ msgstr "generisk snuttkod misslyckas för metoden %qD som använder %<...%>"
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%qD byter namn efter att ha refererats i assembler"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "funktionssymbol som inte är en funktion"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr "inkonsistent %<ifunc%>-attribut"
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "variabelsymbol är inte en variabel"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "noden har okänd typ"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "noden har en ogiltig ordning %i"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nod ej funnen found node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "noden skiljer från node->decl->decl_with_vis.symtab_node"
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "hashlistan över assemblernamn trasig"
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "nod finns inte i hashen av symboltabellassemblernamn"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "dubbellänkad lista av assemblernamn är trasig"
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "noden har body_removed men är en definition"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "noden är analyserad men den är inte en definition"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "noden är ett alias men inte ett implicit alias"
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "noden är ett alias men inte en definition"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "noden är weakref men inte ett transparent_alias"
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "noden är transparent_alias men inte ett alias"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "noden är en symver men inte ett alias"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr "symver-målet exporteras inte med standardsynlighet"
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr "symver är inte exporterad med standardsynlighet"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "noden är i same_comdat_group-listan men den har ingen comdat_group"
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group-lista över olika grupper"
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "blandning av olika typer av symboler i samma comdat-grupper stödjs inte"
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "noden är ensam i en comdat-grupp"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group är inte en cirkulär lista"
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "comdat-lokal symbol refererad till av %s utanför dess comdat"
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "flaggan implicit_section är satt men sektionen är inte det"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "både sektion och comdat-grupp är satt"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr "Aliasets och målets sektion skiljer"
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr "Aliasets och målets comdat-grupper skiljer"
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "Transparent alias och målets assemblernamn skiljer"
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Kedjade genomskinliga alias"
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify misslyckades"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "ogiltig ordning i asm-nod %i"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Två symboler med samma comdat_group är inte länkade av listan same_comdat_group."
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "funktionen %q+D är en del av en aliascykel"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabeln %q+D är del i en aliascykel"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "sektionen för aliaset %q+D måste stämma med sektionen för dess mål"
@@ -31476,27 +31481,27 @@ msgstr "maskinoberoende inbyggd kod utanför intervallet"
 msgid "target specific builtin not available"
 msgstr "målspecifik inbyggd funktion är inte tillgänglig"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "vektoroperationen kommer expanderas bitvis"
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "vektoroperationen kommer expanderas parallellt"
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "vektoroperationen kommer expanderas med en ensam skalär operation"
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "vektorvillkor kommer expanderas bitvis"
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "vektorblandningsoperationen kommer expanderas bitvis"
@@ -32312,7 +32317,7 @@ msgstr "attributet %qE ignorerat för att %qD inte är en variabel"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "attributet %qE ignorerat för att %qD inte är en lokal variabel"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "attributet %qE har bara effekt på publika objekt"
@@ -34398,7 +34403,7 @@ msgstr "ej stödd konkatenering av stränglitteraler som inte följer standard"
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionell C stödjer inte strängkonstantsammanslagning"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> med %<hint%>-klausul kräver ett namn, utom när %<omp_sync_hint_none%> används"
@@ -36067,7 +36072,7 @@ msgstr "för många indatafiler"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%qs är definierad i huvudet %qs; glömde du %<#include %s%>?"
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "okänt värde %qs till %<-mcpu%>"
@@ -36098,15 +36103,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "okänd flagga skickad till %%:%<target_mode_check%>"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "giltiga argument är: %s; menade du %qs?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "giltiga argument är: %s"
@@ -36191,48 +36196,48 @@ msgstr "%<-mcpu=%s%> är inte giltigt"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "%<-mcpu=%s%> har ogiltig kiselversion"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "%<-malign-loops%> är föråldrat, använd %<-falign-loops%>"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "%<-malign-loops=%d%> är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "%<-malign-jumps%> är föråldrat, använd %<-falign-jumps%>"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "%<-malign-jumps=%d%> är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "%<-malign-functions%> är föråldrat, använd %<-falign-functions%>"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "%<-malign-functions=%d%> är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "%<-mbranch-cost=%d%> är inte mellan 0 och 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> stödjs för närvarande bara på GNU/Linux"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> kräver assemblerstöd för CFI-direktiv"
@@ -36716,13 +36721,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "ACLE-funktionen %qD är inkompatibel med användningen av %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "argument %d till %qE måste vara ett konstant heltalsuttryck"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr "skickar %wd som argument %d till %qE, vilken förväntar sig ett värdet i intervallet [%wd, %wd]"
@@ -36960,7 +36965,7 @@ msgstr "skickar %qT som argument %d till %qE, men dess %qT-form tar inte skalär
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "dubblerad definition av %qs"
@@ -37001,7 +37006,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "SVE-typen %qT har inte en definierad justering"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr "variabler av typen %qT kan inte ha trådlokal lagringsvaraktighet"
@@ -37088,323 +37093,323 @@ msgstr "man kan aktivera SVE genom att använda kommandoradsflaggan %<-march%>,
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "argument av typen %qT kräver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "SVE-typen %qT kan inte skickas till en funktion utan prototyp"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 13.1"
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 9.1"
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE behöver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "anrop till funktioner av typen %qT behöver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "stackprov för SVE-ramar"
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "okänd flagga skickad i %<-moverride=%s%> (%s)"
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr "%qs-sträng är felformad"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "felaktigt format på %<sve_width%>"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr "ogiltigt %<sve_width%>-värde: %d"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "trimningssträngen saknas i flaggan (%s)"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "okänd trimningsflagga (%s)"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "inkompatibla flaggor %<-mstack-protector-guard=global%> och %<-mstack-protector-guard-offset=%s%>"
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "både %<-mstack-protector-guard-offset%> och %<-mstack-protector-guard-reg%> måste användas med %<-mstack-protector-guard=sysreg%>"
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr "ange ett systemregister med en liten stränglängd"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs är inte ett giltigt avstånd i %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr "%<-fsanitize=shadow-call-stack%> kräver %<-ffixed-x18%>"
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "endast värdena 12 (4 kB) och 16 (64 kB) stödjs som vaktstorlek.  Det givna värdet %d (%llu kB) är utanför intervallet"
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "stackkrockvaktsstorlek %<%d%> måste vara lika med testintervallet %<%d%>"
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "cpu-namn saknas i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "ogiltig funktionsmodifierare %qs i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ogiltigt argument givet till %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr "%qs måste vara ensamt till %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "ogiltigt argument %<%s%> till %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "arkitekturnamn saknas i %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "okänt värde %qs till %<-march%>"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "menade du %<-mcpu=%s%>?"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "ogiltig funktionsmodifierare %qs i %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "cpu-namn saknas i %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "okänt värde %qs till %<-mtune%>"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "flaggan %<-mcpu=%s%> står i konflikt med flaggan %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "assemblern stödjer inte %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "signering av returadress stödjs endast för %<-mabi=lp64%>"
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "kodmodell %qs med %<-f%s%>"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "kodmodellen %qs stödjs inte i ilp32-läge"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "felaktigt namn %qs i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "felaktig funktionsmodifierare %s på värdet %qs i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "felaktigt namn %qs i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "felaktig funktionsmodifierare %qs på värdet %qs i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "argument saknas till pragmat eller attributet %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "felaktig skyddstyp %qs i pragmat eller attributet %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "felaktigt namn %qs i pragmat eller attributet %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "värde saknas i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target()%>"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tar inte något argument"
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tillåter inte en negerad form"
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s=%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr "arkitekturutvidgningen %<%s%> skall prefixas av %<+%>"
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "parameterskickandet för argument av typen %qT med %<[[no_unique_address]]%>-medlemmar ändrades %{i GCC 10.1%}"
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "parameterskickandet för argument av typen %qT när C++17 är aktiverat ändrades till att matcha C++14 %{i GCC 10.1%}"
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr "parameterskickandet för argument av typen %qT ändrades %{i GCC 12.1%}"
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "bana %wd utanför intervallet %wd - %wd"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "ej stödd simdlen %wd"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte typer av blandad storlek till %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte returtypen %qT för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "returtypen %qT stödjs ej för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte argumenttypen %qT för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "GCC stödjer för närvarande inte simdlen %wd för typen %qT"
@@ -37589,13 +37594,13 @@ msgstr "argumentet till attributet %qE är inte ”ilink” eller ”firq”"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -37736,17 +37741,17 @@ msgstr "argumentet till attributet %qE ignoreras"
 msgid "%qE attribute only applies to variables"
 msgstr "attributet %qE är bara tillämpligt på variabler"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "alternativ är inte tillåtna i %<asm%>-flaggutdata"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "okänd %<asm%>-flaggutdata %qs"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "ogiltig typ för %<asm%>-flaggutdata"
@@ -37953,7 +37958,7 @@ msgstr "målprocessorn stödjer inte THUMB-instruktioner"
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessorn stödjer inte ojusterade åtkomster"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "Denna arkitektur stödjer inte grenskyddsinstruktioner"
@@ -38008,7 +38013,7 @@ msgstr "storleksgräns för poster kan bara sättas till 8 eller 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC är inkompatibelt med %<-msingle-pic-base%>"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "FDPIC-läget stödjs inte i Thumb-1-läge"
@@ -38114,7 +38119,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "argument av typen %qT är inte tillåtna med %<-mgeneral-regs-only%>"
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 7.1"
@@ -38164,32 +38169,32 @@ msgstr "att nå trådlokal lagring stödjs inte för närvarande med %<-mpure-co
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan inte beräkna verklig plats för stackparameter"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Oväntat långt thumb1-hopp"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "inga låga register tillgängliga för att poppa höga register"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Avbrottshanteringsrutiner kan inte kodas i Thumb-1-läge"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> för Thumb-1"
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ogiltig fpu för målattributet eller pragmat %qs"
@@ -38197,22 +38202,22 @@ msgstr "ogiltig fpu för målattributet eller pragmat %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatiskt fpu-val är för närvarande inte tillåtet här"
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ogiltig arkitektur för målattribut eller -pragma %qs"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "okänt målattribut eller -pragma %qs"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%<asm%>-flaggor stödjs inte i thumb1-läge"
@@ -38286,17 +38291,17 @@ msgstr "%<-fpie%> stödjs inte"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> stödjs inte"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "funktionsattributen %qs och %qs är ömsesidigt uteslutande"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "funktionen %qs kan inte ha argument"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktionen %qs kan inte returnera ett värde"
@@ -38610,7 +38615,7 @@ msgstr "ogiltigt andra argument inbyggd funktion"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "ogiltigt argument inbyggd funktion"
@@ -39203,754 +39208,754 @@ msgstr "funktionsversioner kan inte markeras som %<gnu_inline%>, kropparna måst
 msgid "virtual function multiversioning not supported"
 msgstr "multiversionering av virtuell funktion stödjs inte"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "multiversionering behöver %<ifunc%> som inte stödjs på detta mål"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodmodellen %s stödjer inte PIC-läge"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "argument till attribut %qs är inte en sträng"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "argument %2$qs till attribut %1$qs är okänt"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "attributvärdet %qs specificerades redan i attributet %qs"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "attributvärdet %qs är okänt i attributet %qs"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "felaktigt argument %qs till flaggan %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "storleksintervall till flaggan %qs skall vara ökande"
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "felaktigt strateginamn %qs angivet till flaggan %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginamn %qs angivet till flaggan %qs stödjs inte i 32-bitars kod"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "okänd justering %qs angiven till flaggan %qs"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "maxvärdet för det sista storleksintervallet skall vara -1 för flaggan %qs"
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "för många storleksintervall angivna i flaggan %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "okänd parameter till flaggan %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI stödjs inte i %s-läge"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> bör undvikas.  Använd istället det som passar av %<-mtune=k8%> och %<-mtune=generic%>"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> bör undvikas.  Använd istället det som passar av %<target(\"tune=k8\")%> och %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "%<-mlam=%> flaggan: [u48|u57] stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressläget %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> stödjs inte med X32 ABI"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodmodellen %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodmodellen %qs stödjs inte i x32-läge"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> stödjs inte i denna konfiguration"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bitsläge inte inkompilerat"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<generic%> kan användas endast till flaggan %<-mtune=%>"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<generic%> kan användas endast till attributet %<target(\"tune=\")%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<intel%> kan användas endast till flaggan %<-mtune=%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<intel%> kan användas endast till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU:n du valde stödjer inte instruktionsuppsättningen x86-64"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "felaktigt värde %qs till flaggan %<-march=%>"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "felaktigt värde %qs till attributet %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "felaktigt värde %qs till flaggan %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "felaktigt värde %qs till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> ignoreras för Intel MCU psABI"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> är inte mellan 0 och %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> stödjs inte för denna målarkitektur"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> är inte mellan %d och %d"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> är inte mellan %d och 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> är inte implementerat för %<-fPIC%>"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> använd utan SSE aktiverat"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> använt utan SSE aktiverat"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "instruktionsuppsättningen SSE avaktiverad, använder 387-aritmetik"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "instruktionsuppsättningen 387 avaktiverad, använder SSE-aritmetik"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stackavkänning kräver %<-maccumulate-outgoing-args%> för att bli korrekt"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stackavkänning kräver %<target(\"accumulate-outgoing-args\")%> för att bli korrekt"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "fasta ebp-register kräver %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "fasta ebp-register kräver %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> stödjs inte för 32 bitar i kombination med %<-fpic%>"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> är inte kompatibelt med SEH"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> stödjs inte för närvarande med SEH"
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "okänt alternativ till %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs är inte ett giltigt tal i %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs är inte ett giltigt avstånd i %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs är inte ett giltigt basregister i %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attributen interrupt och naked är inte kompatibla"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "endast felsökningsformatet DWARF stödjs för en avbrottshanteringsrutin"
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner är inte tillåtna i en undantagshanteringsrutin"
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner är inte tillåtna i en avbrottshanteringsrutin"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner är inte tillåtna i en funktion med attributet %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attributen %qs och %qs är inte kompatibla"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attributet %qE kräver en strängkonstant som argument"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "avbrottshanteringsrutiner skall ha en pekare som första argument"
 
 # "unsigned %sint" är tänkt att expanderas till C-syntax
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "avbrottshanteringsrutiner skall ha %qs som andra argument"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "avbrottshanteringrutiner kan endast ha ett pekarargument och ett valfritt heltalsargument"
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "avbrottshanteringsrutiner måste returnera %<void%>"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qD med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qT med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "X32 stödjer inte attributet %<ms_abi%>"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "attributet %<ms_hook_prologue%> är inte kompatibelt med nästade funktioner"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorargument utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorretur utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-vektorargument utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-vektorretur utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-vektorargument utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-vektorretur utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-vektorargument utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-vektorretur utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med en flexibel vektormedlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "ABI:et för att skicka unioner med %<long double%> har ändrats i GCC 4.4"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med %<complex float%> medlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "ABI:et för att skicka C-poster med bitfält med nollbredd har ändrats i GCC %{12.1%}"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-registerretur med SSE avaktiverat"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-registerargument med SSE avaktiverat"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-registerretur med x87 avaktiverat"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "anrop av %qD med SSE-anropskonvention utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "detta är ett fel i GCC som kan gås runt genom att lägga till attributet used till den anropade funktionen"
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI:et för att skicka parametrar med %d-bytejustering har ändrats i GCC 4.6"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "%<-mcall-ms2sysv-xlogues%> är inte kompatibel med %s"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "attributet %<ms_hook_prologue%> är inte kompatibelt med %<-mfentry%> i 32-bitsläge"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) stödjs inte i avbrottshanteringsrutiner.  Detta kan gås runt genom att undvika funktioner med sammansatta returvärden."
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "Stackomjustering stödjs inte med %<__builtin_eh_return%>"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "regparm-nästade funktioner stödjs inte med %<__builtin_eh_return%>"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "%<-fsplit-stack%> stödjer inte fastcall med nästade funktioner"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "%<-fsplit-stack%> stödjer inte 2 registerparametrar för en nästad funktion"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "%<-fsplit-stack%> stödjer inte 3 registerparametrar"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr "modifieraren %<V%> på ett register som inte är heltal"
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "ej stödd storlek för heltalsregister"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "utökade register har inga höga halvor"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ej stödd operandstorlek för utökat register"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "operand som inte är heltal använt med operandkod %<z%>"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "den tomma klassen %qT parameterskickande ABI ändras i %<-fabi-version=12%> (GCC 8)"
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "justeringen av %<_Atomic %T%>-fält ändrades i %{GCC 11.1%}"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "profileringen %<-mcmodel=large%> med PIC stödjs inte"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "okänd arkitekturspecifik minnesmodell"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "%<HLE_ACQUIRE%> används inte med %<ACQUIRE%> eller starkare minnesmodell"
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "%<HLE_RELEASE%> används inte med %<RELEASE%> eller starkare minnesmodell"
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "returtyp %qT stödjs ej för simd"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "argumenttyp %qT som inte stödjs till simd"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> är inte kompatibel med %<-mfpmath=387%>"
@@ -40295,7 +40300,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE omdeklarerad med motstridiga %qs-attribut"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "attributet %qE behöver ett strängargument"
@@ -41416,52 +41421,52 @@ msgstr "%<#pragma riscv intrinsic%>-alternativet %qs behöver ha utvidgningen 
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "okänd %<#pragma riscv intrinsic%>-flagga %qs"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr "RVV-typen %qT har inte en fast storlek"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "RVV-typen %qT har inte en definierad justering"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "aritmetik på pekare till RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr "medlemsvariabler kan inte ha RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "fält kan inte ha RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr "vektorelement kan inte ha RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, gcc-internal-format
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "det går inte att allokera objekt med RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "kan inte radera objekt med RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, gcc-internal-format
 msgid "cannot throw or catch RVV type %qT"
 msgstr "kan inte kasta eller fånga RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr "fångst av kopia av RVV-typen %qT"
@@ -41481,66 +41486,71 @@ msgstr "denna åtgärd kräver ISA-utökningen RVV"
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "man kan aktivera RVV genom att använda kommandoradsflaggan %<-march%>, eller genom att använda attributet eller pragmat %<target%>"
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI:et för en tillplattad post med nollängds bitfält ändrades i GCC 10"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "argumentet till attributet %qE är inte %<\"user\"%>, %<\"supervisor\"%> eller %<\"machine\"%>"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> kräver %<-march%> för att innefatta utökningen %<M%>"
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "begärt ABI kräver %<-march%> för att innefatta utökningen %qc"
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e kräver ABI:et ilp32e"
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr "z*inx kräver ABI ilp32, ilp32e eller lp64"
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI:et kräver %<-march=rv%d%>"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> måste vara mellan %d och %d"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V ELF-attribut behöver GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs är inte ett giltigt basregister i %qs"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs är inte ett giltigt tal i %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "funktionen %qs kan inte ha olika avbrottstyp"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr "kan inte allokera vl-register för %qs på detta mål"
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, gcc-internal-format
@@ -42010,97 +42020,97 @@ msgstr "%qs bör undvikas och rekommenderas inte under några omständigheter"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs är en ogenomskinlig typ, och det går inte att sätta den till andra värden"
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "du kan inte ta adressen till en nästad funktion om du använder flaggan %qs"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan %qs"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "felaktig cpu %qs för %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s är inte tillåtet"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s är ogiltigt"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> slår av %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "attributet %<target_clones%> behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "resultatet av instruktionen xxspltidp är odefinierat för undernormala indatavärden"
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "typen %<__vector_quad%> behöver flaggan %qs"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "typen %<__vector_pair%> behöver flaggan %qs"
@@ -43500,7 +43510,7 @@ msgstr "kan inte lägga objekt med volatile-fält i register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "oinitierad %<const %D%> är ogiltig i C++"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
@@ -43685,7 +43695,7 @@ msgstr "lagringsklass angiven för parameter %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklass angiven för namnlös parameter"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklass angiven för typnamn"
@@ -43854,7 +43864,7 @@ msgstr "typnamn är deklarerat som en funktion som returnerar en vektor"
 msgid "function definition has qualified void return type"
 msgstr "funktionsdefinition som har kvalificerad void-returtyp"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typkvalificerare ignoreras för funktions returtyp"
@@ -43981,7 +43991,7 @@ msgstr "ISO C förbjuder const- eller volatile-funktionstyper"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "en medlem av an post eller union får inte ha variabel typ"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel eller fält %qE deklarerad void"
@@ -44181,7 +44191,7 @@ msgstr "att definiera en typ i %qs-uttryck är ogiltigt i C++"
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qT är definierat i underspecificerad objektinitierare"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "deklaration som inte deklarerar något"
@@ -44231,7 +44241,7 @@ msgstr "posten har inga namngivna medlemmar"
 msgid "struct has no members"
 msgstr "posten har inga medlemmar"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibel vektormedlem i union"
@@ -44276,7 +44286,7 @@ msgstr "omdeklaration av %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr "%<enum%> deklarerad med men definierad utan en fast underliggande typ"
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angiven sort för liten för uppräkningsvärden"
@@ -44321,7 +44331,7 @@ msgstr "uppräkningsvärdet är utanför intervallet för %qs"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C begränsar uppräkningsvärden till intervallet hos %<int%> före C2X"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline-funktionen %qD har fått attributet %qs"
@@ -44351,7 +44361,7 @@ msgstr "ingen tidigare prototyp för %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD användes utan någon prototyp före sin definition"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidigare deklaration av %qD"
@@ -44466,12 +44476,12 @@ msgstr "argument %qD stämmer inte med inbyggd prototyp"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen retursats i funktion som returnerar icke-void"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametern %qD sätts men används inte"
@@ -46483,7 +46493,7 @@ msgstr "för få perfekt nästade slingor"
 msgid "collapsed loops not perfectly nested"
 msgstr "kollapsade slingor inte perfekt nästade"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
@@ -46613,12 +46623,12 @@ msgstr "%<match%> förväntades"
 msgid "variant %qD is not a function"
 msgstr "varianten %qD är inte en funktion"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "varianten %qD och basen %qD har inkompatibla typer"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "varianten %qD är en inbyggd"
@@ -46879,7 +46889,7 @@ msgstr "ogiltig användning av void-uttryck"
 msgid "invalid use of flexible array member"
 msgstr "ogiltig användning av flexibla vektormedlemmar"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "ogiltig användning av vektor med ospecificerade gränser"
@@ -47828,12 +47838,12 @@ msgstr "%<constexpr%>-initierare för en reell typ har komplex typ"
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr "%<constexpr%>-initierare för en binär flyttalstyp har en decimal typ"
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initiering av medlem som är en flexibel vektor"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "det går inte att initiera vektorn av %qT från en stränglitteral med typvektor %qT"
@@ -47874,7 +47884,7 @@ msgstr "initierarelement är inte beräkningsbart vid laddtidpunkt"
 msgid "invalid initializer"
 msgstr "ogiltig initierare"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "ogenomskinliga vektortyper kan inte initieras"
@@ -47889,8 +47899,8 @@ msgstr "extra klammergrupp vid slutet av initierare"
 msgid "braces around scalar initializer"
 msgstr "klamrar runt skalär initierare"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initiering av medlem som är en flexibel vektor i nästat sammanhang"
@@ -47980,7 +47990,7 @@ msgstr "överflödiga element i postinitierare"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionsinitiering av fält i %<struct%> deklarerad med attributet %<designated_init%>"
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "icke-statisk initiering av an flexibel vektormedlem"
@@ -49321,7 +49331,7 @@ msgstr "ingen passande %<operator %s%> för %qT"
 msgid "%q#D is private within this context"
 msgstr "%q#D är privat inom denna kontext"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "deklarerad privat här"
@@ -49331,7 +49341,7 @@ msgstr "deklarerad privat här"
 msgid "%q#D is protected within this context"
 msgstr "%q#D är skyddad inom denna kontext"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "deklarerad skyddad här"
@@ -49346,7 +49356,7 @@ msgstr "%q#D är oåtkomlig inom denna kontext"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "skickar NULL till icke-pekarargument %P till %qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, gcc-internal-format
 msgid "  declared here"
@@ -49677,7 +49687,7 @@ msgstr "ingen matchande funktion för anrop av %<%T::%s%E(%A)%#V%>"
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
@@ -50246,7 +50256,7 @@ msgstr "flexibel vektor medlem %qD i en i övrigt tom %q#T"
 msgid "next member %q#D declared here"
 msgstr "nästa medlem %q#D är deklarerad här"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
@@ -50367,7 +50377,7 @@ msgstr "ogiltig typ för parameter %d till %<constexpr%>-funktion %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "lambdan är implicit %<constexpr%> endast i C++17 och senare"
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%>-destruerare är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
@@ -50436,7 +50446,7 @@ msgstr "%qE beräknas till falskt"
 msgid "failed %<assume%> attribute assumption"
 msgstr "misslyckat %<assume%>-attributantagande"
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -50483,7 +50493,7 @@ msgstr "%qT är en tvetydig basklass till den dynamiska typen %qT av sin operand
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "den dynamiska typen %qT av sin operand har inte en otvetydig publik basklass %qT"
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -50607,7 +50617,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "derefererar en nollpekare i %qE"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -50706,7 +50716,7 @@ msgstr "%qs använder oinitierad byte vid avståndet %d"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs kan inte beräknas konstant eftersom argumentet inte kan tolkas"
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -50782,7 +50792,7 @@ msgstr "ändring av den aktiva medlemmen av en union %qD till %qD"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ändring av den aktiva medlemmen av en union %qD till %qD under initiering"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -50848,190 +50858,190 @@ msgstr "kontrollen skickas via definitionen av %qD med trådlagringsvaraktighet"
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "kontrollen skickas via definitionen av %qD med statisk Lagringsvaraktighet"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporär av den ej litterala typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "en %<reinterpret_cast%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "konvertering från pekartypen %qT till den aritmetiska typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "typkonvertering från %qT är inte tillåtet"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE är inte ett konstant uttryck när kassen %qT fortfarande är ofullständig"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "uttrycket %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "kontraktspredikatet är falskt i ett konstant uttryck"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "oväntat mall-id %qE"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "funktionskoncept måste anropas"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "adressen för ett anrop av %qs är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "oväntat uttryck %qE av sorten %s"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE är inte ett konstant uttryck eftersom det har referenser till muterbara delobjekt av %qT"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar till en ofullständigt initierad variabel"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar ett resultat av %<operator new%>"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE är inte ett konstant uttryck eftersom allokerad lagring inte har avallokerats"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "omedelbar evaluering returnerar adressen till en omedelbar funktion %qD"
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "konvertering av l-värde till r-värde av ett volatilt l-värde %qE med typen %qT"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "lambdafångst av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "för att det används som ett gl-värde"
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> från heltal till pekare"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "adress-av på ett objekt %qE med trådlokal eller automatisk lagring är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%<this%> används i ett konstant uttryck"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "lambdauttryck är inte ett konstant uttryck före C++17"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "new-uttryck är inte ett konstant uttryck före C++20"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "virtuella funktioner kan inte %<constexpr%> före C++20"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> är inte ett konstant uttryck eftersom %qE har polymorf typ"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "typkonvertering till %qT som inte är en heltalstyp i ett konstant uttryck"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD är definierad %<thread_local%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD är definierad %<static%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "division med noll är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "ingendera grenen av %<if%> är ett konstant uttryck"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ickekonstant vektorinitierare"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "en etikettdefinition i en %<constexpr%>-funktion är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
 # ast = abstract syntax tree
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
@@ -51604,7 +51614,7 @@ msgstr "korutinlöftestypen %qT deklarerar både %<return_value%> och %<return_v
 msgid "%<return_void%> declared here"
 msgstr "%<return_void%> deklarerades här"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "ingen medlem med namnet %qE i %qT"
@@ -51696,7 +51706,7 @@ msgstr "riktningsargumentet till %<__builtin_coro_promise%> måste vara en konst
 msgid "no suspend point info for %qD"
 msgstr "ingen suspenderingspunktsinformation för %qD"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr "%qE tillhandahålls av %qT men är inte användbart med funktionssignaturen %qD"
@@ -51716,23 +51726,23 @@ msgstr "vänteuttryck är inte tillåtna i hanterare"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "vektorer med variabel längd stödjs inte ännu i korutiner"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr "%qE tillhandahålls av %qT men %qE är inte markerad %<throw()%> eller %<noexcept%>"
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr "%qE är markerad %<throw()%> eller %<noexcept%> men ingen användbar %<get_return_object_on_allocation_failure%> tillhandahålls av %qT"
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr "%qE tillhandahålls av %qT men %<std::nothrow%> finns inte"
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "det går inte att initiera ett returobjekt av typen %qT med ett r-värde av typen %<void%>"
@@ -52212,7 +52222,7 @@ msgstr "än tidigare deklaration av %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "omdeklaration av %qD skiljer i %qs från tidigare deklaration"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "tidigare deklaration %qD"
@@ -52612,2274 +52622,2274 @@ msgstr "%qD är en funktion, inte en typ"
 msgid "%q#T is not a class"
 msgstr "%q#T är inte en klass"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klassmall med namnet %q#T i %q#T"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "ingen typ med namnet %q#T i %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "uppslagning av %qT i %qT är tvetydig"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en klassmall"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> namnger %q#D, som inte är en typ"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "mallparametrar stämmer inte med mallen %qD"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> är inte en potens av två"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr "%<--param destructive-interference-size=%d%> är mindre än %d"
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> är mindre än %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr "%<--param constructive-interference-size=%d%> är mindre än %d"
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> är större än %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha publika ickestatiska datamedlemmar"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "denna flexibilitet bör undvikas och kommer tas bort"
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonym post med basklasser"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med konstruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med destruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator är inte tillåten i anonymt aggregat"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoreras i deklaration av %q#T"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "attribut för %q#T måste komma efter nyckelordet %qs"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flera typer i en deklaration"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omdeklaration av inbyggd C++-typ %qT"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kan endast anges för variabler eller funktionsdeklarationer"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typnamn saknas i typedef-deklaration"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ förbjuder anonyma poster"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kan endast anges för funktioner"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kan endast anges för funktioner"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kan endast anges inuti en klass"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kan endast anges för konstruerare"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "en lagringsklass kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> ignorerades i denna deklaration"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kan inte användas till typdeklarationer"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoreras i explicit instansiering av %q#T"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "inget attribut kan användas på en explicit instansiering"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "ignorerar attribut använda på klasstypen %qT utanför dess definition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "ignorerar attribut använda på beroende typ %qT utan en associerad deklaration"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD är initierad (använd %qs istället)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarationen av %q#D har %<extern%> och är initierad"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definitionen av %q#D är markerad %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D är inte en statisk datamedlem i %q#T"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "icke-medlemsmalldeklaration av %qD"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "stämmer inte med medlemsmalldeklarationen här"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillåter inte %<%T::%D%> att definieras som %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubblerad initierare av %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklaration av %q#D utanför en klass är inte en definition"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr "extern-deklaration %q#D med blockräckvidd är inte tillåtet i modulens räckvidd"
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD definierad %<thread_local%> i en %qs-funktion är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD definierad %<static%> i en %qs-funktion är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabeln %q#D har initierare men ofullständig typ"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen i vektorn %q#D har ofullständig typ"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "aggregatet %q#D har ofullständig typ och kan inte definieras"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD är deklarerad som en referens men inte initierad"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "namn använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "namnet %qD använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "icketriviala designerade initierare stödjs inte"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-beteckningen %qE är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "initierare misslyckas med att bestämma storleken på %qD"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "vektorstorlek saknas i %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "vektor med storlek noll %qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstorlek på %qD är inte känd"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstorlek på %qD är inte konstant"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-variabeln %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-funktioners statiska data %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "du kan gå runt detta genom att ta bort initieraren"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "oinitierad %<const %D%>"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "oinitierad variabel %qD i %<constexpr%>-funktion"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "oinitierad variabel %qD i %<constexpr%>-kontext"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T har ingen användardefinierad standardkonstruerare"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "konstrueraren är inte användarens egna eftersom den är uttryckligen standarddefinierad i klasskroppen"
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "och den implicit definierade konstrueraren initierar inte %q#D"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ogiltig typ %qT som initierare för en vektor med typ %qT"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "initierare för %qT måste vara inom klamrar"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> använt i en designerad initierare i GNU-stil för klassen %qT"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT har ingen icke-statisk medlem med namnet %qD"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD har inte en direkt medlem i %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ogiltig initierare för %q#D"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-beteckningen %qE utanför aggregatinitierare"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "för många initierare för %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "för många klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "klamrar saknas runt initierare för %qT"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "strukturerad bindning har en ofullständig typ %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "element i vektorn %q#T har ofullständig typ"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "sammansatta litteral med variabel storlek"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D har ofullständig typ"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalärt objekt %qD kräver ett element i initieraren"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "i C++98 måste %qD initieras med en konstruerare, inte med %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "vektor %qD initierad från strängkonstant inom parentes %qE"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initierare är ogiltig för statisk medlem med konstruerare"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ej konstant initiering inom klassen av statisk medlem %qD"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ej konstant initiering inom klassen är felaktig för icke inline statisk medlem %qD"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en initiering utanför klassen krävs)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "referensen %qD initieras med sig själv"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "kunde inte hitta en variantdeklaration"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> på konstrueraren %qD"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> på destrueraren %qD"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> på standarddefinierad %qD"
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> på raderad %qD"
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> på virtuell %qD"
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tilldelning (inte initiering) i deklaration"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillåter inte specificeraren %<register%> av lagringsklass"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "specificeraren %<register%> av lagringsklass angiven"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarationen av %q#D har ingen initierare"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "initieraren för %<decltype(auto) %D%> har funktionstyp; glömde du %<()%>?"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "härledd typ %qT för %qD är ofullständig"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "variabelkoncept har ingen initierare"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skuggar tidigare typdeklaration av %q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> kan bara tillämpas på en variabel med statisk eller trådlagringsvaraktighet"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen %q#D är initierad som en variabel"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "det går inte dekomponera klasstypen %qT för att den har en anonym struct-medlem"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "kan inte dekomponera klasstypen %qT för att den har en anonym unionsmedlem"
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "det går inte att dekomponera en oåtkomlig medlem %qD av %qT"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: både den och dess basklass %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: dess basklasser %qT och %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "strukturerad bindning refererar till ofullständig typ %qT"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u namn angivet för strukturerad bindning"
 msgstr[1] "%u namn angivna för strukturerad bindning"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "endast %u namn angivet för strukturerad bindning"
 msgstr[1] "endast %u namn angivna för strukturerad bindning"
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "medan %qT dekomponeras till %wu element"
 msgstr[1] "medan %qT dekomponeras till %wu element"
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "medan %qT dekomponeras till %E element"
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr "%<std::tuple_element<%u, %T>::type%> är %<void%>"
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "i initieringen av variabel %qD i strukturerad bindning"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "det går inte att dekomponera unionstypen %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "det går inte att dekomponera typen %qT som inte är en klass eller vektor"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "det går inte att dekomponera lambdahöljestypen %qT"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "strukturerad bindning refererar till ofullständig klasstyp %qT"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "det går inte att dekomponera klasstypen %qT utan icke-statiska datamedlemmar"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "ickelokal variabel %qD deklarerad %<__thread%> behöver dynamisk initiering"
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "den icke-lokala variabeln %qD deklarerad %<__thread%> har en icke-trivial destruerare"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> tillåter dynamisk initialisering och destruktion"
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "initierare misslyckas med att bestämma storleken på %qT"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "vektorstorlek saknas i %qT"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "vektor med storlek noll %qT"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruerare för främmande class %qT kan inte vara en medlem"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruerare för främmande klass %qT kan inte vara en medlem"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD deklarerad som en %<virtual%>-variabel"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i variabeldeklaration"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD deklarerad som en %<virtual%>-parameter"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD deklarerad som en %<inline%>-parameter"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i parameterdeklaration"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD deklarerad som en %<virtual%>-typ"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD deklarerad som en %<inline%>-typ"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i typdeklaration"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD deklarerat som ett %<virtual%>-fält"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD deklarerat som ett %<inline%>-fält"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i fältdeklaration"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D deklarerad som en vän"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D deklarerad med en undantagsspecifikationer"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definitionen av %qD är inte i en namnrymd som innesluter %qT"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion %q#D deklarerad med typkvalificerare"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "konceptet %q#D deklarerad med funktionsparametrar"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "konceptet %q#D deklarerat med en härledd returtyp"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "koncept %q#D med icke-%<bool%>-returtyp %qT"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "konceptet %qD har ingen definition"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "ett funktionskoncept kan inte begränsas"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "begränsning av en funktion som inte är en mall"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definierar explicit specialisering %qD i vändeklaration"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ogiltig användning av mall-id %qD i deklaration av primär mall"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardargument är inte tillåtna i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> är inte tillåtet i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "vändeklarationen av %qD anger standardargument och är inte en definition"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "det går inte att deklarera %<::main%> som en mall"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "det går inte att deklarera %<::main%> som inline"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "det går inte att deklarera %<::main%> som %qs"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "det går inte att deklarera %<::main%> som static"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "härledningsguiden %qD måste deklareras med i samma räckvidd som %qT"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "härledningsguiden %qD måste ha samma åtkomst som %qT"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "härledningsguiden %qD får inte ha en funktionskropp"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "litteral operator med C-länkning"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD har en ogiltig argumentlista"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "heltalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "flyttalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "litterala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD måste vara en icke-medlems-funktion"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> måste returnera %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "omdefinition av implicit deklarerad %qD"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition av explicit standarddefinierad %q+D"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicit standarddefinierad här"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion %q#D deklarerad i klassen %qT"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "det går inte att deklarera %<::main%> som en global variabel"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "en icke-mallvariabel variabel kan inte vara %<concept%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "koncept måste definieras med namnrymdsräckvidd"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "koncept måste ha typen %<bool%>"
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "ett variabelkoncept kan inte begränsas"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med ofullständig typ"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> behövs för initiering i klassen av statisk datamedlem med icke heltalstyp %q#D"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med icke-litteral typ"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ogiltig initiering i klassen av statisk datamedlem med icke heltalstyp %qT"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ förbjuder initiering inom klassen av icke-konstant statisk medlem %qD"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ förbjuder initiering av medlemskonstant %qD av icke heltalstyp %qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "storlek på vektorn %qD av typen %qT är inte en heltalstyp"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "storlek på vektorn av typen %qT är inte en heltalstyp"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "storlek på vektorn %qD är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "storlek på vektorn är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med storlek noll"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ förbjuder vektor med storlek noll"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med variabel längd"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ förbjuder vektor med variabel längd"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "vektor %qD med variabel längd används"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "vektor med variabel längd används"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "spill i vektordimension"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD är deklarerad som en vektor av mallens platshållartyp %qT"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "skapar en vektor av mallens platshållartyp %qT"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "deklaration av %qD som en vektor av void"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "skapar vektor av void"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "deklaration av %qD som en vektor av funktioner"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "skapar vektor av funktioner"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "deklaration av %qD som en vektor av referenser"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "skapar vektor av referenser"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "deklaration av %qD som en vektor av funktionsmedlemmar"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "skapar vektor av funktionsmedlemmar"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qD som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "vektor med variabel längd av %<auto%>"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "en returtypsspecifikation för konstruerare är ogiltig"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kvalificerare är inte tillåtna vid konstruerardeklaration"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "specifikation av returtyp för destruerare är ogiltigt"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kvalificerare är inte tillåtna vid destruerardeklaration"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "returtyp angiven för %<operator %T%>"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kvalificerare är inte tillåtna på deklaration av %<operator %T%>"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "returtypen angiven för härledningsguiden"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kvalificerare är inte tillåtna på deklaration av härledningsguide"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "mallmallparameter %qT i deklaration av härledningsguide"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> i deklaration av härledningsguide"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "namnlös variabel eller fält deklarerad void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller fält deklarerad void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "specificeraren %<inline%> är ogiltig för variabeln %qD deklarerad med blockräckvidd"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline-variabler är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> får inte vara cv-kvalificerad"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T är inte en klass eller namnrymd"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "deklaration av %qE som en icke-funktion"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "deklaration av %qE som icke-medlem"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "deklarerar-id saknas, använder reserverat ord %qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktionsdefinition deklarerar inte parametrar"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklaration av %qD som en icke-funktion"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklaration av %qD som %<typedef%>"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "deklaration av %qD som en parameter"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "både %qs och %qs angivna"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "man kan använda högst en av specificerarna %<constinit%> och %<constexpr%>"
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "två eller fler datatyper i deklaration av %qs"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ förbjuder deklaration av %qs utan typ"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> stödjs inte på denna målarkitektur"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ stödjer inte %<__int%d%> för %qs"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> och %<unsigned%> givna tillsammans"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> och %<short%> angivna tillsammans"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs specificerad med %qT"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "%qs specificerad med %qD"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs specificerad med %<decltype%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs specificerad med %<typeof%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ogiltig för %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "mallargumentlistan saknas efter %qE; för härledning måste mallplatshållare följas av ett enkelt deklarerar-id"
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlem %qD kan inte deklareras både %<virtual%> och %<static%>"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "medlem %qD kan deklareras både %<virtual%> och %<constexpr%> endast i %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-deklaration ogiltig i parameterdeklaration"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklass angiven för mallparameter %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklass angiven för parameter %qs"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "en parameter kan inte deklareras %qs"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> utanför klassdeklaration"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "deklaration av strukturerad bindning får inte vara %qs"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "strukturerade bindningsdeklarationer kan vara %qs endast i %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "%<volatile%>-kvalificerad strukturerad bindning bör undvikas"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "deklaration av strukturerad bindning får inte vara C++98 %<auto%>"
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "deklaration av strukturerad bindning får inte ha typen %qT"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "typen måste vara en cv-kvalificerad %<auto%> eller en referens till en cv-kvalificerad %<auto%>"
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "deklaration av strukturerad bindning får inte ha begränsat %<auto%>-typ %qT"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flera lagringsklasser i deklaration av %qs"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "lagringsklass angiven för %qs"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "nästad funktion %qs är deklarerad %<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "toppnivådeklaration av %qs anger %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktionsdefinitionsområde %qs implicit auto och deklarerat %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "ogiltig specificerare av lagringsklass i vänfunktionsdeklarationer"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attributet ignorerat"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ett attribut som gäller en viss typspecificerare ignoreras"
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "onödiga parenteser i deklaration av %qs"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "ta port parenteser"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-klausul på returtypen"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "funktionen %qs använder typspecificeraren %<auto%> utan avslutande returtyp"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "härledd returtyp är endast tillgänglig med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuell funktion kan inte ha härledd returtyp"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %qT som sin typ istället för bara %<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %<decltype(auto)%> som sin typ istället för bara %<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ogiltig användning av %<decltype(auto)%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "härledd klasstyp %qD i funktionens returtyp"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "härledningsguiden för %qT måste ha en avslutande returtyp"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "den avslutande returtypen %qT hos deduktionsguiden är inte en specialisering av %qT"
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "avslutande returtyp är endast tillgänglig med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "funktionen %qs med avslutande returtyp är inte deklarerad med typspecificeraren %<auto%>"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en konverteringsfunktion kan inte ha en avslutande returtyp"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-kvalificerad returtyp bör undvikas"
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs är deklarerad som en funktion som returnerar en funktion"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs är deklarerad som en funktion som returnerar en vektor"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> på en funktions returtyp är inte tillåtet"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "destruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "konstruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "destruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "konstruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruerare kan inte deklareras %<virtual%>"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuella funktioner kan inte vara vänner"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "vändeklaration är inte i klassdefinition"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "det går inte att definiera vänfunktion %qs i en lokal klassdefinition"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<::%>"
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<%D::%>"
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruerare får inte ha parametrar"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "det går inte att deklarera pekare till %q#T"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "det går inte att deklarera referens till %q#T"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "det går inte att deklarera pekare medlem av %q#T"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "det går inte att deklarera en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "det går inte att deklarera en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "det går inte att deklarera en referens till %q#T, som inte är ett typedef- eller ett malltypargument"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "mall-id %qD använd som en deklarerare"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner är implicit vänner till sin klass"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "extra kvalifikation %<%T::%> på medlem %qs"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "det går inte att definiera medlemsfunktion %<%T::%s%> inuti %qT"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlemsfunktionen %<%T::%s%> inuti %qT"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlem %<%T::%s%> inuti %qT"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "icke-parameter %qs kan inte vara ett parameterpaket"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem får inte ha variabel typ %qT"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter får inte ha variabel typ %qT"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> utanför klassdeklaration"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> i vändeklaration"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "endast deklarationer av konstruerare och konverteringsoperatorer kan vara %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "icke-medlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "icke-objektmedlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referensen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef kan inte vara en funktionsdefinition"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef får inte vara en medlemsfunktionsdefinition"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> är inte tillåtet i en aliasdeklaration"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef deklarerad %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-klausul på typedef"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-namn får inte vara en nästad-namnspecificerare"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ förbjuder nästad typ %qD med samma namn som en omgivande klass"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet för vänklassdeklaration"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "mallparametrar kan inte vara vänner"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "försöker göra klassen %qT en vän med global räckvidd"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ogiltiga kvalificerare på typ som inte är medlemsfunktion"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-klausul på type-id"
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt deklarerare %qT använd som deklaration"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-klausul vid deklaration av icke-funktionstypen %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "det går inte att använda %<::%> i parameterdeklaration"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "det går inte att deklarera en parameter med %<decltype(auto)%>"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr "saknad mallargumentlista efter %qE; platshållare för mall är inte tillåtet i en parameter"
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "eller använd %<auto%> för en förkortad funktionsmall"
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "en %<auto%>-parameter är tillåten i detta sammanhang"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ogiltig användning av mallnamnet %qE utan en argumentlista"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ej statisk datamedlem deklarerad med platshållaren %qT"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ förbjuder den flexibla vektormedlemmen %qs"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ förbjuder flexibla vektormedlemmar"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ogiltig användning av %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "deklaration av funktionen %qD i ogiltig kontext"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen %qD deklarerad %<virtual%> inuti en union"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kan inte deklareras %<virtual%>, eftersom den alltid är statisk"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för destruerare %qD"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklaration av %qD som medlem av %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "en destruerare kan inte vara %qs"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för konstruerare %qD"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "en konstruerare kan inte vara %<concept%>"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ett koncept kan inte vara en medlemsfunktion"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kan inte vara %qs"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering av variabelmall %qD deklarerad som en funktion"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabelmallen är deklarerad här"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "fältet %qD har den ofullständiga typen %qT"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "namnet %qT har ofullständig typ"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "ett namnlöst fält är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "ett attribut som tillhör en vändeklaration som inte är en definition ignoreras"
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statiska %<constexpr%>-datamedlemmen %qD måste ha en initierare"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ickestatisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen %<auto%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen %<register%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen %<__thread%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen %<thread_local%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specificerare i %qs är inte tillåtet utanför en klassdefinition"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<static%> är ogiltigt för funktion %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<inline%> är ogiltig för funktionen %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuell icke klassfunktion %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs definierad utan att vara i klassräckvidd"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs deklarerad utan att vara i klassräckvidd"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "det går inte deklarera medlemsfunktionen %qD att ha statisk länkklass"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan inte deklarera en statisk funktion i en annan funktion"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> får inte användas vid definition (till skillnad mot deklaration) av statisk datamedlem"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem %qD deklarerad %<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "det går inte att deklarera medlem %q#D att ha extern länkklass"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarationen av %<constexpr%>-variabeln %qD är inte en definition"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "en variabel kan inte deklareras %<consteval%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initierad och deklarerad %<extern%>"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs har både %<extern%> och initierare"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "standardargument %qE använder %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardargument %qE använder lokal variabel %qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "felaktig användning av cv-kvalificerad typ %qT i en parameterdeklaration"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "felaktig användning av typen %<void%> i en parameterdeklaration"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-kvalificerad parameter bör undvikas"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD ogiltigt deklarerad metodtyp"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar pekare till vektor %qT med okänd gräns"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar referens till vektor %qT med okänd gräns"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ogiltig konstruerare, du menade förmodligen %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD är kanske inte deklarerad i en namnrymd"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD får inte deklareras som statisk"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD måste vara en icke-statisk medlemsfunktion"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD måste vara en medlemsfunktion"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%qD får bara vara en statisk medlemsfunktion med %<-std=c++23%> eller %<-std=gnu++23%>"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD måste vara antingen en medlemsfunktion som inte är statisk eller funktion som inte är medlem"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD måste ha ett argument med klass- eller uppräkningstyp"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ förhindrar överlagring av %<operator ?:%>"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD får inte ha variabelt antal argument"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD måste ha antingen noll eller ett argument"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD måste ha antingen ett eller två argument"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD måste ha %<int%> som sitt argument"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD måste ha %<int%> som sitt andra argument"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD får inte ha några argument"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD måste ha exakt ett argument"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD måste ha exakt två argument"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kan inte ha standardargument"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering av %qT till %<void%> kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering av %qT till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering av %qT till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering av %qT till en referens till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering av %qT till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "användardefinierad %qD beräknar alltid båda argumenten"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD skall returnera %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD skall returnera %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD skall returnera som värde"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "malltypparametern %qT används efter %qs"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "användning av aliasmallspecialisering %qT efter %qs"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-namnet %qD används efter %qs"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD har en tidigare deklaration här"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT refererad till som %qs"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT har en tidigare deklaration här"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT refererad till som enum"
@@ -54891,110 +54901,110 @@ msgstr "%qT refererad till som enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "mallargument krävs för %<%s %T%>"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "klassmallen %qD omdeklarerad som en icke-mall"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "kanske du vill explicit lägga till %<%T::%>"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "enum %q#D används utan tidigare deklaration"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "omdeklaration av %qT som en icke-mall"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "det går inte att deklarera %qD i en annan modul"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "härledd unionen %qT ogiltig"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT definierad med flera direkta baser"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT definierad med en direkt virtuell bas"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "bastyp %qT är ingen post- eller klasstyp"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiv typ %qT odefinierad"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "upprepat bastyp %qT ogiltig"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "underliggande typ stämmer inte överens i enum %q#T"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "olika underliggande typ i enum %q#T"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "det går inte att definiera %qD i en annan modul"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
@@ -55003,82 +55013,82 @@ msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ingen heltalstyp kan representera alla uppräkningsvärdena i %qT"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "uppräkningsvärde för %qD är inte en heltalstyp eller uppräkningstyp utan räckviddsbegränsning"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "uppräkningsvärde för %qD är inte en heltalskonstant"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<unsigned long%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<long%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "överspill i uppräkningsvärden vid %qD"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "uppräkningsvärdet %qE är utanför intervallet för den underliggande typen %qT"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ingen retursats i %<constexpr%>-funktion som returnerar icke-void"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD är redan definierad i klassen %qT"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "använder %qs"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "användning av %qD före härledning av %<auto%>"
@@ -55927,7 +55937,7 @@ msgstr "typ %qT är inte en direkt eller virtuell bas till %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typ %qT är inte en direkt bas till %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
@@ -56981,7 +56991,7 @@ msgstr "using-deklaration för icke-medlem vid klassräckvidd"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> med uppräkningsräckvidd %q#T är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT är inte en klass, namnrymd eller uppräkning"
@@ -57725,7 +57735,7 @@ msgstr "typer får inte definieras i ett %<typeid%>-uttryck"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "fel antal argument till %<__builtin_addressof%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "fel antal argument till %<__builtin_launder%>"
@@ -58434,12 +58444,12 @@ msgstr "endast konstruerare tar medlemsinitierare"
 msgid "cannot expand initializer for member %qD"
 msgstr "det går inte att expandera initierare för medlem %qD"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "minnesinitierare för %qD följer en konstruerardelegering"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "konstruerardelegering följer mem-initierare för %qD"
@@ -59037,7 +59047,7 @@ msgstr "mallargument saknas efter %qE"
 msgid "%qT not permitted in template argument"
 msgstr "%qT är inte tillåtet i mallargument"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -59898,7 +59908,7 @@ msgstr "%<[[omp::directive(%s)]]%> måste vara det enda angivna attributet på e
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "en %<ordered%>-klausul med parameter på en intervallbaserad %<for%>-slinga"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
@@ -60905,7 +60915,7 @@ msgstr "icke-malltyp %qT använd som en mall"
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "mallbegränsningsfel för %qD"
@@ -60998,276 +61008,276 @@ msgstr "funktion som returnerar en vektor"
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD instansieras för ett tomt paket"
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "initierare för %q#D expanderar till en tom uttryckslista"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%> för att expandera argumentpaket"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tom initierare i lambdas init-fångst"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD deklarerades inte i detta definitionsområde, och inga deklarationer hittades av en argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "fel antal argument till %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "fel antal argument till attributet %<assume%>"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT är/använder en namnlös typ"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansiering av icke-mall %q#D"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "explicit instansiering av variabelkonceptet %q#D"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "explicit instansiering av funktionskonceptet %q#D"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "explicit specifikation av %qD beror på sig själv"
@@ -61279,163 +61289,163 @@ msgstr "explicit specifikation av %qD beror på sig själv"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd %<-ftemplate-depth=%> för att öka maxvärdet)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mallparameter av härledd klasstyp som inte är en typ är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT är inte en giltig typ för en mallparameter som inte är en typ eftersom det inte är en struktur"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mallparameter av klasstyp som inte är en typ är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "nyckelordet %<template%> är inte tillåtet i deklarerar-id"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ett koncept kan inte begränsas"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "konceptet %qE är inte i namnrymdsräckvidd"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "konceptet %qE har multipla mallparameterlistor"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "härledning från klammeromsluten initierarlista kräver %<#include <initializer_list>%>"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "icke härledbar mall %qT använd utan mallargument"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "aliasmallhärledning är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "använd %qD direkt istället"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "kan inte härleda mallargument för kopieinitiering av %qT, eftersom den inte har några icke-explicita härledningsguider eller användardeklarerade konstruerare"
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "kan inte härleda mallargument till %qT, eftersom den inte några användbara härledningsguider"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "härledning av klassmallargument misslyckades:"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "explicita härledningsguider övervägs inte vid kopieinitiering"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "klassmallargumentshärledningen för %qT misslyckades: explicit härledningsguide vald i kopieringslistinitiering"
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "explicit härledningsguide deklarerad här"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT är kanske inte avsett att stödja härledning av klassmallargument"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "lägg till en härledningsguide för att undertrycka denna varning"
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "platshållarbegränsningar är inte uppfyllt"
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "härledd initierare uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "härledd returtyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "härledd uttryckstyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "felaktig användning av %qT i mallargument"
@@ -61746,7 +61756,7 @@ msgstr "ogiltig basklasspecifikation"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
@@ -62154,27 +62164,27 @@ msgstr "%<__builtin_is_corresponding_member%> behöver två argument"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr "argumentet till %<__builtin_is_corresponding_member%> är inte en pekare till en medlem"
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qD är inte en klass- eller aliasmall"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operanden till vikningsuttrycket har inget oexpanderat parameterpaket"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "båda argumenten i en binär vikning har oexpanderade parameterpaket"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "inga oexpanderade parameterpack i binär fold"
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "icke-pekar-argument till %<__builtin_launder%>"
@@ -62182,22 +62192,22 @@ msgstr "icke-pekar-argument till %<__builtin_launder%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "%<__builtin_bit_cast%>-måltyp %qT är en vektortyp"
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%>-måltyp %qT är inte trivialt kopierbar"
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%>-källtyp %qT är inte trivialt kopierbar"
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "%<__builtin_bit_cast%>-källstorlek %qE är inte lika med måltypstorleken %qE"
@@ -63429,220 +63439,220 @@ msgstr "framåtdeklaration av %q#T"
 msgid "declaration of %q#T"
 msgstr "deklaration av %q#T"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qD har ofullständig typ"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "ogiltig användning av ofullständig typ %q#T"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "ogiltig användning av medlemsfunktionen %qD (glömde du %<()%> ?)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "ogiltig användning av medlem %qD (glömde du %<&%>?)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "ogiltig användning av platshållaren %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "ogiltig användning av malltypparameter %qT"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "ogiltigt standardargument för mallmallparameter %qT"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "ogiltig användning av paketexpansion %qT"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "ogiltig användning av beroende typ %qT"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "ogiltig användning av klammeromsluten initierarlista"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "adress till överlagrad funktion utan typinformation från sammanhanget"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "överlagrad funktion utan typinformation från sammanhanget"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "otillräcklig sammanhangsinformation för att avgöra typen"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "konstruerarsyntax använd, men ingen konstruerare är deklarerad för typ %qT"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%<constinit%>-variabeln %qD har inte en konstant initierare"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "avsmalnande konvertering av %qE från %qH till %qI är felaktig i C++11"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "avsmalnande konvertering av %qE från %qH till %qI"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr " uttrycket har ett konstant värde men är inte ett C++ konstant uttryck"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "initierarsträng för %qT är för lång"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr "att initiera en basklass av typ %qT resulterar i objektskivning"
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "ta bort %<{ }%> runt initierare"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "det går inte att initiera aggregat med typ %qT med en sammansatt litteral"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initierare saknas för medlem %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "medlem %qD är oinitierad referens"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlem %qD med oinitierade referensfält"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "ordningen på designeraren för fält %qD stämmer inte med deklarationsordningen i %qT"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "inget fält %qD finns i unionen som initieras"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indexvärde istället för fältnamn i unioninitierare"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "cirkulär pekardelegering detekterad"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "basoperanden till %<->%> har icke-pekartyp %qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet av %<operator->()%> ger annat än pekare"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "basoperanden till %<->%> är inte en pekare"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kan inte användas som en medlemspekare eftersom den är av typen %qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "det går inte att applicera medlemspekare %qE på %qE, som är av typ %qT som inte är en klass"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "pekare-på-medlemstyp %qT är inkompatibel med objekttyp %qT"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pekare-till-medlemsfunktionstyp %qT kräver ett r-värde"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde före C++20"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionell konvertering till vektortypen %qT"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "%<auto(x)%> kan inte begränsas"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto(x)%> är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ogiltig värdeinitiering av referenstyper"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "anrop till funktion %qD som kastar ofullständig typ %q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "anrop till funktion som kastar ofullständig typ %q#T"
@@ -64578,7 +64588,7 @@ msgstr "BOZ-litteralkonstanten vid %L kan inte vara ett aktuellt argument till %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argument till %qs vid %L och %L kan inte båda vara litterala BOZ-konstanter"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Felaktig användning av en BOZ-litteralkonstant vid %L"
@@ -65671,12 +65681,12 @@ msgstr "Oanvänd initieringssträng vid %L för att variabeln har nollängd"
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initieringssträng vid %L höggs av för att stämma med variabeln (%ld/%ld)"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Delsträngs startindex vid %L är mindre än ett"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Slutindex för delsträng vid %L överstiger strängens längd"
@@ -65857,7 +65867,7 @@ msgstr "Felaktig INTENT-specifikation vid %C"
 msgid "deferred type parameter at %C"
 msgstr "fördröjd typparameter vid %C"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalärt INTEGER-uttryck förväntades vid %L"
@@ -67868,7 +67878,7 @@ msgstr "transformerande inbyggd %qs vid %L är inte tillåten i ett initieringsu
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Beräkning av ett initieringsuttryck utanför standarden vid %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "Funktionen %qs i initieringsuttrycket vid %L måste vara en inbyggd funktion"
@@ -68139,7 +68149,7 @@ msgstr "Gränssnitten stämmer inte överens i procedurpekartilldelning vid %L:
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för komponenten %qs vid %L: %s"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för %qs vid %L: %s"
@@ -68257,7 +68267,7 @@ msgstr "Tilldelning till sammanhängande pekare från icke sammanhängande mål
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Pekare vid %L i pekartilldelning kan överleva pekarmålet"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Pekarinitieringsmål vid %L får inte vara ALLOCATABLE"
@@ -68267,7 +68277,7 @@ msgstr "Pekarinitieringsmål vid %L får inte vara ALLOCATABLE"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Målet för pekarinitieringen vid %L måste ha attributet TARGET"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Pekarinitieringsmål vid %L måste ha attributet SAVE"
@@ -68398,7 +68408,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Otillåtet id i copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -68614,12 +68624,12 @@ msgstr "Första argumentet till definierad tilldelning vid %L måste vara INTENT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
@@ -68729,562 +68739,562 @@ msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt argum
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (ordning %d och ordning %d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ogiltigt procedurargument vid %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Gränssnitt stämmer inte överens i attrapprocedur %qs vid %L: %s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Aktuellt argument till sammanhängande pekarattrapp %qs vid %L måste vara enkelt sammanhängande"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Typen stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (%s/%s)."
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Typ stämmer inte i argument %qs vid %L; skickade %s till %s"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Aktuellt argument med antagen typ vid %L kräver att attrappargumentet %qs har antagen typ"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "Aktuellt argument med antagen typ vid %L motsvarande ett attrappargument %qs med antagen ordning måste ha antagen form eller antagen ordning"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Aktuellt argument till %qs vid %L måste vara polymorft"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Aktuellt argument till %qs vid %L måste ha samma deklarerade typ"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Aktuella argument till %qs vid %L måste vara obegränsat polymorfa eftersom det formella argumentet är en pekare eller allokerbar obegränsat polymorf entitet [F2008: 12.5.2.5]"
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktuellt argument till %qs vid %L måste vara en co-vektor"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Co-ordning stämmer inte i argument %qs vid %L (%d och %d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Aktuellt argument till %qs vid %L måste vara enkelt sammanhängande eller ett element i en sådan vektor"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Aktuellt argument till icke-INTENT(INOUT)-attrappen %qs vid %L, som är LOCK_TYPE eller har en LOCK_TYPE-komponent"
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Aktuellt argument till icke-INTENT(INOUT)-attrappen %qs vid %L, som är EVENT_TYPE eller har en EVENT_TYPE-komponent"
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Attrappargument %qs måste vara en pekare, vektor med antagen form eller ordning utan attributet CONTIGUOUS - eftersom det aktuella argumentet vid %L inte är enkelt sammanhängande och båda är ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor, INTENT(OUT) attrappargument %qs"
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor attrappargument %qs, som är ogiltigt om allokeringsstatusen ändras"
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorf skalär skickad till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Element av vektor med antagen form eller pekare skickat som aktuellt argument vid %L kan inte motsvara aktuellt argument vid %L"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element av vektor med antagen form eller pekare skickat till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Utökning: Skalärt CHARACTER-argument som inte är av standardsort och inte C_CHAR-sort med vektorattrappargument %qs vid %L"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Aktuellt skalärt CHARACTER-argument med attrappargument som är vektor %qs vid %L"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Nyckelordsargument %qs vid %L är felaktigt i en satsfunktion"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Nyckelordsargument %qs vid %L finns inte i proceduren; menade du %qs?"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Nyckelordsargument %qs vid %L finns inte i proceduren"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Nyckelordsargumentet %qs vid %L är redan associerat med ett annat aktuellt argument"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Fler aktuella än formella argument i proceduranrop vid %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returspecificerare saknas i subrutinanrop vid %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Oväntad alternativ returspecificerare i subrutinanrop vid %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Oväntad inbyggd NULL() vid %L till attrapp %qs"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nollpekare vid %L till icke-pekarattrapp %qs"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr "Aktuellt argument vid %L till attrapp med antagen typ har typparametrar eller är av en härledd typ med typgräns eller FINAL-procedurer"
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och pekare eller allokerbart attrappargument %qs vid %L"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och attrappargument med antagen form %qs vid %L"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Aktuellt argument vid %L till allokerbart eller pekarattrappargument %qs måste ha en fördröjd längdtypparameter om och endast om attrappen har en"
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Teckenlängden på aktuellt argument är kortare än attrappargumentet %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Aktuellt argument innehåller för få element för attrappargument %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "En procedurpekare förväntade som argument %qs vid %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Förväntade en procedur som argument %qs vid %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktuellt argument till %qs kan inte vara en vektor med antagen storlek vid %L"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr "Aktuellt argument till INTENT(OUT)-attrapp med antagen ordning %qs vid %L får inte ha okänd storlek"
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Aktuellt argument till %qs vid %L skall vara en pekare"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Aktuellt argument som inte är en pekare vid %L till pekarattrapp %qs"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr "Det aktuella argumentet till %qs vid %L måste vara en pekare eller ett giltigt mål för attrappekaren i en pekartilldelningssats"
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Co-indexerat faktiskt argument vid %L till pekarattrapp %qs"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Co-indexerat aktuellt argument vid %L till allokerbar attrapp %qs kräver INTENT(IN)"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Co-indexerat ASYNCHRONOUS eller VOLATILE aktuellt argument vid %L kräver att attrappen %qs varken har ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Co-indexerat faktiskt argument vid %L med allokerbar slutlig komponent till attrappen %qs kräver antingen VALUE eller INTENT(IN)"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktuellt CLASS-vektorargument till %qs måste vara en fullständig vektor vid %L"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktuellt argument till %qs skall vara en ALLOCATABLE vid %L"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Vektorsektion som aktuellt argument med vektorindex vid %L är inte kompatibelt med attributet INTENT(OUT), INTENT(INOUT), VOLATILE eller ASYNCHRONOUS på attrappargumentet %qs"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Aktuellt argument med antagen form vid %L är inte kompatibel med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Vektorsektion som aktuellt argument vid %L är inkompatibelt med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pekarvektor som aktuellt argument vid %L kräver ett attrappargument %qs med antagen form eller pekarvektor på grund av attributet VOLATILE"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Alternativ returspecifikation saknas i subrutinanrop vid %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Aktuellt argument saknas för argument %qs vid %L"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Felaktig komponentkod"
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Listor stämmer inte"
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): trasig data"
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Samma aktuella argument associerat med INTENT(%s)-argument %qs och INTENT(%s)-argument %qs vid %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Listor stämmer inte"
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Procedurargument vid %L är lokalt i en PURE-procedur och har attributet POINTER"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Co-indexerat aktuellt argument vid %L i en PURE-procedur skickas till ett INTENT(%s)-argument"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Co-indexerat aktuell argument vid %L i en PURE-procedur skickas till ett POINTER-attrappargument"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Co-indexerat polymorft aktuellt argument vid %L skickas ett polymorft attrappargument %qs"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Proceduren %qs anropad vid %L är inte explicit deklarerad; menade du %qs?"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Proceduren %qs anropad vid %L är inte explicit deklarerad"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Procedur %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Pekarobjektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Det allokerbara objektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allokerbar funktion %qs vid %L måste ha ett explicit funktionsgränssnitt"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Explicit gränssnitt krävs för polymorft argument vid %L"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för proceduren %qs vid %L"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argumentet ”%s” med antagen typ vid %L kräver ett explicit gränssnitt"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Aktuellt argument till LOCK_TYPE eller med LOCK_TYPE-komponent vid %L kräver ett explicit gränssnitt för proceduren %qs"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Aktuellt argument till EVENT_TYPE eller med EVENT_TYPE-komponent vid %L kräver ett explicit gränssnitt för proceduren %qs"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-argumentet till NULL krävs vid %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "Att skicka ett inbyggt NULL som aktuellt argumentet vid %L kräver ett explicit gränssnitt"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argumentet med antagen ordning kräver ett explicit gränssnitt vid %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Procedurpekarkomponent %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för procedurpekarkomponent %qs vid %L"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= krävs i NULL()-argument vid %L: Tvetydighet mellan de specifika funktionerna %s och %s"
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Kan inte hitta symbolen %qs"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiteten %qs vid %L finns redan i gränssnittet"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Felaktig gränssnittstyp"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Det går inte att skriva över GENERIC %qs vid %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs vid %L åsidosätter en procedurbindning deklarerad NON_OVERRIDABLE"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs vid %L får inte vara DEFERRED eftersom det åsidosätter en ej DEFERRED bindning"
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs vid %L åsidosätter en PURE-procedur och måste också vara PURE"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs vid %L åsidosätter en ELEMENTAL-procedur och måste också vara ELEMENTAL"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs vid %L åsidosätter en icke-ELEMENTAL-procedur och får inte heller vara ELEMENTAL"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs vid %L åsidosätter en SUBROUTINE och måste också vara en SUBROUTINE"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs vid %L åsidosätter en FUNCTION och måste också vara en FUNCTION"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Resultaten stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs vid %L åsidosätter en PUBLIC-procedur och får inte vara PRIVATE"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Attrappargument %qs till %qs vid %L skulle ha namnet %qs för att stämma med motsvarande argument i den åsidosatta proceduren"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Argument stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs vid %L måste ha samma antal formella argument som den åsidosatta proceduren"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs vid %L åsidosätter en NOPASS-bindning och måste också vara NOPASS"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs vid %L åsidosätter en bindning med PASS och måste också vara PASS"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Attrappargument för pass-objekt till %qs vid %L måste vara på samma position som attrappargumentet för pass-objektet i den åsidosatta proceduren"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO-attrappargument vid %L måste ha typen %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO-attrappargument vid %L måste ha KIND = %d"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO-attrappargument vid %L måste vara skalärt"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO-attrappargument vid %L måste vara en ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "DTIO-teckenargumentet vid %L måste ha antagen längd"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO-attrappargument vid %L måste ha INTENT %s"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Alternativ retur vid %L är inte tillåtet i en DTIO-procedur"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO-proceduren %qs vid %L måste vara en subrutin"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "För få attrappargument i DTIO-proceduren %qs vid %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "För många attrappargument i DTIO-proceduren %qs vid %L"
@@ -69468,7 +69478,7 @@ msgstr "Konvertering från %s till %s vid %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Kan inte konvertera %s till %s vid %L"
@@ -70019,7 +70029,7 @@ msgstr "NAMELIST %qs i READ-sats vid %L innehåller symbolen %qs som inte får s
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
@@ -70586,7 +70596,7 @@ msgstr "STOP-koden vid %L måste vara standard tecken-KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-kod vid %L måste vara standard heltal KIND=%d"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "QUIET-specificerare vid %L måste vara en skalär LOGICAL"
@@ -72440,8 +72450,8 @@ msgstr "ORDERED-klausulparameter är mindre än COLLAPSE vid %L"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "en ORDER-klausul får inte användas tillsammans med ORDERED vid %L"
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
@@ -74407,708 +74417,718 @@ msgstr "Teckenvärd modulprocedur %qs vid %L får inte ha antagen längd"
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Teckenvärd intern funktion %qs vid %L får inte ha antagen längd"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "Funktion %s vid %L har ingångar med vektorspecifikationer som ej stämmer överens"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "Funktion %s vid %L har ingången %s med egenskaper som inte stämmer"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "Funktionen ”%s” vid %L med ingångar som returnerar variabler av olika stränglängder"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "FUNCTION-resultat %s får inte vara en vektor i FUNCTION %s vid %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "ENTRY-resultat %s får inte vara en vektor i FUNCTION %s vid %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "FUNCTION-resultat %s får inte vara en POINTER i FUNCTION %s vid %L"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "ENTRY-resultat %s får inte vara en POINTER i FUNCTION %s vid %L"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "FUNCTION-resultat %s får inte vara ALLOCATABLE i FUNCTION %s vid %L"
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "ENTRY-resultat %s får inte vara ALLOCATABLE i FUNCTION %s vid %L"
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "FUNCTION-resultat %s får inte vara av typen %s i FUNCTION %s vid %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "ENTRY-resultat %s får inte vara av typen %s i FUNCTION %s vid %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "Den globala entiteten %qs vid %L får inte förekomma i ett COMMON-block vid %L"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "Den globala entiteten %qs vid %L får inte förekomma i ett COMMON-block"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr "COMMON-block vid %L"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "Variabel %qs vid %L är i COMMON men endast i BLOCK DATA är initiering tillåten"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "Initierad variabel %qs vid %L är i en blank COMMON men initiering ir endast tillåten i namngivna common-block"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr "%qs vid %L kan inte förekomma i COMMON [F2008:C5100]"
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "Härledd typvariabel %qs i COMMON vid %L har varken attributet SEQUENCE eller BIND(C)"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "Härledd typvariabel %qs i COMMON vid %L har en slutlig komponent som är allokerbar"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "Härledd typvariabel %qs i COMMON vid %L får inte ha standardinitierare"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr "I Fortran 2003 är COMMON %qs-block vid %L en global identifierare och måste således ha samma bindningsnamn som COMMON-blocket med samma namn vid %L: %s resp %s"
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "COMMON-block %qs vid %L använder samma globala identifierare som en entitet vid %L"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr "Fortran 2008: COMMON-block %qs med bindningsetikett vid %L delar identifierare med en global ej-COMMON-blockentitet vid %L"
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "COMMON-block vid %L med bindningsetikett %qs använder samma globala identifierare som entiteten vid %L"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "COMMON-block %qs vid %L används som PARAMETER vid %L"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "COMMON-blocket %qs vid %L får inte ha attributet EXTERNAL"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "COMMON-block %qs vid %L är också en inbyggd procedur"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "COMMON-block %qs vid %L som också är ett funktionsresultat"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "COMMON-block %qs vid %L som också är en global procedur"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr "KIND-parametern %qs i PDT-konstrueraren vid %C har inget värde"
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "Ordningen på elementet i postkonstrueraren vid %L stämmer inte överens med komponentens (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "Elementet i postkonstrueraren vid %L, för pekarkomponent %qs, är %s men borde vara %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Olika teckenlängder (%wd/%wd) för pekarkomponenten %qs i konstrueraren vid %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "NULL i postkonstrueraren vid %L används på komponenten %qs, som varken är en POINTER eller en ALLOCATABLE"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "Gränssnittet stämmer inte för procedurpekarkomponenten %qs i postkonstruerare vid %L: %s"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "Felaktig vektorspecifikation av komponenten %qs refererad i postkonstruerare vid %L"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "Formen på komponenten %qs i postkonstrueraren vid %L skiljer från formen på den deklarerade komponenten för dimension %d (%ld/%ld)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "Elementet i postkonstrueraren vid %L, för pekarkomponent %qs, borde vara en POINTER eller en TARGET"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "Ogiltigt uttryck i postkonstrueraren för pekarkomponent %qs vid %L i PURE-procedur"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "Den övre gränsen i sista dimensionen måste vara med i referensen till vektorn %qs med antagen storlek vid %L"
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "%qs vid %L är tvetydig"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC procedur %qs är inte tillåten som aktuellt argument vid %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Typ angiven för inbyggd funktion %qs vid %L ignoreras"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Inbyggd subrutin %qs vid %L får inte ha en typspecificerare"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%qs deklarerad INTRINSIC vid %L finns inte"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Den inbyggda %qs deklarerad INTRINSIC vid %L är inte tillgänglig i den aktuella standardinställningen utan i %s.  Använd en lämplig flagga %<-std=*%> eller aktivera %<-fall-intrinsics%> för att använda den."
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etikett %d som refereras vid %L är aldrig definierad"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Den härledda typen %qs används som aktuellt argument vid %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Satsfunktionen %qs vid %L får inte vara ett aktuellt argument"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Inbyggd %qs vid %L får inte vara ett aktuellt argument"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Den interna proceduren %qs används som aktuellt argument vid %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL icke INTRINSIC procedur %qs är inte tillåten som aktuellt argument vid %L"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Det går inte att hitta en angiven INTRINSIC-procedur för referensen %qs vid %L"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Symbolen %qs vid %L är tvetydig"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Värdesargument vid %L har inte en numerisk typ"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Värdeargument vid %L får inte vara en vektor eller vektorsektion"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Värdesargument vid %L är inte tillåtet i denna kontext"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Att skicka intern procedur som plats vid %L är inte tillåtet"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL icke INTRINSIC procedur %qs är inte tillåten som aktuellt argument vid %L"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Co-indexerat aktuellt argument vid %L med slutlig pekarkomponent"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "%qs vid %L är en vektor och OPTIONAL.  Om den inte finns, då kan den inte vara det aktuella argumentet i en ELEMENTAL-procedur om det inte finns ett ej valfritt argument med samma ordning (Fortran 2018, 15.5.2.12)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Aktuellt argument vid %L för INTENT(%s)-attrapp %qs av ELEMENTAL-subrutin %qs är en skalär, men ett annat aktuellt argument är en vektor"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Returtypen stämmer inte för funktionen %qs vid %L (%s/%s)"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Gränssnitt stämmer inte överens i den globala proceduren %qs vid %L: %s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Det finns ingen specifik funktionen för den generiska %qs vid %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generisk funktion %qs vid %L är inte konsistent med ett specifikt inbyggt gränssnitt"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Funktionen %qs vid %L är INTRINSIC men är inte kompatibel med en inbyggd"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Kan inte slå upp den specifika funktionen %qs vid %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr "Saknad explicit deklaration med attributet EXTERNAL för symbolen %qs vid %L"
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Referens till den orena funktionen %qs vid %L är inuti ett FORALL-%s"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Referens till den orena funktionen %qs vid %L är inuti ett DO CONCURRENT-%s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Referens till den orena funktionen %qs vid %L inuti en PURE-procedur"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Oväntat skräp efter %qs vid %L"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs vid %L är inte en funktion"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs får inte refereras vid %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr "ABSTRACT INTERFACE %qs vid %L får inte ha ett antaget teckenlängdsresultat (F2008: C418)"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Funktionen %qs är deklarerad CHARACTER(*) och får inte användas vid %L eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): felaktig funktionstyp"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr "En litteral BOZ-konstant vid %L får inte förekomma som ett faktiskt argument i en funktionsreferens"
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Användardefinierad ej ELEMENTAL funktion %qs vid %L är inte tillåten i WORKSHARE-konstruktion"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs vid %L får inte anropas rekursivt, eftersom funktionen %qs inte är RECURSIVE"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktion %qs vid %L får inte anropas rekursivt, eftersom den inte är RECURSIVE"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "Att använda funktionen %qs vid %L bör undvikas"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Subrutinanrop till %qs i FORALL-block vid %L är inte PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Subrutinanrop till %qs i DO CONCURRENT-block vid %L är inte PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Subrutinanrop till %qs vid %L är inte PURE"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Det finns ingen specifik subrutinen för den generiska %qs vid %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generisk subrutin %qs vid %L är inte konsistent med ett inbyggt subrutingränssnitt"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Subrutin %qs vid %L är INTRINSIC men är inte kompatibel med en inbyggd"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Kan inte slå upp den specifika subrutinen %qs vid %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs vid %L har en typ som inte är konsistent med CALL vid %L"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs vid %L är får inte anropas rekursivt, eftersom subrutinen %qs inte är RECURSIVE"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs vid %L får inte anropas rekursivt, eftersom den inte är RECURSIVE"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): felaktig funktionstyp"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "Att använda subrutinen %qs vid %L bör undvikas"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Formerna för operanderna vid %L och %L är inte konforma"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Felaktig inbyggd"
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Den orena funktionen %qs vid %L beräknas eventuellt inte"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "Den orena funktionen vid %L beräknas eventuellt inte"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "BOZ-litteralkonstanten vid %L får inte vara en operand till den unära operatorn %qs"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Operander vid %L och %L kan inte förekomma som operander av den binära operatorn %qs"
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "BOZ-litteralkonstanten nära %L får inte förekomma som en operand till en relationsoperator"
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "Likhetsjämförelse av %s vid %L"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "Olikhetsjämförelse av %s vid %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Felaktig inbyggd"
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i co-dimension %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i co-dimension %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Otillåtet steg på noll vid %L"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Felaktig vektorreferens"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Högraste övre gränsen av en sektion av vektor med antagen storlek inte angiven vid %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Ordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Co-indexordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Co-index i co-dimension %d måste vara en skalär vid %L"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Vektorindex vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Vektorindex vid %L måste ha INTEGER-typ, fann %s"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-vektorindex vid %L"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Dim-argumentet vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Dim-argumentet vid %L måste ha INTEGER-typ"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "Felaktig vektorreferens till en icke-vektorentitet vid %L"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): oanvänd as(1)"
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): oanvänd as(2)"
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Vektorindex vid %L är en vektor med ordning %d"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Startindex för delsträng vid %L måste typen INTEGER"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Startindex för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Slutindex för delsträng vid %L måste ha typen INTEGER"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Slutsträng för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Slutindex för delsträng vid %L är för stort"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Felaktig vektorreferens"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet POINTER vid %L"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet ALLOCATABLE vid %L"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Två eller flera delreferenser med ordning skild från noll får inte anges vid %L"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Två vektorspecifikationer"
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får bara användas som ett aktuellt argument"
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt argument"
@@ -75117,12 +75137,12 @@ msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen typ %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktuellt argument"
@@ -75131,293 +75151,293 @@ msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktue
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen ordning %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall inte ha en subobjektreferens"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen typ vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen ordning vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs, använd i ett specifikationsuttryck, refereras vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs används vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorft subobjekt till co-indexerat objekt vid %L"
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Co-indexerat objekt med polymorf allokerbar delkomponent vid %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Att använda variabeln %qs vid %L bör undvikas"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs vid %L är värdassocierad vid %L in i en innesluten procedur med en intern procedur med samma namn"
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fel i typbundet anrop vid %L"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Skickat objekt vid %L måste vara skalär"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för procedurpekarkomponentanrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för typbundet proceduranrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basobjekt för typbundet NOPASS-proceduranrop vid %L måste vara skalärt"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Hittade ingen matchande specifik bindning för anropet till GENERIC %qs vid %L"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs vid %L skulle vara en FUNCTION"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Felaktig uttryckstyp"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s vid %L måste vara en skalär"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s vid %L måste vara ett heltal"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s vid %L måste vara INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Steguttryck i DO-slinga vid %L får inte vara noll"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-slinga vid %L kommer köras noll gånger"
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller över"
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller under"
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-steguttryck vid %L måste vara en skalär %s"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-steguttryck vid %L får inte vara noll"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-index %qs får inte förekomma i triplettspecifikation vid %L"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allokeringsobjekt vid %L måste vara ALLOCATABLE eller en POINTER"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Co-indexerat allokerbart objekt vid %L"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Källuttryck vid %L måste vara skalärt eller ha samma ordning som allokeringsobjektet vid %L"
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typen på entiteten vid %L är typinkompatibel med källuttrycket vid %L"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allokeringsobjektet vid %L och källuttrycket vid %L skall ha samma sorts typparameter"
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen LOCK_TYPE eller ha en LOCK_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen EVENT_TYPE eller ha en EVENT_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Allokering %s av ABSTRACT bastyp vid %L behöver en typspecifikation eller source-uttryck"
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Allokerar %s vid %L med typspecifikation kräver samma teckenlängdsparameter som i deklarationen"
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation eller vektorvärt SOURCE=-uttryck krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Co-vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Felaktig co-vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Övre cobound är mindre än den lägre cobound vid %L"
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Övre cobound är mindre än lägre cobound av 1 vid %L"
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Felaktig vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs får inte förekomma i vektorspecifikationen vid %L i samma ALLOCATE-sats där den själv allokeras"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%<*%> förväntades i co-indexspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Statvariabel vid %L måste vara en INTEGER-variabel"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Statvariabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG vid %L är oanvändbart utan en STAT-tagg"
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG-variabeln vid %L måste vara en skalär standard-CHARACTER-variabel"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allokeringsobjekt vid %L förekommer också vid %L"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
@@ -75426,284 +75446,284 @@ msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-etikett vid %L överlappar med CASE-etikett vid %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "uttryck i CASE-sats vid %L måste vara av typ %s"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Uttryck i CASE-sats vid %L måste ha sort %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Uttryck i CASE-sats vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Valuttryck i beräknad-GOTO-sats vid %L måste vara ett skalärt heltalsuttryck"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument till SELECT-sats vid %L kan inte vara %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumentet till SELECT-satsen vid %L måste vara ett skalärt uttryck"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Uttryck i CASE-sats vid %L ligger inte i intervallet %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE vid %L får inte följas av ett andra DEFAULT CASE vid %L"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logiskt intervall CASE-sats vid %L är inte tillåtet"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstant logiskt värde i CASE-sats upprepas vid %L"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Intervallspecifikationen vid %L kan aldrig matchas"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Den associerande entiteten %qs vid %L är en procedurpekare"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Den härledda typen %qs får inte användas som en variabel vid %L"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Den associerande entiteten %qs vid %L är ett procedurnamn"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Det associerande selector-uttrycket vid %L ger en procedur"
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektorn vid %L får inte vara NULL()"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektorn vid %L har ingen typ"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associationsnamn %qs vid %L används som en vektor"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-väljare vid %L behöver en temporär som inte är implementerad ännu"
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektorer skall vara polymorfiska i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektorn vid %L får inte vara co-indexerad"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS vid %L överlappar med TYPE IS vid %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Härledd typ %qs vid %L måste vara utökningsbar"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Härledd typ %qs vid %L måste vara en utökning av %qs"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Oväntad inbyggd typ %qs vid %L"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Typspecifikationen vid %L skall ange att varje längdtypparameter är antagen"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Dubbelt CLASS IS-block i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT vid %L upprepas vid %L"
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) vid %L upprepas vid %L"
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) vid %L upprepas vid %L"
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) vid %L får inte användas med en pekare eller allokerbar selector vid %L"
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ogiltigt sammanhang för inbyggd NULL () vid %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s-procedur vid %L måste vara rekursiv"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte vara polymorft om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha POINTER-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Dataöverföringselement vid %L får inte ha procedurpekarkomponenter"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha ALLOCATABLE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Dataöverföringselement vid %L får inte ha PRIVATE-komponenter"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha PRIVATE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Dataöverföringselement vid %L får inte vara en full referens till en vektor med antagen storlek"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Låsvariabel vid %L måste vara en skalär av typen LOCK_TYPE"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Händelsevariabeln vid %L måste vara en skalär av typen EVENT_TYPE"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor eller co-indexerat"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor men inte co-indexerat"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=-argumentet vid %L måste vara en skalär INTEGER-variabel"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=-argumentet vid %L måste vara en skalär LOGICAL-variabel"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT=-argumentet vid %L måste vara ett skalärt INTEGER-uttryck"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller INTEGER-uttryck av ordning 1"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Bildmängdsargument vid %L måste vara mellan 1 och num_images()"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sats vid %L är inte en giltig grenmålssats för grensatsen vid %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Gren vid %L kan orsaka en oändlig slinga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar CRITICAL-konstruktion för etikett vid %L"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
@@ -75711,207 +75731,207 @@ msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Etiketten vid %L är inte i samma block som GOTO-satsen vid %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-mask vid %L har inkonsistent form"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-tilldelningsmål vid %L har inkonsistent form"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Ej ELEMENTAL användardefinierad tilldelning i WHERE vid %L"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ej stödd sats inuti WHERE vid %L"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Tilldelning till en FORALL-indexvariabel vid %L"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL med index %qs används inte på vänster sida av en tilldelning vid %L och kan därför orsaka multipla tilldelningar till detta objekt"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-konstruktion vid %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär variabel av heltalstyp"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "En yttre FORALL-konstruktion har redan ett index med detta namn %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE-klausul vid %L kräver en LOGICAL-vektor"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Felaktig blocktyp"
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i tilldelning (%ld/%ld) vid %L"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Co-indexerat uttryck vid %L är tilldelat till en härledd typvariabel med en POINTER-komponent i en PURE-procedur"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "I ett rent underprogram skall inte ett INTENT(IN) attrappargument användas som uttrycket vid %L av en inbyggd tilldelningssats i vilken variabeln är av an härledd typ om den härledda typen har en pekarkomponent på någon nivå av komponentvalet."
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Tilldelning till en co-indexerad variabel vid %L i en PURE-procedur"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Tilldelning till en polymorf co-vektor vid %L är inte tillåtet"
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L kräver %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "Ej allokerbar variabel får inte vara polymorf i inbyggd tilldelning vid %L - kontrollera att det finns en matchande specifik subrutin för operatorn %<=%>"
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Co-indexerad variabel får inte ha en allokerbar yttersta komponent i tilldelningen vid %L"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "ATT GÖRA: typbegränsad definierad tilldelning vid %L inte gjord för att multipla delvektorreferenser skulle uppträda i intermediära uttryck."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Procedurpekartilldelning vid %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsresultatet på vänstersidan av tilldelningen vid %L måste ha attributet pointer."
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "TEAM-argumentet till %qs vid %L måste vara ett skalärt uttryck av typen TEAM_TYPE"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "TEAM NUMBER-argumentet till FORM TEAM vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO-sats vid %L kräver en skalär INTEGER-variabel"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabeln %qs har inte tilldelats någon måletikett vid %L"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternativ RETURN-sats vid %L kräver en SCALAR-INTEGER-returspecificerare"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Inbyggd tilldelning förväntades i OMP WORKSHARE vid %L"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-sats vid %L kräver en skalär standard-INTEGER-variabel"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ogiltig NULL vid %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Aritmetisk IF-sats vid %L kräver ett skalärt REAL- eller INTEGER-uttryck"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Inget uttryck i DO WHILE"
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Avslutsvillkor i DO WHILE-slinga vid %L måste vara ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-maskklausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Felaktig satskod"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Att använda parametern %qs deklarerad vid %L bör undvikas"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en entitet vid %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använder samma globala identifierare som entiteten vid %L från modulen %qs"
@@ -75919,984 +75939,984 @@ msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använde
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Proceduren %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som entiteten vid %L"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Stränglängden vid %L är för stor"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Den allokerbara vektorn %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalärt objekt %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Vektorpekaren %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Vektor %qs vid %L kan inte ha en fördröjd form"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typen %qs på CLASS-variabeln %qs vid %L är inte utvidgningsbar"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-variabel %qs vid %L måste vara en attrapp, allokerbar eller pekare"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Typen %qs kan inte vara värdassocierad vid %L för att den blockeras av ett inkompatibelt objekt med samma namn deklarerat vid %L"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Implicerad SAVE för modulvariabeln %qs vid %L, behövs på grund av standardinitieringar"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Enheten %qs vid %L har en fördröjd typparameter och kräver antingen attributet POINTER eller ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul- eller huvudprogramvektorn %qs vid %L måste ha konstant form"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entitet med antagen teckenlängd vid %L måste vara ett attrappargument eller en PARAMETER"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs vid %L måste ha konstant teckenlängd i detta sammanhang"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-variabeln %qs vid %L måste ha konstant teckenlängd"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Allokerbar %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Extern %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Attrapp-%qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Inbyggd %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsresultat %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisk vektor %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s vid %L"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Teckenvärd satsfunktion %qs vid %L måste ha konstant längd"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs är av en PRIVATE-typ och kan inte vara ett attrappargument till %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Proceduren %qs i PUBLIC-gränssnittet %qs vid %L tar attrappargument för %qs som är PRIVATE"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externt objekt %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktion %qs vid %L måste ha ett skalärt resultat"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Satsfunktionen %qs vid %L får inte ha attributet pointer eller allocatable"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha vektorvärde"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha pekarvärde"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara pure"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara rekursiv"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktionen %qs vid %L"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Procedurpekaren %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Attrapprocedur %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionens resultatvariabel %qs vid %L för den elementära funktionen %qs skall inte ha ett attribut ALLOCATABLE eller POINTER"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med SAVE-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med INTENT-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med RESULT-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribut i konflikt med FUNCTION-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Procedurpekarresultat %qs vid %L saknar pekarattributet"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "ELEMENTAL-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "PURE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "RECURSIVE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s mellan MODULE PROCEDURE-deklarationen i MODULE %qs och deklarationen vid %L i (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Gränssnittet för %qs vid %L måste vara explicit"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-procedur %qs vid %L är inte en SUBROUTINE"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-procedur vid %L måste ha precis ett argument"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument till FINAL-procedur vid %L måste ha typen %qs"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr "FINAL-procedur vid %L med argument med antagen ordning måste vara den enda avslutaren med samma sort/typ (F2018: C790)"
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument till FINAL-procedur vid %L får inte vara en POINTER"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument till FINAL-procedur vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument till FINAL-procedur vid %L får inte vara OPTIONAL"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument till FINAL-procedur vid %L får inte vara INTENT(OUT)"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Ickeskalär FINAL-procedur vid %L skulle ha argument med antagen form"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL-procedur %qs deklarerad vid %L har samma ordning (%d) som %qs"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Endast vektor-FINAL-procedurer deklarerade för den härledda typen %qs definierade vid %L, föreslår även en skalär om inte en avslutare med antagen ordning har deklarerats"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs och %qs kan inte blandad FUNCTION/SUBROUTINE för GENERIC %qs vid %L"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs och %qs för GENERIC %qs vid %L är tvetydiga"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Odefinierad specifik bindning %qs som mål för GENERIC %qs vid %L"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs vid %L måste ha som mål en specifik bindning, %qs är också GENERIC"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs vid %L kan inte åsidosätta en specifik bindning med samma namn"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typbindningsoperator vid %L kan inte vara NOPASS"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs måste vara en modulprocedur eller en extern procedur med ett explicit gränssnitt vid %L"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Proceduren %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Procedur %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Ickepolymorfa attrappargument för pass-objekt till %qs vid %L"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Skickat objekt-attrappargument till %qs vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara POINTER"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Procedur %qs vid %L har samma namn som en komponent i %qs"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proceduren %qs vid %L har samma namn som den ärvd komponent i %qs"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Härledd typ %qs deklarerad vid %L måste vara ABSTRACT för att %qs är DEFERRED och inte åsidosatt"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Co-vektorkomponent %qs vid %L måste vara allokerbar med fördröjd form"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponenten %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponenten %qs vid %L med co-vektorkomponent skall skalär som inte är en pekare eller allokerbar"
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Component %qs vid %L har attributet CONTIGUOUS men är inte en vektorpekare"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponenten %qs med typen BIND(C) vid %L måste ha längden ett"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Procedurpekarkomponent %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Procedurpekarkomponent %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte ha attributet POINTER"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponent %qs i %qs vid %L har samma namn som en ärvd typbunden procedur"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Teckenlängd på komponent %qs behöver vara ett konstant specifikationsuttryck vid %L"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Teckenlängdsuttrycket för komponenten %qs vid %L måste vara av typen INTEGER, hittade %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Teckenkomponent %qs av %qs vid %L med fördröjd längd måste vara en POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "komponenten %qs är en PRIVATE-typ och kan inte vara en komponent i %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorf komponent %s vid %L i SEQUENCE- eller BIND(C)-typ %s"
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponent %s av SEQUENCE-typ deklarerad vid %L har inte attributet SEQUENCE"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initierare som står i konflikt i unionen vid %L och %L"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Eftersom utvidgningen av %qs vid %L har en co-vektorkomponent, skall föräldratypen %qs också ha en"
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Ej utvidgningsbar härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Den parametriserade typen %qs har inte någon komponent som motsvarar parametern %qs vid %L"
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet %qs på funktionen %qs vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Härledd typ %qs vid %L har inte deklarerats"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variabeln %qs vid %L får inte ha attributet PARAMETER"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Objektet %qs vid %L har en fördröjd LEN-parameter %qs och är varken allokerbar eller en pekare"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "AUTOMATIC-objektet %qs vid %L får inte ha attributet SAVE eller vara en variabel deklarerad i huvudprogrammet, en modul eller en submodul(F08/C513)"
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Objektet %qs vid %L med ASSUMED typparametrar måste vara en attrapp eller en SELECT TYPE-selektor(F08/4.2)"
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Ledsen, allocatable/pointer-komponenter i co-vektor av polymorf (CLASS)-typ vid %L stödjs inte"
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr "%<omp_all_memory%>, deklarerat vid %L, får endast användas i OpenMP-klausulen DEPEND"
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Felaktig specifikation för vektor med antagen storlek vid %L"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-variabeln %qs vid %L måste ha längden ett"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen EVENT_TYPE eller med en delkomponent av typen EVENT_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av EVENT_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namnlistan %qs får inte vara ett argument till en subrutin eller funktion vid %L"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbar entitet förväntades nära %L"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "DATA-objektet nära %L har pekarattributet och det motsvarande DATA-värdet är inte ett giltigt initialt-data-mål"
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "DATA-elementet %qs vid %L får inte ha attributet ALLOCATABLE"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "steget i implicerad do-slinga vid %L skall inte vara noll"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Självreferens i uttrycket för teckenlängd för %qs vid %L"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -77791,7 +77811,7 @@ msgstr "Överlappande olika initierare i EQUIVALENCE vid %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Överlappande olika initierare i EQUIVALENCE vid %C"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr "Postkonstrueraren vid %C har avslutats. Denna funktion togs bart av f08/0011. Använd -std=f2018 eller -std=gnu för att eliminera avslutningen."
@@ -77803,12 +77823,12 @@ msgstr "Postkonstrueraren vid %C har avslutats. Denna funktion togs bart av f08/
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Antalet element i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Skapar vektortemporär vid %L för argument %qs"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "felaktig uttryckstyp under genomlöpning (%d)"
@@ -77900,81 +77920,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr "Vektorn %qs vid %L är större än gränsen satt med %<-fmax-stack-var-size=%>, flyttad från stacken till statisk lagring.  Detta gör proceduren osäker när den anropas rekursivt, eller samtidigt från flera trådar.  Överväg att öka gränsen %<-fmax-stack-var-size=%> (eller använd %<-frecursive%>, som implicerad obegränsad %<-fmax-stack-var-size=%> – eller ändra koden till att använda en ALLOCATABLE vektor. Om variabeln aldrig används av flera samtidigt kan denna varning ignoreras och variabeln skulle också kunna deklareras med attributet SAVE."
 
 #: fortran/trans-decl.cc:1795
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "%s vid %C har ingen standardtyp"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "inbyggd variabel som inte är en procedur"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Returvärdet för funktionen %qs vid %L är inte satt"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Fördröjd typparameter stödjs inte ännu"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "bakändedeklaration för modulvariabel %qs finns redan"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Oanvänd PRIVATE modulvariabel %qs deklarerad vid %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "Symbolen %qs vid %L har attributet WEAK men är ett attrappargument"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "Symbolen %qs vid %L har attributet WEAK men är en lokal variabel"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Attrappargument %qs vid %L deklarerades INTENT(OUT) men sattes inte"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Attrappargument med härledd typ %qs vid %L deklarerades INTENT(OUT) men sattes inte och har inte en standardinitierare"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Oanvänt attrappargument %qs vid %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Oanvänd modulvariabel %qs som uttryckligen har importerats vid %L"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Oanvänd variabel %qs deklarerad vid %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Oanvänd parameter %qs deklarerad vid %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Oanvänd parameter %qs som uttryckligen har importerats vid %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Returvärdet %qs för funktionen %qs deklarerad vid %L är inte satt"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Ledsen, !$ACC DECLARE vid %L är inte tillåtet i BLOCK-konstruktion"
@@ -77989,27 +78014,27 @@ msgstr "Kan inte beräkna längden på teckenvektorn vid %L."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Kod för omallokering av den allokerbara variabeln vid %L kommer läggas till"
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till ett obegränsat polymorft objekt vid %L stödjs inte ännu"
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till en obegränsat polymorf komponent vid %L stödjs inte"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Okänd inbyggd op"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Okänd argumentlistefunktion vid %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Om ommappning av gränser anges vid %L skall pekarmålet inte vara NULL"
diff --git a/gcc/po/tr.po b/gcc/po/tr.po
index c78fdbcad1a..f1cbb05ce4f 100644
--- a/gcc/po/tr.po
+++ b/gcc/po/tr.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2015-09-11 20:22+0300\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@fide.org>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -4471,7 +4471,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -8494,6 +8494,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "MMX ve SSE2 yerleşik işlevleri ve kod üretimi desteklenir"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy, no-c-format
 #| msgid "Assume code will be linked by GNU ld"
@@ -19262,12 +19268,12 @@ msgstr "'%%l' terimi bir yafta değil"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "gerçel sayı sabit yanlış kullanılmış"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -20467,63 +20473,63 @@ msgstr "Bu seçenek belgelenmedi"
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr ""
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr ""
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr ""
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[iptal edildi]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "Pass arguments on the stack"
 msgid ""
@@ -20531,67 +20537,67 @@ msgid ""
 "   "
 msgstr "Yığıttaki argümanlar aktarılır"
 
-#: opts.cc:1958
+#: opts.cc:1959
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are target specific"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:1961
+#: opts.cc:1962
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options control compiler warning messages"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:1964
+#: opts.cc:1965
 #, fuzzy
 #| msgid "Perform loop optimizations"
 msgid "The following options control optimizations"
 msgstr "Döngü eniyilemeleri uygulanır"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-independent"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "Perform loop optimizations"
 msgid "The following options control parameters"
 msgstr "Döngü eniyilemeleri uygulanır"
 
-#: opts.cc:1976
+#: opts.cc:1977
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are specific to just the language "
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:1978
+#: opts.cc:1979
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are supported by the language "
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:1989
+#: opts.cc:1990
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are not documented"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:1991
+#: opts.cc:1992
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take separate arguments"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:1993
+#: opts.cc:1994
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take joined arguments"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.cc:2005
+#: opts.cc:2006
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-related"
@@ -20996,82 +21002,82 @@ msgstr "strfmon biçiminde uzunluk değiştirici"
 msgid "<command-line>"
 msgstr "<komut-satırı>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid vector constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "terim eksik"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "geçersiz %%d terimi"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "adres geçersiz"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands to binary %s"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "iki terimli %s için terimler geçersiz"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -21088,18 +21094,18 @@ msgid "invalid %%r value"
 msgstr "%%r değeri geçersiz"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "%%R değeri geçersiz"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
@@ -21129,7 +21135,7 @@ msgstr "%%M değeri geçersiz"
 msgid "invalid %%U value"
 msgstr "%%U değeri geçersiz"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
@@ -21139,7 +21145,7 @@ msgstr "%%s değeri geçersiz"
 msgid "invalid %%C value"
 msgstr "%%C değeri geçersiz"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
@@ -21152,7 +21158,7 @@ msgstr "bilinmeyen yerdeğişim unspec"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "%%xn kodu geçersiz"
@@ -21242,37 +21248,37 @@ msgstr "terim olarak UNSPEC geçersiz"
 msgid "unrecognized supposed constant"
 msgstr "tanınmayan tahmini sabit"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "isnatlı Thumb komutu"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "koşullu dizilimde isnatlı komut"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -21281,31 +21287,31 @@ msgstr "terim, kod `%c' için geçersiz"
 msgid "invalid operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "komut hiç çalıştırılmadı"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -21695,112 +21701,112 @@ msgstr "geçersiz komut:"
 msgid "Expected register or constant integer."
 msgstr "birikeç bir tamsayı sabit değil"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 #| msgid "invalid conditional operand"
 msgid "invalid vector immediate"
 msgstr "koşullu terim geçersiz"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "bilinmeyen komut kipi"
 
@@ -21832,7 +21838,7 @@ msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 msgid "invalid %%P operand"
 msgstr "%%P terimi geçersiz"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -21882,8 +21888,8 @@ msgstr "'%s' geçerli bir sınıf ismi değil"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -21916,7 +21922,7 @@ msgid "post-increment address is not a register"
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -22090,7 +22096,7 @@ msgstr "desteklenmeyen birleşim: %s"
 msgid "unsupported memory expression:"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid vector operand"
@@ -22157,159 +22163,159 @@ msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "%%D değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -22822,7 +22828,7 @@ msgstr "1. aday:"
 msgid "  after user-defined conversion:"
 msgstr "DB komutunun kullanımı etkin olur"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -23372,7 +23378,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Sürülüm:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -23538,11 +23544,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "örtük END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "atama"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "gösterici ataması"
 
@@ -23550,252 +23556,252 @@ msgstr "gösterici ataması"
 msgid "simple IF"
 msgstr "basit IF"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 #, fuzzy
 #| msgid "elemental subroutine"
 msgid "elemental procedure"
 msgstr "öğesel altyordam"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "gösterici ataması"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki tek terimli sayısal '%s' işlecinin terimi %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki iki terimli sayısal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "%%L'deki dizge ekleme işlecinin terimleri %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki mantıksal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L'deki .NOT. işlecinin terimi %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L'de COMPLEX nicelikler karşılaştırılamıyor"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L'deki mantıksallar %s ile karşılaştırılmalı %s ile değil"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' karşılaştırma işlecinin terimleri %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimi %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimleri %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Değişken izleme uygulanır"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "terim olarak ifade geçersiz"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "YERAÇ "
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "AYIR "
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -23808,27 +23814,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -24861,7 +24867,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "static TPF-OS'da desteklenmiyor"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
@@ -25287,7 +25293,7 @@ msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -25393,10 +25399,10 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -25540,7 +25546,7 @@ msgstr "sınıf %s için dosya bulunamıyor"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "göreli konum sabit dizgenin sınırlarının dışında"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -27541,7 +27547,7 @@ msgstr "büyük tamsayı örtük olarak unsigned türe indirgendi"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "karşılaştırma bit alanının genişliğinden dolayı daima %d"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -28404,7 +28410,7 @@ msgstr "işlev yerel değişkenin adresi ile dönüyor"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -29563,14 +29569,14 @@ msgstr "%qD üyesine gösterici varsayılıyor"
 msgid "using a dangling pointer to %qD"
 msgstr "gösterici kipi olarak %qs geçersiz"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -29620,7 +29626,7 @@ msgstr "%qE işlevinin örtük bildirimi"
 msgid "call to %qD"
 msgstr "  %qD çağrısında"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -30758,7 +30764,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid jump function in LTO stream"
@@ -31771,7 +31777,7 @@ msgstr "Çapraz atlama eniyilemesi uygulanır"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
@@ -31818,13 +31824,13 @@ msgstr "-mips16 ve -mdsp birlikte kullanılamaz"
 msgid "unrecognized argument in option %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -31995,7 +32001,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -32038,202 +32044,202 @@ msgstr "değişken izleme istendi, ama hata ayıklama bilgisi üretilmeksizin fa
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "değişken izleme istendi, ama bu hata ayıklama biçimi tarafından desteklenmiyor"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition bu mimaride çalışmaz"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition bu mimaride çalışmaz"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition bu mimaride çalışmaz"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute directive ignored"
 msgid "%qs attribute directive ignored"
 msgstr "%qs öznitelik yönergesi yoksayıldı"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "yapı hizalama ikinin küçük bir üssü olmalı %d değil"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %qs"
 msgid "unknown stack check parameter %qs"
 msgstr "parametre %qs kullanılmamış"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "hedef sistem hata ayıklama çıktısını desteklemiyor"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "\"%s\" hata ayıklama biçimi önceki seçimle çelişiyor"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "hata ayıklama çıktı seviyesi \"%s\" tanınmıyor"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "hata ayıklama çıktılama seviyesi %s çok yüksek"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized btf debug output level %qs"
 msgstr "hata ayıklama çıktı seviyesi \"%s\" tanınmıyor"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "core dosyasının boyu azami sınıra getiriliyor: %m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "core dosyasının boyut sınırı azami değere ayarlanıyor: %m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "tanınmayan gcc hata ayıklama seçeneği: %c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "%<%3$E%4$s%> içindeki %<%2$s işleci%> için %1$s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -32960,199 +32966,199 @@ msgstr "%<...%> kullanan yöntem %q#D için soysal thunk kodu başarısız olur"
 msgid "%qD renamed after being referenced in assembly"
 msgstr "makina dilinde referanslandıktan sonra %D yeniden isimlendirilmiş."
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "function symbol is not function"
 msgstr "bir işlev döndüren işlev"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "node has invalid order %i"
 msgstr "seçenek argümanı %qs geçersiz"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "çağrılan nesne %qE bir işlev değil"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is transparent_alias but not an alias"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is symver but not alias"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa başarısız"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "gösterici kipi olarak %qs geçersiz"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D part of alias cycle"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -34992,27 +34998,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -35893,7 +35899,7 @@ msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
@@ -38192,7 +38198,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "geleneksel C dizge sabitlerin birleştirilmesine izin vermez"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -40046,7 +40052,7 @@ msgstr "girdi dosyası sayısı çok fazla"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -40080,16 +40086,16 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s"
@@ -40184,55 +40190,55 @@ msgstr "spec '%s' geçersiz"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops is obsolete, use -falign-loops"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops artık kullanılmıyor yerine -falign-loops kullanın"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malıgn-jumps artık atıl, yerine -falign-jumps kullanın"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions is obsolete, use -falign-functions"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions artık atıl, yerine -falign-functions kullanın"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d, 0 ile 5 arasında değil"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -40763,14 +40769,14 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
@@ -41016,7 +41022,7 @@ msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür d
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "duplicate definition of %qs"
@@ -41064,7 +41070,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "%qT türü bilinen bir boyuta sahip değil"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -41163,350 +41169,350 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cray Pointer extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Cray Göstericisi eklentisi kullanılır"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "%qs özniteliği yoksayıldı"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid format for %<sve_width%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%H value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "%%H değeri geçersiz"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid floating point option: -mfpu=%s"
 msgid "tuning string missing in option (%s)"
 msgstr "geçersiz gerçel değer seçeneği: -mfpu=%s"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "bilinmeyen '%s' spec işlevi"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-march%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 #| msgid "missing filename after %qs"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs den sonra dosyaismi yok"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "multilib desteklenmiyor"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> bozuk"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -41712,13 +41718,13 @@ msgstr "%qs özniteliğinin argümanı \"ilink1\" ya da \"ilink2\" değildir"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -41878,18 +41884,18 @@ msgstr "%qE özniteliği yoksayıldı"
 msgid "%qE attribute only applies to variables"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for %<asm%> flag output"
@@ -42114,7 +42120,7 @@ msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 msgid "target CPU does not support unaligned accesses"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -42177,7 +42183,7 @@ msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -42292,7 +42298,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -42348,34 +42354,34 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "yığıttaki parametrenin gerçek konumu hesaplanamıyor"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Beklenmeyen modül sonu"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "yüksek yazmaçları çekmeye elverişli düşük yazmaç yok"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -42384,24 +42390,24 @@ msgstr "%qs özniteliğinin argümanı geçersiz"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
@@ -42486,19 +42492,19 @@ msgstr "-pipe desteklenmiyor"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe desteklenmiyor"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G ve -static birlikte kullanılamaz"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -42856,7 +42862,7 @@ msgstr "yerleşik işleve aktarılan argüman geçersiz"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument to built-in function"
@@ -43530,753 +43536,753 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "attribute %qs argument is not a string"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "%C'de SEQUENCE deyimi zaten TYPE deyiminde belirtilmiş"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "'%s' spec işlevi için argümanlar hatalı"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 #| msgid "static is not supported on TPF-OS"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "static TPF-OS'da desteklenmiyor"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bitlik kip bunun içinde derlenmiş değil:"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Seçtiginiz işlemci  x86-64 komutlarını desteklemiyor."
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp32 used with a 64-bit ABI"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mgp32 bir 64-bit ABI ile kullanılmış"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d, 0 ile %d arasında değil"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE komut kümesi iptal edildi, 387 aritmetiği kullanılıyor"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 komut kümesi iptal edildi, SSE aritmetiği kullanılıyor"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, fuzzy, gcc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 #| msgid "'-%c' option must have argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "'-%c' seçeneğinde argüman eksik"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qT çağrısı"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "multilib desteklenmiyor"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç argümanı"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, fuzzy, gcc-internal-format
 #| msgid "SSE register return with SSE disabled"
 msgid "x87 register return with x87 disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 #| msgid "global destructors not supported on this target"
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "bu hedefte global yıkıcılar desteklenmiyor"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "%s bu yapılandırma ile desteklenmiyor"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
@@ -44284,82 +44290,82 @@ msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "ek yazmaçların yüksek yarıları yok"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for code '%c'"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "unknown architecture specific memory model"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -44749,7 +44755,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string argument"
@@ -45976,60 +45982,60 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "'#pragma options' sonunda karışıklık"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "%qT türü bilinen bir boyuta sahip değil"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "%qT türü bilinen bir boyuta sahip değil"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "fields cannot have RVV type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "array elements cannot have RVV type %qT"
 msgstr "işlev bir küme ile dönüyor"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "soyut %qT türünde bir nesne tahsis edilemez"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "soyut %qT türünde bir nesne tahsis edilemez"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "capture by copy of RVV type %qT"
@@ -46051,71 +46057,76 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs geçerli bir sınıf ismi değil"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -46635,107 +46646,107 @@ msgstr "Önerilmiyor. Bu seçenek etkisizdir."
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' geçersiz"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -48277,7 +48288,7 @@ msgstr "oynak alanlı nesne yazmaça konulamaz"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -48482,7 +48493,7 @@ msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 msgid "storage class specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
@@ -48679,7 +48690,7 @@ msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 msgid "function definition has qualified void return type"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
@@ -48824,7 +48835,7 @@ msgstr "ISO C 'const' ya da 'volatile' işlev türlerini yasaklar"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "void bildirimli değişken ya da alan %qE"
@@ -49043,7 +49054,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr "ilklendiricide bilinmeyen %qE alanı belirtilmiş"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
@@ -49095,7 +49106,7 @@ msgstr "yapı hiç isimli üye içermiyor"
 msgid "struct has no members"
 msgstr "yapı hiç üye içermiyor"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -49144,7 +49155,7 @@ msgstr "%<enum %E%> yeniden bildirilmiş"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -49195,7 +49206,7 @@ msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırla
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -49229,7 +49240,7 @@ msgstr "%q+D için önceki prototip yok"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -49359,12 +49370,12 @@ msgstr "%qD argümanı yerleşik prototiple eslesmiyor"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "%qD argümanı prototiple uyumsuz"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -51598,7 +51609,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
@@ -51742,13 +51753,13 @@ msgstr "%<{%> umuluyordu"
 msgid "variant %qD is not a function"
 msgstr "%q+D bir işlev değil,"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -52028,7 +52039,7 @@ msgstr "void ifade kullanımı geçersiz"
 msgid "invalid use of flexible array member"
 msgstr "esnek dizi üyesinin kullanımı geçersiz"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "sınırları belirsiz dizi kullanımı geçersiz"
@@ -53067,12 +53078,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -53114,7 +53125,7 @@ msgstr "ilkledirici öğe yükleme sırasında hesaplanabilir değil"
 msgid "invalid initializer"
 msgstr "geçersiz ilklendirici"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opak vektör türleri ilklendirilemez"
@@ -53129,8 +53140,8 @@ msgstr "ilklendiricinin sonunda fazladan parantezli grup"
 msgid "braces around scalar initializer"
 msgstr "skalar ilklendiriciyi kuşatan parantezler"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "iç içe bağlam içinde esnek dizi üyesi ilklendirmesi"
@@ -53224,7 +53235,7 @@ msgstr "struct ilklendiricide gereğinden fazla öğe"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "esnek dizi üyesinin statik olmayan ilklendirmesi"
@@ -54701,7 +54712,7 @@ msgstr "%2$qT için uygun bir %<%1$s işleci%> yok"
 msgid "%q#D is private within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
@@ -54713,7 +54724,7 @@ msgstr "burada bildirilmiş %q+D"
 msgid "%q#D is protected within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
@@ -54730,7 +54741,7 @@ msgstr "%q+#D erişilebilir değil"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "%2$qD işlevinin gösterici olmayan %1$P argümanına NULL aktarılması"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -55105,7 +55116,7 @@ msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -55745,7 +55756,7 @@ msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 msgid "next member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
@@ -55875,7 +55886,7 @@ msgstr "işlev %q+#D için soyut dönüş değeri türü geçersiz"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -55951,7 +55962,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -56004,7 +56015,7 @@ msgstr "%qT bir belirsiz %qT tabanıdır"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -56148,7 +56159,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -56260,7 +56271,7 @@ msgstr "uye %qD için ilklendirici eksik"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -56350,7 +56361,7 @@ msgstr "%s den %s e dönüşüm (%L'de)"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
@@ -56422,215 +56433,215 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "cast from %qT is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "contract predicate is false in constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "unexpected template-id %qE"
 msgstr "deyim umuluyordu"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 #| msgid "function not inlinable"
 msgid "function concept must be called"
 msgstr "işlev satıriçine alınabilir değil"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "ifade umuluyordu"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -57277,7 +57288,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
@@ -57383,7 +57394,7 @@ msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 msgid "no suspend point info for %qD"
 msgstr "%q+D için önceki prototip yok"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -57405,23 +57416,23 @@ msgstr "case değeri olarak göstericiler kullanılamaz"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -57964,7 +57975,7 @@ msgstr "önceki %q+F bildirimindeki farklı olağandışılıkları yakalıyor"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -58427,668 +58438,668 @@ msgstr "%qD bir işlev şablonu değil"
 msgid "%q#T is not a class"
 msgstr "%q#T bir şablon değil"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde sınıf şablonu yok"
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "trampolines desteklenmiyor"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "anonim yapı isimli türün içinde değil"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kuruculu üye %q+#D kullanılamaz"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde yıkıcılı üye %q+#D kullanılamaz"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kopya atama isleçli üye %q+#D kullanılamaz"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T için öznitelik %qs anahtar sözcüğünü izlemeli"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "bir bildirimde birden fazla tür"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++ yerleşik türü %qT için yeniden bildirim"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef bildiriminde tür ismi eksik"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ anonim yapıları (struct) yasaklar"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sadece kurucular için belirtilebilir"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ %<%T::%D%>nin %<%T::%D%> olarak tanımlanmasına izin vermez"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "%qD ilklendirmesi yinelenmiş"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "%q#D değişkeni ilklendirilmiş ama içi boş türde"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "küme %q#D içi boş türde olup tanımlı olamaz"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD başvuru olarak bildirilmiş ama ilklendirilmemiş"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "alelade olmayan ilklendiriciler desteklenmiyor"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  ilklendiriciyi kaldırarak bunun olurunu bulabilirsiniz"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "%qs türü bir kullanıcı tanımlı yapıcıya sahip"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "%2$qT türündeki bir vektör için ilklendirici olarak %1$qT türü geçersiz"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "geçersiz ilklendirici"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT için ilklendirici sayısı çok fazla"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C90 bileşik sabitlere izin vermez"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD içi boş türde"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD bir kurucu ile ilklendirilmeli, %<{...}%> ile değil"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "parantezli dizge sabiti %2$qE ile ilklendirilmiş %1$qD dizgesi"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "kuruculu statik üye için ilklendirici geçersiz"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(bir sınıf dışı ilklendirme gerekli)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD parametresi ilklendirilmiş"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "could not find variant declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "enumerator %q+D yeniden bildirilmiş"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "önceki %q#D tür bildirimini gölgeliyor"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "%q#D işlevi bir değişken gibi ilklendirilmiş"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  %q+D'deki atıl baglantı bir yıkıcıya sahip olduğundan kullanılamaz"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT, bir erişilemeyen %qT tabanıdır"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "içi boş ture gösterici ilişkilendirme"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%u name provided for structured binding"
@@ -59096,1838 +59107,1838 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs yapı alan için saklama sınıfı belirtilmiş"
 msgstr[1] "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "in initialization of structured binding variable %qD"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot decompose union type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "adres çözümlenemez"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için yıkıcı, bir üye olamaz"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için kurucu, bir üye olamaz"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D bir olağandışılık belirtimi ile bildirilmiş"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD tanımı %qT bağlamını kapsayan isim alanınında değil"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statik üye işlev %q#D tür niteleyicilerle bildirilmiş"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java yöntemi %qD Java olmayan %qT dönüş türünü içeriyor"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "concept %qD has no definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "a function concept cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD bir şablon işlevi değildir"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%qD doğrudan özelleştirmesinin kardeş bildirimde tanımı"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde %qD şablon kimliğinin kullanımı geçersiz"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "kardeş şablon özelleştirmesi %qD bildiriminde %<inline%> kullanılamaz"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "seçenek argümanı %qs geçersiz"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> %<int%> döndürmeli"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "sınıf %2$qT içinde bildirilmiş %1$q#D diye bir üye işlev yok"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "strong using only meaningful at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "kesin kullanım sadece isimalanı kapsamında anlamlıdır"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "a variable concept cannot be constrained"
 msgstr "%C'deki döngü değişkeni bir alt bileşen olamaz"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ tümlemeyen %2$qT türündeki %1$qD üye sabitinin ilklendirilmesine izin vermez"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ değişken boyutlu %qD dizisine izin vermez"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++  değişken boyutlu diziye izin vermez"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "dizi boyutunda taşma"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when a variable is unused"
 msgid "variable-length array of %<auto%>"
 msgstr "Bir değişken kullanılmamışsa uyarır"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "kurucu için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "%<operator %T%> için dönüş türü belirtilmiş"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "void bildirimli adsız değişken ya da alan"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "üye olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "bildirimci kimliği eksik; yedek sözcük %qD kullanılıyor"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "function definition does not declare parameters"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs bildiriminde iki veya daha fazla veri türü"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ türsüz %qs bildirimine izin verilmez"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%qs için signed ve unsigned birlikte verilmiş"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%qs için long ve short birlikte belirtilmiş"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs specified with %qD"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%qs için tepe-seviye bildirim %<auto%> belirtiyor"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs işlevinin etki alanı dolaylı olarak auto ve %<__thread%> bildirimli"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "saklatım sınıfı belirteçleri kardeş işlev bildirimlerinde geçersiz"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Umulmadık sol parantez"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "requires-clause on return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "yıkıcı bir statik üye işlev olamaz"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "kurucular cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "yerel sınıf tanımı içinde kardeş işlev %qs tanımlanamaz"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "yıkıcılar parametre almayabilir"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "%q#T üyeye gösterici bildirilemez"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "şablon kimliği %qD bir bildirici olarak kullanılmış"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "üye işlevler sınıflarının örtük kardeşleridir"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, fuzzy, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "üye %2$qs üzerinde fazladan niteleme %<%1$T::%>"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "üye işlev %<%T::%s%> %<%T%> içinde tanımlanamaz"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "uye işlev %<%T::%s%> %<%T%> içinde bildirilemez"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "üye %<%T::%s%> %qT içinde bildirilemez"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "sadece kurucuların bildirimleri %<explicit%> olabilir"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "sabit %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a member function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ kapsayan sınıf ile aynı isimde yuvalanmış %qD türüne izin vermez"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için %<inline%> belirtilmiş"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend bildirimi sınıf anahtarı gerektirir, %<friend class %T::%D%> gibi"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend bildirimi %<friend %#T%> gibi bir sınıf anahtarı gerektirir"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "sınıf %qT genel bağlamın kardeşi yapılmaya çalışılıyor"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "üye olmayan işlev türünde niteleyiciler geçersiz"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "mutlak bildirimci %qT bildirim olarak kullanılmış"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametre %q+D soyut %qT türünde bildirilemez"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "işlev %qD bir union içinde virtual olarak bildirilmiş"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD daima static olduğundan sanal olarak bildirilemez"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "%s açılamıyor"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "saklama sınıfı %<auto%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "saklama sınıfı %<register%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<static%> belirteci geçersiz"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs defined in a non-class scope"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statik işlev başka bir işlevin içinde bildirilemez"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "bir statik veri üyesi tanımlarken (bildirime zit olarak) %<static%> kullanılamayabilir"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "üye %q#D harici ilintilemeli olarak doğrudan bildirilemez"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "kurucu geçersiz; muhtemelen %<%T (const %T&)%> anlamında kullandınız"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD static olarak bildirilemeyebilir"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD ya bir statik olmayan üye işlev ya da üye olmayan işlev olmalıdır"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD ya bir sınıf argümanına sahip olmalı ya da enum türünde olmalı"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ ?: üç terimlisinin aşırı yüklenmesini yasaklar"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD ya hiç argüman almamalı ya da bir argüman almalı"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD ya bir ya da iki argüman almalı"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "sonek %qD argüman olarak %<int%> almalı"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "sonek %qD ikinci argümanı olarak %<int%> almalı"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD sadece ve sadece bir argüman almalı"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "önek %qD %qT döndürmeli"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "sonek %qD %qT döndürmeli"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD değeriyle döndürülmeli"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "%2$qs sonrası typedef-ismi %1$qD kullanımı"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D için burada önceki bir bildirim var"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T için burada önceki bir bildirim var"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT türüne enum olarak başvuruluyor"
@@ -60939,116 +60950,116 @@ msgstr "%qT türüne enum olarak başvuruluyor"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "class template %qD redeclared as non-template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "önceden bildirim olmaksızın enum %q#D kullanımı"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "%qD bir bit alanı türü olarak bildirilemez"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "türetilmiş union %qT geçersiz"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in the class %qT"
 msgid "%qT defined with multiple direct bases"
 msgstr "%qD zaten sınıf %qT içinde tanımlı"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "taban tür %qT bir yapı veya sınıf türü olarak hatalı"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "ardışık tür %qT tanımsız"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "yinelenmiş taban türü %qT geçersiz"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
@@ -61057,91 +61068,91 @@ msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarı
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "%qT için simgesel sabit değerlerinin tamamını hiçbir tümleyen tür temsil edemez"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD'de simgesel sabit değerlerinde taşma"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD zaten %qT sınıfında tanımlı"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "%J%s %<%c%s%>"
 msgid "using %qs"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -62052,7 +62063,7 @@ msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -63194,7 +63205,7 @@ msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -64028,7 +64039,7 @@ msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -64795,13 +64806,13 @@ msgstr "temel ilklendiricileri sadece kurucular alır"
 msgid "cannot expand initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -65470,7 +65481,7 @@ msgstr "%q#D için öntanımlı argüman %qT türünde"
 msgid "%qT not permitted in template argument"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
@@ -66438,7 +66449,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
@@ -67549,7 +67560,7 @@ msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "template constraint failure for %qD"
@@ -67650,299 +67661,299 @@ msgstr "bir dizi döndüren işlev"
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<__builtin_choose_expr%> not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "%<__builtin_choose_expr%> için ilk argüman bir sabit değil"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -67955,182 +67966,182 @@ msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "a concept cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bir isim alanı değil"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "şablon parametre listesi içinde %q#T tanımı"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "yerine #include kullanın"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "işlev satıriçine alınma sırasında görmezden gelinir"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "explicit deduction guide declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %qT in template argument"
@@ -68472,7 +68483,7 @@ msgstr "taban sınıf belirtimi geçersiz"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
@@ -68923,30 +68934,30 @@ msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE bir şablon değil"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -68955,22 +68966,22 @@ msgstr "%<__builtin_return_address%>'e aktarılan argüman desteklenmiyor"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -70363,247 +70374,247 @@ msgstr "%q#D yeniden bildirimi"
 msgid "declaration of %q#T"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%qD has incomplete type"
 msgstr "%qD içi boş türde"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of incomplete type %q#T"
 msgstr "tamamlanmamış typedef %qD kullanımı geçersiz"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of placeholder %qT"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of template type parameter %qT"
 msgstr "tamamlanmamış typedef %qD kullanımı geçersiz"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "invalid use of template template parameter %qT"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of dependent type %qT"
 msgstr "tamamlanmamış typedef %qD kullanımı geçersiz"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "kurucu sözdizimi kullanılmış ama %qT türü için kurucu bildirilmemiş"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 #| msgid "interface %qE does not have valid constant string layout"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%qE arayüzü geçerli sabit dizge yerleşimi içermiyor"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "karakter dizisi için dizge ilklendirici çok uzun"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "bir bileşik sabitli %qT türündeki küme ilklendirilemez"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "birlesik yapı ilklendiricideki alan isminin yerine index değeri"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> için taban terim gösterici olmayan %qT türünde"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr " %<operator->()%> gösterici olmayan sonuc veriyor"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE bir üye göstericisi olarak kullanilamaz, cunku %qT türünde"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer %qE to %qE, which is of non-aggregate type %qT"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "uye göstericisi %qE %qE'ye kümeleme türü olmayan %qT türünde uygulanamaz"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%qD işlevine çağrı (ici boş tür `%q#T' yakalanırken)"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "ici boş tür `%q#T' yakalanırken işleve çağrı"
@@ -71629,7 +71640,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir sabit olmalı"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -72862,12 +72873,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "%C'deki ilklendirme bir gösterici değişkeni için değil"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L'deki altdizge başlangıç indisi birden küçük olmalıdır"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L exceeds the string length"
@@ -73070,7 +73081,7 @@ msgstr "%C'deki INTENT belirtimi hatalı"
 msgid "deferred type parameter at %C"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -75294,7 +75305,7 @@ msgstr "%s'in KIND parametresi %L'de bir ilklendirme ifadesi olmalıdır"
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Ek: %L'de standartdışı ilklendirme ifadesinin değerlenimi"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -75605,7 +75616,7 @@ msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -75733,7 +75744,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
@@ -75745,7 +75756,7 @@ msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
@@ -75884,7 +75895,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
@@ -76124,12 +76135,12 @@ msgstr "%L'de tanımlanmış atamanın ilk argümanı INTENT(IN) veya INTENT(INO
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
@@ -76254,615 +76265,615 @@ msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "%L'de IBITS'in üçüncü argümanı geçersiz"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Anahtar sözcük argümanı '%s' (%L'de) başka bir fiili argümanla zaten ilişkili"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L'deki yordam çağrısında biçimselden daha gerçekçi argümanlar"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında umulmadık diğer return belirtimi"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' için fiili argüman (%L'de) bir tahmini boyutlu dizi olamaz"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Argüman '%s' için fiili argüman eksik (%L'de)"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "INTENT(%s) ile '%s' argümanı ve INTENT(%s) ile '%s' argümanı aynı fiili argüman ile ilişkilendirilmiş"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup POINTER özniteliğine sahiptir"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "'%s' simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "'%s' simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D tanımsız %qs simgesine rumuzlu"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "'%s' öğesi (%C'de) zaten arayüzde mevcut"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Karakter değerli iç işlev '%s' tahmini uzunlukta olmamalı (%L'de)"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "'%s' yordamı (%s içinde, %L'de) be işlev ne de altyordam"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "`%s' çağrısındaki argümanlar çok fazla (%L'de)"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -77069,7 +77080,7 @@ msgstr "%s den %s e dönüşüm (%L'de)"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -77701,7 +77712,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -78334,7 +78345,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -80375,8 +80386,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
@@ -82508,791 +82519,803 @@ msgstr "Karakter değerli iç işlev '%s' tahmini uzunlukta olmamalı (%L'de)"
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Karakter değerli iç işlev '%s' tahmini uzunlukta olmamalı (%L'de)"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "çeliskili gerçekleme değişkeni özelliği"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "çeliskili gerçekleme değişkeni özelliği"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be an array in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "FUNCTION sonucu %s FUNCTION %s içinde bir dizi olamaz (%L'de)"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be an array in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "ENTRY sonucu %s FUNCTION %s içinde bir dizi olamaz (%L'de)"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "FUNCTION sonucu %s FUNCTION %s içinde bir POINTER olamaz (%L'de)"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "ENTRY sonucu %s FUNCTION %s içinde bir POINTER olamaz (%L'de)"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "FUNCTION sonucu %s FUNCTION %s içinde bir POINTER olamaz (%L'de)"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "ENTRY sonucu %s FUNCTION %s içinde bir POINTER olamaz (%L'de)"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be of type %s in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "FUNCTION sonucu %s, %s türünde olamaz (FUNCTION %s içinde, %L'de)"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be of type %s in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "ENTFY sonucu %s, %s türünde olamaz (FUNCTION %s içinde, %L'de)"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "'%s' simgesi (%C'deki) zaten bir COMMON blokundadır"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "'%s' simgesi (%C'deki) zaten bir COMMON blokundadır"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "%C'de COMMON içindeki türetilmiş tür değişkeni SEQUENCE özniteliğine sahip değildir"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "%C'de COMMON içindeki türetilmiş tür değişkeni SEQUENCE özniteliğine sahip değildir"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "%C'de COMMON içindeki türetilmiş tür değişkeni SEQUENCE özniteliğine sahip değildir"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not an intrinsic subroutine"
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "Soysal işlev '%s' (%L'de) bir yerleşik altyordam değil"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "%L'de türetilmiş tür kurucusundaki öğe, gösterici bileşeni '%s' için %s'tir fakat %s olmalıydı"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %C"
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "%C'deki yapı kurucuda çok fazla bileşen"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %C"
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "%C'deki yapı kurucuda çok fazla bileşen"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "%L'de türetilmiş tür kurucusundaki öğe, gösterici bileşeni '%s' için %s'tir fakat %s olmalıydı"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "%L'de türetilmiş tür kurucusundaki öğe, gösterici bileşeni '%s' için %s'tir fakat %s olmalıydı"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, fuzzy, gcc-internal-format
 #| msgid "The element in the derived type constructor at %L, for pointer component '%s', is %s but should be %s"
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "%L'de türetilmiş tür kurucusundaki öğe, gösterici bileşeni '%s' için %s'tir fakat %s olmalıydı"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, fuzzy, gcc-internal-format
 #| msgid "The upper bound in the last dimension must appear in the reference to the assumed size array '%s' at %L."
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "Son boyuttaki üst sınır tahmini boyutlu '%s' dizisine başvuru içinde görünmelidir (%L'de)."
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "%qs at %L is ambiguous"
 msgstr "'%s' simgesi (%L'de) belirsiz"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "'%s' işlevinde diğer return belirtecine %L'de izin verilmiyor"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%L'deki yerleşik mevcut değil"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Yafta %d (%L'de başvurulu) hiç tanımlanmamış"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL INTRINSIC olmayan '%s' yordamına %L'de bir fiili argüman olarak izin verilmez"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "'%s' simgesi (%L'de) belirsiz"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of INT at %L is not a valid type"
 msgid "By-value argument at %L is not of numeric type"
 msgstr "%L'de INT'in argümanı geçerli bir tür değil"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL INTRINSIC olmayan '%s' yordamına %L'de bir fiili argüman olarak izin verilmez"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "%2$qs sayacı okunurken %1$qs işlevi için kapsanma çelişkisi"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Soysal işlev '%s' (%L'de) belirli bir yerleşik arayüz ile uyumlu değil"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "İşlev '%s' (%L'de) bir INTRINSIC ama bir yerleşik ile uyumlu değil"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Function reference to '%s' at %L is inside a FORALL block"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "'%s' için işlev başvurusu %L'de bir FORALL blokunun içindedir"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "PURE yordamının içinde dahili dosya birimi '%s' yazılamıyor (%C'de)"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "%q+D bir işlev değil,"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "'%s' işlevi CHARACTER(*) bildirimli olup, bir sözde argüman olmadığından %L'de kullanılamaz"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Using function %qs at %L is deprecated"
 msgstr "%L'deki deyim işlevi iç içe"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "'%s' (%L'de bir FORALL blokunun içindeki) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "'%s' (%L'de bir FORALL blokunun içindeki) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "'%s' (%L'de) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Özel altyordam '%s' %L'de çözümlenemiyor"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Soysal işlev '%s' (%L'de) bir yerleşik altyordam arayüzü ile uyumlu değil"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Altyordam '%s' (%L'de) bir INTRINSIC ama bir yerleşik ile uyumlu değil"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Özel altyordam '%s' %L'de çözümlenemiyor"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' (%L'deki) %L'deki CALL ile uyumlu olmayan bir türe sahip"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L ve %L'de terimlerin biçimleri benzer değil"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L'de sıfır adım uzunluğu kuraldışı"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Tahmini boyutlu dizi bölümünün en sağ üst sınırı %L'de belirtilmemiş"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L'de dizi indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ek: %L'de REAL dizi indisi"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of array reference at %C"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "%C'de dizi başvurusunun yapılışı geçersiz"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L'deki dizi indisi %d. mertebeden bir dizidir"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge başlangıç indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L'deki altdizge başlangıç indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge son indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L'de sıfırdan farklı bir mertebeden iki veya daha fazla parça başvurusu belirtilmemelidir"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -83302,12 +83325,12 @@ msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -83317,309 +83340,309 @@ msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in typebound call at %L"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Öğesel yordamın '%s' argümanı değişmez olmalı (%L'de)"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL başlatma ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL son ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L'deki FORALL adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L'de ALLOCATE deyimindeki ifade ya bir POINTER ya da ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -83628,301 +83651,301 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L'de CASE deyimindeki ifade %d. çeşit olmalı"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L'deki DEFAULT CASE deyiminden sonra %L'de ikinci bir DEFAULT CASE olamaz"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L'deki aralık belirtimi asla eşleşmeyebilir"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L'deki mantıksal SELECT CASE blokunun ikiden fazla case'i var"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "'%s' ismi (%C'de) tanımlı bir işleç olarak kullanılamaz"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L'deki veri aktarım elemanı tahmini boyutlu bir diziye bir tam başvuru olamaz"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L'deki deyim %L'deki dallanma deyimi için geçerli bir dallanma hedef deyimi değildir"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -83930,12 +83953,12 @@ msgstr "%L'deki dallanma bir sonsuz döngüye sebep oluyor"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -83943,219 +83966,219 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L'deki WHERE maskesi uyumsuz biçimde"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L'deki WHERE atama hedefi uyumsuz biçimde"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L'deki WHERE içinde desteklenmeyen deyim"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "'%s' indisli FORALL %L'de bu nesneye birden fazla atamaya sebep oluyor"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "FORALL construct at %L"
 msgstr "Kurucu %s olmayabilir"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Bir dış FORALL oluşumu zaten bu isimde bir indise sahip (%L'de)"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L'deki WHERE/ELSEWHERE deyimi bir değişmez LOGICAL dizisi gerektirir"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate RETURN statement at %L requires an INTEGER return specifier"
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Diğer RETURN deyimi %L'de bir INTEGER dönüş belirteci gerektirir"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "%C'deki CASE'de ilklendime ifadesi umuluyordu"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L'deki aritmetik IF deyimi bir sayısal ifade gerektirir"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L'deki DO WHILE döngüsünün çıkış koşulu bir sabit LOGICAL ifadesi olmalıdır"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki FORALL maske deyimi bir LOGICAL ifadesi gerektirir"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -84163,7 +84186,7 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -84172,63 +84195,63 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -84236,1018 +84259,1018 @@ msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olm
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modül veya ana program dizisi '%s' %L'de sabit biçimde olmalı"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L'deki tahmini karakter uzunluklu öğe ya bir sözde argüman ya da bir PARAMETER olmalı"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Özdevinimli dizi '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s işlevinde (%s dosyasının %d. satırı)"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "'%s' bir PRIVATE türündedir ve '%s' (%L'de PUBLIC tanımlı) için bir sözde argüman olamaz"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de iç içe olamaz"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "PURE yordamının '%s' sözde yordamı da ayrıca PURE olmalı"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) OPTIONAL olmamalı"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Bileşen karakter uzunluğu '%s'in %L'de bir sabit belirtim ifadesi olması gerekir"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "%L'deki ifade INTEGER türünde olmalı"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Bileşen '%s' bir PRIVATE türdür ve '%s' (%L'de PUBLIC tanımlı) bileşeni olamaz"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s of SEQUENCE type declared at %C does not have the SEQUENCE attribute"
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "SEQUENCE türünün %s bileşeni SEQUENCE özniteliğine sahip değil (%C'de)"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olmaksızın ertelenmiş dizi boyutu"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş %qs türü %L'de tanımlanmamış olan %qs türündedir."
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman %qs %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi %qs %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi %qs %L'de, %qs pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%qs isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan %qs dizisi %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni %qs %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü %qs %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı %qs %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı %qs %L'de için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -86212,7 +86235,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -86224,12 +86247,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "yürüyüş sırasında ifade türü hatalı (%d)"
@@ -86338,91 +86361,97 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Symbol '%s' at %L has no IMPLICIT type"
+msgid "%s at %C has no default type"
+msgstr "'%s' simgesi %C'de hiç IMPLICIT tür içermiyor"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "bir yordam olmayan yerleşik değişken"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "FPU yazmaçlarındaki işlevlerin değerleri döner"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "modül değişkeni %qs için artyüz bildirimi zaten mevcut"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "gerçekleme değişkeni %qs %s olarak bildirilmiş"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs at %C has already been host associated"
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "%qs simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "INTENT(OUT) sözde argüman '%s' %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Unused variable %qs declared at %L"
 msgstr "gerçekleme değişkeni %qs %s olarak bildirilmiş"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "Unused parameter %qs declared at %L"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "FPU yazmaçlarındaki işlevlerin değerleri döner"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -86437,28 +86466,28 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Bilinmeyen yerleşik terim"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Unknown argument list function at %L"
 msgstr "'%s' işlevinde argüman listesi eksik (%C'de)"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -88510,6 +88539,11 @@ msgstr "parametre %q+D kullanılmamış"
 #~ msgid "PIC register isn't set up"
 #~ msgstr "PIC yazmacı ayarlı değil"
 
+#, fuzzy
+#~| msgid "invalid operand for code '%c'"
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "terim, kod `%c' için geçersiz"
+
 #, fuzzy
 #~| msgid "Use native (MS) bitfield layout"
 #~ msgid "Use gcc default bitfield layout"
diff --git a/gcc/po/uk.po b/gcc/po/uk.po
index 464dcff7ec8..6e35bb1310e 100644
--- a/gcc/po/uk.po
+++ b/gcc/po/uk.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 12.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2022-05-08 14:31+0300\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <trans-uk@lists.fedoraproject.org>\n"
@@ -3999,7 +3999,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7662,6 +7662,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr ""
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17193,12 +17198,12 @@ msgstr "операнд «%%l» не є міткою"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "помилкове використання сталої із рухомою крапкою"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18277,63 +18282,63 @@ msgstr "Цей перемикач не документовано."
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr ""
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr "Те саме, що і %s"
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr "[доступний у "
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[типовий]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[увімкнено]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[вимкнено]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -18342,47 +18347,47 @@ msgstr ""
 "  Відомі коректні аргументи для параметра %s:\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr ""
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr ""
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr ""
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr ""
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr ""
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr ""
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr ""
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr ""
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr ""
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr ""
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr ""
 
@@ -18763,72 +18768,72 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "некоректний операнд для «%%%c»"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, c-format
 msgid "invalid vector constant"
 msgstr "некоректна векторна константа"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "несумісний операнд регістру для «%%%c»"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "пропущено операнд"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "некоректна константа"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "некоректний операнд"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "некоректний префікс операнда «%%%c»"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "некоректний режим адресування"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' використано без будь-яких локальних динамічних посилань TLS"
@@ -18845,18 +18850,18 @@ msgid "invalid %%r value"
 msgstr "некоректне значення %%r"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "некоректне значення %%R"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "некоректне значення %%N"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "некоректне значення %%P"
@@ -18886,7 +18891,7 @@ msgstr "некоректне значення %%M"
 msgid "invalid %%U value"
 msgstr "некоректне значення %%U"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "некоректне значення %%s"
@@ -18896,7 +18901,7 @@ msgstr "некоректне значення %%s"
 msgid "invalid %%C value"
 msgstr "некоректне значення %%C"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "некоректне значення %%E"
@@ -18909,7 +18914,7 @@ msgstr ""
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
@@ -18992,35 +18997,35 @@ msgstr ""
 msgid "unrecognized supposed constant"
 msgstr ""
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr ""
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr ""
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19029,26 +19034,26 @@ msgstr ""
 msgid "invalid operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "некоректне перетворення з типу %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "некоректне перетворення до типу %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19411,97 +19416,99 @@ msgstr "некоректна константа з рухомою крапкою
 msgid "Expected register or constant integer."
 msgstr "Мало бути використано регістр або стале ціле число."
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "некоректне використання регістру «%s»"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr ""
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.cc:13283
-#, c-format
-msgid "invalid operand type used with operand code 'Z'"
-msgstr ""
+#: config/i386/i386.cc:13290
+#, fuzzy, c-format
+#| msgid "invalid operand type %qT for %qs"
+msgid "invalid operand type used with operand code '%c'"
+msgstr "некоректний тип операнда %qT %qs"
 
-#: config/i386/i386.cc:13288
-#, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr ""
+#: config/i386/i386.cc:13295
+#, fuzzy, c-format
+#| msgid "invalid operand for '%%%c'"
+msgid "invalid operand size for operand code '%c'"
+msgstr "некоректний операнд для «%%%c»"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, c-format
 msgid "invalid vector immediate"
 msgstr "некоректна векторна константа"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr ""
 
@@ -19532,7 +19539,7 @@ msgstr ""
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "некоректне значення %%p"
@@ -19577,8 +19584,8 @@ msgstr ""
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr ""
@@ -19610,7 +19617,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "помилкова адреса"
 
@@ -19768,7 +19775,7 @@ msgstr ""
 msgid "unsupported memory expression:"
 msgstr "непідтримуваний вираз пам'яті:"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -19821,143 +19828,143 @@ msgstr ""
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "Помилкове 128-бітове пересування"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, c-format
 msgid "invalid %%A value"
 msgstr "некоректне значення %%A"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "некоректне значення %%D"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "некоректне значення %%e"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "некоректне значення %%f"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "некоректне значення %%F"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "некоректне значення %%G"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "некоректне значення %%t"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "некоректне значення %%T"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "некоректне значення %%u"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "некоректне значення %%v"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "некоректне значення %%V"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "некоректне значення %%z"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "некоректне перетворення з типу %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "некоректне перетворення до типу %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "некоректне перетворення з типу %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "некоректне перетворення до %<__vector_pair%>"
 
@@ -20414,7 +20421,7 @@ msgstr "кандидат:"
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -20887,7 +20894,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Керування:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "справжній аргумент INTENT = OUT/INOUT"
 
@@ -21045,11 +21052,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "присвоювання"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr ""
 
@@ -21057,200 +21064,200 @@ msgstr ""
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr ""
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr ""
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr ""
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr ""
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr ""
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr ""
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr ""
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr ""
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr ""
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr ""
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Невідомий оператор %%<%s%%> у %%L; хотіли написати «%s»?"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Невідомий оператор %%<%s%%> у %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -21263,27 +21270,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22153,7 +22160,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -22529,7 +22536,7 @@ msgstr ""
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -22627,10 +22634,10 @@ msgstr ""
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -22767,7 +22774,7 @@ msgstr "не вдалося прочитати профіль функції з
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE оголошено тут"
@@ -24599,7 +24606,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25368,7 +25375,7 @@ msgstr ""
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -26499,14 +26506,14 @@ msgstr ""
 msgid "using a dangling pointer to %qD"
 msgstr ""
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -26551,7 +26558,7 @@ msgstr ""
 msgid "call to %qD"
 msgstr ""
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, gcc-internal-format
 msgid "storing the address of local variable %qD in %qE"
 msgstr ""
@@ -27636,7 +27643,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr ""
@@ -28596,7 +28603,7 @@ msgstr ""
 msgid "command-line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr ""
@@ -28636,12 +28643,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -28796,7 +28803,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "підтримки %<-fsanitize-recover=%s%> не передбачено"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsanitize-recover=%s%> is not supported"
 msgid "%<-fsanitize-trap=%s%> is not supported"
@@ -28838,182 +28845,182 @@ msgstr ""
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr ""
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr ""
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr ""
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr ""
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr ""
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "некоректна кількість аргументів параметра %<-falign-%s%>: %qs"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, gcc-internal-format
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr ""
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "некоректні аргументи %<-fpatchable-function-entry%>"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr ""
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, gcc-internal-format
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr ""
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr ""
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr ""
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr ""
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr ""
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr ""
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr ""
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr ""
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "%<-W%serror=%s%>: немає параметра %<-%s%>"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr ""
@@ -29688,187 +29695,187 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr ""
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr ""
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr ""
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "встановлено прапорець implicit_section, але розділ не є"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
 msgstr "некоректний порядок у вузлі asm %i"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -31538,27 +31545,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -32380,7 +32387,7 @@ msgstr ""
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "атрибут %qE проігноровано, оскільки %qD не є локальною змінною"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -34468,7 +34475,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36144,7 +36151,7 @@ msgstr "надто багато вхідних файлів"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -36175,15 +36182,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "%%:%<target_mode_check%> передано нерозпізнаний параметр"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "коректними аргументами є такі: %s; ви мали на увазі %qs?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "коректні аргументи: %s"
@@ -36268,48 +36275,48 @@ msgstr "%<-mcpu=%s%> є некоректним"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, gcc-internal-format
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -36793,13 +36800,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -37038,7 +37045,7 @@ msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "подвійне визначення %qs"
@@ -37079,7 +37086,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -37166,324 +37173,324 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, gcc-internal-format
 msgid "%qs string ill-formed"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "некоректний формат для %<sve_width%>"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, gcc-internal-format
 msgid "invalid %<sve_width%> value: %d"
 msgstr "некоректне значення %<sve_width%>: %d"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невідомий параметр регулювання (%s)"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs не є коректним зсувом у %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "некоректний модифікатор можливості %qs у %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "некоректний аргумент %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr "%qs має бути від себе самого для %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "некоректний аргумент %<%s%> %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "некоректний модифікатор можливості %qs у %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "некоректний модифікатор можливості %qs у %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "перемикач <-mcpu=%s%> конфліктує з перемикачем %<-march=%s%>"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "підтримки моделі коду %qs у режимі ilp32 не передбачено"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "помилкове форматування вказівки транслятору або атрибута %<target()%>"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "помилкове форматування вказівки транслятору або атрибута %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "непідтримуване simdlen %wd"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -37668,13 +37675,13 @@ msgstr ""
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -37815,17 +37822,17 @@ msgstr "аргумент атрибута %qE проігноровано"
 msgid "%qE attribute only applies to variables"
 msgstr ""
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
@@ -38032,7 +38039,7 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "don%'t support performance extension instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -38089,7 +38096,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
@@ -38195,7 +38202,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -38245,32 +38252,32 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -38278,22 +38285,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr ""
@@ -38367,17 +38374,17 @@ msgstr "підтримки %<-fpie%> не передбачено"
 msgid "%<-fPIE%> is not supported"
 msgstr "підтримки %<-fPIE%> не передбачено"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
@@ -38696,7 +38703,7 @@ msgstr "некоректний аргумент вбудованої функц
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr ""
@@ -39298,750 +39305,750 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr ""
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "помилковий аргумент %qs параметра %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "невідомий параметр параметра %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> вважається застарілим; скористайтеся одним із відповідників: %<-mtune=k8%> або %<-mtune=generic%>"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> вважається застарілим; скористайтеся одним із відповідників: %<target(\"tune=k8\")%> або %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "підтримки %<-mstringop-strategy=rep_8byte%> для 32-бітового коду не передбачено"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "підтримки %<-muintr%> для 32-бітового коду не передбачено"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 #| msgid "%<-muintr%> not supported for 32-bit code"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "підтримки %<-muintr%> для 32-бітового коду не передбачено"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "підтримки %<-mabi=ms%> для ABI X32 не передбачено"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "помилкове значення %qs для перемикача %<-march=%>"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "помилкове значення %qs атрибуту %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-march=%> є такі: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "помилкове значення %qs перемикача %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "помилкове значення %qs атрибуту %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-mtune=%> є такі: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> є несумісним із цією ціллю"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "підтримки %<-mpreferred-stack-boundary%> для цього призначення не передбачено"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> є несумісним із цим призначенням"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "невідомий параметр для %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> є несумісним із цією ціллю"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, gcc-internal-format
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr ""
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr ""
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr ""
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "двійковий інтерфейс передавання порожнього параметра %qT класу змінено у %<-fabi-version=12%> (GCC 8)"
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "вирівнювання полів %<_Atomic %T%> змінено у %{GCC 11.1%}"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "підтримки профілювання %<-mcmodel=large%> із PIC не передбачено"
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> є несумісним із %<-mfpmath=387%>"
@@ -40393,7 +40400,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -41515,58 +41522,58 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "невідома назва %<#pragma member_alignment%> %s"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, gcc-internal-format
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, fuzzy, gcc-internal-format
 #| msgid "fields cannot have SVE type %qT"
 msgid "member variables cannot have RVV type %qT"
 msgstr "поля не можуть належати до типу SVE %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "fields cannot have SVE type %qT"
 msgid "fields cannot have RVV type %qT"
 msgstr "поля не можуть належати до типу SVE %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 #| msgid "fields cannot have SVE type %qT"
 msgid "array elements cannot have RVV type %qT"
 msgstr "поля не можуть належати до типу SVE %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot delete objects with SVE type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "не можна вилучати об'єкти із типом SVE %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot delete objects with SVE type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "не можна вилучати об'єкти із типом SVE %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot delete objects with SVE type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "не можна вилучати об'єкти із типом SVE %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -41586,66 +41593,71 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, gcc-internal-format
@@ -42116,97 +42128,97 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "некоректний процесор %qs для %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> вимикає %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -43603,7 +43615,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -43788,7 +43800,7 @@ msgstr ""
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -43957,7 +43969,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -44084,7 +44096,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -44285,7 +44297,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr ""
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -44335,7 +44347,7 @@ msgstr ""
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -44380,7 +44392,7 @@ msgstr ""
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -44425,7 +44437,7 @@ msgstr ""
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr ""
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
@@ -44455,7 +44467,7 @@ msgstr ""
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
@@ -44570,12 +44582,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "встановлено значення параметра %qD, але сам параметр ніде не використано"
@@ -46610,7 +46622,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
@@ -46741,12 +46753,12 @@ msgstr "мало бути %<match%>"
 msgid "variant %qD is not a function"
 msgstr ""
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr ""
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47012,7 +47024,7 @@ msgstr ""
 msgid "invalid use of flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr ""
@@ -47964,12 +47976,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -48010,7 +48022,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозорі типи векторів не може бути ініціалізовано"
@@ -48025,8 +48037,8 @@ msgstr ""
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -48116,7 +48128,7 @@ msgstr ""
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -49459,7 +49471,7 @@ msgstr ""
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
@@ -49469,7 +49481,7 @@ msgstr ""
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
@@ -49484,7 +49496,7 @@ msgstr ""
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, gcc-internal-format
 msgid "  declared here"
@@ -49815,7 +49827,7 @@ msgstr ""
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -50386,7 +50398,7 @@ msgstr ""
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
@@ -50508,7 +50520,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -50577,7 +50589,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -50624,7 +50636,7 @@ msgstr ""
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -50748,7 +50760,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -50847,7 +50859,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -50923,7 +50935,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -50989,191 +51001,191 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%<reinterpret_cast%> не є сталим виразом"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr ""
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не є сталим виразом"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "вираз %qE не є сталим виразом"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не є сталим виразом"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 #| msgid "%<reinterpret_cast%> is not a constant expression"
 msgid "contract predicate is false in constant expression"
 msgstr "%<reinterpret_cast%> не є сталим виразом"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "вираз %qE не є сталим виразом"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ділення на нуль не є сталим виразом"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не є сталим виразом"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -51763,7 +51775,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%<return_void%> оголошено тут:"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "немає члена із назвою %qE у %qT"
@@ -51855,7 +51867,7 @@ msgstr ""
 msgid "no suspend point info for %qD"
 msgstr ""
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -51875,23 +51887,23 @@ msgstr ""
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -52371,7 +52383,7 @@ msgstr "з попереднього оголошення %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr ""
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "попереднє оголошення %qD"
@@ -52772,605 +52784,605 @@ msgstr "%qD є функцією, а не типом"
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%E%> is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<%T::%E%> не є типом"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> є меншим за %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> є більшим за %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr ""
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "не ініціалізовано %<const %D%>"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD не є безпосереднім членом %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "тип структурованої прив'язки є неповним, %qT"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "у C++98 %qD має бути ініціалізовано конструктором, а не за допомогою %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr ""
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr ""
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "неможливо розкласти недоступний член %qD %qT"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -53378,7 +53390,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -53386,7 +53398,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -53394,1659 +53406,1659 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не є інтегральним сталим виразом"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "не вдалося розкласти тип об'єднання %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явним чином типово визначено тут"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "масив змінної довжини %<auto%>"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T не є класом або простором назв"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr ""
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr ""
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs визначено з %qT"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified with %qT"
 msgid "%qs specified with %qD"
 msgstr "%qs визначено з %qT"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs визначено з %<decltype%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs визначено з %<typeof%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr ""
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, fuzzy, gcc-internal-format
 #| msgid "structured binding has incomplete type %qT"
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "тип структурованої прив'язки є неповним, %qT"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "некоректне використання %<decltype(auto)%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr ""
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "некоректне використання %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD не може бути %qs"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "шаблон змінної оголошено тут:"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD має бути нестатичною функцією-членом"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-static member function"
 msgid "%qD must be a member function"
 msgstr "%qD має бути нестатичною функцією-членом"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD не приймає аргументів"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT має попереднє оголошення тут"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -55058,110 +55070,110 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr ""
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "використання переліку %q#D без попереднього оголошення"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторне оголошення %qT не як шаблона"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "не можна оголошувати %qD в іншому модулі"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -55170,83 +55182,83 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "evaluating %qs"
 msgid "using %qs"
 msgstr "обчислюємо %qs"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -56096,7 +56108,7 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "масив має бути ініціалізовано за допомогою взятого у фігурні дужки ініціалізатора"
@@ -57146,7 +57158,7 @@ msgstr ""
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT не є класом, простором назв або переліком"
@@ -57891,7 +57903,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "помилкова кількість аргументів %<__builtin_addressof%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "помилкова кількість аргументів %<__builtin_launder%>"
@@ -58600,12 +58612,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -59204,7 +59216,7 @@ msgstr "пропущено аргументи шаблона"
 msgid "%qT not permitted in template argument"
 msgstr "%qT не можна використовувати у аргументі шаблона"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -60071,7 +60083,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
@@ -61085,7 +61097,7 @@ msgstr ""
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
@@ -61178,277 +61190,277 @@ msgstr ""
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "порожній ініціалізатор у захопленні під час ініціалізації лямбди"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "скористайтеся краще %<this->%D%>"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "скористайтеся краще %<%T::%D%>"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD оголошено тут, пізніше у модулі трансляції"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "помилкова кількість аргументів %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "помилкова кількість аргументів %<__builtin_complex%>"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не є класом або простором назв"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не є класом або простором назв"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT є змінним за змінними типом"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "інтегральний вираз %qE не є сталою"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "дублювання явного створення екземпляра %q#T"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "специфікація виключення %qD залежить від самої себе"
@@ -61460,163 +61472,163 @@ msgstr "специфікація виключення %qD залежить ві
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некоректний шаблон нетипізованого параметра"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "концепцію не може бути обмежено"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr ""
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "скористатися, замість цього, безпосередньо %qD"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr ""
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "не вдалося вивести %qT з %qE"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "некоректне використання %qT в аргументі шаблона"
@@ -61929,7 +61941,7 @@ msgstr ""
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -62337,28 +62349,28 @@ msgstr ""
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a class or namespace"
 msgid "%qD is not a class or alias template"
 msgstr "%qD не є класом або простором назв"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "аргумент, який не є вказівником, у %<__builtin_launder%>"
@@ -62366,22 +62378,22 @@ msgstr "аргумент, який не є вказівником, у %<__builti
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -63615,220 +63627,220 @@ msgstr ""
 msgid "declaration of %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr ""
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr ""
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr ""
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr ""
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr ""
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "некоректне використання розгортання пакета %qT"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr ""
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr ""
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr ""
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "пропущено ініціалізатор для члена %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -64771,7 +64783,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -65864,12 +65876,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -66050,7 +66062,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -68061,7 +68073,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -68332,7 +68344,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -68450,7 +68462,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
@@ -68460,7 +68472,7 @@ msgstr ""
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
@@ -68591,7 +68603,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -68807,12 +68819,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -68922,563 +68934,563 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Некоректний аргумент процедури у %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неочікуваний специфікатор повернення з альтернативи у виклику підпрограми у %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Неочікуване NULL() всередині у %L до фіктивного %qs"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be positive"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "аргумент %qs внутрішньої частини %qs у %L має бути додатним"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr ""
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -69663,7 +69675,7 @@ msgstr ""
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
@@ -70214,7 +70226,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -70782,7 +70794,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -72649,8 +72661,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -74616,708 +74628,718 @@ msgstr ""
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr ""
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr ""
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr ""
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr ""
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr ""
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr ""
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "Використання функції %qs у %L вважається застарілим"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "Використання підпрограми %qs у %L вважається застарілим"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75326,12 +75348,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75340,293 +75362,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Використання змінної %qs у %L вважається застарілим"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -75635,284 +75657,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Похідний тип %qs не можна використовувати як змінну у %L"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -75920,207 +75942,207 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -76128,984 +76150,984 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr ""
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -77997,7 +78019,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -78009,12 +78031,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -78106,82 +78128,88 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%qs at %C is not a variable"
+msgid "%s at %C has no default type"
+msgstr "%qs у %C не є змінною"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored because %qD is not a local variable"
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "атрибут %qE проігноровано, оскільки %qD не є локальною змінною"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Невикористану змінну %qs оголошено у рядку %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Невикористаний параметр %qs, оголошено у %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Невикористаний параметр %qs, який було явно імпортовано у %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -78196,27 +78224,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
diff --git a/gcc/po/vi.po b/gcc/po/vi.po
index eda1a117425..f7773d72fd5 100644
--- a/gcc/po/vi.po
+++ b/gcc/po/vi.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 7.1-b20170101\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2017-01-08 08:33+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -4115,7 +4115,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -7866,6 +7866,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support XOP built-in functions and code generation."
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "Hỗ trợ các hàm dựng sẵn và chức năng tạo ra mã loại XOP."
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -17593,12 +17599,12 @@ msgstr "toán hạng “%%l” không phải là một nhãn"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "sai sử dụng hằng số dấu chấm động"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -18712,65 +18718,65 @@ msgstr "Tùy chọn này còn thiếu tài liệu hướng dẫn."
 msgid "Uses of this option are diagnosed."
 msgstr "Dùng tùy-chọn này để chuẩn đoán."
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s%s."
 msgstr "%s Giống như %s."
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s."
 msgstr "%s Giống như %s."
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s Giống như %s."
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr ""
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[mặc định]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[đã bật]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[bị tắt]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Không tìm thấy tùy chọn có những đặc điểm đã muốn\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Không tìm thấy. Hãy sử dụng --help=%s để hiển thị *tất cả* các tùy chọn được giao diện %s hỗ trợ.\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Đã hiển thị tất cả các tùy chọn có những đặc điểm đã muốn\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "Valid arguments for the -msdata= option."
 msgid ""
@@ -18778,49 +18784,49 @@ msgid ""
 "   "
 msgstr "Đối số hợp lệ cho tùy chọn -msdata=."
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "Theo đây có những tùy chọn đặc trưng cho đích"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "Theo đây có những tùy chọn điều khiển các thông điệp cảnh báo của bộ biên dịch"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "Theo đây có những tùy chọn điều khiển việc tối ưu hóa"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "Theo đây có những tùy chọn không phụ thuộc vào ngôn ngữ"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options control optimizations"
 msgid "The following options control parameters"
 msgstr "Theo đây có những tùy chọn điều khiển việc tối ưu hóa"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "Theo đây có những tùy chọn đặc trưng cho chỉ ngôn ngữ "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "Theo đây có những tùy chọn được hỗ trợ bởi ngôn ngữ "
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "Theo đây có những tùy chọn không có tài liệu diễn tả"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "Theo đây có những tùy chọn chấp nhận các đối số riêng"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "Theo đây có những tùy chọn chấp nhận các đối số nối lại"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "Theo đây có những tùy chọn liên quan đến ngôn ngữ"
 
@@ -19211,78 +19217,78 @@ msgstr "đồ sửa đổi chiều dài theo định dạng strfmon"
 msgid "<command-line>"
 msgstr "<dòng lệnh>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "toán hạng không hợp lệ đối với “%%%c”"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "toán hạng còn thiếu"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "toán hạng không hợp lệ"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "tiền tố toán hạng không hợp lệ “%%%c”"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "sai đặt chế độ đặt địa chỉ"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "toán hạng không hợp lệ trong phép toán nhị phân"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "“%%&” bị sử dụng mà không có tham chiếu TLS năng động cục bộ"
@@ -19299,18 +19305,18 @@ msgid "invalid %%r value"
 msgstr "giá trị %%r sai"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "giá trị %%R sai"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
@@ -19340,7 +19346,7 @@ msgstr "giá trị %%M sai"
 msgid "invalid %%U value"
 msgstr "giá trị %%U sai"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
@@ -19350,7 +19356,7 @@ msgstr "giá trị %%s sai"
 msgid "invalid %%C value"
 msgstr "giá trị %%C sai"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
@@ -19363,7 +19369,7 @@ msgstr "không rõ bỏ ghi rõ bố trí lại"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "mã %%xn sai"
@@ -19447,35 +19453,35 @@ msgstr "UNSPEC không hợp lệ như là toán hạng: %d"
 msgid "unrecognized supposed constant"
 msgstr "không nhận ra điều nên là hằng số"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "sai đặt toán hạng dời"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "lệnh Thumb căn cứ vào"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "gặp lệnh căn cứ vào trong dãy có điều kiện"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -19484,30 +19490,30 @@ msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 msgid "invalid operand for code '%c'"
 msgstr "sai đặt toán hạng cho mã “%c”"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "lệnh chưa bao giờ thực hiện"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "định dạng mã Maverick đã cũ “%c”"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -19888,103 +19894,105 @@ msgstr "hằng không hợp lệ"
 msgid "Expected register or constant integer."
 msgstr "cần giao diện hay con trỏ đến giao diện"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "đặt sai UNSPEC như là toán hạng"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "dùng %<restrict%> không hợp lệ"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "sử dụng kết xuất cờ asm sai"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “O”"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “z”"
 
-#: config/i386/i386.cc:13283
-#, c-format
-msgid "invalid operand type used with operand code 'Z'"
+#: config/i386/i386.cc:13290
+#, fuzzy, c-format
+#| msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "sử dụng loại toán hạng không hợp lệ với mã toán hạng “Z”"
 
-#: config/i386/i386.cc:13288
-#, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "sai kích cỡ toán hạng cho mã toán hạng “Z”"
+#: config/i386/i386.cc:13295
+#, fuzzy, c-format
+#| msgid "invalid operand size for operand code 'O'"
+msgid "invalid operand size for operand code '%c'"
+msgstr "sai kích cỡ toán hạng cho mã toán hạng “O”"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “D”"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng không hợp lệ “%c”"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "mã toán hạng sai “%c”"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 #| msgid "invalid zero extract"
 msgid "invalid vector immediate"
 msgstr "trích số không không hợp lệ"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "không rõ chế độ lệnh"
 
@@ -20015,7 +20023,7 @@ msgstr "thao tác sai %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "gặp toán hạng %%P sai"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -20060,8 +20068,8 @@ msgstr "“%%%c” không phải là một tiền tố toán hạng đúng"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "sai sử dụng “%%%c”"
@@ -20093,7 +20101,7 @@ msgid "post-increment address is not a register"
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -20261,7 +20269,7 @@ msgstr "Hóa hợp không được hỗ trợ: %s"
 msgid "unsupported memory expression:"
 msgstr "không hỗ trợ chuyển đổi dấu chấm cố định"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -20328,155 +20336,155 @@ msgstr "-mquad-memory không sẵn sàng trên chế độ little endian"
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "Di chuyển 128-bit sai"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "giá trị %%D sai"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Bật sử dụng câu lệnh dấu số thực chấm động 128-bit IEEE."
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Không thể tạo ra việc tải/lưu offset cho hợp nhất"
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "Hợp nhất GPR sai"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -20946,7 +20954,7 @@ msgstr "ứng cử 1:"
 msgid "  after user-defined conversion:"
 msgstr "Bật câu lệnh được người dùng xác định."
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
@@ -21439,7 +21447,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Đang điều khiển:"
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "tham số thực tế cho INTENT = OUT/INOUT"
 
@@ -21605,11 +21613,11 @@ msgstr "IF (nếu) loại khối"
 msgid "implied END DO"
 msgstr "ngụ ý END DO (kết thúc làm)"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "sự gán"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "sự gán hàm trỏ"
 
@@ -21617,201 +21625,201 @@ msgstr "sự gán hàm trỏ"
 msgid "simple IF"
 msgstr "IF (nếu) đơn giản"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "thủ tục loại yếu tố"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 msgid "allocatable argument"
 msgstr "đối số phân bổ được"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 msgid "asynchronous argument"
 msgstr "đối số không đồng bộ"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "đối số tùy chọn"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 msgid "pointer argument"
 msgstr "đối số con trỏ"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 msgid "target argument"
 msgstr "đối số đích"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 msgid "value argument"
 msgstr "đối số giá trị"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 msgid "volatile argument"
 msgstr "đối số hay thay đổi"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 msgid "assumed-shape argument"
 msgstr "đối số assumed-shape"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 msgid "assumed-rank argument"
 msgstr "đối số assumed-rank"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 msgid "coarray argument"
 msgstr "đối số coarray"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr "đối số kiểu được dẫn suất tham số hóa"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 msgid "polymorphic argument"
 msgstr "đối số polymorphic"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr "thuộc tính NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 msgid "assumed-type argument"
 msgstr "đối số assumed-type"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr "kết quả mảng"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 msgid "pointer or allocatable result"
 msgstr "con trỏ hoặc kết quả cấp phát được"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 msgid "bind(c) procedure"
 msgstr "thủ tục bind(c)"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Gặp ngữ cảnh sai cho hàm trỏ NULL() tại %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Tại %%L có một toán tử thuộc số nguyên phân “%s” với toán hạng %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử ghép nối chuỗi với các toán hạng %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử hợp lý “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Tại %%L có một toán tử .not. với toán hạng %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Không thể so sánh các số lượng PHỨC TẠP tại %L"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Tại %%L thì các bộ hợp lý phải được so sánh với %s thay cho %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử so sánh “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "Unknown operator %%<%s%%> at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Các toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tại %%L và %%L có một toán tử với các phân hàng mâu thuẫn nhau"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "Biến vòng lặp"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 msgid "iterator variable"
 msgstr "biến iterator"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr "Biểu thức bắt đầu trong vòng lặp DO (làm)"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr "Biểu thức kết thúc trong vòng lặp DO (làm)"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr "Biểu thức bước trong vòng lặp DO (làm)"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 msgid "DEALLOCATE object"
 msgstr "đối tượng DEALLOCATE"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 msgid "ALLOCATE object"
 msgstr "đối tượng ALLOCATE"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 msgid "STAT variable"
 msgstr "biến STAT"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 msgid "ERRMSG variable"
 msgstr "Biến ERRMSG"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 msgid "item in READ"
 msgstr "mục tin trong READ"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 msgid "ACQUIRED_LOCK variable"
 msgstr "biến ACQUIRED_LOCK"
 
@@ -21824,27 +21832,27 @@ msgstr "Bộ dựng mảng chứa các chiều dài KÝ_TỰ khác nhau (%ld/%ld
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật không tương ứng với điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr "Gán vô hướng cho mảng chưa cấp phát"
 
@@ -22743,7 +22751,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax chỉ hỗ trợ cho RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -23138,7 +23146,7 @@ msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -23237,10 +23245,10 @@ msgstr ""
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -23379,7 +23387,7 @@ msgstr "không thể đọc hồ sơ hàm từ %s."
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -25282,7 +25290,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -26103,7 +26111,7 @@ msgstr "hàm trả về địa chỉ của biến cục bộ"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -27227,14 +27235,14 @@ msgstr ""
 msgid "using a dangling pointer to %qD"
 msgstr "chế độ con trỏ %qs không hợp lệ"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
@@ -27281,7 +27289,7 @@ msgstr "gọi hàm nội bộ"
 msgid "call to %qD"
 msgstr "  trong gọi đến %qD"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %qD returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -28356,7 +28364,7 @@ msgstr ""
 msgid "IPA modref summary is missing in input file"
 msgstr ""
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid jump function in LTO stream"
@@ -29356,7 +29364,7 @@ msgstr "(gần chỗ khởi tạo cho %qs)"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "%s không được hỗ trợ bởi cấu hình này"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "thiếu đối số đối cho %qs"
@@ -29398,12 +29406,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr "không nhận ra đối số tới tùy chọn %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
@@ -29569,7 +29577,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-fsanitize-recover=leak không được hỗ trợ"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "-fsanitize-recover=leak không được hỗ trợ"
@@ -29612,203 +29620,203 @@ msgstr ""
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition không được hỗ trợ trên kiến trúc này"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition không được hỗ trợ trên kiến trúc này"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition không được hỗ trợ trên kiến trúc này"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr ""
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=all option is not valid"
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr "tùy chọn -fsanitize=all không hợp lệ"
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize%s= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "không nhận ra đối số cho tùy chọn -fsanitize%s=: %q.*s"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize%s= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "không nhận ra đối số cho tùy chọn -fsanitize%s=: %q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs attribute directive ignored"
 msgstr "thuộc tính %qs bị bỏ qua"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize%s= option: %q.*s"
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "không nhận ra đối số cho tùy chọn -fsanitize%s=: %q.*s"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize%s= option: %q.*s"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "không nhận ra đối số cho tùy chọn -fsanitize%s=: %q.*s"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "sai số lượng đối số cho hàm %<va_start%>"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malign-loops=%d không nằm giữa 0 và %d"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments for spec function"
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "không có đối số tới hàm đặc tả"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, fuzzy, gcc-internal-format
 #| msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "đối số --help %q.*s chưa rõ ràng, hãy chính xác hơn"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "không nhận ra đối số cho tùy chọn --help=: %q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be a power of 2"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "vectorlength phải là lũy thừa 2"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr ""
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "dwarf version %d is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "dwarf phiên bản %d không được hỗ trợ"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "không nhận ra đối số cho tùy chọn --help=: %q.*s"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "hệ thống đích không hỗ trợ xuất gỡ lỗi"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr ""
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized debug output level %qs"
 msgstr "không nhận ra tên thanh ghi %qs"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "mức gỡ lỗi %qs là quá cao"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized btf debug output level %qs"
 msgstr "không nhận ra tên thanh ghi %qs"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "-Werror=%s: không có tùy chọn -%s"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: không có tùy chọn -%s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
@@ -30520,191 +30528,191 @@ msgstr ""
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "ký hiệu hàm không phải là một hàm"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "ký hiệu biến đổi không là một biến"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "nút có kiểu không hiểu"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "node has invalid order %i"
 msgstr "số ảo không hợp lệ cho %qs"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr ""
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, gcc-internal-format
 msgid "symver is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify gặp lỗi"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "chế độ con trỏ %qs không hợp lệ"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -32436,27 +32444,27 @@ msgstr ""
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -33310,7 +33318,7 @@ msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -35484,7 +35492,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37214,7 +37222,7 @@ msgstr "quá nhiều tập tin nhập vào"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -37248,15 +37256,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr ""
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ là: %s; có phải ý bạn là là: %qs?"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -37353,55 +37361,55 @@ msgstr "-mcpu=%s không hợp lệ"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "-mcpu=%s có số sửa đổi silíc không hợp lệ"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops is obsolete, use -falign-loops"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops đã cũ, hãy dùng -falign-loops"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malign-jumps đã cũ, hãy dùng -falign-jumps"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps=%d is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-jumps=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions is obsolete, use -falign-functions"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions đã cũ, hãy dùng -falign-functions"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-functions=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d không nằm trong khoảng 0 và 5"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> hiện nay chỉ được hỗ trợ trên GNU/Linux"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -37925,13 +37933,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "%qs không tương thích với %s %s"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -38174,7 +38182,7 @@ msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %qD"
 msgid "duplicate definition of %qs"
@@ -38221,7 +38229,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr ""
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr ""
@@ -38317,347 +38325,347 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "Vector argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Dùng lệnh mở rộng SPE ABI."
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "thuộc tính %qs bị bỏ qua"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for %<sve_width%>"
 msgstr "định dạng của %s không hợp lệ"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%J value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "giá trị %%J sai"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "không hiểu tùy chọn chỉnh (%s)"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mcpu=%qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "thiếu cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "đối số không hợp lệ cho %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "đối số không hợp lệ cho %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, fuzzy, gcc-internal-format
 #| msgid "missing arch name in -march=%qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "thiếu tên kiến trúc trong -march=%qs"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "không hiểu giá trị %qs cho -march"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mtune=%qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "thiếu tên cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s xung đột với -march=%s"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "Assembler không hỗ trợ -mabi=ilp32"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "mô hình mã %qs với -f%s"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<=%> (after %<getter%> attribute)"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> sai dạng"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
 msgstr "simdlen không được hỗ trợ %d"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -38857,13 +38865,13 @@ msgstr "đối số của thuộc tính %qE không hợp lệ"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -39011,18 +39019,18 @@ msgstr "thuộc tính %qE bị lờ đi"
 msgid "%qE attribute only applies to variables"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 #| msgid "unknown linker output %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "không hiểu xuất bộ liên kết %qs"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of asm flag output"
 msgid "invalid type for %<asm%> flag output"
@@ -39243,7 +39251,7 @@ msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "CPU đích không hỗ trợ truy cập chưa cân chỉnh"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -39304,7 +39312,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC không tương thích với -msingle-pic-base"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -39419,7 +39427,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -39469,33 +39477,33 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific cho Thumb-1"
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 #| msgid "invalid fpu for attribute(target(\"%s\"))"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -39504,23 +39512,23 @@ msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown target attribute or pragma %qs"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
@@ -39598,18 +39606,18 @@ msgstr "-fpie không được hỗ trợ"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE không được hỗ trợ"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-fwpa và -fltrans loại trừ lẫn nhau"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs hàm không có đối số"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs hàm không trả về giá trị nào"
@@ -39944,7 +39952,7 @@ msgstr "đối số mô hình bộ nhớ không hợp lệ cho phần tích hợ
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr ""
@@ -40580,786 +40588,786 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "dwarf phiên bản %d không được hỗ trợ"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 #| msgid "the call requires ifunc, which is not supported by this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "mô hình mã %s không hỗ trợ chế độ PIC"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %<target%> argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "không hiểu hàm đặc tả %qs"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "không chỉ định tên lớp với %qs"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> không được hỗ trợ, dùng =2"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -static with -fsanitize=address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "không thể chỉ định -static với -fsanitize=địa_chỉ"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fsanitize=address xung khắc với -fsanitize=kernel-address"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fsanitize=address xung khắc với -fsanitize=kernel-address"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel không được hỗ trợ trong cấu hình này"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "chế độ %i-bit chưa được biên dịch bên trong"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU bạn chọn không hỗ trợ chỉ lệnh x86-64"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d không nằm giữa 0 và %d"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary không được hỗ trợ trên đích này"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d không ở giữa %d và 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, fuzzy, gcc-internal-format
 #| msgid "%<-msseregparm%> used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "Chỉ lệnh SSE đặt là tắt, sử dụng số học 387"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry không hỗ trợ cho 32-bit trong tổ hợp cùng với -fpic"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry không tương thích với SEH"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 #| msgid "cdecl and thiscall attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "thuộc tính regparam và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and thiscall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int%d%> types"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not compatible with %qD"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "%qD không tương thích với %qD"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr ""
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, gcc-internal-format
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr ""
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr ""
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand type used with operand code 'Z'"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "sử dụng loại toán hạng không hợp lệ với mã toán hạng “Z”"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 #| msgid "unknown pointer size model %qs"
 msgid "unknown architecture specific memory model"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported return type %qT for simd"
 msgstr "đối số không được hỗ trợ cho %D"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported argument type %qT for simd"
 msgstr "đối số không được hỗ trợ cho %D"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -41736,7 +41744,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Thuộc tính %qE cần tham số là chuỗi"
@@ -42907,57 +42915,57 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "có rác ở cuối %<#pragma reset_options%>"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "useless cast to type %qT"
 msgid "fields cannot have RVV type %qT"
 msgstr "trừ phi ép thành kiểu %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 #| msgid "function parameters cannot have __fp16 type"
 msgid "array elements cannot have RVV type %qT"
 msgstr "tham số hàm không thể có loại __fp16"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 msgid "cannot delete objects with RVV type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr ""
@@ -42978,71 +42986,76 @@ msgstr ""
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs hàm không có đối số"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -43556,102 +43569,102 @@ msgstr "%qs đã lỗi thời và không có tác động gì"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "Use decimal floating point instructions."
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "Sử dụng câu lệnh dấu chấm động thập phân bằng phần cứng."
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -45115,7 +45128,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -45301,7 +45314,7 @@ msgstr ""
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -45470,7 +45483,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr "định nghĩa hàm có kiểu trả về là void"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -45597,7 +45610,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -45799,7 +45812,7 @@ msgstr ""
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -45849,7 +45862,7 @@ msgstr "cấu có không thành viên đã đặt tên"
 msgid "struct has no members"
 msgstr "struct không có thành viên nào"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -45895,7 +45908,7 @@ msgstr "khai báo lại của %<enum %E%>"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -45941,7 +45954,7 @@ msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr ""
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared weak"
 msgid "inline function %qD given attribute %qs"
@@ -45972,7 +45985,7 @@ msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "chưa có khai báo trước đây cho %qD"
@@ -46087,12 +46100,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
@@ -48200,7 +48213,7 @@ msgstr ""
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
@@ -48342,13 +48355,13 @@ msgstr "cần %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -48623,7 +48636,7 @@ msgstr "sử dụng sai biểu thức void"
 msgid "invalid use of flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr ""
@@ -49593,12 +49606,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -49639,7 +49652,7 @@ msgstr "yếu tố khởi tạo không tính được vào lúc nạp"
 msgid "invalid initializer"
 msgstr "bộ khởi tạo sai"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -49654,8 +49667,8 @@ msgstr "gặp nhóm ngoặc móc thừa tại kết thúc của bộ khởi tạ
 msgid "braces around scalar initializer"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "bộ phận mảng dẻo bị khởi tạo trong một ngữ cảnh lồng nhau"
@@ -49746,7 +49759,7 @@ msgstr "gặp yếu tố thừa trong bộ khởi tạo cấu trúc"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
@@ -51159,7 +51172,7 @@ msgstr ""
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "đã được khai báo ở đây"
@@ -51169,7 +51182,7 @@ msgstr "đã được khai báo ở đây"
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "được khai báo bảo vệ ở đây"
@@ -51184,7 +51197,7 @@ msgstr "%q#D là không thể truy cập trong ngữ cảnh này"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, gcc-internal-format
 msgid "  declared here"
@@ -51529,7 +51542,7 @@ msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
@@ -52121,7 +52134,7 @@ msgstr ""
 msgid "next member %q#D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
@@ -52246,7 +52259,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
@@ -52319,7 +52332,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -52369,7 +52382,7 @@ msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -52496,7 +52509,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -52603,7 +52616,7 @@ msgstr ""
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -52683,7 +52696,7 @@ msgstr "Đổi giá trị trong chuyển đổi từ %qs sang %qs tại %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -52751,194 +52764,194 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "cần template-id"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
@@ -53574,7 +53587,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "đã khai báo trước ở đây"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "no member named %qE in %qT"
@@ -53679,7 +53692,7 @@ msgstr "đối số 1 của __builtin_paired_predicate phải là một hằng"
 msgid "no suspend point info for %qD"
 msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -53701,23 +53714,23 @@ msgstr "biểu thức như là toán hạng không hợp lệ"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -54218,7 +54231,7 @@ msgstr "từ khai báo trước đây %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "khai báo trước đây %q#D"
@@ -54643,2335 +54656,2335 @@ msgstr "%qD không phải là một mẫu hàm"
 msgid "%q#T is not a class"
 msgstr "%q#T không phải là một lớp"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "không có kiểu có tên %q#T trong %q#T"
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names the constructor, not the type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<%T::%D%> tên cấu tử, không phải kiểu"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d không được hỗ trợ"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> chỉ có thể được chỉ định trong một lớp"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> chỉ có thể được chỉ định cho cấu tử"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> chỉ có thể được chỉ định cho lớp và hàm"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> bị bỏ qua trong khai báo này"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D không phải là thành viên tĩnh của %q#T"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ không cho phép %<%T::%D%> được định nghĩa như là %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "khởi tạo lặp lại cho %qD"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<thread_local%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD được khai báo như là một tham chiếu nhưng lại chưa được khởi tạo"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "thiếu kích thước mảng trong %qD"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "mảng có kích thước bằng không %qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "uninitialized %<const %D%>"
 msgstr "lặp lại %<const%>"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "quá nhiều bộ khởi tạo cho %qT"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "đối số %q#D có kiểu chưa đầy đủ"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "tham chiếu %qD được khởi tạo bằng chính nó"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "khai báo của %q#D chưa có bộ khởi tạo"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "nguồn là một hàm trỏ tới loại không hoàn toàn"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "nguồn có loại lớp không hoàn toàn"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "thiếu kích thước mảng trong %qT"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "mảng có kích thước không %qT"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD được khai báo là một biến %<virtual%>"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD được khai báo như là đối số %<virtual%>"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD được khai báo là một đối số %<inline%>"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD được khai báo như là kiểu %<virtual%>"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD được khai báo là một kiểu %<inline%>"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD được khai báo như là trường %<virtual%>"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD được khai báo là một trường %<inline%>"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "a function concept cannot be constrained"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD không phải là một hàm mẫu"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> phải trả về %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D đã là mặc định rõ ràng ở đây"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "a variable concept cannot be constrained"
 msgstr "Biến vòng lặp tại %C không thể là một coarray"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ cấm mảng có kích thước bằng không"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ cấm biến có kích thước biến đổi %qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ cấm biến có kích thước biến đổi"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "mảng có độ dài biến đổi %qD được dùng"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tràn kích thước mảng"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as array of %qT"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD được khai báo là mảng của %qT"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L"
 msgid "creating array of template placeholder type %qT"
 msgstr "Đang tạo mảng tạm tại %L"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "sự khai báo của %qD như là mảng void"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "tạo mảng void"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "sự khai báo của %qD như là mảng của các hàm"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "tạo mảng hàm"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "sự khai báo của %qD như là mảng của các tham chiếu"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "tạo mảng tham chiếu"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "sự khai báo của %qD như là mảng của các thành viên hàm"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "tạo mảng của thành viên hàm"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "no processor type specified for linking"
 msgid "return type specified for deduction guide"
 msgstr "chưa ghi rõ loại bộ xử lý cần liên kết"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "biến hay trường được khai báo là void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "@catch parameter can not be protocol-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "đối số @catch không thể là từ hạn định giao thức"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "sự khai báo của %qD như là non-member"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "định nghĩa hàm không khai báo đối số"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "sự khai báo của %qD như là %<typedef%>"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "%qs cannot appear in a constant-expression"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs không thể xuất hiện trong biểu thức hằng"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ không hỗ trợ %<__int%d%> cho %qs"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> và %<unsigned%> được chỉ định cùng với nhau cho %qs"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> và %<short%> được chỉ định cùng nhau với %qs"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%qs được dùng với %qE"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qD"
 msgstr "%qs được dùng với %qE"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "số ảo không hợp lệ cho %qs"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> ngoài khai báo lớp"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "thuộc tính bị bỏ qua"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Mong đợi một dấu ngoặc đơn mở"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not have parameters"
 msgid "constructors may not be ref-qualified"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "không thể khai báo con trỏ cho thành viên %q#T"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD được dùng như bộ khai báo"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> ngoài khai báo lớp"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "typedef may not be a function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "typedef may not be a member function definition"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef được khai báo %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "dùng %<::%> không hợp lệ"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "cấu tử không thể là %<concept%>"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "không thể mở %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qD in unnamed class"
 msgid "static data member %qE declared %qs"
 msgstr "thành viên dữ liệu tĩnh %qD trong lớp không tên"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared with placeholder %qT"
 msgid "non-static data member %qE declared %qs"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> không sử dụng khi định nghĩa (như ngược với khai báo) một thành viên dữ liệu tĩnh"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD không được khai báo như là tĩnh"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số của nó"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số thứ hai của nó"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "tiền tố %qD cần trả về %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "hậu tố %qD cần trả về %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD cần trả về bằng giá trị"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT được coi là %qs"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+T có một khai báo trước ở đây"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT được coi là enum"
@@ -56983,112 +56996,112 @@ msgstr "%qT được coi là enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "class template %qD redeclared as non-template"
 msgstr "template-id %qD trong khai báo của mẫu nguyên gốc"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare %qD in a different module"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT được định nghĩa với cơ sở đa trực tiếp"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT được định nghĩa cơ sở trực tiếp ảo"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
@@ -57097,85 +57110,85 @@ msgstr "đối số %d của %qE phải là một địa chỉ"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 #| msgid "increment of enumeration value is invalid in C++"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD đã sẵn định nghĩa trong %qT"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 #| msgid "using %<%c%s%>"
 msgid "using %qs"
 msgstr "đang dùng %<%c%s%>"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -58058,7 +58071,7 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
@@ -59161,7 +59174,7 @@ msgstr ""
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%E%> is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -59930,7 +59943,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "sai số tham số cho %<__builtin_addressof%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "đối số sai số lượng cho %<__builtin_launder%>"
@@ -60682,12 +60695,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -61307,7 +61320,7 @@ msgstr "thiếu đối số mẫu sau %qT"
 msgid "%qT not permitted in template argument"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -62196,7 +62209,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
@@ -63228,7 +63241,7 @@ msgstr ""
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
@@ -63325,284 +63338,284 @@ msgstr "hàm trả về một mảng"
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "sai số lượng đối số cho %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "đối số sai số lượng cho %<__builtin_complex%>"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 #| msgid "%s %#S"
 msgid "%s %#qS"
 msgstr "%s %#D"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate instance variable %q+D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "previous specification in %q#D here"
 msgid "exception specification of %qD depends on itself"
@@ -63615,168 +63628,168 @@ msgstr "sau đặc tả trước đây trong %q#D"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT không phải là một namespace hay enum không hoạt vi"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr ""
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "hàm không phải được tính để chèn vào trực tiếp"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in template argument"
 msgid "invalid use of %qT in template argument"
@@ -64104,7 +64117,7 @@ msgstr "đặc tả lớp-cơ-sở không hợp lệ"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
@@ -64531,28 +64544,28 @@ msgstr "%<__builtin_next_arg%> được gọi mà không có đối số"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE không phải một lớp mẫu"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
@@ -64560,22 +64573,22 @@ msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -65861,229 +65874,229 @@ msgstr "khai báo trước của %q#T"
 msgid "declaration of %q#T"
 msgstr "khai báo của %q#T"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%qD có kiểu chưa đầy đủ"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr ""
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qT"
 msgid "invalid use of placeholder %qT"
 msgstr "cách dùng không hợp lệ %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr ""
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr ""
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "sử dụng sai biểu thức void"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr ""
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr ""
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %q#D is invalid"
 msgid "initializer-string for %qT is too long"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "toán hạng cơ sở của %<->%> không phải là một con trỏ"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -67065,7 +67078,7 @@ msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -68174,12 +68187,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -68362,7 +68375,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -70407,7 +70420,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -70680,7 +70693,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -70799,7 +70812,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
@@ -70809,7 +70822,7 @@ msgstr ""
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
@@ -70945,7 +70958,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -71169,12 +71182,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -71285,567 +71298,567 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Đối số thủ tục không hợp lệ tại %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr ""
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 #| msgid "Interface %qs at %L may not be a statement function"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Giao diện %qs tại %L không thể là hàm khai báo"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%qs” (%lu/%lu) tại %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Đối số thực tế có chứa quá ít phần tử cho đối số giả “%qs” (%lu/%lu) tại %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Cần một con trỏ thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr ""
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Thiếu đối số đối thực tế cho đối số %qs tại %L"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Mã thành phần sai"
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Danh sách không khớp"
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Danh sách không khớp"
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Thủ tục %qs được gọi tại %L không được khai báo rõ ràng"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Thủ tục %qs được gọi tại %L không được khai báo rõ ràng"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument %qs at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "không thể tìm thấy ký hiệu %qs"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Kiểu giao diện sai"
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC %qs at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "không thể đè GENERIC %qs tại %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "thẻ %s tại %L phải là kiểu %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là các loại %d"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Đối số giả chưa dùng %qs tại %L"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Quá nhiều đối số trong cuộc gọi đến %qs tại %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Quá nhiều đối số trong cuộc gọi đến %qs tại %L"
@@ -72037,7 +72050,7 @@ msgstr "Chuyển đổi từ %s sang %s tại %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -72617,7 +72630,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -73198,7 +73211,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -75130,8 +75143,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -77125,719 +77138,729 @@ msgstr ""
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Trả lại giá trị của hàm %qs tại %L chưa đặt"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr ""
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr ""
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr ""
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:885
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:923
 #, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "Ký hiệu %qs tại %C đã có trong khối COMMON"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs at %C is already in a COMMON block"
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "Ký hiệu %qs tại %C đã có trong khối COMMON"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr ""
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr ""
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr ""
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr ""
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr ""
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr ""
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "%qs tại %L phải là số nguyên"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is used as actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Thủ tục nội tại %qs được dùng làm đối số thật tại %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Thủ tục nội tại %qs được dùng làm đối số thật tại %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Ký hiệu “%qs” tại %L chưa rõ ràng"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr ""
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Không thể phân giải hàm đặc tả %qs tại %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected intrinsic type %qs at %L"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs phải không tham chiếu tại %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): kiểu hàm sai"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "Using function %qs at %L is deprecated"
 msgstr "%qs đã lạc hậu"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): kiểu hàm sai"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qE is deprecated"
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "giao thức %qE đã lạc hậu"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, fuzzy, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function %qs at %L not set"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Trả lại giá trị của hàm %qs tại %L chưa đặt"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "loại không hợp lệ cho %s tại %L"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "loại không hợp lệ cho %s tại %L"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -77846,12 +77869,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -77860,296 +77883,296 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs đã lạc hậu"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Sai trong type-spec tại %L"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs tại %L phải là THỦ TỤC CON"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs tại %L phải là HÀM"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): sai kiểu biểu thức"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 #| msgid "Expected %<,%> or end of statement at %C"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "cần %<,%> hoặc kết thúc câu lệnh tại %C"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -78158,285 +78181,285 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "tham số %u có kiểu void"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ngữ cảnh sai cho hạn chế NULL() tại %L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -78444,211 +78467,211 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "cấu trúc BLOCK tại %C"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Kiểu khối sai"
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be a scalar"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là tuyến tính"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL không hợp lệ %L"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Không có biểu thức trên DO WHILE"
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mã câu lệnh sai"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %qs declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Đối số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -78656,990 +78679,990 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Chiều dài chuỗi tại %L là quá lớn"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s tại %L"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 #| msgid "Interface %qs at %L may not be a statement function"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Giao diện %qs tại %L không thể là hàm khai báo"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Đối số của thủ tục FINAL tại %L phải là kiểu %qs"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là kiểu dẫn xuất %qs"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là dẫn xuất kiểu %qs"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qE chưa được khai báo"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %L"
 msgid "Expecting definable entity near %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -80542,7 +80565,7 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -80554,12 +80577,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -80651,81 +80674,87 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%qs at %C is not a variable"
+msgid "%s at %C has no default type"
+msgstr "%qs tại %C không phải là một biến"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Trả lại giá trị của hàm %qs tại %L chưa đặt"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr ""
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr ""
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Đối số giả chưa dùng %qs tại %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Biến số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Đối số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Trả lại giá trị %sq của hàm %qs khai báo tại %L chưa đặt"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -80740,27 +80769,27 @@ msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Không hiểu intrinsic op"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -82705,6 +82734,9 @@ msgstr "tham số chưa dùng %q+D"
 #~ msgid "PIC register isn't set up"
 #~ msgstr "Chưa cài đặt thanh ghi PIC"
 
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "sai kích cỡ toán hạng cho mã toán hạng “Z”"
+
 #~ msgid "-maltivec=le not allowed for big-endian targets"
 #~ msgstr "-maltivec=le không cho phép trên đích big-endian"
 
diff --git a/gcc/po/zh_CN.po b/gcc/po/zh_CN.po
index 383f580a314..fc6ba9b9d52 100644
--- a/gcc/po/zh_CN.po
+++ b/gcc/po/zh_CN.po
@@ -34,7 +34,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 13.1-b20230409\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2023-04-13 22:07-0400\n"
 "Last-Translator: Boyuan Yang <073plan@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
@@ -4405,7 +4405,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -8389,6 +8389,12 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+#| msgid "Support AES built-in functions and code generation."
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "支持 AES 内建函数及代码生成。"
+
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
 msgid "Assume code will be linked by GNU ld."
@@ -18942,12 +18948,12 @@ msgstr "‘%%l’操作数不是一个标号"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "错误地使用了浮点常量"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -20018,68 +20024,68 @@ msgstr "此开关缺少文档。"
 msgid "Uses of this option are diagnosed."
 msgstr "对此选项的使用将被诊断。"
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s%s."
 msgstr "%s  与 %s 相同。"
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, fuzzy, c-format
 #| msgid "%s  Same as %s."
 msgid "Same as %s."
 msgstr "%s  与 %s 相同。"
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  与 %s 相同。"
 
-#: opts.cc:1732
+#: opts.cc:1733
 #, fuzzy
 #| msgid "Loop variable"
 msgid "[available in "
 msgstr "循环变量"
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[默认]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr ""
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[启用]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[禁用]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " 找不到具有指定特性的选项\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, fuzzy, c-format
 #| msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " 找不到对应的选项。使用 --help=%s 显示 %s 前端所支持的所有选项\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " 所有具有指定特性的选项已被显示\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, fuzzy, c-format
 #| msgid "Valid arguments for the -msdata= option"
 msgid ""
@@ -20087,49 +20093,49 @@ msgid ""
 "   "
 msgstr "-msdata= 选项的有效参数为："
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "下列选项与特定目标机相关"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "下列选项控制编译器警告信息"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "下列选项控制优化"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "下列选项与具体语言无关"
 
-#: opts.cc:1970
+#: opts.cc:1971
 #, fuzzy
 #| msgid "The following options control optimizations"
 msgid "The following options control parameters"
 msgstr "下列选项控制优化"
 
-#: opts.cc:1976
+#: opts.cc:1977
 msgid "The following options are specific to just the language "
 msgstr "下列选项只与特定语言相关 "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "下列选项被语言支持"
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "下列选项未列入文档"
 
-#: opts.cc:1991
+#: opts.cc:1992
 msgid "The following options take separate arguments"
 msgstr "下列选项带分立的参数"
 
-#: opts.cc:1993
+#: opts.cc:1994
 msgid "The following options take joined arguments"
 msgstr "下列选项带联合的参数"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "下列选项与语言相关"
 
@@ -20520,75 +20526,75 @@ msgstr "strfmon 格式的长度修饰符"
 msgid "<command-line>"
 msgstr "<命令行>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "缺少操作数"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "%%R 代码的操作数无效"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "‘%%%c’不是一个有效的操作数前缀"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "无效寻址模式"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "二元操作中中操作数无效"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "使用‘%%&’ 时没有指定任何动态 TLS 引用"
@@ -20605,18 +20611,18 @@ msgid "invalid %%r value"
 msgstr "无效 %%r 值"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "无效 %%R 值"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
@@ -20646,7 +20652,7 @@ msgstr "无效 %%M 值"
 msgid "invalid %%U value"
 msgstr "无效 %%U 值"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
@@ -20656,7 +20662,7 @@ msgstr "无效 %%s 值"
 msgid "invalid %%C value"
 msgstr "无效 %%C 值"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
@@ -20669,7 +20675,7 @@ msgstr "未指定未知的重定位方式"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "无效的 %%xn 代码"
@@ -20753,35 +20759,35 @@ msgstr "无效的 UNSPEC 用作操作数"
 msgid "unrecognized supposed constant"
 msgstr "预期的常量无法识别"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, c-format
 msgid "invalid shift operand"
 msgstr "无效的移位操作数"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "预测到的 Thumb 指令"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在条件序列中预测到的指令"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -20790,30 +20796,30 @@ msgstr "代码‘%c’的操作数无效"
 msgid "invalid operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, c-format
 msgid "instruction never executed"
 msgstr "指令从不被执行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支持的算符用于编码‘%c’"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -21199,103 +21205,103 @@ msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 msgid "Expected register or constant integer."
 msgstr "%C 需要一个无名接口"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "错误地使用了%<restrict%>"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand：%%A 代码操作数无效"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "‘z’修饰符的操作数无效"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "操作数代码‘%c’的操作数类型无效"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
-msgid "invalid operand size for operand code 'Z'"
-msgstr "‘z’修饰符的操作数无效"
+msgid "invalid operand size for operand code '%c'"
+msgstr "fr30_print_operand：%%A 代码操作数无效"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "操作数的约束无效"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "无效的控制谓词"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "未知的指令模式"
 
@@ -21326,7 +21332,7 @@ msgstr "对%<__fpreg%>的操作无效"
 msgid "invalid %%P operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -21371,8 +21377,8 @@ msgstr "‘%%%c’不是一个有效的操作数前缀"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "对‘%%%c’的使用无效"
@@ -21404,7 +21410,7 @@ msgid "post-increment address is not a register"
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "错误地址"
 
@@ -21567,7 +21573,7 @@ msgstr "不支持的组合：%s"
 msgid "unsupported memory expression:"
 msgstr "整点转换中类型无效"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "%%R 的操作数无效"
@@ -21632,154 +21638,154 @@ msgstr "生成小端在前的代码"
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "无效 %%J 值"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "无效的 %%D 值"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, c-format
 msgid "invalid %%e value"
 msgstr "无效 %%e 值"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, c-format
 msgid "invalid %%t value"
 msgstr "无效 %%t 值"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, c-format
 msgid "invalid %%V value"
 msgstr "无效 %%V 值"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效 %%x 值"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, c-format
 msgid "invalid %%z value"
 msgstr "无效 %%z 值"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "使用十进制浮点指令"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "无法生成重新载入，为："
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "向%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -22259,7 +22265,7 @@ msgstr "备选 1："
 msgid "  after user-defined conversion:"
 msgstr "启用用户自定义指令"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
@@ -22759,7 +22765,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "驱动："
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 #, fuzzy
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "实际参数到含义=出/INOUT"
@@ -22931,11 +22937,11 @@ msgstr "块 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "赋值"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "指针赋值"
 
@@ -22943,229 +22949,229 @@ msgstr "指针赋值"
 msgid "simple IF"
 msgstr "简单的 IF"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 msgid "elemental procedure"
 msgstr "基本过程"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 msgid "allocatable argument"
 msgstr "没有参数"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "参数"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 msgid "optional argument"
 msgstr "可选参数"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 msgid "pointer argument"
 msgstr "对空指针指向内容的写操作(实参 %d)"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 msgid "target argument"
 msgstr "目标"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 msgid "value argument"
 msgstr "%L处按值传递的实参不能是数组或数组段"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 msgid "volatile argument"
 msgstr "重复的%<volatile%>"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "在调度器中启用秩启发"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 msgid "coarray argument"
 msgstr "无效的参数"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 #, fuzzy
 msgid "parametrized derived type argument"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "源类型不是多态的"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr "NO_ARG_CHECK 属性"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "该类型不支持自增"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr "数组结果"
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "%3$L 处“%1$s”分句对象“%2$s”有 ALLOCATABLE 组件"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "%C处带有 NAME 的 BIND(C)过程不能有 POINTER 属性"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字符串毗连运算符(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "逻辑运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L处的 .not. 运算符的操作数为 %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L处复数不能比较大小"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L处逻辑值必须与 %s 比较，而不是 %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比较运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%%L和%%L处的操作数的秩不一致"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 msgid "Loop variable"
 msgstr "循环变量"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 #, fuzzy
 msgid "iterator variable"
 msgstr "变量"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 msgid "Start expression in DO loop"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 msgid "End expression in DO loop"
 msgstr "DO 循环中结束表达式"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 msgid "Step expression in DO loop"
 msgstr "DO 循环中的步进表达式"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "试图 DEALLOCATE 未分配的‘%s’"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 #, fuzzy
 msgid "STAT variable"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 #, fuzzy
 msgid "item in READ"
 msgstr "读取概要："
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "无法锁定新归档文件"
@@ -23180,27 +23186,27 @@ msgstr "数组构造函数中 CHARACTER 长度不同(%ld/%ld)"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "试图分配负数大小的内存。可能有整数溢出"
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度不匹配其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度短于其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目标的分级重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -24159,7 +24165,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax 只在 RTP PIC 上受支持"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 语句在%C处语法错误"
@@ -24544,7 +24550,7 @@ msgstr "%qE属性与 %s 属性冲突"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -24643,10 +24649,10 @@ msgstr "类型属性在定义后被忽略"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -24783,7 +24789,7 @@ msgstr "无法从 “%s” 中读取 LTO decls"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量越过字符串常量界"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -26681,7 +26687,7 @@ msgstr "大定点常量隐式截断为定点类型"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由于位段宽度所限，比较结果永远为 %d"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "简化范围检查时假定有符号数从不溢出"
@@ -27490,7 +27496,7 @@ msgstr "函数返回局部变量的地址"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -28641,14 +28647,14 @@ msgstr "假定是成员指针%qD"
 msgid "using a dangling pointer to %qD"
 msgstr "无效的指针模式%qs"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
@@ -28697,7 +28703,7 @@ msgstr "调用非函数的%qD"
 msgid "call to %qD"
 msgstr "在调用%qD时"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -29783,7 +29789,7 @@ msgstr "ipa 内联概要缺少在中输入文件"
 msgid "IPA modref summary is missing in input file"
 msgstr "ipa 内联概要缺少在中输入文件"
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid jump function in LTO stream"
@@ -30787,7 +30793,7 @@ msgstr "进行跨跳转优化"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "此配置不支持命令行选项%qs"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "%qs缺少参数"
@@ -30828,12 +30834,12 @@ msgstr "-mcorea 和 -mcoreb 不能一起使用"
 msgid "unrecognized argument in option %qs"
 msgstr "memusage：无法识别的选项“$1”"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs对%qs而言无效"
@@ -30995,7 +31001,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "不支持 -fpic"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "不支持 -fpic"
@@ -31037,194 +31043,194 @@ msgstr "要求追踪变量，但若不生成调试信息则无用"
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "求追踪变量，但不为这种调试格式所支持"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments 改变了选择性调度"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work with exceptions on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition 不能在此架构下和异常一起工作"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not support unwind info on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition 在此架构下不支持堆栈展开信息"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition 不能在此架构下工作"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "传递给 print_specific_help 的 include_flags 0x%x 不可识别"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "警告：--help= 选项的参数不可识别：%.*s\n"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "警告：--help= 选项的参数不可识别：%.*s\n"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute directive ignored"
 msgid "%qs attribute directive ignored"
 msgstr "%qE属性指定被忽略"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "%P: 无法辨认的仿真模式: %s\n"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "内建函数实参无效"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "提供给函数%qE的实参太多"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malign-loops=%d 不在 0 和 %d 之间"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "内建函数实参无效"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, fuzzy, gcc-internal-format
 #| msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "--help 的参数%q.*s有歧义，请改用更加明确的参数"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "--help= 选项的参数未知：%q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "结构的对齐必须是 2 的较小次方，而不是 %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "未知的堆栈检查参数“%s”"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 #| msgid "dwarf version %d is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "不支持 dwarf 版本 %d"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "--help= 选项的参数未知：%q.*s"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "目标系统不支持调试输出"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "调试格式“%s”与先前的选择冲突"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "无法识别的调试输出级别“%s”"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "调试输出级别 %s 太高"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 msgid "unrecognized btf debug output level %qs"
 msgstr "无法识别的调试输出级别“%s”"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "获取核心文件大小上限：%m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "将核心文件大小上限设为最大值：%m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "无法识别的 gcc 调试选项：%c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "命令行选项文件“%s”不存在"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s：没有选项 -%s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "%qs对%qs而言无效"
@@ -31952,191 +31958,191 @@ msgstr "泛型的转换层代码(thunk)对使用了%<...%>的方法%q#D失效"
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D 在汇编中被引用后又被重命名"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "函数返回了一个函数"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "未知类型的输入行"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD has invalid argument list"
 msgid "node has invalid order %i"
 msgstr "%qD 带有无效参数列表"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "cgraph_hash 中找不到节点"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, fuzzy, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "双向克隆链接列表已损坏"
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "-fmit-class-file 的别名"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, fuzzy, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, fuzzy, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared %qs which implies default visibility"
 msgid "symver is not exported with default visibility"
 msgstr "%qD声明为有默认可见性的%qs"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, fuzzy, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group 并非环状清单"
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, fuzzy, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "不支持组合有不同取样信息的单元。"
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, fuzzy, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "节点是单独在中 comdat 群组"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group 并非环状清单"
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "隐式声明函数%qE"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, fuzzy, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "节点是单独在中 comdat 群组"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, fuzzy, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr "--help=target 的别名"
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, fuzzy, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr "--help=target 的别名"
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, fuzzy, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr "--help=target 的别名"
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify 失败"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "无效的指针模式%qs"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "函数%q+D重声明为内联的"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "变量%qD被设定但未被使用"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -33866,27 +33872,27 @@ msgstr "机器独立内置编码超出范围"
 msgid "target specific builtin not available"
 msgstr "目标相关的内建函数不可用"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "矢量作业将被展开 piecewise"
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "矢量作业将被展开在中平行"
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "矢量作业将被展开与单一纯量作业"
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, fuzzy, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "矢量作业将被展开 piecewise"
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, fuzzy, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "矢量随机播放作业将被展开 piecewise"
@@ -34749,7 +34755,7 @@ msgstr "%qE属性被忽略，因为%qT已被定义"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE属性被忽略，因为%qT已被定义"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE属性只能应用到公共对象上"
@@ -36954,7 +36960,7 @@ msgstr "不受支持的非标准字面字符串毗连"
 msgid "traditional C rejects string constant concatenation"
 msgstr "传统 C 不接受字符串常量毗连"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -38715,7 +38721,7 @@ msgstr "输入文件太多"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -38749,15 +38755,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "无法识别的选项"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "%qs对%qs而言无效"
@@ -38849,51 +38855,51 @@ msgstr "-mcpu=%s 无效"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "-mcpu=%s 芯片版本不正确"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "%salign-loops%s 已经过时，请使用 -falign-loops%s"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "%salign-jumps%s 已经过时，请使用 -falign-jumps%s"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps=%d is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-jumps=%d 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "%salign-functions%s 已过时，请使用 -falign-functions%s"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-functions=%d 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s不在 0 和 5 之间"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%>只在 GNU/Linux 下被支持"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
@@ -39413,13 +39419,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "%qs必须与%qs一起使用"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
@@ -39688,7 +39694,7 @@ msgstr "传递%2$qE的第 %1$d 个参数时将指针赋给整数，未作类型
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "duplicate definition of %qs"
@@ -39733,7 +39739,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "类型 %qT 大小未知"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored because %qT is already defined"
 msgid "variables of type %qT cannot have thread-local storage duration"
@@ -39828,332 +39834,332 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "忽略%qs属性"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 msgid "invalid format for %<sve_width%>"
 msgstr "操作无效的对象"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "无效 %%h 值"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "%s: 不适用的选项 -- %c\n"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "spec 函数名格式错误"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, gcc-internal-format
 msgid "specify a system register with a small string length"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "%X%P: 未知特征 %s\n"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%<...%>作为实参。)"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "内建函数实参无效"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "开关 -mcpu=%s 与 -march=%s 冲突"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "汇编器不支持 -mabi=ilp32"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "%qs后断言"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "%qs后断言"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "%qs后断言"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%qs后断言"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s 只接受 2 个参数"
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "目标系统不支持调试输出"
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "不支持的真理哈希类型 %d。\n"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -40353,13 +40359,13 @@ msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -40508,18 +40514,18 @@ msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 msgid "%qE attribute only applies to variables"
 msgstr "属性%qE只能用于变量"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "向函数类型%qT的转换无效"
@@ -40731,7 +40737,7 @@ msgstr "目标 CPU 不支持 THUMB 指令"
 msgid "target CPU does not support unaligned accesses"
 msgstr "目标 CPU 不支持未对齐的访问"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -40792,7 +40798,7 @@ msgstr "结构大小边界只能被设定为 %s"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 与 -msingle-pic-base 不兼容"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
@@ -40909,7 +40915,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -40964,33 +40970,33 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "无法计算出栈中参数的真实地址"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "非预期的模块结束"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高寄存器弹栈时没有可用的低寄存器"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 #| msgid "invalid element type for attribute %qs"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -40999,24 +41005,24 @@ msgstr "属性%qs的元素类型无效"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "属性%qE的向量类型无效"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes SPE ABI"
 msgid "unknown target attribute or pragma %qs"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -41093,17 +41099,17 @@ msgstr "不支持"
 msgid "%<-fPIE%> is not supported"
 msgstr "不支持"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-flto and -fwhopr 互斥"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD不能有默认参数"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "不正确的函数返回值"
@@ -41439,7 +41445,7 @@ msgstr "内建函数实参无效"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "内建函数实参无效"
@@ -42067,726 +42073,726 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "代码模式 %s 在 PIC 模式下不受支持"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "%C处 SEQUENCE 属性已经在 TYPE 语句中指定"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "错误的选项于环境变量 MINICOM=“%s”\n"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D的寄存器名无效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D的寄存器名无效"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%s：未知选项 -%c\n"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs没有指定类名"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "%L处参数列表函数未知"
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> 不受支持，将使用 =2"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-fsanitize=address 与 -fsanitize=kernel-address 不兼容"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fsanitize=address 与 -fsanitize=kernel-address 不兼容"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -static with -fsanitize=thread"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "不能同时指定 -static 及 -fsanitize=thread"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel 在此配置下不受支持"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未编译入对 %i 位模式的支持"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您选择的 CPU 不支持 x86-64 指令集"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-march= 的值(%s)不正确"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "%2$sarch=%3$s %4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mtune switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "-mtune 开关的值%qs错误"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "%2$stune=%3$s%4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之间"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 不在 %d 和 12 之间"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "模块间优化未为 C++ 实现"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已禁用，使用 387 指令"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已禁用，使用 SSE 指令"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry 在 32 位下不能和 -fpic 同时使用"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "未知的选项：%s %s %s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 字节 cop 指针不允许被用在 VLIW 模式中"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt function must have no arguments"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "中断函数不能有参数"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qT却没有启用 SSE/SSE2"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "X32 does not support ms_abi attribute"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "X32 不支持 ms_abi 属性"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却出现了 SSE 向量实参，这改变了 ABI"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "没有启用 MMX却返回 MMX 向量，这改变了 ABI"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有一个可变数组成员的结构的 ABI 有了改变"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 #, fuzzy
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中返回"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中传递参数"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "已禁用 x87 却在 x87 寄存器中返回"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "assert：%s 与 %s 赋值兼容"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "%qE属性在此平台上不受支持"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support fastcall with nested function"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支持对嵌套函数使用 fastcall"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
@@ -42794,79 +42800,79 @@ msgstr "-fsplit-stack 不支持在嵌套函数中使用 2 个寄存器参数"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 3 register parameters"
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "-fsplit-stack 不支持 3 个寄存器参数"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "扩展的寄存器没有高半部分"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "非整数操作数使用了操作数代码‘%c’"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "32 位系统不支持 -mcmodel="
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "未知的架构特定的内存模型"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 #| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -43239,7 +43245,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE重声明有冲突的属性%qs"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -44400,60 +44406,60 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "未知‘# pragma externmodel’式样‘%s’(_M)"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a fixed size"
 msgstr "类型 %qT 大小未知"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT does not have a known size"
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "类型 %qT 大小未知"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, fuzzy, gcc-internal-format
 #| msgid "function parameters cannot have __fp16 type"
 msgid "member variables cannot have RVV type %qT"
 msgstr "函数形参不能有 __fp16 类型"
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 msgid "fields cannot have RVV type %qT"
 msgstr "%qD类型不完全"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 #| msgid "function parameters cannot have __fp16 type"
 msgid "array elements cannot have RVV type %qT"
 msgstr "函数形参不能有 __fp16 类型"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "无法为有抽象类型%qT的对象分配内存"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "无法为有抽象类型%qT的对象分配内存"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "无法为有抽象类型%qT的对象分配内存"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
@@ -44474,70 +44480,75 @@ msgstr "不使用位段指令"
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e 需要 ilp32e ABI"
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs没有指定类名"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD不能有默认参数"
 
+#: config/riscv/riscv.cc:7095
+#, fuzzy, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr "堆栈限制在此目标机上不受支持"
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -45045,101 +45056,101 @@ msgstr "已弃用。此开关不起作用。"
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "已弃用在 AltiVec 类型中使用%<long%>；请改用%<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%s：无效的目的：%s\n"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "无效的 %s 字组：%s\n"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "内建函数%q+D未被声明为函数"
@@ -46617,7 +46628,7 @@ msgstr "不能将带有 volatile 字段的对象放入寄存器"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -46807,7 +46818,7 @@ msgstr "为形参%qE指定了存储类"
 msgid "storage class specified for unnamed parameter"
 msgstr "为无名形参指定了存储类"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "为类型名指定了存储类"
@@ -46980,7 +46991,7 @@ msgstr "类型名声明为返回一个数组的函数"
 msgid "function definition has qualified void return type"
 msgstr "函数定义有限定的 void 返回类型"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函数返回类型的类型限定"
@@ -47107,7 +47118,7 @@ msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "结构或联合成员不能具有可变类型"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "变量或字段%qE声明为 void"
@@ -47310,7 +47321,7 @@ msgstr "C++ 不允许在%qs表达式中定义类型"
 msgid "%qT defined in underspecified object initializer"
 msgstr "初始值设定项里有未知的字段%qE"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "没有声明任何东西"
@@ -47360,7 +47371,7 @@ msgstr "结构不包含任何有名成员"
 msgid "struct has no members"
 msgstr "结构体没有成员"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "联合和可变数组成员"
@@ -47406,7 +47417,7 @@ msgstr "%<enum %E%>重声明"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -47454,7 +47465,7 @@ msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C 将枚举值限制在%<int%>范围内"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -47485,7 +47496,7 @@ msgstr "%qD先前没有原型"
 msgid "%qD was used with no prototype before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD先前没有声明"
@@ -47601,12 +47612,12 @@ msgstr "实参%qD与内建原型不符"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "实参%qD与原型不符"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "形参%qD被设定但未被使用"
@@ -49714,7 +49725,7 @@ msgstr "不够完美的嵌套循环"
 msgid "collapsed loops not perfectly nested"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
@@ -49850,13 +49861,13 @@ msgstr "需要%<catch%>"
 msgid "variant %qD is not a function"
 msgstr "在函数%qs中"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不兼容"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -50125,7 +50136,7 @@ msgstr "对 void 表达式的使用无效"
 msgid "invalid use of flexible array member"
 msgstr "对可变数组成员的使用无效"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "对未指定边界的数组的使用无效"
@@ -51136,12 +51147,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "对可变数组成员的初始化"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -51182,7 +51193,7 @@ msgstr "初始值设定中的元素在载入时无法被计算出"
 msgid "invalid initializer"
 msgstr "无效的初始值设定"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量类型不能被初始化"
@@ -51197,8 +51208,8 @@ msgstr "初始值设定项末尾有多余的花括号组"
 msgid "braces around scalar initializer"
 msgstr "标量初始化带花括号"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在嵌套的上下文中初始化可变数组成员"
@@ -51289,7 +51300,7 @@ msgstr "结构初始值设定项中有多余元素"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "对可变数组成员非静态地初始化"
@@ -52703,7 +52714,7 @@ msgstr "没有合适的%<operator %s%>给%qT"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
@@ -52715,7 +52726,7 @@ msgstr "在此声明"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
@@ -52732,7 +52743,7 @@ msgstr "%q+#D无法访问"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "将 NULL 作为非指针实参 %P 传递给%qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
@@ -53092,7 +53103,7 @@ msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
@@ -53699,7 +53710,7 @@ msgstr "可变数组是结构中的唯一成员"
 msgid "next member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
@@ -53824,7 +53835,7 @@ msgstr "函数%q+#D的抽象返回类型无效"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
@@ -53896,7 +53907,7 @@ msgstr "用户定义的%qD总是计算所有两个参数"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -53946,7 +53957,7 @@ msgstr "%qT是%qT的有歧义的基类"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -54074,7 +54085,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "提领%<void *%>指针"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -54174,7 +54185,7 @@ msgstr "成员%qD是未初始化的引用"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -54253,7 +54264,7 @@ msgstr "扩展：从 %s 到 %s，位于 %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -54322,197 +54333,197 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "截取的变量 %qD 与 non-automatic 贮藏体持续时间"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "需要模板 ID"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "function concept must be called"
 msgstr "内建函数%qD只需要一个实参"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "KIND 参数 %s 在%L处必须是初始化表达式"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 对象 %qE 与线程本地或自动贮藏体并非常数运算式"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "虚函数不能是友元"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%L处被零除"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "%L处非常量初始化表达式"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "%2$L处 %1$s 种别无效"
@@ -55130,7 +55141,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%qD在此声明"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 msgid "no member named %qE in %qT"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
@@ -55235,7 +55246,7 @@ msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 msgid "no suspend point info for %qD"
 msgstr "%qD先前没有原型"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -55258,23 +55269,23 @@ msgstr "指针不能用作 case 常量"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "使用了变长数组"
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -55785,7 +55796,7 @@ msgstr "从先前的声明%q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "先前的声明%q+D"
@@ -56206,2378 +56217,2378 @@ msgstr "%qD不是一个函数模板"
 msgid "%q#T is not a class"
 msgstr "%q#T不是一个类"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "在%2$qT中查询%1$qT有歧义"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类模板"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类型"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "不支持 -falign-labels=%d"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "匿名结构不在有名类型内"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有构造函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有构构函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T的属性必须跟在%qs关键字后面"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一个声明指定了多个类型"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "对 C++ 内建类型%qT的重声明"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 声明中缺少类型名"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允许匿名结构"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%>只能在类中指定"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能为构造函数指定%<explicit%>"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "此声明中的%<typedef%>被忽略"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%>不能被用作类型声明"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略在定义之外为类类型%qT应用的属性"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略在关联定义之外为依赖类类型%qT应用的属性"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef%qD被初始化(改用 decltype)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D声明有%<extern%>并被初始化"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允许将%<%T::%D%>定义为%<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允许成员%qD的初始化"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "变量%q#D有初始值设定，但是类型不完全"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "数组%q#D的元素类型不完全"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名字被用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值设定不受支持"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD的存储大小未知"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD的存储大小不是常量"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr " 变通的作法是删除初始值设定"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常量%qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T没有用户提供的默认构造函数"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建构子未被 user-provided 因为它是明确的缺席在中类别本体"
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建构子不初始化 %q+#D"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "无效类型%qT被用作类型为%qT的向量的初始值设定"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT没有名为%qD的非静态数据成员"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "初始值设定无法决定%q+D的大小"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示项 %qE 外侧汇总初始设置式"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT的初始值设定项太多"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "数组%q#T的元素类型不完全"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "变长复合字面量"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q+D类型不完全"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "标量对象%qD在初始值设定中需要一个元素"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在 C++98 中%qD必须由构造函数而不是%<{...}%>初始化"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "数组%qD被有括号的字面字符串%qE所初始化"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "构造函数中对静态成员的初始化无效"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一个类外的初始化)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "对成员的使用无效(您是否遗忘了%<&%>？)"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隐藏了早先的类型声明%q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE属性只能为变量或函数所使用"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函数%q#D像变量一样被初始化"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "不能在%q+D使用过时的绑定，因为它有析构函数"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT是%qT不可访问的基类"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "为结构字段指定了%qs"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "无法分解地址"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "源有不完全的类类型"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "不能对静态数据成员%qD取%<offsetof%>"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解构式"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的析构函数不能用作成员"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的构造函数不能用作成员"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD声明为%<virtual%>变量"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD声明为%<virtual%>参数"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD声明为%<inline%>参数"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD声明为%<virtual%>类型"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD声明为%<inline%>类型"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD声明为%<virtual%>字段"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD声明为%<inline%>字段"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D声明时带有异常规范"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD的定义不在包含%qT的命名空间中"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "静态成员函数%q#D的声明带有类型限定符"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD没有声明为一个参数"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法%qD返回非 Java 类型%qT"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "-fmit-class-file 的别名"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "不能内联%<main%>函数"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD不是一个模板函数"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在友元声明中定义显式特例化%qD"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本模板的声明中对模板标识符%qD的使用无效"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%>不允许用于友元模板特例化%qD的声明"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能将%<::main%>声明为 inline"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 带有无效参数列表"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "浮点数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "实字运算符后缀无法前继的由 %<_%>被保留的用于未来标准化"
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%>必须返回%<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隐式声明的%qD的定义"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成员函数%q#D未在类%qT中声明"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允许在类内初始化非常量静态成员%qD"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允许初始化成员常量%qD，因为它有非整数的类型%qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "数组%qD的大小具有非整数类型%qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允许大小为 0 的数组"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ 不允许变长数组%qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ 不允许变长数组"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "使用了变长数组%qD"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "使用了变长数组"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "数组维数溢出"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD声明为 void 的数组"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "创建 void 数组"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD声明为函数的数组"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "创建函数的数组"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD声明为引用的数组"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "创建引用的数组"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD声明为函数成员的数组"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "创建函数成员的组织"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "声明多维数组必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "使用了变长数组"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "为构造函数指定返回值无效"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "为%<operator %T%>指定了返回值"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "无名变量或字段声明为 void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "变量或字段声明为 void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "对限定名%<::%D%>的使用无效"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "对限定名%<%T::%D%>的使用无效"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "对限定名%<%D::%D%>的使用无效"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "%qD未声明为成员"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少声明标识符：使用了保留字%qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函数定义未声明形参"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "声明的形参%qD不存在"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs的声明指定了两个以上的数据类型"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ 不支持单独以 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允许声明无类型的%qs"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 对 %2$qs 不支持 %<__int%1$d%>"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "为%qs同时给定了%<signed%>和%<unsigned%>"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "为%qs同时给定了%<long%>和%<short%>"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qD"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "对%qs而言无效的复数"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "为模板参数%qs指定了存储类"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "为形参%qs指定了存储类"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "无效的函数声明"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在文件层将%qs声明为%<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "为友元函数声明指定了无效的存储类"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "忽略%qs属性"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "需要左圆括号"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs函数使用了%<auto%>类型限定却没有迟返回类型"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "错误地使用了%<auto%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs函数使用了迟返回类型却未用%<auto%>类型限定声明"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs声明为返回一个函数的函数"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs声明为返回一个数组的函数"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "构造函数不能被声明为虚函数"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "局部类定义中不能定义友元函数%qs"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "析构函数不能有参数"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "无法声明指向%q#T成员的指针"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "无法声明对%q#T的引用，因为它不是 typedef 或者模板类型实参"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "模板标识符%qD用作声明"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成员函数隐式地成为所属类的友元"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多余的限定%<%T::%>在成员%qs上"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非形参%qs不能是一个参数包"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "数据成员不能具有可变类型%qT"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有构造函数才能被声明为%<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非对象成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "静态%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允许嵌类的类型%qD与其所属的类重名"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "友元函数声明中出现了%<inline%>"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "模板参数不能是友元"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "友元声明需要 class，即%<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "友元声明需要 class，即%<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "试图让%qT成为全局域的友元"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象声明%qT被用作声明"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用模板名%qE时不带实参表无效"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允许可变数组成员"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "错误地使用了%<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%qD模板声明无效"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD不能声明为虚函数，因为它总是静态的"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在析构函数%qD中的友元声明需要限定名"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "在构造函数%qD中的友元声明需要限定名"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "不能打开 %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "模板声明%q#D"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名字%qT类型不完全"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函数%qs的存储类%<auto%>无效"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函数%qs的存储类%<register%>无效"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<static%>无效"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虚函数%qs不是类成员"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能将成员函数%qD声明为有静态链接"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一个函数中声明一个静态函数"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "与声明不同，定义静态数据成员时不能使用%<static%>"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "静态成员%qD声明为%<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能显式地将成员%q#D声明为有外部链接"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs已初始化，却又被声明为%<extern%>"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs既有%<extern%>又有初始值设定"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的引用"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "无效的构造函数：您要的可能是%<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD不能被声明为静态的"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD必须是一个非静态成员函数或非成员函数"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD的实参必须有类或枚举类型"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允许重载 ?: 运算符"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD必须带 0 或 1 个实参"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD必须带 1 或 2 个实参"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "后缀%qD必须使用%<int%>作为它的参数"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "后缀%qD必须使用%<int%>作为它的第二个参数"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD带且仅带 1 个实参"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD不能有默认参数"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "向具有相同类型的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "向相同类型的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "向指向基类的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "向基类的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "前缀%qD应当返回%qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "后缀%qD应当返回%qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD应当返回值而非引用"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名%qD，在%qs后"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT作为%qs被引用"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT作为枚举被引用"
@@ -58589,114 +58600,114 @@ msgstr "%qT作为枚举被引用"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%>需要模板参数"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用枚举%q#D前没有给出声明"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT重声明为非模板"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "不能将%qD声明为位段类型"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "派生联合%qT无效"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "此函数中的%qD在使用前未初始化"
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基类型%qT不是结构或类"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "递归的类型%qT未定义"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重复的基类型%qT无效"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "范围/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "条件表达式中类型不匹配"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下层的输入 enum %q#T"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "在不同命名空间内对%qD的特例化"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -58706,84 +58717,84 @@ msgstr "%<%2$T%>的内在类型%<%1$T%>必须是整型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "没有一个整数类型可以表示%qT的所有枚举值"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD处枚举值溢出"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD已在类%qT中定义过"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "括入并行"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD的类型默认为%<int%>"
@@ -59667,7 +59678,7 @@ msgstr "类型%qT不是%qT的直接或虚基类"
 msgid "type %qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
@@ -60770,7 +60781,7 @@ msgstr "在类作用域使用非成员的 using 声明"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
@@ -61537,7 +61548,7 @@ msgstr "类型不能定义在%<typeid%>表达式中"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -62267,12 +62278,12 @@ msgstr "只有构造函数才能有基类初始值设定"
 msgid "cannot expand initializer for member %qD"
 msgstr "无法从成员%<%D%>中扩展初始值"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建构子 delegation 追随 mem-initializer 用于 %qD"
@@ -62896,7 +62907,7 @@ msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 msgid "%qT not permitted in template argument"
 msgstr "参数不匹配"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -63785,7 +63796,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
@@ -64831,7 +64842,7 @@ msgstr "非模板类型%qT用作模板"
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
@@ -64930,282 +64941,282 @@ msgstr "函数返回了一个数组"
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被声明在中这个范围，而找不到任何声明是由 argument-dependent 查找于点的实体化"
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "声明在中附属基底 %qT 找不到由资格不符的查找"
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "为%qE属性给定的实参数目错误"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 msgid "%s %#qS"
 msgstr "张贴被搁置的文章 [%%s]？(%s/%s/%s/%s/%s)："
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -65218,174 +65229,174 @@ msgstr "在初次使用后显式特例化%qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT作为枚举被引用"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "在模板参数列表中定义了%q#T"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非模板%qD用作模板"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "改用 #include"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考虑内联函数"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weakref"
 msgid "explicit deduction guide declared here"
 msgstr "内联函数%q+D不能声明为有弱链接"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "模板第 %d 个参数无效"
@@ -65718,7 +65729,7 @@ msgstr "无效的基类"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
@@ -66133,28 +66144,28 @@ msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -66162,22 +66173,22 @@ msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -67476,229 +67487,229 @@ msgstr "%q+T先前在此处有过声明"
 msgid "declaration of %q#T"
 msgstr "在求%<%Q(%#T, %#T)%>值时"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%q+D类型不完全"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "对不完全的类型%q#T的非法使用"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "对成员的使用无效(您是否遗忘了%<&%>？)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the %<&%> ?)"
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "对成员的使用无效(您是否遗忘了%<&%>？)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qT"
 msgid "invalid use of placeholder %qT"
 msgstr "对%qT的使用非法"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "对模板的模板参数%qT的使用无效"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of pack expansion expression"
 msgid "invalid use of pack expansion %qT"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "对依赖类型%qT的使用无效"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "访问没有上下文类型信息的重载函数的地址"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "被重载的函数缺少上下文信息"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "上下文信息不足以确定类型"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "使用了构造函数的语法，但没有为类型%qT声明构造函数"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "位段%qs的宽度不是一个整数常量表达式"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "用以初始化字符数组的字符串太长"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "标量初始化带花括号"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "无法用复合字面常量初始化类型为%qT的聚集"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "类型%qD不匹配原先的声明"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的联合中找不到字段%qD"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在联合初始值设定中出现了索引值而不是字段名"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "检测到循环指针代理"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%>的基操作数具有非指针类型%qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%>的结果给出了非指针的结果"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%>的左操作数不是一个指针"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE不能用作成员指针，因为它的类型为%qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "无法将成员指针%qE应用到%qE上，因为后者的类型%qT不是一个类"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "不能内联%<main%>函数"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "引用类型的非法值初始化"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "调用的函数%qD会抛出不完全的类型%q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "调用的函数会抛出不完全的类型%q#T"
@@ -68685,7 +68696,7 @@ msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "‘我’于 %L 和‘J’于 %L 无法两者是 BOZ 实字常数"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%2$C处 DATA 语句初始值设定 %1$s 无效"
@@ -69783,12 +69794,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "初始化字符串被截断，以匹配%L处的变量"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L处的子字符串起始索引小于 1"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L处的子字符串终止索引超过了字符串长度"
@@ -69983,7 +69994,7 @@ msgstr "%C处错误的 INTENT 规格"
 msgid "deferred type parameter at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -72041,7 +72052,7 @@ msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
@@ -72314,7 +72325,7 @@ msgstr "%L处过程指针赋值中接口不匹配：%s"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
@@ -72433,7 +72444,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
@@ -72443,7 +72454,7 @@ msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%L 处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "%2$L 处的对象“%1$s”对于成分的默认初始化必须有 SAVE 属性，"
@@ -72576,7 +72587,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -72795,12 +72806,12 @@ msgstr "%L处定义赋值的第一个参数必须是 INTENT(OUT) 或 INTENT(INOU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
@@ -72910,569 +72921,569 @@ msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) %L处的实参可能干涉%L处的实参。"
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "%2$L处实参‘%1$s’类型不匹配；将 %3$s 传递给 %4$s"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参类型必须相同"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "实际参数到 non-INTENT (INOUT) 虚设‘%s’于 %L, 该项是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "实际参数到 non-INTENT (INOUT) 虚设‘%s’于 %L, 该项是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "虚参数‘%s’必须是指标或 assumed-shape 数组而无需 CONTIGUOUS 属性 - 作为实际参数于 %L 不是仅需 contiguous 和两者是异步或易变的"
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "传递 coarray 于 %L 到 allocatable、noncoarray，含义 (出) 虚参数‘%s’"
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "传递 coarray 于 %L 到 allocatable，noncoarray 虚参数‘%s’，该项无效如果配额状态被已修改"
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "%2$L 处假定外形的数组的元素传递给哑参数“%1$s”"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "%2$L处假定外形的数组的元素传递给虚参‘%1$s’"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "%2$L处假定外形的数组的元素传递给虚参‘%1$s’"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "%2$L处关键字参数‘%1$s’已经与另一个实参相关联"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L处调用过程时实参比形参多"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "%L处子进程调用中的替代返回限定与预期不符"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008:空指标于 %L 到 non-pointer 虚设‘%s’"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "%4$L处实参和指针或可分配虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "%4$L处实参和假定外形虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "实际参数于 %L 到 allocatable 或指标虚参数‘%s’必须有已推迟长度类型参数如果和只有如果虚设有一个"
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参的字符长度短于虚参‘%1$s’(%2$lu/%3$lu)"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参包含的元素对于虚参‘%1$s’(%2$lu/%3$lu)而言太少"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "‘%s’的实参在%L处必须不是一个假定大小的数组"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr "实际参数到 non-INTENT (INOUT) 虚设‘%s’于 %L, 该项是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008:Non-pointer 实际参数于 %L 到指标虚设‘%s’"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, fuzzy, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Coindexed 异步或易变的实际参数于 %L 需求该虚设‘%s’有 neither 异步 nor 易变的"
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "%L处带有向量下标的数组节实际参数与虚参‘%s’的 INTENT(OUT)、INTENT(INOUT) 或 VOLATILE 属性不兼容"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处数组节实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处指针数组的实参由于 VOLATILE 属性要求一个假定外形或指针数组虚参‘%s’"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "%C处的实参数列中缺少关键字名"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "%5$L处同样的实际参数与 INTENT(%1$s) 实参‘%2$s’和 INTENT(%3$s)实参‘%4$s’相关联"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L处的过程参数对于 PURE 过程是局部的，但是有 POINTER 属性"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "%2$L处调用的过程‘%1$s’不是显式声明的"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "%2$L处调用的过程‘%1$s’不是显式声明的"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "调用过程‘%s’带隐式接口，位于 %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "%2$L处的自动字符长度函数‘%1$s’必须有一个显式的接口"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "铸型参数到空值必要项于 %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "%2$L调用过程指针组件‘%1$s’时有隐式接口"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "%2$L处过程指针组件‘%1$s’的关键字实参需要显式接口"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "铸型=必要项在中空值() 参数于 %L:模棱两可介于特定的函数 %s 和 %s"
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "在类%qs中找不到可溢出的寄存器"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%2$C处实体‘%1$s’已经出现在接口中"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "不能覆盖%2$L处的 GENERIC‘%1$s’"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%2$L处的‘%1$s’覆盖了一个绑定声明为 NON_OVERRIDABLE 的过程"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%2$L处的‘%1$s’不能被 DEFERRED，因为它覆盖了一个非 DEFERRED 绑定"
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PURE 过程因此必须也是 PURE"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%2$L处的‘%1$s’覆盖了一个 ELEMENTAL 过程因此也必须是 ELEMENTAL"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%2$L处的‘%1$s’覆盖了一个非 ELEMENTAL 过程因此必须也不是 ELEMENTAL"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 SUBROUTINE 因此也必须是 SUBROUTINE"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PUBLIC 过程因此必须不是 PRIVATE"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%2$L处的‘%1$s’必须有与被覆盖的过程相同数量的形式参数"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个 NOPASS 绑定因此必须也是 NOPASS"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个具有 PASS 的绑定因此也必须是 PASS"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "%2$L处的‘%1$s’的传递对象虚参必须与被覆盖的过程传递对象的虚参位置相同"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s 标记在%L处必须具有类型 %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "%3$L处有字符值的 %1$s‘%2$s’不能是假定长度的"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "过程‘%s’(在 %s 中，位于 %L) 既不是函数也不是子进程"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
@@ -73658,7 +73669,7 @@ msgstr "从 %s 转换到 %s，位于 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -74240,7 +74251,7 @@ msgstr "名称表列‘%s’在中读取叙述于 %L 含有符号‘%s’该项
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
@@ -74824,7 +74835,7 @@ msgstr "停止编码于 %L 必须是缺省字符 KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -76728,8 +76739,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
@@ -78725,723 +78736,735 @@ msgstr "%3$L处有字符值的 %1$s‘%2$s’不能是假定长度的"
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "%3$L处有字符值的 %1$s‘%2$s’不能是假定长度的"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "%2$L处函数‘%1$s’有不匹配的数组规格说明"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function %s at %L has entries with mismatched array specifications"
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "%2$L处函数‘%1$s’有不匹配的数组规格说明"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "扩展：%2$L处函数 %1$s 有返回不同字符串长度的变量的表项"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be an array in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "%3$L处函数 %2$s 的返回值 %1$s 不能是一个数组"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be an array in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "%3$L处函数 %2$s 中入口返回值 %1$s 不能是一个数组"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "%3$L处函数 %2$s 的返回值 %1$s 不能是一个指针"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "%3$L处函数 %2$s 中入口返回值 %1$s 不能是一个指针"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "%3$L处函数 %2$s 的返回值 %1$s 不能是一个指针"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "%3$L处函数 %2$s 中入口返回值 %1$s 不能是一个指针"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FUNCTION result %s can't be of type %s in FUNCTION %s at %L"
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "%4$L处函数 %2$s 的返回值 %1$s 不能具有 %3$s 具型"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY result %s can't be of type %s in FUNCTION %s at %L"
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "%4$L处函数 %2$s 中入口返回值 %1$s 不能具有 %3$s 具型"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "符号‘%s’在%C处已经在一个 COMMON 块中"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "符号‘%s’在%C处已经在一个 COMMON 块中"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "COMMON block /%s/ not found at %C"
 msgid "COMMON block at %L"
 msgstr "%2$C处未发现 COMMON 块 /%1$s/"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "%2$L处变量‘%1$s’是在 COMMON 中, 但初始化仅允许出现在 BLOCK DATA 中"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, fuzzy, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "%2$L处被初始化的变量‘%1$s’是在一个空白 COMMON 中，但是初始化仅容许出现在有名公用块中"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "%2$L处 COMMON 中的派生类型变量‘%1$s’既没有 SEQUENCE 也没有 BIND(C) 属性"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "%2$L处 COMMON 中的派生类型变量‘%1$s’有一个可分配的最终组件"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "%2$L处 COMMON 中的派生类型变量‘%1$s’不能有默认的初始值设定"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的 COMMON 块‘%1$s’在%3$L处被用作 PARAMETER"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, fuzzy, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "%2$L处的 COMMON 块‘%1$s’在%3$L处被用作 PARAMETER"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "%2$L处的 COMMON 块‘%1$s’也是一个内建过程"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "Fortran 2003：%2$L处的 COMMON 块‘%1$s’也是一个函数返回值"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "Fortran 2003：%2$L处的 COMMON 块‘%1$s’也是一个全局过程"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "%L处的派生类型构造函数中元素的秩与该组件(%d/%d)的不匹配"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, fuzzy, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "%L处指针组件‘%s’的派生类型构造函数中的元素是 %s 但应该是 %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, fuzzy, gcc-internal-format
 #| msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "%4$L处 %3$s 中字符长度不相等 (%1$ld/%2$ld)"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, fuzzy, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "%L处派生类型构造函数中的 NULL 被用在既不是一个指针也不是 ALLOCATABLE 的组件‘%s’上"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "%C处结构构造函数中组件太多！"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "%C处结构构造函数中组件太多！"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "%L处的派生类型构造函数中元素的秩与该组件(%d/%d)的不匹配"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, fuzzy, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "%L处指针组件‘%s’的派生类型构造函数中的元素应该是 POINTER 或 TARGET"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, fuzzy, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "%2$L处指针组件‘%1$s’的派生类型构造函数中表达式无效"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, fuzzy, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "最后一维的上限必须出现在对在%2$L处假定大小数组‘%1$s’的引用中"
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "‘%s’(位于 %L)有歧义"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC 过程‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, fuzzy, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "%2$L处为内建函数‘%1$s’指定的类型被忽略"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "%2$L处的内建子例程‘%1$s’不应该有类型限定符"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%2$L 处‘%1$s’声明的 INTRINSIC 不存在"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, fuzzy, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "在%2$L处由内建函数‘%1$s’声明的 INTRINSIC 在当前的标准设置中是不可用的，但在 %3$s 下可用。使用一个适当的 -std=* 选项或启用 -fall-intrinsics 以便使用它。"
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, fuzzy, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "标号 %d(引用自 %L)从未被定义"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "内部过程‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "内建函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "内部过程‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL 非 INTRINSIC 过程‘%s’不允许在%L处作为实际参数"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "%2$L处对‘%1$s’的引用找不到特定的 INTRINSIC 过程"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "%L处按值传递的实参不具有数字类型"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "%L处按值传递的实参不能是数组或数组段"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "不允许按位置传递%L处的内部过程"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL 非 INTRINSIC 过程‘%s’不允许在%L处作为实际参数"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Coindexed 实际参数于 %L 与 ultimate 指标成分"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "%2$L处的‘%1$s’是个数组且是可选的；如果它缺失, 它不能是一个 ELEMENTAL 过程的实际参数，除非有一个具有相同秩的非可选的参数(12.4.1.5)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "%1$L处 ELEMENTAL 子程序‘%4$s’的 INTENT(%2$s) 哑‘%3$s’的实际参数是一个标量，但是另一个实际参数是一个数组"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "函数不能返回函数"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "%2$L处的泛型‘%1$s’没有指定的函数"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "%2$L处泛型函数‘%1$s’与特定的内建接口不一致"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "不能解析 %2$L处的函数‘%1$s’"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "%2$L处的 ABSTRACT INTERFACE‘%1$s’不能被引用"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, fuzzy, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "函数‘%s’被声明为 CHARACTER(*)从而不能被使用在%L处，因为它不是一个虚参"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "不良的 C++ 方法函数类型"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, fuzzy, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "%2$L处用户定义的非 ELEMENTAL 函数‘%1$s’不允许出现在 WORKSHARE 构造中"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "%2$L处 ENTRY‘%1$s’不能递归调用，因为函数‘%3$s’并非 RECURSIVE"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%2$L处的函数‘%1$s’不能被递归调用，因为它并非 RECURSIVE"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "已弃用%qE"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "%2$L处 FORALL 块内对‘%1$s’子例程的调用不是 PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "%2$L处 FORALL 块内对‘%1$s’子例程的调用不是 PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "泛型‘%s’在%L处没有特定的子进程"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "%2$L处泛型子进程‘%1$s’与一个内建子进程接口不一致"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, fuzzy, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "不能解决%2$L处的指定子例程‘%1$s’"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%2$L处的‘%1$s’的类型与%3$L处 CALL 的类型不一致"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "%2$L处 ENTRY‘%1$s’不能被递归调用，因为子进程‘%3$s’并非 RECURSIVE"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%2$L处 SUBROUTINE‘%1$s’不能递归调用，因为它并非 RECURSIVE"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "不良的 C++ 方法函数类型"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "已弃用%qE"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L和%L处的操作数外形不相容"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, fuzzy, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "%L处按值传递的实参不能是数组或数组段"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, fuzzy, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "%L处未指定假定大小数组段的最右端上限"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L处数组索引必须是标量"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L处数组索引必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of array reference at %C"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "%C处数组引用形式无效"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L处的子字符串起始索引类型必须为 INTEGER"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L处的子字符串起始索引必须是标量"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L处的子字符串终止索引类型必须为 INTEGER"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L处的子字符串终止索引必须是标量"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "%L处子串结束索引太大"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 POINTER 属性"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 ALLOCATABLE 属性"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L处不能指定两个或以上秩不为零的部分引用"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的数组在 %L 处必须是哑参数"
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -79450,12 +79473,12 @@ msgstr "%L处假定外形的数组必须是一个虚参"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -79464,294 +79487,294 @@ msgstr "%L处假定外形的数组必须是一个虚参"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "“%s”是必须是一个模块过程或有显式接口的外部过程于 %L 处"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "用在一个规格说明表达式中的变量‘%s’在%L处的引用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "变量‘%s’在%L处的使用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "%2$L处非多态的传递对象哑元实参‘%1$s’"
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 对象与 polymorphic allocatable subcomponent 于 %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "已弃用%qE"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "%C处类型指定无效"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "%L处传递的对象必须是标量"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%2$L处对 GENERIC‘%1$s’的调用没有找到匹配特别的限定"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要表达式类型"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 起始表达式必须是一个标量整数"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 结束表达式必须是一个标量整数"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L处 FORALL 间隔表达式不能是零"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引‘%s’不能出现在%L处的三元组规格说明中"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "%L处的源表达式必须是标量或者与%L处的分配对象有相同的秩"
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "%L处实体的类型与%L处的源表达式类型不兼容"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "%L处的分配对象和%L处的源表达式应该有相同的种别类型参数"
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "%2$L处分配具有 ABSTRACT 基类型的 %1$s 需要一个类型指定或 SOURCE="
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 于 %L 与 type-spec 需求相同 character-length 参数作为在中声明"
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’不能出现在%L处其自身被分配的 ALLOCATE 语句的数组规格说明中"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "%L处分配的对象也出现在%L处"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
@@ -79760,285 +79783,285 @@ msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L 处 CASE 语句中的表达式种别必须为 %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L处 SELECT 语句的实参不能是 %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L处的 DEFAULT CASE 为%L处的第二个 DEFAULT CASE 所跟随"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L 处 CASE 语句中的常量逻辑值被重复了"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L处范围规格无法匹配"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L处逻辑 SELECT CASE 块有多于两个的情况"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名字‘%s’在%C处不能用作已定义的运算符"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%C处 SELECT TYPE 语句中的选择子应该是多态的"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "%2$L处派生类型‘%1$s’必须是‘%3$s’的一个扩展"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "%L处 SELECT TYPE 语句中有双重的 CLASS IS 块"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "数据转移组件于 %L 无法 polymorphic 除非它被处理由定义的输入/输出进程"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 ALLOCATABLE 组件"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L处数据传输元素不能是对一个假定大小数组的全引用"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L处的语句对%L处的分支语句而言不是一个有效的分支目标语句"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "%L处的分支可能导致无穷循环"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往叙述于 %L 树叶重要建构用于标贴于 %L"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
@@ -80046,215 +80069,215 @@ msgstr "%s 语句在%C处离开 OpenMP 结构块"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L处的标号与%L处 GOTO 语句不在相同的块中"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L处的 WHERE 掩码外形不一致"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L处 WHERE 赋值目标外形不一致"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "%L处 WHERE 中用户定义的非 ELEMENTAL 用户赋值"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L处在 WHERE 内不支持的语句"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "%2$L处带索引‘%1$s’的 FORALL 没有被用在赋值的左侧，所以可能导致对这个对象的多个赋值"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "%L处外部 FORALL 构造已经有一个同名的索引"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L处的 WHERE/ELSEWHERE 子句需要一个 LOGICAL 数组"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, fuzzy, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "变量必须不是 polymorphic 在中 intrinsic 指派于 %L - 检查该有匹配特定的副常式用于‘=’运算符"
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "%L处赋值中的变量类型不能是多态的"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "变量‘%s’在 %L 尚未指派目标标号"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "%L处的替代 RETURN 语句需要一个 SCALAR-INTEGER 返回限定符"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "%C处 CASE 中需要初始化表达式"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L处的 ASSIGN 语句需要一个默认标量 INTEGER 变量"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L处的算术 IF 语句要求一个数字表达式"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L处 DO WHILE 循环的退出条件必须是一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -80262,996 +80285,996 @@ msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "%L处字符串太长"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可分配的数组‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "%2$L处标量对象‘%1$s’不能为 ALLOCATABLE"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "%2$L处的 CLASS 变量‘%1$s’必须是哑元、可分配的或者指针"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "‘%s’在%L处不能是主机相关的，因为它被在%L处声明的一个不兼容的同名对象所阻碍"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008：%2$L处模块变量‘%1$s’隐含使用了 SAVE，因为默认初始化有此需求"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "%2$L处的模块或主程序数组‘%1$s’必须有常量外形"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L处假定字符长度的实体必须是个虚参或是个 PARAMETER"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "内建函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自动数组‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，于 %s:%d"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%2$L处有字符值的语句函数‘%1$s’必须有常量长度"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处‘%1$s’是 PRIVATE 类型因而不能是 PUBLIC 类型‘%2$s’的虚参"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: %3$L处 PUBLIC 接口‘%2$s’中的过程‘%1$s’有 PRIVATE 的虚参‘%4$s’"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%2$L处 ELEMENTAL 函数‘%1$s’必须有一个标量返回值"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为数组值"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能是递归的"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "哑过程‘%s’在%C处不能有泛型接口"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 INTENT 属性冲突"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与在%2$L处‘%1$s’中的 RESULT 属性冲突"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "%2$L处过程指针结果‘%1$s’缺少指针属性"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%L处的 FINAL 过程有且只有一个参数"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L处 FINAL 过程的参数必须不是 INTENT(OUT)"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "%2$L处声明的 FINAL 过程‘%1$s’有与‘%4$s’相同的秩(%3$d)"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "仅为定义在%2$L处的派生类型‘%1$s’声明了数组 FINAL 过程，建议也定义一个标量过程"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%4$L处‘%1$s’和‘%2$s’对 GENERIC‘%3$s’不能是混合的 FUNCTION/SUBROUTINE"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "引用%qs有歧义：出现在接口%qs和接口%qs中"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定义的指定绑定‘%1$s’用作%3$L处的 GENERIC‘%2$s’的目标"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "%2$L处 GENERIC‘%1$s’必须定位一个特定的绑定，‘%3$s’也是 GENERIC"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "%2$L处 GENERIC‘%1$s’无法覆盖同名的特定绑定"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L处类型限定的操作数不能是 NOPASS"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%2$L处的‘%1$s’必须是一个模块过程或带有显式接口的外部过程"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处有 PASS(%2$s)的过程‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%2$L处非多态的传递对象虚参‘%1$s’"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%2$L处‘%1$s’的传递对象虚参必须是标量"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 POINTER"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的组件重名"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的继承组件重名"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "%2$L处声明的派生类型‘%1$s’必须是 ABSTRACT，因为‘%3$s’是 DEFERRED 且没有被覆盖"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L处 ICHAR 的参数长度必须为 1"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "%4$L处具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须有派生类型‘%5$s’"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%4$L 处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须是标量"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能有 POINTER 属性"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能是 ALLOCATABLE"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "%2$L处组件‘%1$s’的字符长度必须是一个常量规格表达式"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字符成分‘%s’的‘%s’于 %L 与已推迟长度必须是指标或 ALLOCATABLE"
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处组合‘%1$s’是一个 PRIVATE 类型，因此不能是 PUBLIC‘%2$s’的组合"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 于 %L 在中串行或绑定©类型 %s"
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "%2$L处声明的有 SEQUENCE 类型的组件 %1$s 没有 SEQUENCE 属性"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%L处非常量初始化表达式"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "作为延伸类型‘%s’于 %L 有 coarray 成分，亲代类型‘%s’应该也有一个"
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%2$L处不能扩展的派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C处假定大小数组的规格说明错误"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "变量‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "变量‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "变量‘%s’于 %L 是 coarray 和不是 ALLOCATABLE，保存 nor 虚参数"
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "在 %2$L 处基本过程的参数“%1$s”不能有 POINTER 属性"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "开始的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "结束的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "%2$L处 PURE 过程中包含的过程‘%1$s’必须也是 PURE"
@@ -82160,7 +82183,7 @@ msgstr "%L 处  EQUIVALENCE 中不等的初始值设定重叠"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "%L 处  EQUIVALENCE 中不等的初始值设定重叠"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -82172,12 +82195,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "%L处数组构造函数中的元素数超过容许的上限 %d。请参见 -fmax-array-constructor 选项"
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "在%L处建立临时数组"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "走过错误的表达式类型(%d)"
@@ -82271,81 +82294,86 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "字母 %c 在%C处已经有了一个隐式类型"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "内建函数变量不是一个过程"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "%2$L处函数‘%1$s’的返回值没有设置"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, fuzzy, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "模块变量 %s 的后端声明已存在"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "%2$L处的虚参‘%1$s’被声明为 INTENT(OUT)，但没有设置"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "%2$L处的虚参‘%1$s’被声明为 INTENT(OUT)，但没有设置"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "%3$L处声明的的函数‘%2$s’的返回值‘%1$s’没有设置"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -82360,27 +82388,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "未知的内建操作"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "%L处参数列表函数未知"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -84251,6 +84279,10 @@ msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 msgid "unused name %qE"
 msgstr "未使用的名称 %qE"
 
+#, fuzzy
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "‘z’修饰符的操作数无效"
+
 #, fuzzy
 #~ msgid "-gz=zlib is not supported in this configuration"
 #~ msgstr "弱引用在此配置下不受支持"
diff --git a/gcc/po/zh_TW.po b/gcc/po/zh_TW.po
index e99b66d5a99..ebe87a6a707 100644
--- a/gcc/po/zh_TW.po
+++ b/gcc/po/zh_TW.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2023-04-04 17:04+0000\n"
+"POT-Creation-Date: 2023-04-25 21:43+0000\n"
 "PO-Revision-Date: 2020-11-19 00:56+0800\n"
 "Last-Translator: Yi-Jyun Pan <pan93412@gmail.com>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@lists.linux.org.tw>\n"
@@ -4306,7 +4306,7 @@ msgstr ""
 
 #: m2/lang.opt:123
 #, no-c-format
-msgid "specify the library order, the libraries maybe specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
 msgstr ""
 
 #: m2/lang.opt:127
@@ -8174,6 +8174,11 @@ msgstr ""
 msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
 msgstr ""
 
+#: config/i386/i386.opt:1280
+#, fuzzy, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr "支援 XOP 內建函式和編碼產生 "
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy, no-c-format
 #| msgid "Assume code will be linked by GNU ld"
@@ -18357,12 +18362,12 @@ msgstr "「%%l」運算元不是一個標籤"
 #. PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. TARGET_PRINT_OPERAND must handle them.
-#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12317
+#: final.cc:3729 config/arc/arc.cc:6430 config/i386/i386.cc:12318
 #, c-format
 msgid "floating constant misused"
 msgstr "錯誤地使用了浮點常數"
 
-#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12408
+#: final.cc:3787 config/arc/arc.cc:6527 config/i386/i386.cc:12409
 #: config/pdp11/pdp11.cc:1871
 #, c-format
 msgid "invalid expression as operand"
@@ -19437,63 +19442,63 @@ msgstr "此選項無文件。"
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.cc:1651
+#: opts.cc:1652
 #, c-format
 msgid "Same as %s%s (or, in negated form, %s%s)."
 msgstr ""
 
-#: opts.cc:1656
+#: opts.cc:1657
 #, c-format
 msgid "Same as %s%s."
 msgstr "等於 %s%s。"
 
-#: opts.cc:1661
+#: opts.cc:1662
 #, c-format
 msgid "Same as %s."
 msgstr "等於 %s。"
 
-#: opts.cc:1669
+#: opts.cc:1670
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  等於 %s。"
 
-#: opts.cc:1732
+#: opts.cc:1733
 msgid "[available in "
 msgstr "[受支援於"
 
-#: opts.cc:1764
+#: opts.cc:1765
 msgid "[default]"
 msgstr "[預設]"
 
-#: opts.cc:1773
+#: opts.cc:1774
 #, c-format
 msgid "%llu bytes"
 msgstr "%llu 位元組"
 
-#: opts.cc:1810
+#: opts.cc:1811
 msgid "[enabled]"
 msgstr "[已啟用]"
 
-#: opts.cc:1812
+#: opts.cc:1813
 msgid "[disabled]"
 msgstr "[已停用]"
 
-#: opts.cc:1848
+#: opts.cc:1849
 #, fuzzy, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " 找不到任何選項與設想的特性是\n"
 
-#: opts.cc:1857
+#: opts.cc:1858
 #, fuzzy, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " 無找到。 使用 --help=%s 到顯示 * 所有 * 選項支援的由 %s 前端\n"
 
-#: opts.cc:1863
+#: opts.cc:1864
 #, fuzzy, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " 所有選項與設想的特性已顯示\n"
 
-#: opts.cc:1908
+#: opts.cc:1909
 #, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
@@ -19502,50 +19507,50 @@ msgstr ""
 "  已知用於 %s 選項的有效引數：\n"
 "   "
 
-#: opts.cc:1958
+#: opts.cc:1959
 msgid "The following options are target specific"
 msgstr "下列選項是目標特定的"
 
-#: opts.cc:1961
+#: opts.cc:1962
 msgid "The following options control compiler warning messages"
 msgstr "下列選項控制編譯器警告訊息"
 
-#: opts.cc:1964
+#: opts.cc:1965
 msgid "The following options control optimizations"
 msgstr "下列選項控制最佳化"
 
-#: opts.cc:1967 opts.cc:2007
+#: opts.cc:1968 opts.cc:2008
 msgid "The following options are language-independent"
 msgstr "下列選項與語言無關"
 
-#: opts.cc:1970
+#: opts.cc:1971
 msgid "The following options control parameters"
 msgstr "下列選項控制參數"
 
-#: opts.cc:1976
+#: opts.cc:1977
 #, fuzzy
 msgid "The following options are specific to just the language "
 msgstr "下列選項是特定的到僅語言 "
 
-#: opts.cc:1978
+#: opts.cc:1979
 msgid "The following options are supported by the language "
 msgstr "以下選項支援此語言"
 
-#: opts.cc:1989
+#: opts.cc:1990
 msgid "The following options are not documented"
 msgstr "以下選項未被文件記載"
 
-#: opts.cc:1991
+#: opts.cc:1992
 #, fuzzy
 msgid "The following options take separate arguments"
 msgstr "下列選項會取分隔引數"
 
-#: opts.cc:1993
+#: opts.cc:1994
 #, fuzzy
 msgid "The following options take joined arguments"
 msgstr "下列選項需聯結的引數"
 
-#: opts.cc:2005
+#: opts.cc:2006
 msgid "The following options are language-related"
 msgstr "下列選項與語言有關"
 
@@ -19935,73 +19940,73 @@ msgstr "strfmon 格式的長度修飾符"
 msgid "<command-line>"
 msgstr "<命令列>"
 
-#: config/aarch64/aarch64.cc:11879 config/loongarch/loongarch.cc:4992
+#: config/aarch64/aarch64.cc:11892 config/loongarch/loongarch.cc:4992
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "「%c」代碼不支援的運算元"
 
-#: config/aarch64/aarch64.cc:11888 config/aarch64/aarch64.cc:11901
-#: config/aarch64/aarch64.cc:11913 config/aarch64/aarch64.cc:11924
-#: config/aarch64/aarch64.cc:11940 config/aarch64/aarch64.cc:11954
-#: config/aarch64/aarch64.cc:11974 config/aarch64/aarch64.cc:12051
-#: config/aarch64/aarch64.cc:12062 config/aarch64/aarch64.cc:12076
-#: config/aarch64/aarch64.cc:12298 config/aarch64/aarch64.cc:12318
+#: config/aarch64/aarch64.cc:11901 config/aarch64/aarch64.cc:11914
+#: config/aarch64/aarch64.cc:11926 config/aarch64/aarch64.cc:11937
+#: config/aarch64/aarch64.cc:11953 config/aarch64/aarch64.cc:11967
+#: config/aarch64/aarch64.cc:11987 config/aarch64/aarch64.cc:12064
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12089
+#: config/aarch64/aarch64.cc:12311 config/aarch64/aarch64.cc:12331
 #: config/pru/pru.cc:1760 config/pru/pru.cc:1771 config/pru/pru.cc:1843
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "「%%%c」的運算元無效"
 
-#: config/aarch64/aarch64.cc:11992 config/aarch64/aarch64.cc:12003
-#: config/aarch64/aarch64.cc:12158 config/aarch64/aarch64.cc:12169
-#: config/riscv/riscv.cc:4397 config/riscv/riscv.cc:4404
-#: config/riscv/riscv.cc:4411 config/riscv/riscv.cc:4415
-#: config/riscv/riscv.cc:4462 config/riscv/riscv.cc:4481
+#: config/aarch64/aarch64.cc:12005 config/aarch64/aarch64.cc:12016
+#: config/aarch64/aarch64.cc:12171 config/aarch64/aarch64.cc:12182
+#: config/riscv/riscv.cc:4403 config/riscv/riscv.cc:4410
+#: config/riscv/riscv.cc:4417 config/riscv/riscv.cc:4421
+#: config/riscv/riscv.cc:4468 config/riscv/riscv.cc:4487
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "無效指令："
 
-#: config/aarch64/aarch64.cc:12015 config/aarch64/aarch64.cc:12027
+#: config/aarch64/aarch64.cc:12028 config/aarch64/aarch64.cc:12040
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:12044
+#: config/aarch64/aarch64.cc:12057
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "「%%%c」的寄存器運算元不相容"
 
-#: config/aarch64/aarch64.cc:12110 config/arm/arm.cc:24708
+#: config/aarch64/aarch64.cc:12123 config/arm/arm.cc:24721
 #, c-format
 msgid "missing operand"
 msgstr "缺少運算元"
 
-#: config/aarch64/aarch64.cc:12195
+#: config/aarch64/aarch64.cc:12208
 #, c-format
 msgid "invalid constant"
 msgstr "常數無效"
 
-#: config/aarch64/aarch64.cc:12198
+#: config/aarch64/aarch64.cc:12211
 #, c-format
 msgid "invalid operand"
 msgstr "運算元無效"
 
-#: config/aarch64/aarch64.cc:12326 config/aarch64/aarch64.cc:12331
+#: config/aarch64/aarch64.cc:12339 config/aarch64/aarch64.cc:12344
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "無效的運算元前綴「%%%c」"
 
-#: config/aarch64/aarch64.cc:12351
+#: config/aarch64/aarch64.cc:12364
 #, c-format
 msgid "invalid address mode"
 msgstr "無效的定址模式"
 
-#: config/aarch64/aarch64.cc:27134
+#: config/aarch64/aarch64.cc:27161
 #, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "無效的運算元在中二進運算"
 
-#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13577
-#: config/rs6000/rs6000.cc:14355 config/sparc/sparc.cc:9370
+#: config/alpha/alpha.cc:5076 config/i386/i386.cc:13585
+#: config/rs6000/rs6000.cc:14364 config/sparc/sparc.cc:9370
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "『%%&』使用的而無需任何本地動態 TLS 參考"
@@ -20018,18 +20023,18 @@ msgid "invalid %%r value"
 msgstr "無效 %%r 值"
 
 #: config/alpha/alpha.cc:5174 config/ia64/ia64.cc:5532
-#: config/rs6000/rs6000.cc:14050 config/xtensa/xtensa.cc:3008
+#: config/rs6000/rs6000.cc:14059 config/xtensa/xtensa.cc:3008
 #, c-format
 msgid "invalid %%R value"
 msgstr "無效 %%R 值"
 
-#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13970
+#: config/alpha/alpha.cc:5180 config/rs6000/rs6000.cc:13979
 #: config/xtensa/xtensa.cc:2981
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
-#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:13998
+#: config/alpha/alpha.cc:5188 config/rs6000/rs6000.cc:14007
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
@@ -20059,7 +20064,7 @@ msgstr "無效 %%M 值"
 msgid "invalid %%U value"
 msgstr "無效 %%U 值"
 
-#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14058
+#: config/alpha/alpha.cc:5274 config/rs6000/rs6000.cc:14067
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
@@ -20069,7 +20074,7 @@ msgstr "無效 %%s 值"
 msgid "invalid %%C value"
 msgstr "無效 %%C 值"
 
-#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13834
+#: config/alpha/alpha.cc:5322 config/rs6000/rs6000.cc:13843
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
@@ -20082,7 +20087,7 @@ msgstr "不明的不可預期重定位"
 #: config/alpha/alpha.cc:5356 config/gcn/gcn.cc:6940 config/gcn/gcn.cc:6949
 #: config/gcn/gcn.cc:7009 config/gcn/gcn.cc:7017 config/gcn/gcn.cc:7033
 #: config/gcn/gcn.cc:7051 config/gcn/gcn.cc:7102 config/gcn/gcn.cc:7221
-#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14360
+#: config/gcn/gcn.cc:7332 config/rs6000/rs6000.cc:14369
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無效的 %%xn 程式碼"
@@ -20171,35 +20176,35 @@ msgstr "無效的 UNSPEC 做為運算元"
 msgid "unrecognized supposed constant"
 msgstr "預期的常數無法識別"
 
-#: config/arm/arm.cc:20996 config/arm/arm.cc:21021 config/arm/arm.cc:21031
-#: config/arm/arm.cc:21040 config/arm/arm.cc:21049
+#: config/arm/arm.cc:21009 config/arm/arm.cc:21034 config/arm/arm.cc:21044
+#: config/arm/arm.cc:21053 config/arm/arm.cc:21062
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "無效的 Shift 運算元"
 
-#: config/arm/arm.cc:23958 config/arm/arm.cc:23976
+#: config/arm/arm.cc:23971 config/arm/arm.cc:23989
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "預測到的 Thumb 指令"
 
-#: config/arm/arm.cc:23964
+#: config/arm/arm.cc:23977
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在條件序列中預測到的指令"
 
-#: config/arm/arm.cc:24085 config/arm/arm.cc:24098 config/arm/arm.cc:24123
+#: config/arm/arm.cc:24098 config/arm/arm.cc:24111 config/arm/arm.cc:24136
 #: config/nios2/nios2.cc:3084
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/arm/arm.cc:24200 config/arm/arm.cc:24222 config/arm/arm.cc:24232
-#: config/arm/arm.cc:24242 config/arm/arm.cc:24252 config/arm/arm.cc:24291
-#: config/arm/arm.cc:24309 config/arm/arm.cc:24327 config/arm/arm.cc:24354
-#: config/arm/arm.cc:24369 config/arm/arm.cc:24396 config/arm/arm.cc:24403
-#: config/arm/arm.cc:24421 config/arm/arm.cc:24428 config/arm/arm.cc:24436
-#: config/arm/arm.cc:24457 config/arm/arm.cc:24464 config/arm/arm.cc:24655
-#: config/arm/arm.cc:24662 config/arm/arm.cc:24689 config/arm/arm.cc:24696
+#: config/arm/arm.cc:24213 config/arm/arm.cc:24235 config/arm/arm.cc:24245
+#: config/arm/arm.cc:24255 config/arm/arm.cc:24265 config/arm/arm.cc:24304
+#: config/arm/arm.cc:24322 config/arm/arm.cc:24340 config/arm/arm.cc:24367
+#: config/arm/arm.cc:24382 config/arm/arm.cc:24409 config/arm/arm.cc:24416
+#: config/arm/arm.cc:24434 config/arm/arm.cc:24441 config/arm/arm.cc:24449
+#: config/arm/arm.cc:24470 config/arm/arm.cc:24477 config/arm/arm.cc:24668
+#: config/arm/arm.cc:24675 config/arm/arm.cc:24702 config/arm/arm.cc:24709
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492
@@ -20208,28 +20213,28 @@ msgstr "不受支援的運算元用於編碼『%c』"
 msgid "invalid operand for code '%c'"
 msgstr "程式碼「%c」的運算元無效"
 
-#: config/arm/arm.cc:24304
+#: config/arm/arm.cc:24317
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "指令永不執行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24345
+#: config/arm/arm.cc:24358
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/arm/arm.cc:34257
+#: config/arm/arm.cc:34270
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/arm/arm.cc:34259
+#: config/arm/arm.cc:34272
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/arm/arm.cc:34274 config/arm/arm.cc:34290
+#: config/arm/arm.cc:34287 config/arm/arm.cc:34303
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
@@ -20601,99 +20606,99 @@ msgstr "無效指令："
 msgid "Expected register or constant integer."
 msgstr "預期的介面或指標到介面"
 
-#: config/i386/i386.cc:12402
+#: config/i386/i386.cc:12403
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/i386/i386.cc:12941
+#: config/i386/i386.cc:12942
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "錯誤地使用了 %<restrict%>"
 
-#: config/i386/i386.cc:12946
+#: config/i386/i386.cc:12947
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: config/i386/i386.cc:13179
+#: config/i386/i386.cc:13180
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.cc:13214
+#: config/i386/i386.cc:13215
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.cc:13283
+#: config/i386/i386.cc:13290
 #, fuzzy, c-format
-msgid "invalid operand type used with operand code 'Z'"
+msgid "invalid operand type used with operand code '%c'"
 msgstr "無效的運算元類型使用的與運算元編碼『%c』"
 
-#: config/i386/i386.cc:13288
+#: config/i386/i386.cc:13295
 #, fuzzy, c-format
-msgid "invalid operand size for operand code 'Z'"
+msgid "invalid operand size for operand code '%c'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.cc:13365
+#: config/i386/i386.cc:13373
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.cc:13444
+#: config/i386/i386.cc:13452
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.cc:13462
+#: config/i386/i386.cc:13470
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.cc:13475
+#: config/i386/i386.cc:13483
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "運算元不是 offsettable 記憶體參考，無效的運算元編碼『H』"
 
-#: config/i386/i386.cc:13490
+#: config/i386/i386.cc:13498
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.cc:13518
+#: config/i386/i386.cc:13526
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.cc:13536
+#: config/i386/i386.cc:13544
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.cc:13559
+#: config/i386/i386.cc:13567
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.cc:13663
+#: config/i386/i386.cc:13671
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/i386/i386.cc:13725 config/i386/i386.cc:14114
+#: config/i386/i386.cc:13733 config/i386/i386.cc:14122
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "運算元的約束無效"
 
-#: config/i386/i386.cc:13826
+#: config/i386/i386.cc:13834
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "無效的控制述詞"
 
-#: config/i386/i386.cc:16903
+#: config/i386/i386.cc:16911
 msgid "unknown insn mode"
 msgstr "不明的指令模式"
 
@@ -20724,7 +20729,7 @@ msgstr "對 %<__fpreg%> 的作業無效"
 msgid "invalid %%P operand"
 msgstr "無效的 %%P 運算元"
 
-#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13988
+#: config/iq2000/iq2000.cc:3134 config/rs6000/rs6000.cc:13997
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -20772,8 +20777,8 @@ msgstr "『%%%c』並非有效運算元前綴"
 #: config/mips/mips.cc:9219 config/mips/mips.cc:9231 config/mips/mips.cc:9234
 #: config/mips/mips.cc:9294 config/mips/mips.cc:9301 config/mips/mips.cc:9322
 #: config/mips/mips.cc:9337 config/mips/mips.cc:9356 config/mips/mips.cc:9365
-#: config/riscv/riscv.cc:4272 config/riscv/riscv.cc:4535
-#: config/riscv/riscv.cc:4541 config/riscv/riscv.cc:4550
+#: config/riscv/riscv.cc:4278 config/riscv/riscv.cc:4541
+#: config/riscv/riscv.cc:4547 config/riscv/riscv.cc:4556
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "無效的使用的『%%%c』"
@@ -20805,7 +20810,7 @@ msgid "post-increment address is not a register"
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.cc:2340 config/m32r/m32r.cc:2355
-#: config/rs6000/rs6000.cc:20702
+#: config/rs6000/rs6000.cc:20711
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -20968,7 +20973,7 @@ msgstr "不支援的組合：%s"
 msgid "unsupported memory expression:"
 msgstr "無效的類型在中定點轉換"
 
-#: config/riscv/riscv.cc:4378
+#: config/riscv/riscv.cc:4384
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "無效的 %%r 運算元"
@@ -21025,157 +21030,157 @@ msgstr "%<-mquad-memory%> 無法在低位位元組在前模式中使用"
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/rs6000/rs6000.cc:13618
+#: config/rs6000/rs6000.cc:13627
 msgid "Bad 128-bit move"
 msgstr "錯誤 128 位元移動"
 
-#: config/rs6000/rs6000.cc:13798
+#: config/rs6000/rs6000.cc:13807
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "無效 %%J 值"
 
-#: config/rs6000/rs6000.cc:13807 config/xtensa/xtensa.cc:2957
+#: config/rs6000/rs6000.cc:13816 config/xtensa/xtensa.cc:2957
 #, c-format
 msgid "invalid %%D value"
 msgstr "無效的 %%D 值"
 
-#: config/rs6000/rs6000.cc:13822
+#: config/rs6000/rs6000.cc:13831
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:13843
+#: config/rs6000/rs6000.cc:13852
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/rs6000/rs6000.cc:13852
+#: config/rs6000/rs6000.cc:13861
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/rs6000/rs6000.cc:13861
+#: config/rs6000/rs6000.cc:13870
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/rs6000/rs6000.cc:13896
+#: config/rs6000/rs6000.cc:13905
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/rs6000/rs6000.cc:13906
+#: config/rs6000/rs6000.cc:13915
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/rs6000/rs6000.cc:13916
+#: config/rs6000/rs6000.cc:13925
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/rs6000/rs6000.cc:13931 config/xtensa/xtensa.cc:2994
+#: config/rs6000/rs6000.cc:13940 config/xtensa/xtensa.cc:2994
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/rs6000/rs6000.cc:13978
+#: config/rs6000/rs6000.cc:13987
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/rs6000/rs6000.cc:14025
+#: config/rs6000/rs6000.cc:14034
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/rs6000/rs6000.cc:14067
+#: config/rs6000/rs6000.cc:14076
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:14084
+#: config/rs6000/rs6000.cc:14093
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/rs6000/rs6000.cc:14096
+#: config/rs6000/rs6000.cc:14105
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/rs6000/rs6000.cc:14110 config/xtensa/xtensa.cc:2969
+#: config/rs6000/rs6000.cc:14119 config/xtensa/xtensa.cc:2969
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/rs6000/rs6000.cc:14160
+#: config/rs6000/rs6000.cc:14169
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:14176 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14185 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/rs6000/rs6000.cc:14233
+#: config/rs6000/rs6000.cc:14242
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:14302
+#: config/rs6000/rs6000.cc:14311
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/rs6000/rs6000.cc:15232
+#: config/rs6000/rs6000.cc:15241
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "啟用 32-bit multiply 指令"
 
-#: config/rs6000/rs6000.cc:24099
+#: config/rs6000/rs6000.cc:24108
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/rs6000/rs6000.cc:27721
+#: config/rs6000/rs6000.cc:27730
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/rs6000/rs6000.cc:27790
+#: config/rs6000/rs6000.cc:27799
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "無法產生重新載入，為："
 
-#: config/rs6000/rs6000.cc:27866
+#: config/rs6000/rs6000.cc:27875
 msgid "Bad GPR fusion"
 msgstr "錯誤 GPR 融合"
 
-#: config/rs6000/rs6000.cc:28468
+#: config/rs6000/rs6000.cc:28477
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/rs6000/rs6000.cc:28470
+#: config/rs6000/rs6000.cc:28479
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/rs6000/rs6000.cc:28472
+#: config/rs6000/rs6000.cc:28481
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "從 %<__fpreg%> 的轉換無效"
 
-#: config/rs6000/rs6000.cc:28474
+#: config/rs6000/rs6000.cc:28483
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
@@ -21655,7 +21660,7 @@ msgstr "備選 1："
 msgid "  after user-defined conversion:"
 msgstr "啟用使用者定義的指令"
 
-#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26135
+#: cp/call.cc:8357 cp/pt.cc:2022 cp/pt.cc:26138
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -22188,7 +22193,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "驅動："
 
-#: fortran/interface.cc:3631 fortran/intrinsic.cc:4506
+#: fortran/interface.cc:3647 fortran/intrinsic.cc:4506
 #, fuzzy
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "實際引數到含義=出/INOUT"
@@ -22361,11 +22366,11 @@ msgstr "區塊 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.cc:2240 fortran/resolve.cc:12367
+#: fortran/parse.cc:2240 fortran/resolve.cc:12393
 msgid "assignment"
 msgstr "賦值"
 
-#: fortran/parse.cc:2243 fortran/resolve.cc:12433 fortran/resolve.cc:12436
+#: fortran/parse.cc:2243 fortran/resolve.cc:12459 fortran/resolve.cc:12462
 msgid "pointer assignment"
 msgstr "指標賦值"
 
@@ -22373,235 +22378,235 @@ msgstr "指標賦值"
 msgid "simple IF"
 msgstr "簡單的 IF"
 
-#: fortran/resolve.cc:2396 fortran/resolve.cc:2591
+#: fortran/resolve.cc:2413 fortran/resolve.cc:2608
 #, fuzzy
 msgid "elemental procedure"
 msgstr "elemental 程序"
 
-#: fortran/resolve.cc:2494
+#: fortran/resolve.cc:2511
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.cc:2499
+#: fortran/resolve.cc:2516
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "不足引數"
 
-#: fortran/resolve.cc:2504
+#: fortran/resolve.cc:2521
 #, fuzzy
 msgid "optional argument"
 msgstr "無效的 PHI 引數"
 
-#: fortran/resolve.cc:2509
+#: fortran/resolve.cc:2526
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "指標賦值"
 
-#: fortran/resolve.cc:2514
+#: fortran/resolve.cc:2531
 #, fuzzy
 msgid "target argument"
 msgstr "太多引數"
 
-#: fortran/resolve.cc:2519
+#: fortran/resolve.cc:2536
 #, fuzzy
 msgid "value argument"
 msgstr "無效的 PHI 引數"
 
-#: fortran/resolve.cc:2524
+#: fortran/resolve.cc:2541
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.cc:2529
+#: fortran/resolve.cc:2546
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.cc:2534
+#: fortran/resolve.cc:2551
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.cc:2539
+#: fortran/resolve.cc:2556
 #, fuzzy
 msgid "coarray argument"
 msgstr "陣列指派"
 
-#: fortran/resolve.cc:2544
+#: fortran/resolve.cc:2561
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.cc:2549
+#: fortran/resolve.cc:2566
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.cc:2554
+#: fortran/resolve.cc:2571
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.cc:2561
+#: fortran/resolve.cc:2578
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.cc:2572
+#: fortran/resolve.cc:2589
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.cc:2577
+#: fortran/resolve.cc:2594
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.cc:2584
+#: fortran/resolve.cc:2601
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.cc:2596
+#: fortran/resolve.cc:2613
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "模組程序"
 
-#: fortran/resolve.cc:4158
+#: fortran/resolve.cc:4175
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.cc:4175
+#: fortran/resolve.cc:4192
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "單位元數值運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.cc:4192
+#: fortran/resolve.cc:4209
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.cc:4197
+#: fortran/resolve.cc:4214
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元數值運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.cc:4212
+#: fortran/resolve.cc:4229
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字串粘貼運算子(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.cc:4255
+#: fortran/resolve.cc:4272
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "邏輯運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.cc:4278
+#: fortran/resolve.cc:4295
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "運算元的.not。運算子於 %%L 是 %s"
 
-#: fortran/resolve.cc:4292
+#: fortran/resolve.cc:4309
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L 處複數不能比較大小"
 
-#: fortran/resolve.cc:4390
+#: fortran/resolve.cc:4407
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L 處邏輯值必須與 %s 比較，而不是 %s"
 
-#: fortran/resolve.cc:4396
+#: fortran/resolve.cc:4413
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比較運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.cc:4410
+#: fortran/resolve.cc:4427
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.cc:4413
+#: fortran/resolve.cc:4430
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.cc:4418
+#: fortran/resolve.cc:4435
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.cc:4423
+#: fortran/resolve.cc:4440
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.cc:4509
+#: fortran/resolve.cc:4526
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "不一致分級用於運算子於 %%L 和 %%L"
 
-#: fortran/resolve.cc:7383
+#: fortran/resolve.cc:7400
 #, fuzzy
 msgid "Loop variable"
 msgstr "迴圈變數"
 
-#: fortran/resolve.cc:7387
+#: fortran/resolve.cc:7404
 #, fuzzy
 msgid "iterator variable"
 msgstr "迭代器變數"
 
-#: fortran/resolve.cc:7391
+#: fortran/resolve.cc:7408
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "開始運算式在中做迴圈"
 
-#: fortran/resolve.cc:7395
+#: fortran/resolve.cc:7412
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "結束運算式在中做迴圈"
 
-#: fortran/resolve.cc:7399
+#: fortran/resolve.cc:7416
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "步驟運算式在中做迴圈"
 
-#: fortran/resolve.cc:7686 fortran/resolve.cc:7689
+#: fortran/resolve.cc:7703 fortran/resolve.cc:7706
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "取消配置物件"
 
-#: fortran/resolve.cc:8067 fortran/resolve.cc:8070
+#: fortran/resolve.cc:8084 fortran/resolve.cc:8087
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "配置物件"
 
-#: fortran/resolve.cc:8304 fortran/resolve.cc:10280 fortran/resolve.cc:10401
+#: fortran/resolve.cc:8324 fortran/resolve.cc:10311 fortran/resolve.cc:10432
 #, fuzzy
 msgid "STAT variable"
 msgstr "STAT 變數"
 
-#: fortran/resolve.cc:8355 fortran/resolve.cc:10292 fortran/resolve.cc:10413
+#: fortran/resolve.cc:8375 fortran/resolve.cc:10323 fortran/resolve.cc:10444
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "ERRMSG 變數"
 
-#: fortran/resolve.cc:10082
+#: fortran/resolve.cc:10113
 #, fuzzy
 msgid "item in READ"
 msgstr "項目在中讀取"
 
-#: fortran/resolve.cc:10304
+#: fortran/resolve.cc:10335
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK 變數"
@@ -22616,27 +22621,27 @@ msgstr "不同的字元長度 (%ld/%ld) 在中陣列建構子"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "整數溢位時計算數目的記憶體到配置"
 
-#: fortran/trans-array.cc:10188
+#: fortran/trans-array.cc:10211
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.cc:6203
+#: fortran/trans-decl.cc:6206
 #, fuzzy, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度不匹配宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-decl.cc:6211
+#: fortran/trans-decl.cc:6214
 #, fuzzy, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度是短於宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-expr.cc:10333
+#: fortran/trans-expr.cc:10376
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目標的分級重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.cc:11893
+#: fortran/trans-expr.cc:11936
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -23623,7 +23628,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax 是只有支援的用於 RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3341 fortran/io.cc:3736 fortran/io.cc:4422
+#: fortran/gfortran.h:3343 fortran/io.cc:3736 fortran/io.cc:4422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 敘述在 %C 處語法錯誤"
@@ -24009,7 +24014,7 @@ msgstr "%qE 屬性衝突與屬性 %s"
 
 #: attribs.cc:553 c-family/c-attribs.cc:937 c-family/c-attribs.cc:2439
 #: c-family/c-attribs.cc:2928 c-family/c-attribs.cc:4790
-#: c-family/c-attribs.cc:4883 cp/decl.cc:15960 cp/decl.cc:16010
+#: c-family/c-attribs.cc:4883 cp/decl.cc:15970 cp/decl.cc:16020
 #: cp/friend.cc:318 cp/tree.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -24106,10 +24111,10 @@ msgstr "型態屬性忽略的之後型態已經定義"
 #: config/arm/arm.cc:7472 config/arm/arm.cc:7489 config/avr/avr.cc:9568
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6520
 #: config/h8300/h8300.cc:4968 config/h8300/h8300.cc:4992
-#: config/i386/i386-options.cc:3426 config/i386/i386-options.cc:3584
-#: config/i386/i386-options.cc:3816 config/i386/i386-options.cc:3846
+#: config/i386/i386-options.cc:3428 config/i386/i386-options.cc:3586
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3848
 #: config/ia64/ia64.cc:785 config/loongarch/loongarch.cc:6539
-#: config/rs6000/rs6000.cc:20466 ada/gcc-interface/utils.cc:6588
+#: config/rs6000/rs6000.cc:20475 ada/gcc-interface/utils.cc:6588
 #: ada/gcc-interface/utils.cc:6604 ada/gcc-interface/utils.cc:6642
 #: ada/gcc-interface/utils.cc:6659 ada/gcc-interface/utils.cc:6676
 #: ada/gcc-interface/utils.cc:6691 ada/gcc-interface/utils.cc:6707
@@ -24245,7 +24250,7 @@ msgstr "無法讀取 LTO decls 從 %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量超過字串常數界"
 
-#: builtins.cc:705 gimple-ssa-warn-access.cc:4596 cp/name-lookup.cc:6417
+#: builtins.cc:705 cp/name-lookup.cc:6417
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qD 宣告的在此"
@@ -26123,7 +26128,7 @@ msgstr "大定點常數隱含地截短至定點型態"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由於位元段寬度所限，比較結果永遠為 %d"
 
-#: fold-const.cc:6080 tree-ssa-reassoc.cc:2868 tree-ssa-reassoc.cc:3950
+#: fold-const.cc:6080 tree-ssa-reassoc.cc:2877 tree-ssa-reassoc.cc:3959
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "假設帶正負號溢位不發生時簡化範圍測試"
@@ -26908,7 +26913,7 @@ msgstr "函式回傳局部變數的位址"
 #: c/c-typeck.cc:11303 c/c-typeck.cc:11320 c/gimple-parser.cc:2484
 #: c/gimple-parser.cc:2492 cp/call.cc:8064 cp/call.cc:10213 cp/class.cc:9076
 #: cp/constexpr.cc:894 cp/constexpr.cc:4077 cp/cvt.cc:1079 cp/cvt.cc:1117
-#: cp/decl.cc:8876 cp/decl.cc:16157 cp/decl.cc:16524 cp/decl2.cc:5715
+#: cp/decl.cc:8886 cp/decl.cc:16167 cp/decl.cc:16534 cp/decl2.cc:5715
 #: cp/decl2.cc:5770 cp/parser.cc:21904 cp/pt.cc:9026 cp/semantics.cc:2192
 #: cp/semantics.cc:3549 cp/semantics.cc:4636 cp/typeck.cc:2143
 #: cp/typeck.cc:2363 cp/typeck.cc:4494 cp/typeck.cc:10582
@@ -28023,14 +28028,14 @@ msgstr "假定是成員指標 %qD"
 msgid "using a dangling pointer to %qD"
 msgstr "無效的指標模式 %qs"
 
-#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4588
-#: gimple-ssa-warn-restrict.cc:1828 tree-ssa-uninit.cc:906
-#: tree-ssa-uninit.cc:1105 c/c-decl.cc:3989 c/c-decl.cc:4270
-#: c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492 cp/class.cc:3291
-#: cp/constexpr.cc:1067 cp/decl.cc:4440 cp/decl.cc:12599 cp/decl.cc:13099
-#: cp/decl.cc:13108 cp/decl.cc:14069 cp/friend.cc:406 cp/friend.cc:416
-#: cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712 cp/parser.cc:3763
-#: cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4617
+#: gimple-ssa-warn-access.cc:4620 gimple-ssa-warn-restrict.cc:1828
+#: tree-ssa-uninit.cc:906 tree-ssa-uninit.cc:1105 c/c-decl.cc:3989
+#: c/c-decl.cc:4270 c/c-typeck.cc:9355 c/c-typeck.cc:12105 cp/class.cc:1492
+#: cp/class.cc:3291 cp/constexpr.cc:1067 cp/decl.cc:4450 cp/decl.cc:12609
+#: cp/decl.cc:13109 cp/decl.cc:13118 cp/decl.cc:14079 cp/friend.cc:406
+#: cp/friend.cc:416 cp/init.cc:2918 cp/parser.cc:3566 cp/parser.cc:3712
+#: cp/parser.cc:3763 cp/parser.cc:7005 cp/parser.cc:24456 cp/typeck.cc:4944
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
@@ -28078,7 +28083,7 @@ msgstr "呼叫非函式的 %qD"
 msgid "call to %qD"
 msgstr "  在呼叫 %qD 時"
 
-#: gimple-ssa-warn-access.cc:4582
+#: gimple-ssa-warn-access.cc:4611
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "storing the address of local variable %qD in %qE"
@@ -29156,7 +29161,7 @@ msgstr "ipa 內聯概要缺少在中輸入檔案"
 msgid "IPA modref summary is missing in input file"
 msgstr "ipa 內聯概要缺少在中輸入檔案"
 
-#: ipa-prop.cc:4715 ipa-prop.cc:4757 ipa-prop.cc:4843 ipa-prop.cc:4891
+#: ipa-prop.cc:4730 ipa-prop.cc:4772 ipa-prop.cc:4858 ipa-prop.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "invalid jump function in LTO stream"
 msgstr "無效的函式在中 gimple 呼叫"
@@ -30140,7 +30145,7 @@ msgstr "進行跨跳轉最佳化"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "此配置不支援命令列選項 %qs"
 
-#: opts-common.cc:1419 opts.cc:2511
+#: opts-common.cc:1419 opts.cc:2512
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "缺少引數到 %qs"
@@ -30180,12 +30185,12 @@ msgstr "-mcorea 和 -mcoreb can%'t 一起使用"
 msgid "unrecognized argument in option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: opts-common.cc:1539 config/i386/i386-options.cc:1635
+#: opts-common.cc:1539 config/i386/i386-options.cc:1637
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: opts-common.cc:1542 config/i386/i386-options.cc:1638
+#: opts-common.cc:1542 config/i386/i386-options.cc:1640
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -30341,7 +30346,7 @@ msgstr ""
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-falign-loops=%d 未被支援"
 
-#: opts.cc:1256 opts.cc:2247
+#: opts.cc:1256 opts.cc:2248
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize-trap=%s%> is not supported"
 msgstr "-falign-loops=%d 未被支援"
@@ -30381,190 +30386,190 @@ msgstr "變數追蹤要求的，但是無用的除非產生除錯資訊"
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "變數追蹤要求的，並不是支援的由這個除錯格式"
 
-#: opts.cc:1410
+#: opts.cc:1411
 #, fuzzy, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments 變更選擇性排程"
 
-#: opts.cc:1423
+#: opts.cc:1424
 #, gcc-internal-format
 msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
 msgstr ""
 
-#: opts.cc:1453 config/darwin.cc:3361
+#: opts.cc:1454 config/darwin.cc:3361
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition 不適用於異常於這個架構"
 
-#: opts.cc:1469
+#: opts.cc:1470
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition 不支援展開資訊於這個架構"
 
-#: opts.cc:1487 config/pa/pa.cc:564
+#: opts.cc:1488 config/pa/pa.cc:564
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition 不能在此架構下工作"
 
-#: opts.cc:1996
+#: opts.cc:1997
 #, fuzzy, gcc-internal-format
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "無法辨識的 include_flags 0x%x 傳遞到 print_specific_help"
 
-#: opts.cc:2226
+#: opts.cc:2227
 #, gcc-internal-format
 msgid "%<-fsanitize=all%> option is not valid"
 msgstr ""
 
-#: opts.cc:2281
+#: opts.cc:2282
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "無法辨識的引數到 --help=選項：%q.*s"
 
-#: opts.cc:2287
+#: opts.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "無法辨識的引數到 --help=選項：%q.*s"
 
-#: opts.cc:2322
+#: opts.cc:2323
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute directive ignored"
 msgstr "%qE 屬性指令忽略"
 
-#: opts.cc:2346
+#: opts.cc:2347
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: opts.cc:2370
+#: opts.cc:2371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid alignment for %<#pragma align%>, ignoring"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "%<#pragma align%> 指定的對齊邊界無效，忽略"
 
-#: opts.cc:2385
+#: opts.cc:2386
 #, fuzzy, gcc-internal-format
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "不正確引數數量到函式 %qE"
 
-#: opts.cc:2394
+#: opts.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "-malign-loops=%d 不在 0 和 %d 之間"
 
-#: opts.cc:2453
+#: opts.cc:2454
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
 msgstr "無效的引數到內建函式"
 
-#: opts.cc:2566
+#: opts.cc:2567
 #, fuzzy, gcc-internal-format
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "--help 引數 %q.*s 是模稜兩可的，請是更多特定的"
 
-#: opts.cc:2575
+#: opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "無法辨識的引數到 --help=選項：%q.*s"
 
-#: opts.cc:2755
+#: opts.cc:2756
 #, gcc-internal-format
 msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
 msgstr ""
 
-#: opts.cc:2761
+#: opts.cc:2762
 #, gcc-internal-format
 msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
 msgstr ""
 
-#: opts.cc:2982
+#: opts.cc:2983
 #, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.cc:2990
+#: opts.cc:2991
 #, fuzzy, gcc-internal-format
 #| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "結構的對齊必須是 2 的較小次方，而不是 %d"
 
-#: opts.cc:3111
+#: opts.cc:3112
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "不明堆疊檢查參數「%s」"
 
-#: opts.cc:3157
+#: opts.cc:3158
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
 msgstr ""
 
-#: opts.cc:3168
+#: opts.cc:3169
 #, fuzzy, gcc-internal-format
 msgid "dwarf version %wu is not supported"
 msgstr "dwarf 版本 %d 未被支援"
 
-#: opts.cc:3205
+#: opts.cc:3206
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "無法辨識的引數到 --help=選項：%q.*s"
 
-#: opts.cc:3405
+#: opts.cc:3406
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "目的系統不支援除錯輸出"
 
-#: opts.cc:3443
+#: opts.cc:3444
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "除錯格式「%s」與先前的選擇衝突"
 
-#: opts.cc:3467
+#: opts.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "無法辨識的除錯輸出層級「%s」"
 
-#: opts.cc:3469
+#: opts.cc:3470
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "除錯輸出層級 %s 太高"
 
-#: opts.cc:3481
+#: opts.cc:3482
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized btf debug output level %qs"
 msgstr "無法辨識的除錯輸出層級「%s」"
 
-#: opts.cc:3498
+#: opts.cc:3499
 #, fuzzy, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "提取記憶體檔案大小最大值限制：%m"
 
-#: opts.cc:3502
+#: opts.cc:3503
 #, fuzzy, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "設定記憶體檔案大小限制到最大值：%m"
 
-#: opts.cc:3547
+#: opts.cc:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "無法辨識的 gcc 除錯選項：%c"
 
-#: opts.cc:3576
+#: opts.cc:3577
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "無法辨識的命令列選項 %<-fdump-%s%>"
 
-#: opts.cc:3580
+#: opts.cc:3581
 #, fuzzy, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s：沒有選項 -%s"
 
-#: opts.cc:3584
+#: opts.cc:3585
 #, fuzzy, gcc-internal-format
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "%qs 並非有效選項到前置處理器"
@@ -31262,190 +31267,190 @@ msgstr "通用的轉換層程式碼(thunk)對使用了 %<...%> 的方法 %q#D 
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D 重新命名的之後被引用在中組譯的"
 
-#: symtab.cc:1107
+#: symtab.cc:1109
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "函式回傳了一個函式"
 
-#: symtab.cc:1114
+#: symtab.cc:1116
 #, gcc-internal-format
 msgid "inconsistent %<ifunc%> attribute"
 msgstr ""
 
-#: symtab.cc:1122
+#: symtab.cc:1124
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%qE 屬性只有套用到變數"
 
-#: symtab.cc:1128
+#: symtab.cc:1130
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "節點有錯誤的仿本清單"
 
-#: symtab.cc:1133
+#: symtab.cc:1135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "node has invalid order %i"
 msgstr "%qD 有無效的引數清單"
 
-#: symtab.cc:1142
+#: symtab.cc:1144
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1150
+#: symtab.cc:1152
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.cc:1161 symtab.cc:1168
+#: symtab.cc:1163 symtab.cc:1170
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.cc:1177
+#: symtab.cc:1179
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "節點找不到在中 cgraphhash(_H)"
 
-#: symtab.cc:1186
+#: symtab.cc:1188
 #, fuzzy, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "雙倍鏈結的仿本清單的已損壞"
 
-#: symtab.cc:1191
+#: symtab.cc:1193
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "%qD 使用的之前它的定義"
 
-#: symtab.cc:1196
+#: symtab.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.cc:1201
+#: symtab.cc:1203
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.cc:1206
+#: symtab.cc:1208
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.cc:1211
+#: symtab.cc:1213
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.cc:1216
+#: symtab.cc:1218
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.cc:1221
+#: symtab.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "node is symver but not alias"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.cc:1230
+#: symtab.cc:1232
 #, gcc-internal-format
 msgid "symver target is not exported with default visibility"
 msgstr ""
 
-#: symtab.cc:1237
+#: symtab.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "Set the default symbol visibility"
 msgid "symver is not exported with default visibility"
 msgstr "設定預設的符號可見性"
 
-#: symtab.cc:1246
+#: symtab.cc:1248
 #, fuzzy, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.cc:1251
+#: symtab.cc:1253
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group 並非環狀清單"
 
-#: symtab.cc:1256
+#: symtab.cc:1258
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.cc:1261
+#: symtab.cc:1263
 #, fuzzy, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: symtab.cc:1268
+#: symtab.cc:1270
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group 並非環狀清單"
 
-#: symtab.cc:1283
+#: symtab.cc:1285
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.cc:1293
+#: symtab.cc:1295
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "隱含宣告函式 %qE"
 
-#: symtab.cc:1300
+#: symtab.cc:1302
 #, fuzzy, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: symtab.cc:1312
+#: symtab.cc:1314
 #, gcc-internal-format
 msgid "Alias and target%'s section differs"
 msgstr ""
 
-#: symtab.cc:1319
+#: symtab.cc:1321
 #, gcc-internal-format
 msgid "Alias and target%'s comdat groups differs"
 msgstr ""
 
-#: symtab.cc:1334
+#: symtab.cc:1336
 #, gcc-internal-format
 msgid "Transparent alias and target%'s assembler names differs"
 msgstr ""
 
-#: symtab.cc:1342
+#: symtab.cc:1344
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.cc:1365 symtab.cc:1383 symtab.cc:1410
+#: symtab.cc:1367 symtab.cc:1385 symtab.cc:1412
 #, fuzzy, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "verify_cgraph_node 失敗"
 
-#: symtab.cc:1382
+#: symtab.cc:1384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid order in asm node %i"
 msgstr "無效的指標模式 %qs"
 
-#: symtab.cc:1406
+#: symtab.cc:1408
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.cc:1844
+#: symtab.cc:1846
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "函式 %q+D 部分的別名週期"
 
-#: symtab.cc:1846
+#: symtab.cc:1848
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "變數 %q+D 部分的別名週期"
 
-#: symtab.cc:1874
+#: symtab.cc:1876
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -33139,27 +33144,27 @@ msgstr "機器獨立內建編碼超出範圍"
 msgid "target specific builtin not available"
 msgstr "目標特定的內建無法使用"
 
-#: tree-vect-generic.cc:319 tree-vect-generic.cc:489 tree-vect-generic.cc:2051
+#: tree-vect-generic.cc:328 tree-vect-generic.cc:498 tree-vect-generic.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "向量作業將被展開 piecewise"
 
-#: tree-vect-generic.cc:322
+#: tree-vect-generic.cc:331
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "向量作業將被展開在中平行"
 
-#: tree-vect-generic.cc:379
+#: tree-vect-generic.cc:388
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "向量作業將被展開與單一純量作業"
 
-#: tree-vect-generic.cc:1110
+#: tree-vect-generic.cc:1119
 #, fuzzy, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "向量作業將被展開 piecewise"
 
-#: tree-vect-generic.cc:1611
+#: tree-vect-generic.cc:1620
 #, fuzzy, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "向量隨機播放作業將被展開 piecewise"
@@ -34001,7 +34006,7 @@ msgstr "%qE 屬性忽略的因為 %qT 已經定義"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE 屬性忽略的因為 %qT 已經定義"
 
-#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3840
+#: c-family/c-attribs.cc:1701 config/i386/i386-options.cc:3842
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE 屬性只能套用到公共物件上"
@@ -36161,7 +36166,7 @@ msgstr "不受支援的 non-standard 串接的字串實字"
 msgid "traditional C rejects string constant concatenation"
 msgstr "傳統 C 不接受字串常數粘貼"
 
-#: c-family/c-omp.cc:130 cp/pt.cc:19559
+#: c-family/c-omp.cc:130 cp/pt.cc:19567
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37882,7 +37887,7 @@ msgstr "輸入檔案太多"
 msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18127
+#: common/config/aarch64/aarch64-common.cc:400 config/aarch64/aarch64.cc:18140
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "-mcpu 開關的值 %qs 錯誤"
@@ -37915,15 +37920,15 @@ msgid "unrecognized option passed to %%:%<target_mode_check%>"
 msgstr "無法辨識的選項 -fenable"
 
 #: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
-#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18059
-#: config/aarch64/aarch64.cc:18097
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18072
+#: config/aarch64/aarch64.cc:18110
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
 #: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
-#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18062
-#: config/aarch64/aarch64.cc:18100
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18075
+#: config/aarch64/aarch64.cc:18113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -38014,53 +38019,53 @@ msgstr "-mcpu=%s 無效"
 msgid "%<-mcpu=%s%> has invalid silicon revision"
 msgstr "-mcpu=%s 有無效的 silicon 修訂"
 
-#: common/config/i386/i386-common.cc:1759
+#: common/config/i386/i386-common.cc:1776
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops is obsolete, use -falign-loops"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "-malign-loops 已經過時，請使用 -falign-loops"
 
-#: common/config/i386/i386-common.cc:1762
+#: common/config/i386/i386-common.cc:1779
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "-malign-loops=%d 不在 0 和 %d 之間"
 
-#: common/config/i386/i386-common.cc:1769
+#: common/config/i386/i386-common.cc:1786
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "-malign-jumps 已經過時，請使用 -falign-jumps"
 
-#: common/config/i386/i386-common.cc:1772
+#: common/config/i386/i386-common.cc:1789
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "-malign-jumps=%d 未被介於 0 和 %d"
 
-#: common/config/i386/i386-common.cc:1780
+#: common/config/i386/i386-common.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions is obsolete, use -falign-functions"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "-malign-functions 已過時，請使用 -falign-functions"
 
-#: common/config/i386/i386-common.cc:1783
+#: common/config/i386/i386-common.cc:1800
 #, fuzzy, gcc-internal-format
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "-malign-functions=%d 未被介於 0 和 %d"
 
-#: common/config/i386/i386-common.cc:1792
+#: common/config/i386/i386-common.cc:1809
 #, fuzzy, gcc-internal-format
 #| msgid "-mbranch-cost=%d is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "-mbranch-cost=%d 不在 0 和 5 之間"
 
-#: common/config/i386/i386-common.cc:1856
+#: common/config/i386/i386-common.cc:1873
 #: common/config/s390/s390-common.cc:137
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> 目前只有支援的於 GNU/Linux"
 
-#: common/config/i386/i386-common.cc:1866
+#: common/config/i386/i386-common.cc:1883
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
@@ -38556,13 +38561,13 @@ msgid "ACLE function %qD is incompatible with the use of %qs"
 msgstr "%qs 是不相容的與 %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:726
-#: config/riscv/riscv-vector-builtins.cc:3250
+#: config/riscv/riscv-vector-builtins.cc:3260
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be an integer constant expression"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
 #: config/aarch64/aarch64-sve-builtins.cc:738
-#: config/riscv/riscv-vector-builtins.cc:3264
+#: config/riscv/riscv-vector-builtins.cc:3274
 #, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
 msgstr ""
@@ -38830,7 +38835,7 @@ msgstr "傳遞參數 %d (屬於 %qE)時將指標賦給整數，未作類型轉
 
 #: config/aarch64/aarch64-sve-builtins.cc:3536
 #: config/arm/arm-mve-builtins.cc:173
-#: config/riscv/riscv-vector-builtins.cc:3444
+#: config/riscv/riscv-vector-builtins.cc:3454
 #, fuzzy, gcc-internal-format
 msgid "duplicate definition of %qs"
 msgstr "刪除的定義的 %qD"
@@ -38872,7 +38877,7 @@ msgid "SVE type %qT does not have a defined alignment"
 msgstr "型態 %qT 沒有已知大小"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3865
-#: config/riscv/riscv-vector-builtins.cc:3382
+#: config/riscv/riscv-vector-builtins.cc:3392
 #, fuzzy, gcc-internal-format
 msgid "variables of type %qT cannot have thread-local storage duration"
 msgstr "%qE 屬性忽略的因為 %qT 已經定義"
@@ -38965,331 +38970,331 @@ msgstr ""
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "引數到 decltype 必須是運算式"
 
-#: config/aarch64/aarch64.cc:7646
+#: config/aarch64/aarch64.cc:7659
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/aarch64/aarch64.cc:7783 config/aarch64/aarch64.cc:7854
-#: config/aarch64/aarch64.cc:19798
+#: config/aarch64/aarch64.cc:7796 config/aarch64/aarch64.cc:7867
+#: config/aarch64/aarch64.cc:19811
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 13.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7793 config/aarch64/aarch64.cc:7863
-#: config/aarch64/aarch64.cc:19804 config/arm/arm.cc:7266
-#: config/arm/arm.cc:7296 config/arm/arm.cc:29325
+#: config/aarch64/aarch64.cc:7806 config/aarch64/aarch64.cc:7876
+#: config/aarch64/aarch64.cc:19817 config/arm/arm.cc:7266
+#: config/arm/arm.cc:7296 config/arm/arm.cc:29338
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:7931
+#: config/aarch64/aarch64.cc:7944
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/aarch64/aarch64.cc:7934
+#: config/aarch64/aarch64.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/aarch64/aarch64.cc:8112
+#: config/aarch64/aarch64.cc:8125
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17544
+#: config/aarch64/aarch64.cc:17557
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17588
+#: config/aarch64/aarch64.cc:17601
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute ignored"
 msgid "%qs string ill-formed"
 msgstr "忽略 %qs 屬性"
 
-#: config/aarch64/aarch64.cc:17644
+#: config/aarch64/aarch64.cc:17657
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for %<sve_width%>"
 msgstr "運算元的約束無效"
 
-#: config/aarch64/aarch64.cc:17656
+#: config/aarch64/aarch64.cc:17669
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid %<sve_width%> value: %d"
 msgstr "無效 %%h 值"
 
-#: config/aarch64/aarch64.cc:17676
+#: config/aarch64/aarch64.cc:17689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "無效的範圍 %s 在中選項 %s"
 
-#: config/aarch64/aarch64.cc:17694
+#: config/aarch64/aarch64.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "不明 spec 函式 %qs"
 
-#: config/aarch64/aarch64.cc:17882 config/arm/arm.cc:3193
-#: config/riscv/riscv.cc:6320
+#: config/aarch64/aarch64.cc:17895 config/arm/arm.cc:3193
+#: config/riscv/riscv.cc:6326
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17891 config/riscv/riscv.cc:6329
+#: config/aarch64/aarch64.cc:17904 config/riscv/riscv.cc:6335
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:17899
+#: config/aarch64/aarch64.cc:17912
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length"
 msgstr "指定指派暫存器的順序"
 
-#: config/aarch64/aarch64.cc:17909 config/arm/arm.cc:3205
-#: config/riscv/riscv.cc:6358 config/rs6000/rs6000.cc:4531
+#: config/aarch64/aarch64.cc:17922 config/arm/arm.cc:3205
+#: config/riscv/riscv.cc:6364 config/rs6000/rs6000.cc:4531
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/aarch64/aarch64.cc:17916
+#: config/aarch64/aarch64.cc:17929
 #, gcc-internal-format
 msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18006
+#: config/aarch64/aarch64.cc:18019
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18022
+#: config/aarch64/aarch64.cc:18035
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18124
+#: config/aarch64/aarch64.cc:18137
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.cc:18131
+#: config/aarch64/aarch64.cc:18144
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "不明 TLS 式樣 %qs"
 
-#: config/aarch64/aarch64.cc:18190
+#: config/aarch64/aarch64.cc:18203
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/aarch64/aarch64.cc:18201
+#: config/aarch64/aarch64.cc:18214
 #, gcc-internal-format
 msgid "%qs must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18206
+#: config/aarch64/aarch64.cc:18219
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "無效的引數到內建函式"
 
-#: config/aarch64/aarch64.cc:18234
+#: config/aarch64/aarch64.cc:18247
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.cc:18237
+#: config/aarch64/aarch64.cc:18250
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "不明值 %qs 的 -mmacosx-version-min"
 
-#: config/aarch64/aarch64.cc:18243
+#: config/aarch64/aarch64.cc:18256
 #, fuzzy, gcc-internal-format
 msgid "did you mean %<-mcpu=%s%>?"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.cc:18246
+#: config/aarch64/aarch64.cc:18259
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs 後缺少檔案名稱"
 
-#: config/aarch64/aarch64.cc:18274
+#: config/aarch64/aarch64.cc:18287
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.cc:18277
+#: config/aarch64/aarch64.cc:18290
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/aarch64/aarch64.cc:18362
+#: config/aarch64/aarch64.cc:18375
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "切換 -mcpu=%s 衝突與 -march=%s 切換"
 
-#: config/aarch64/aarch64.cc:18416
+#: config/aarch64/aarch64.cc:18429
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s 不支援 %s"
 
-#: config/aarch64/aarch64.cc:18423
+#: config/aarch64/aarch64.cc:18436
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18496
+#: config/aarch64/aarch64.cc:18509
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18499
+#: config/aarch64/aarch64.cc:18512
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/aarch64/aarch64.cc:18651
+#: config/aarch64/aarch64.cc:18664
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18654
+#: config/aarch64/aarch64.cc:18667
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.cc:18658
+#: config/aarch64/aarch64.cc:18671
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.cc:18692
+#: config/aarch64/aarch64.cc:18705
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18695
+#: config/aarch64/aarch64.cc:18708
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.cc:18699 config/aarch64/aarch64.cc:18805
+#: config/aarch64/aarch64.cc:18712 config/aarch64/aarch64.cc:18818
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.cc:18722
+#: config/aarch64/aarch64.cc:18735
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18726
+#: config/aarch64/aarch64.cc:18739
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.cc:18760
+#: config/aarch64/aarch64.cc:18773
 #, fuzzy, gcc-internal-format
 msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.cc:18801
+#: config/aarch64/aarch64.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.cc:18859 config/aarch64/aarch64.cc:19032
+#: config/aarch64/aarch64.cc:18872 config/aarch64/aarch64.cc:19045
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> 格式錯誤"
 
-#: config/aarch64/aarch64.cc:18903
+#: config/aarch64/aarch64.cc:18916
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18911 config/i386/i386-options.cc:1254
+#: config/aarch64/aarch64.cc:18924 config/i386/i386-options.cc:1256
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18965
+#: config/aarch64/aarch64.cc:18978
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.cc:19022 config/arm/arm.cc:33526
-#: config/rs6000/rs6000.cc:24408 config/s390/s390.cc:16053
+#: config/aarch64/aarch64.cc:19035 config/arm/arm.cc:33539
+#: config/rs6000/rs6000.cc:24417 config/s390/s390.cc:16053
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: config/aarch64/aarch64.cc:19057
+#: config/aarch64/aarch64.cc:19070
 #, gcc-internal-format
 msgid "arch extension %<%s%> should be prefixed by %<+%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19060
+#: config/aarch64/aarch64.cc:19073
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.cc:19069
+#: config/aarch64/aarch64.cc:19082
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20549 config/arm/arm.cc:6614
+#: config/aarch64/aarch64.cc:20562 config/arm/arm.cc:6614
 #: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12424
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20554 config/arm/arm.cc:6619
+#: config/aarch64/aarch64.cc:20567 config/arm/arm.cc:6619
 #: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12419
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:20559 config/arm/arm.cc:6624
+#: config/aarch64/aarch64.cc:20572 config/arm/arm.cc:6624
 msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:21713 config/aarch64/aarch64.cc:21716
+#: config/aarch64/aarch64.cc:21726 config/aarch64/aarch64.cc:21729
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
 
-#: config/aarch64/aarch64.cc:26963 config/i386/i386.cc:23702
-#: config/i386/i386.cc:23833
+#: config/aarch64/aarch64.cc:26990 config/i386/i386.cc:23710
+#: config/i386/i386.cc:23841
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "不支援的組合：%s"
 
-#: config/aarch64/aarch64.cc:26975 config/aarch64/aarch64.cc:27004
+#: config/aarch64/aarch64.cc:27002 config/aarch64/aarch64.cc:27031
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26979
+#: config/aarch64/aarch64.cc:27006
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:26983
+#: config/aarch64/aarch64.cc:27010
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.cc:27008
+#: config/aarch64/aarch64.cc:27035
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.cc:27034
+#: config/aarch64/aarch64.cc:27061
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -39486,13 +39491,13 @@ msgstr "%qs 屬性的引數不是「ilink1」或「ilink2」"
 #: config/bfin/bfin.cc:4694 config/bfin/bfin.cc:4755 config/bfin/bfin.cc:4785
 #: config/bpf/bpf.cc:99 config/csky/csky.cc:6458 config/csky/csky.cc:6486
 #: config/epiphany/epiphany.cc:491 config/gcn/gcn.cc:333
-#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3381
-#: config/i386/i386-options.cc:3558 config/i386/i386-options.cc:3614
-#: config/i386/i386-options.cc:3665 config/i386/i386-options.cc:3702
+#: config/h8300/h8300.cc:4944 config/i386/i386-options.cc:3383
+#: config/i386/i386-options.cc:3560 config/i386/i386-options.cc:3616
+#: config/i386/i386-options.cc:3667 config/i386/i386-options.cc:3704
 #: config/m68k/m68k.cc:792 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3988
+#: config/nvptx/nvptx.cc:5800 config/riscv/riscv.cc:3994
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20362 config/rx/rx.cc:2727 config/rx/rx.cc:2753
+#: config/rs6000/rs6000.cc:20371 config/rx/rx.cc:2727 config/rx/rx.cc:2753
 #: config/s390/s390.cc:1164 config/s390/s390.cc:1251 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2229
@@ -39639,17 +39644,17 @@ msgstr "%qE 屬性被忽略"
 msgid "%qE attribute only applies to variables"
 msgstr "%qE 屬性只有套用到變數"
 
-#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22536
+#: config/arm/aarch-common.cc:551 config/i386/i386.cc:22544
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22600
+#: config/arm/aarch-common.cc:612 config/i386/i386.cc:22608
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22629
+#: config/arm/aarch-common.cc:622 config/i386/i386.cc:22637
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "無效的型態用於製作函式"
@@ -39859,7 +39864,7 @@ msgstr "目的 CPU 不支援 THUMB 指令"
 msgid "target CPU does not support unaligned accesses"
 msgstr "目標 CPU 不支援 unaligned 存取"
 
-#: config/arm/arm.cc:3213 config/arm/arm.cc:33199
+#: config/arm/arm.cc:3213 config/arm/arm.cc:33212
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "%qs 架構不支援 branch-likely 指令"
@@ -39917,7 +39922,7 @@ msgstr "結構大小邊界只能是設定為 8 或 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 是不相容的與 -msingle-pic-base"
 
-#: config/arm/arm.cc:3649 config/arm/arm.cc:33540
+#: config/arm/arm.cc:3649 config/arm/arm.cc:33553
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
@@ -40029,7 +40034,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7039 config/arm/arm.cc:7260 config/arm/arm.cc:7293
-#: config/arm/arm.cc:29318
+#: config/arm/arm.cc:29331
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -40080,33 +40085,33 @@ msgstr ""
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:25907
+#: config/arm/arm.cc:25920
 #, fuzzy, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "無法計算真實位置的重疊參數"
 
-#: config/arm/arm.cc:26570
+#: config/arm/arm.cc:26583
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "非預期的模組結束"
 
-#: config/arm/arm.cc:26829
+#: config/arm/arm.cc:26842
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高暫存器彈堆疊時沒有可用的低暫存器"
 
-#: config/arm/arm.cc:27082
+#: config/arm/arm.cc:27095
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/arm/arm.cc:27328
+#: config/arm/arm.cc:27341
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33555
+#: config/arm/arm.cc:33568
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
@@ -40114,22 +40119,22 @@ msgstr "無效的向量型態用於屬性 %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33563
+#: config/arm/arm.cc:33576
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33576
+#: config/arm/arm.cc:33589
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
 
-#: config/arm/arm.cc:33590
+#: config/arm/arm.cc:33603
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "目標屬性或 pragma 變更 SPE ABI"
 
-#: config/arm/arm.cc:34552
+#: config/arm/arm.cc:34565
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
@@ -40204,17 +40209,17 @@ msgstr "-fpic 未被支援"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC 未被支援"
 
-#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6628
+#: config/avr/avr.cc:1050 config/avr/avr.cc:1055 config/riscv/riscv.cc:6634
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "函式屬性 %qs，%qs 和 %qs 彼此互斥"
 
-#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6640
+#: config/avr/avr.cc:1076 config/riscv/riscv.cc:6646
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs 函式無法有引數"
 
-#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6637
+#: config/avr/avr.cc:1079 config/riscv/riscv.cc:6643
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs 函式無法回傳值"
@@ -40539,7 +40544,7 @@ msgstr "無效的引數到內建函式"
 #: config/bpf/bpf.cc:1247 config/bpf/bpf.cc:1292
 #: config/loongarch/loongarch-builtins.cc:313 config/mips/mips.cc:17187
 #: config/nios2/nios2.cc:3600 config/riscv/riscv-builtins.cc:306
-#: config/riscv/riscv-vector-builtins.cc:3230
+#: config/riscv/riscv-vector-builtins.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "無效的引數到內建函式"
@@ -41155,767 +41160,767 @@ msgstr ""
 msgid "virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25106
+#: config/i386/i386-features.cc:3403 config/rs6000/rs6000.cc:25115
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/i386/i386-options.cc:887 config/i386/i386-options.cc:2123
-#: config/i386/i386-options.cc:2132
+#: config/i386/i386-options.cc:888 config/i386/i386-options.cc:2125
+#: config/i386/i386-options.cc:2134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "編碼式樣 %s 不支援 PIC 模式"
 
-#: config/i386/i386-options.cc:1159
+#: config/i386/i386-options.cc:1161
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: config/i386/i386-options.cc:1223
+#: config/i386/i386-options.cc:1225
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/i386/i386-options.cc:1286
+#: config/i386/i386-options.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "序列屬性於 %C 已經指定的在中型態敘述"
 
-#: config/i386/i386-options.cc:1324
+#: config/i386/i386-options.cc:1326
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s 屬性的『%s』衝突與 %s 屬性於 %L"
 
-#: config/i386/i386-options.cc:1606
+#: config/i386/i386-options.cc:1608
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: config/i386/i386-options.cc:1612
+#: config/i386/i386-options.cc:1614
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.cc:1622
+#: config/i386/i386-options.cc:1624
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D 的暫存器名無效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:1648
+#: config/i386/i386-options.cc:1650
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.cc:1661
+#: config/i386/i386-options.cc:1663
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "對齊指定的用於函式 %qE"
 
-#: config/i386/i386-options.cc:1671
+#: config/i386/i386-options.cc:1673
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.cc:1678
+#: config/i386/i386-options.cc:1680
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs 沒有指定類別名"
 
-#: config/i386/i386-options.cc:1731
+#: config/i386/i386-options.cc:1733
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:1945
+#: config/i386/i386-options.cc:1947
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/i386/i386-options.cc:1999
+#: config/i386/i386-options.cc:2001
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
-#: config/i386/i386-options.cc:2001
+#: config/i386/i386-options.cc:2003
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2029
+#: config/i386/i386-options.cc:2031
 #, fuzzy, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.cc:2034
+#: config/i386/i386-options.cc:2036
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.cc:2037
+#: config/i386/i386-options.cc:2039
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "32 位元系統不支援 -mcmodel="
 
-#: config/i386/i386-options.cc:2052
+#: config/i386/i386-options.cc:2054
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386-options.cc:2063
+#: config/i386/i386-options.cc:2065
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-f%s 不受支援：已忽略"
 
-#: config/i386/i386-options.cc:2069
+#: config/i386/i386-options.cc:2071
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "transactional 記憶體未被支援與 non-call 異常"
 
-#: config/i386/i386-options.cc:2072
+#: config/i386/i386-options.cc:2074
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "transactional 記憶體未被支援與 non-call 異常"
 
-#: config/i386/i386-options.cc:2076
+#: config/i386/i386-options.cc:2078
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only 是不相容的與 -traditional"
 
-#: config/i386/i386-options.cc:2093 config/i386/i386-options.cc:2102
-#: config/i386/i386-options.cc:2114 config/i386/i386-options.cc:2125
-#: config/i386/i386-options.cc:2136
+#: config/i386/i386-options.cc:2095 config/i386/i386-options.cc:2104
+#: config/i386/i386-options.cc:2116 config/i386/i386-options.cc:2127
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386-options.cc:2105 config/i386/i386-options.cc:2117
+#: config/i386/i386-options.cc:2107 config/i386/i386-options.cc:2119
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/i386/i386-options.cc:2160
+#: config/i386/i386-options.cc:2162
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel 不支援在中這個組態"
 
-#: config/i386/i386-options.cc:2165
+#: config/i386/i386-options.cc:2167
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未編譯入對 %i 位模式的支援"
 
-#: config/i386/i386-options.cc:2177
+#: config/i386/i386-options.cc:2179
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2179
+#: config/i386/i386-options.cc:2181
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2186
+#: config/i386/i386-options.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2190
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2196 config/i386/i386-options.cc:2328
+#: config/i386/i386-options.cc:2198 config/i386/i386-options.cc:2330
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您選擇的 CPU 不支援 x86-64 指令集"
 
-#: config/i386/i386-options.cc:2267
+#: config/i386/i386-options.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-march= 所帶參數(%s)不正確"
 
-#: config/i386/i386-options.cc:2268
+#: config/i386/i386-options.cc:2270
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %sarch=%s %s"
 
-#: config/i386/i386-options.cc:2290
+#: config/i386/i386-options.cc:2292
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2292
+#: config/i386/i386-options.cc:2294
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2297
+#: config/i386/i386-options.cc:2299
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2298
+#: config/i386/i386-options.cc:2300
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2347
+#: config/i386/i386-options.cc:2349
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/i386/i386-options.cc:2348
+#: config/i386/i386-options.cc:2350
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2369
+#: config/i386/i386-options.cc:2371
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2371
+#: config/i386/i386-options.cc:2373
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2376
+#: config/i386/i386-options.cc:2378
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2377
+#: config/i386/i386-options.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2401
+#: config/i386/i386-options.cc:2403
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386-options.cc:2403
+#: config/i386/i386-options.cc:2405
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386-options.cc:2406
+#: config/i386/i386-options.cc:2408
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之間"
 
-#: config/i386/i386-options.cc:2429
+#: config/i386/i386-options.cc:2431
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.cc:2434
+#: config/i386/i386-options.cc:2436
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386-options.cc:2435
+#: config/i386/i386-options.cc:2437
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386-options.cc:2524
+#: config/i386/i386-options.cc:2526
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary 未被支援用於這個目標"
 
-#: config/i386/i386-options.cc:2527
+#: config/i386/i386-options.cc:2529
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/i386/i386-options.cc:2550
+#: config/i386/i386-options.cc:2552
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 未被介於 %d 和 12"
 
-#: config/i386/i386-options.cc:2563
+#: config/i386/i386-options.cc:2565
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.cc:2566
+#: config/i386/i386-options.cc:2568
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: config/i386/i386-options.cc:2572
+#: config/i386/i386-options.cc:2574
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386-options.cc:2573
+#: config/i386/i386-options.cc:2575
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386-options.cc:2583
+#: config/i386/i386-options.cc:2585
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已停用，使用 387 指令"
 
-#: config/i386/i386-options.cc:2590
+#: config/i386/i386-options.cc:2592
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已停用，使用 SSE 指令"
 
-#: config/i386/i386-options.cc:2640
+#: config/i386/i386-options.cc:2642
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2642
+#: config/i386/i386-options.cc:2644
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2656
+#: config/i386/i386-options.cc:2658
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2658
+#: config/i386/i386-options.cc:2660
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2718
+#: config/i386/i386-options.cc:2720
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry isn%'t 支援的用於 32-bit 在中組合與 -fpic"
 
-#: config/i386/i386-options.cc:2721
+#: config/i386/i386-options.cc:2723
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386-options.cc:2725
+#: config/i386/i386-options.cc:2727
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2839
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/i386/i386-options.cc:2898
+#: config/i386/i386-options.cc:2900
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2903
+#: config/i386/i386-options.cc:2905
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2931
+#: config/i386/i386-options.cc:2933
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2979
+#: config/i386/i386-options.cc:2981
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.cc:3115
+#: config/i386/i386-options.cc:3117
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.cc:3130
+#: config/i386/i386-options.cc:3132
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3179
+#: config/i386/i386-options.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.cc:3189
+#: config/i386/i386-options.cc:3191
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3224
+#: config/i386/i386-options.cc:3226
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.cc:3234
+#: config/i386/i386-options.cc:3236
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3341
+#: config/i386/i386-options.cc:3343
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3343
+#: config/i386/i386-options.cc:3345
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 位元組 cop 指令未被允許在中 64-bit VLIW 模式"
 
-#: config/i386/i386-options.cc:3347
+#: config/i386/i386-options.cc:3349
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3394 config/i386/i386-options.cc:3445
+#: config/i386/i386-options.cc:3396 config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386-options.cc:3399
+#: config/i386/i386-options.cc:3401
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3406 config/i386/i386-options.cc:3634
+#: config/i386/i386-options.cc:3408 config/i386/i386-options.cc:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386-options.cc:3412
+#: config/i386/i386-options.cc:3414
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386-options.cc:3437 config/i386/i386-options.cc:3480
+#: config/i386/i386-options.cc:3439 config/i386/i386-options.cc:3482
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.cc:3441
+#: config/i386/i386-options.cc:3443
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386-options.cc:3449 config/i386/i386-options.cc:3498
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3500
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3459 config/i386/i386-options.cc:3476
+#: config/i386/i386-options.cc:3461 config/i386/i386-options.cc:3478
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.cc:3463
+#: config/i386/i386-options.cc:3465
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386-options.cc:3467 config/i386/i386-options.cc:3494
+#: config/i386/i386-options.cc:3469 config/i386/i386-options.cc:3496
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3484 config/i386/i386-options.cc:3502
+#: config/i386/i386-options.cc:3486 config/i386/i386-options.cc:3504
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3490
+#: config/i386/i386-options.cc:3492
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386-options.cc:3594 config/rs6000/rs6000.cc:20475
+#: config/i386/i386-options.cc:3596 config/rs6000/rs6000.cc:20484
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386-options.cc:3621
+#: config/i386/i386-options.cc:3623
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386-options.cc:3642
+#: config/i386/i386-options.cc:3644
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386-options.cc:3676 config/i386/i386-options.cc:3686
+#: config/i386/i386-options.cc:3678 config/i386/i386-options.cc:3688
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386-options.cc:3713 config/i386/i386-options.cc:3735
+#: config/i386/i386-options.cc:3715 config/i386/i386-options.cc:3737
 #: config/ia64/ia64.cc:812 config/s390/s390.cc:1261
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/i386/i386-options.cc:3723 config/i386/i386-options.cc:3745
+#: config/i386/i386-options.cc:3725 config/i386/i386-options.cc:3747
 #: config/s390/s390.cc:1290
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3779
 #, fuzzy, gcc-internal-format
 #| msgid "dereferenced pointers should have a name or a type tag"
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "提領的指標應具有一個名稱或類型標記"
 
-#: config/i386/i386-options.cc:3784
+#: config/i386/i386-options.cc:3786
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "插斷函式必須沒有任何引數"
 
-#: config/i386/i386-options.cc:3795
+#: config/i386/i386-options.cc:3797
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3798
+#: config/i386/i386-options.cc:3800
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386.cc:1231
+#: config/i386/i386.cc:1232
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.cc:1234
+#: config/i386/i386.cc:1235
 #, fuzzy, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qT 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.cc:1538
+#: config/i386/i386.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "不支援 multilib"
 
-#: config/i386/i386.cc:1572
+#: config/i386/i386.cc:1573
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ms_hook_prologue 不是相容與巢狀的函式"
 
-#: config/i386/i386.cc:1923
+#: config/i386/i386.cc:1924
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.cc:1929
+#: config/i386/i386.cc:1930
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.cc:1943
+#: config/i386/i386.cc:1944
 #, fuzzy, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.cc:1949
+#: config/i386/i386.cc:1950
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.cc:1965
+#: config/i386/i386.cc:1966
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻出現了 SSE 向量引數，這變更了 ABI"
 
-#: config/i386/i386.cc:1971
+#: config/i386/i386.cc:1972
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻有 SSE 向量回傳值，這變更了 ABI"
 
-#: config/i386/i386.cc:1987
+#: config/i386/i386.cc:1988
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX，卻出現了 MMX 向量引數，這變更了 ABI"
 
-#: config/i386/i386.cc:1993
+#: config/i386/i386.cc:1994
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX卻回傳 MMX 向量，這變更了 ABI"
 
-#: config/i386/i386.cc:2191
+#: config/i386/i386.cc:2192
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與 flexible 陣列成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.cc:2312
+#: config/i386/i386.cc:2313
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "ABI 的傳遞聯合與長雙倍已變更在中 GCC 4.4"
 
-#: config/i386/i386.cc:2447
+#: config/i386/i386.cc:2448
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.cc:2568
+#: config/i386/i386.cc:2569
 #, fuzzy
 msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.cc:2663
+#: config/i386/i386.cc:2664
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中回傳"
 
-#: config/i386/i386.cc:2669
+#: config/i386/i386.cc:2670
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中傳遞參數"
 
-#: config/i386/i386.cc:2689
+#: config/i386/i386.cc:2690
 #, fuzzy, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 暫存器回傳與 x87 已停用"
 
-#: config/i386/i386.cc:3017 config/i386/i386.cc:3262 config/i386/i386.cc:4042
+#: config/i386/i386.cc:3018 config/i386/i386.cc:3263 config/i386/i386.cc:4043
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.cc:3019 config/i386/i386.cc:3264 config/i386/i386.cc:4044
+#: config/i386/i386.cc:3020 config/i386/i386.cc:3265 config/i386/i386.cc:4045
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.cc:3667
+#: config/i386/i386.cc:3668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/i386/i386.cc:6564
+#: config/i386/i386.cc:6565
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "assert：%s 與 %s 賦值相容"
 
-#: config/i386/i386.cc:8470
+#: config/i386/i386.cc:8471
 #, fuzzy, gcc-internal-format
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "ms_hook_prologue 屬性 isn%'t 相容與 -mfentry 用於 32-bit"
 
-#: config/i386/i386.cc:8560
+#: config/i386/i386.cc:8561
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.cc:9495
+#: config/i386/i386.cc:9496
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "Stack realignment not supported with %<__builtin_eh_return%>"
 msgstr "%qE 屬性在此平臺上不受支援"
 
-#: config/i386/i386.cc:9500
+#: config/i386/i386.cc:9501
 #, fuzzy, gcc-internal-format
 msgid "regparm nested function not supported with %<__builtin_eh_return%>"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: config/i386/i386.cc:9886
+#: config/i386/i386.cc:9887
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支援 fastcall 與巢狀的函式"
 
-#: config/i386/i386.cc:9906
+#: config/i386/i386.cc:9907
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支援 2 暫存器  參數用於巢狀的函式"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.cc:9917
+#: config/i386/i386.cc:9918
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/i386/i386.cc:12955
+#: config/i386/i386.cc:12956
 #, gcc-internal-format
 msgid "%<V%> modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.cc:12966 config/i386/i386.cc:12980
+#: config/i386/i386.cc:12967 config/i386/i386.cc:12981
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.cc:13012
+#: config/i386/i386.cc:13013
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "擴充的暫存器沒有高半部分"
 
-#: config/i386/i386.cc:13027
+#: config/i386/i386.cc:13028
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.cc:13221
+#: config/i386/i386.cc:13225 config/i386/i386.cc:13227
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "non-integer 運算元使用的與運算元編碼『%c』"
 
-#: config/i386/i386.cc:17330
+#: config/i386/i386.cc:17338
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:21728
+#: config/i386/i386.cc:21736
 #, fuzzy
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "mangling 的 %<va_list%> 已變更在中 GCC 4.4"
 
-#: config/i386/i386.cc:21824
+#: config/i386/i386.cc:21832
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "32 位元系統不支援 -mcmodel="
 
-#: config/i386/i386.cc:23661
+#: config/i386/i386.cc:23669
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "不明 TLS 式樣 %qs"
 
-#: config/i386/i386.cc:23668
+#: config/i386/i386.cc:23676
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23675
+#: config/i386/i386.cc:23683
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:23724
+#: config/i386/i386.cc:23732
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.cc:23755
+#: config/i386/i386.cc:23763
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/i386/i386.cc:24301
+#: config/i386/i386.cc:24309
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "-fdirectives-only 是不相容的與 -traditional"
@@ -42273,7 +42278,7 @@ msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE redeclared 與衝突 %qs 屬性"
 
 #: config/mips/mips.cc:1513 config/mips/mips.cc:1567
-#: config/riscv/riscv.cc:4016
+#: config/riscv/riscv.cc:4022
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 屬性需要字串常數引數"
@@ -43432,57 +43437,57 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "不明 # pragma GCC 輔助處理器 %E"
 
-#: config/riscv/riscv-vector-builtins.cc:3369
+#: config/riscv/riscv-vector-builtins.cc:3379
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a fixed size"
 msgstr "型態 %qT 沒有已知大小"
 
-#: config/riscv/riscv-vector-builtins.cc:3375
+#: config/riscv/riscv-vector-builtins.cc:3385
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT does not have a defined alignment"
 msgstr "型態 %qT 沒有已知大小"
 
-#: config/riscv/riscv-vector-builtins.cc:3390
+#: config/riscv/riscv-vector-builtins.cc:3400
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to RVV type %qT"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: config/riscv/riscv-vector-builtins.cc:3398
+#: config/riscv/riscv-vector-builtins.cc:3408
 #, gcc-internal-format
 msgid "member variables cannot have RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:3400
+#: config/riscv/riscv-vector-builtins.cc:3410
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "fields cannot have RVV type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: config/riscv/riscv-vector-builtins.cc:3406
+#: config/riscv/riscv-vector-builtins.cc:3416
 #, fuzzy, gcc-internal-format
 msgid "array elements cannot have RVV type %qT"
 msgstr "函式參數無法有 __fp16 型態"
 
-#: config/riscv/riscv-vector-builtins.cc:3412
+#: config/riscv/riscv-vector-builtins.cc:3422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot allocate objects with RVV type %qT"
 msgstr "無法為有抽象類型 %qT 的物件指派記憶體"
 
-#: config/riscv/riscv-vector-builtins.cc:3418
+#: config/riscv/riscv-vector-builtins.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot delete objects with RVV type %qT"
 msgstr "無法為有抽象類型 %qT 的物件指派記憶體"
 
-#: config/riscv/riscv-vector-builtins.cc:3424
+#: config/riscv/riscv-vector-builtins.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of abstract type %qT"
 msgid "cannot throw or catch RVV type %qT"
 msgstr "無法為有抽象類型 %qT 的物件指派記憶體"
 
-#: config/riscv/riscv-vector-builtins.cc:3430
+#: config/riscv/riscv-vector-builtins.cc:3440
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of RVV type %qT"
 msgstr "無效的使用的不完整型態 %q#T"
@@ -43502,66 +43507,71 @@ msgstr "不使用 SPE ABI 延伸"
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:3635 config/riscv/riscv.cc:3677
+#: config/riscv/riscv.cc:3641 config/riscv/riscv.cc:3683
 #, fuzzy, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/riscv/riscv.cc:4027
+#: config/riscv/riscv.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/riscv/riscv.cc:6234
+#: config/riscv/riscv.cc:6240
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6277
+#: config/riscv/riscv.cc:6283
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:6281
+#: config/riscv/riscv.cc:6287
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:6286
+#: config/riscv/riscv.cc:6292
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgstr ""
 
-#: config/riscv/riscv.cc:6290
+#: config/riscv/riscv.cc:6296
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:6300
+#: config/riscv/riscv.cc:6306
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/riscv/riscv.cc:6313
+#: config/riscv/riscv.cc:6319
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:6340 config/rs6000/rs6000.cc:4543
+#: config/riscv/riscv.cc:6346 config/rs6000/rs6000.cc:4543
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs 並非有效類別名稱"
 
-#: config/riscv/riscv.cc:6354 config/rs6000/rs6000.cc:4526
+#: config/riscv/riscv.cc:6360 config/rs6000/rs6000.cc:4526
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/riscv/riscv.cc:6666
+#: config/riscv/riscv.cc:6672
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs 函式無法有引數"
 
+#: config/riscv/riscv.cc:7095
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.cc:375
 #, fuzzy, gcc-internal-format
@@ -44059,97 +44069,97 @@ msgstr ""
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:17741
+#: config/rs6000/rs6000.cc:17750
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
 
-#: config/rs6000/rs6000.cc:20137
+#: config/rs6000/rs6000.cc:20146
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.cc:20219
+#: config/rs6000/rs6000.cc:20228
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/rs6000/rs6000.cc:20221
+#: config/rs6000/rs6000.cc:20230
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/rs6000/rs6000.cc:20223
+#: config/rs6000/rs6000.cc:20232
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/rs6000/rs6000.cc:20225
+#: config/rs6000/rs6000.cc:20234
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
 
-#: config/rs6000/rs6000.cc:20231
+#: config/rs6000/rs6000.cc:20240
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.cc:20234
+#: config/rs6000/rs6000.cc:20243
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
 
-#: config/rs6000/rs6000.cc:20239
+#: config/rs6000/rs6000.cc:20248
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.cc:20242
+#: config/rs6000/rs6000.cc:20251
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.cc:24380
+#: config/rs6000/rs6000.cc:24389
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.cc:24383
+#: config/rs6000/rs6000.cc:24392
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.cc:24385
+#: config/rs6000/rs6000.cc:24394
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s「%s」%s 無效"
 
-#: config/rs6000/rs6000.cc:24914
+#: config/rs6000/rs6000.cc:24923
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25073
+#: config/rs6000/rs6000.cc:25082
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25362
+#: config/rs6000/rs6000.cc:25371
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/rs6000/rs6000.cc:28499
+#: config/rs6000/rs6000.cc:28508
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28978
+#: config/rs6000/rs6000.cc:28987
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.cc:28983
+#: config/rs6000/rs6000.cc:28992
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
@@ -45610,7 +45620,7 @@ msgstr "不能將帶有 volatile 欄位的物件放入暫存器"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "uninitialized 常數 %qD 無效在中 C++"
 
-#: c/c-decl.cc:5925 cp/decl.cc:8815
+#: c/c-decl.cc:5925 cp/decl.cc:8825
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -45799,7 +45809,7 @@ msgstr "貯藏類別指定的用於參數 %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "貯藏類別指定的用於未命名參數"
 
-#: c/c-decl.cc:6842 cp/decl.cc:12840
+#: c/c-decl.cc:6842 cp/decl.cc:12850
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "為類型名指定了存儲類別"
@@ -45971,7 +45981,7 @@ msgstr "型態名稱宣告的做為函式回傳陣列"
 msgid "function definition has qualified void return type"
 msgstr "函式定義有限定的 void 回傳類型"
 
-#: c/c-decl.cc:7418 cp/decl.cc:13161
+#: c/c-decl.cc:7418 cp/decl.cc:13171
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函式回傳類型的類型限定"
@@ -46101,7 +46111,7 @@ msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "成員的結構或聯合無法有 variably 已修改型態"
 
-#: c/c-decl.cc:7757 cp/decl.cc:11720
+#: c/c-decl.cc:7757 cp/decl.cc:11730
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "變數或欄位 %qE 宣告為 void"
@@ -46304,7 +46314,7 @@ msgstr "定義輸入 %qs 運算式無效在中 C++"
 msgid "%qT defined in underspecified object initializer"
 msgstr "初始值設定項裡有不明的欄位 %qE"
 
-#: c/c-decl.cc:8759 cp/decl.cc:5469
+#: c/c-decl.cc:8759 cp/decl.cc:5479
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "沒有宣告任何東西"
@@ -46354,7 +46364,7 @@ msgstr "結構不包含任何具名成員"
 msgid "struct has no members"
 msgstr "結構體沒有成員"
 
-#: c/c-decl.cc:9235 cp/decl.cc:14144
+#: c/c-decl.cc:9235 cp/decl.cc:14154
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexible 陣列成員在中聯合"
@@ -46399,7 +46409,7 @@ msgstr "%<enum %E%> 重宣告"
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:9668 cp/decl.cc:16721 m2/gm2-gcc/m2type.cc:2070
+#: c/c-decl.cc:9668 cp/decl.cc:16731 m2/gm2-gcc/m2type.cc:2070
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -46447,7 +46457,7 @@ msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgstr "ISO C 將列舉值限制在 %<int%> 範圍內"
 
-#: c/c-decl.cc:10093 cp/decl.cc:5789 cp/decl.cc:17300
+#: c/c-decl.cc:10093 cp/decl.cc:5799 cp/decl.cc:17310
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "內聯函式 %qD 給定的屬性 noinline"
@@ -46478,7 +46488,7 @@ msgstr "沒有前一個原型用於 %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD 被使用不具任何原型之前它的定義"
 
-#: c/c-decl.cc:10226 cp/decl.cc:17443
+#: c/c-decl.cc:10226 cp/decl.cc:17453
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "沒有前一個宣告用於 %qD"
@@ -46593,12 +46603,12 @@ msgstr "引數 %qD 與內建原型不符"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引數 %qD 與原型不符"
 
-#: c/c-decl.cc:10882 cp/decl.cc:18224
+#: c/c-decl.cc:10882 cp/decl.cc:18234
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: c/c-decl.cc:10901 cp/decl.cc:18308
+#: c/c-decl.cc:10901 cp/decl.cc:18318
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "參數 %qD 設定並不是使用"
@@ -48677,7 +48687,7 @@ msgstr "不足 perfectly 巢狀的迴圈"
 msgid "collapsed loops not perfectly nested"
 msgstr "崩潰的迴圈無法 perfectly 巢狀"
 
-#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18544
+#: c/c-parser.cc:20527 cp/parser.cc:43751 cp/parser.cc:43793 cp/pt.cc:18552
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
@@ -48808,13 +48818,13 @@ msgstr "預期 %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "『%s』於 %L 並非函式"
 
-#: c/c-parser.cc:22839 cp/decl.cc:8102
+#: c/c-parser.cc:22839 cp/decl.cc:8112
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不相容"
 
-#: c/c-parser.cc:22851 cp/decl.cc:8111
+#: c/c-parser.cc:22851 cp/decl.cc:8121
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -49076,7 +49086,7 @@ msgstr "對 void 運算式的無效使用"
 msgid "invalid use of flexible array member"
 msgstr "對彈性陣列成員無效的使用"
 
-#: c/c-typeck.cc:265 cp/typeck2.cc:350 rust/backend/rust-tree.cc:3871
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3871
 #, gcc-internal-format
 msgid "invalid use of array with unspecified bounds"
 msgstr "對未指定邊界的陣列的無效使用"
@@ -50070,12 +50080,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1199
+#: c/c-typeck.cc:8368 c/c-typeck.cc:9294 cp/typeck2.cc:1197
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "對彈性陣列成員的初始化"
 
-#: c/c-typeck.cc:8384 cp/typeck2.cc:1216
+#: c/c-typeck.cc:8384 cp/typeck2.cc:1214
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -50116,7 +50126,7 @@ msgstr "初始值設定中的元素在載入時無法被計算出"
 msgid "invalid initializer"
 msgstr "無效的初始值設定"
 
-#: c/c-typeck.cc:8921 cp/decl.cc:7480
+#: c/c-typeck.cc:8921 cp/decl.cc:7490
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量類型不能被初始化"
@@ -50131,8 +50141,8 @@ msgstr "初始值設定項末尾有多餘的大括號組"
 msgid "braces around scalar initializer"
 msgstr "標量初始化帶大括號"
 
-#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1226
-#: cp/typeck2.cc:1584
+#: c/c-typeck.cc:9291 c/c-typeck.cc:10770 cp/typeck2.cc:1224
+#: cp/typeck2.cc:1582
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在巢狀的上下文中初始化彈性陣列成員"
@@ -50223,7 +50233,7 @@ msgstr "結構初始值設定項中有多餘元素"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10744 cp/typeck2.cc:1203
+#: c/c-typeck.cc:10744 cp/typeck2.cc:1201
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "對彈性陣列成員非靜態地初始化"
@@ -51614,7 +51624,7 @@ msgstr "沒有合適的 %<operator %s%> 給 %qT"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8050 cp/decl.cc:8885
+#: cp/call.cc:8050 cp/decl.cc:8895
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "宣告的在此"
@@ -51625,7 +51635,7 @@ msgstr "宣告的在此"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8056 cp/decl.cc:8886
+#: cp/call.cc:8056 cp/decl.cc:8896
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "宣告的在此"
@@ -51641,7 +51651,7 @@ msgstr "%q+#D 無法存取"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "將 NULL 做為非指標引數 %P 傳遞給 %qD"
 
-#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10557 cp/decl.cc:10565
+#: cp/call.cc:8147 cp/call.cc:8166 cp/decl.cc:10567 cp/decl.cc:10575
 #: cp/typeck.cc:4591
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
@@ -51995,7 +52005,7 @@ msgstr "對 %<%T::%s(%A)%#V%> 的呼叫沒有匹配的函式"
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.cc:11446 cp/pt.cc:16888 cp/typeck.cc:3492
+#: cp/call.cc:11446 cp/pt.cc:16896 cp/typeck.cc:3492
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
@@ -52611,7 +52621,7 @@ msgstr "flexible 陣列成員在中否則清空結構"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.cc:7506 cp/decl.cc:17143 cp/parser.cc:26971
+#: cp/class.cc:7506 cp/decl.cc:17153 cp/parser.cc:26971
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
@@ -52735,7 +52745,7 @@ msgstr "無效的型態用於參數 %d 的 constexpr 函式 %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:272 cp/decl.cc:14246
+#: cp/constexpr.cc:272 cp/decl.cc:14256
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
@@ -52805,7 +52815,7 @@ msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2105 cp/constexpr.cc:9121
+#: cp/constexpr.cc:2105 cp/constexpr.cc:9128
 #: rust/backend/rust-constexpr.cc:5754
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -52854,7 +52864,7 @@ msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9153
+#: cp/constexpr.cc:2576 cp/constexpr.cc:2850 cp/constexpr.cc:9160
 #: rust/backend/rust-constexpr.cc:5785
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -52986,7 +52996,7 @@ msgid "dereferencing a null pointer in %qE"
 msgstr "提領 %<void *%> 指標"
 
 #: cp/constexpr.cc:4342 cp/constexpr.cc:4442 cp/constexpr.cc:4454
-#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9071
+#: cp/constexpr.cc:6998 cp/constexpr.cc:7096 cp/constexpr.cc:9078
 #: rust/backend/rust-constexpr.cc:1735 rust/backend/rust-constexpr.cc:1980
 #: rust/backend/rust-constexpr.cc:2222 rust/backend/rust-constexpr.cc:4739
 #: rust/backend/rust-constexpr.cc:5708
@@ -53087,7 +53097,7 @@ msgstr "成員 %qD 缺少初始值設定"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:5633 cp/constexpr.cc:7717
+#: cp/constexpr.cc:5633 cp/constexpr.cc:7724
 #: rust/backend/rust-constexpr.cc:872 rust/backend/rust-constexpr.cc:2492
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -53164,7 +53174,7 @@ msgstr ""
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/constexpr.cc:6575 cp/constexpr.cc:8058 cp/constexpr.cc:8070
+#: cp/constexpr.cc:6575 cp/constexpr.cc:8065 cp/constexpr.cc:8077
 #: rust/backend/rust-constexpr.cc:4664
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
@@ -53231,192 +53241,192 @@ msgstr ""
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "擷取的變數 %qD 與 non-automatic 貯藏體持續時間"
 
-#: cp/constexpr.cc:7194 cp/constexpr.cc:9785
+#: cp/constexpr.cc:7194 cp/constexpr.cc:9792
 #: rust/backend/rust-constexpr.cc:2053 rust/backend/rust-constexpr.cc:6203
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.cc:7625 cp/constexpr.cc:9286
+#: cp/constexpr.cc:7632 cp/constexpr.cc:9293
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.cc:7653 rust/backend/rust-constexpr.cc:2459
+#: cp/constexpr.cc:7660 rust/backend/rust-constexpr.cc:2459
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/constexpr.cc:7681 rust/backend/rust-constexpr.cc:2478
+#: cp/constexpr.cc:7688 rust/backend/rust-constexpr.cc:2478
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: cp/constexpr.cc:7694
+#: cp/constexpr.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:7728 rust/backend/rust-constexpr.cc:2504
+#: cp/constexpr.cc:7735 rust/backend/rust-constexpr.cc:2504
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:7859 cp/constexpr.cc:9596 cp/constexpr.cc:10008
+#: cp/constexpr.cc:7866 cp/constexpr.cc:9603 cp/constexpr.cc:10015
 #: rust/backend/rust-constexpr.cc:6096 rust/backend/rust-constexpr.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:7904 cp/constexpr.cc:10049
+#: cp/constexpr.cc:7911 cp/constexpr.cc:10056
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:7962
+#: cp/constexpr.cc:7969
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.cc:7978
+#: cp/constexpr.cc:7985
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "預期 template-id"
 
-#: cp/constexpr.cc:7984 cp/constraint.cc:178 cp/constraint.cc:753
+#: cp/constexpr.cc:7991 cp/constraint.cc:178 cp/constraint.cc:753
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: cp/constexpr.cc:8009
+#: cp/constexpr.cc:8016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/constexpr.cc:8073
+#: cp/constexpr.cc:8080
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "未預期的運算式 %qE 的 kind %s"
 
-#: cp/constexpr.cc:8332 rust/backend/rust-constexpr.cc:5154
+#: cp/constexpr.cc:8339 rust/backend/rust-constexpr.cc:5154
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:8340 rust/backend/rust-constexpr.cc:5163
+#: cp/constexpr.cc:8347 rust/backend/rust-constexpr.cc:5163
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8355 rust/backend/rust-constexpr.cc:5179
+#: cp/constexpr.cc:8362 rust/backend/rust-constexpr.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:8366 rust/backend/rust-constexpr.cc:5191
+#: cp/constexpr.cc:8373 rust/backend/rust-constexpr.cc:5191
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:8384 rust/backend/rust-constexpr.cc:5209
+#: cp/constexpr.cc:8391 rust/backend/rust-constexpr.cc:5209
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9009 rust/backend/rust-constexpr.cc:5663
+#: cp/constexpr.cc:9016 rust/backend/rust-constexpr.cc:5663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/constexpr.cc:9251
+#: cp/constexpr.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:9254
+#: cp/constexpr.cc:9261
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9310 rust/backend/rust-constexpr.cc:5889
+#: cp/constexpr.cc:9317 rust/backend/rust-constexpr.cc:5889
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/constexpr.cc:9344 rust/backend/rust-constexpr.cc:5917
+#: cp/constexpr.cc:9351 rust/backend/rust-constexpr.cc:5917
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 物件 %qE 與執行緒本地或自動貯藏體並非常數運算式"
 
-#: cp/constexpr.cc:9383
+#: cp/constexpr.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:9532
+#: cp/constexpr.cc:9539
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:9544
+#: cp/constexpr.cc:9551
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:9610
+#: cp/constexpr.cc:9617
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "虛函式不能是夥伴"
 
-#: cp/constexpr.cc:9626
+#: cp/constexpr.cc:9633
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:9689
+#: cp/constexpr.cc:9696
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.cc:9750
+#: cp/constexpr.cc:9757
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.cc:9758
+#: cp/constexpr.cc:9765
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.cc:9835 rust/backend/rust-constexpr.cc:6248
+#: cp/constexpr.cc:9842 rust/backend/rust-constexpr.cc:6248
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.cc:9936 rust/backend/rust-constexpr.cc:6346
+#: cp/constexpr.cc:9943 rust/backend/rust-constexpr.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:10005
+#: cp/constexpr.cc:10012
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:10018
+#: cp/constexpr.cc:10025
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "non-constant 陣列初始化"
 
-#: cp/constexpr.cc:10066 rust/backend/rust-constexpr.cc:6424
+#: cp/constexpr.cc:10073 rust/backend/rust-constexpr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/constexpr.cc:10097 rust/backend/rust-constexpr.cc:6435
+#: cp/constexpr.cc:10104 rust/backend/rust-constexpr.cc:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
@@ -54016,7 +54026,7 @@ msgstr ""
 msgid "%<return_void%> declared here"
 msgstr "%qD 被宣告在此"
 
-#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4310
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4314
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "no member named %qE in %qT"
@@ -54122,7 +54132,7 @@ msgstr "%<__builtin_prefetch%> 的第三個引數必須是一個常數"
 msgid "no suspend point info for %qD"
 msgstr "沒有前一個原型用於 %qD"
 
-#: cp/coroutines.cc:2120 cp/coroutines.cc:4684
+#: cp/coroutines.cc:2120 cp/coroutines.cc:4688
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54144,23 +54154,23 @@ msgstr "指標不能做為 case 常數"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4689
+#: cp/coroutines.cc:4693
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4692
+#: cp/coroutines.cc:4696
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4721
+#: cp/coroutines.cc:4725
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5118
+#: cp/coroutines.cc:5122
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
@@ -54656,7 +54666,7 @@ msgstr "從先前的宣告 %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl.cc:1391 cp/decl.cc:16146
+#: cp/decl.cc:1391 cp/decl.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -55095,2363 +55105,2363 @@ msgstr "%qD 不是一個函式範本"
 msgid "%q#T is not a class"
 msgstr "%q#T 並非類別"
 
-#: cp/decl.cc:4328 cp/decl.cc:4429
+#: cp/decl.cc:4338 cp/decl.cc:4439
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類別範本，在%q#T 中 "
 
-#: cp/decl.cc:4329
+#: cp/decl.cc:4339
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/decl.cc:4342
+#: cp/decl.cc:4352
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "查找的 %qT 在中 %qT 是模稜兩可的"
 
-#: cp/decl.cc:4351
+#: cp/decl.cc:4361
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非類別模板"
 
-#: cp/decl.cc:4364
+#: cp/decl.cc:4374
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非型態"
 
-#: cp/decl.cc:4438
+#: cp/decl.cc:4448
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "範本參數與範本不符"
 
-#: cp/decl.cc:4795
+#: cp/decl.cc:4805
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求的對齊邊界不是 2 的某次方"
 
-#: cp/decl.cc:4969
+#: cp/decl.cc:4979
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4973
+#: cp/decl.cc:4983
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4996
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:4991
+#: cp/decl.cc:5001
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5317
+#: cp/decl.cc:5327
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/decl.cc:5327 cp/parser.cc:23020
+#: cp/decl.cc:5337 cp/parser.cc:23020
 #, fuzzy, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
 
-#: cp/decl.cc:5356
+#: cp/decl.cc:5366
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "匿名結構不在具名類型內"
 
-#: cp/decl.cc:5368
+#: cp/decl.cc:5378
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有建構式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.cc:5371
+#: cp/decl.cc:5381
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有構構函式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.cc:5374
+#: cp/decl.cc:5384
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/decl.cc:5393
+#: cp/decl.cc:5403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:5396
+#: cp/decl.cc:5406
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "屬性用於 %q#T 必須追隨 %qs 關鍵字"
 
-#: cp/decl.cc:5438
+#: cp/decl.cc:5448
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一個宣告指定了多個類型"
 
-#: cp/decl.cc:5443
+#: cp/decl.cc:5453
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "對 C++ 內建類型 %qT 的重宣告"
 
-#: cp/decl.cc:5460
+#: cp/decl.cc:5470
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: cp/decl.cc:5493
+#: cp/decl.cc:5503
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 宣告中缺少類型名"
 
-#: cp/decl.cc:5501
+#: cp/decl.cc:5511
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允許匿名結構"
 
-#: cp/decl.cc:5508
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.cc:5511
+#: cp/decl.cc:5521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.cc:5516
+#: cp/decl.cc:5526
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> 只能在類別中指定"
 
-#: cp/decl.cc:5519
+#: cp/decl.cc:5529
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能為建構式指定 %<explicit%>"
 
-#: cp/decl.cc:5522
+#: cp/decl.cc:5532
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.cc:5526
+#: cp/decl.cc:5536
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.cc:5530
+#: cp/decl.cc:5540
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.cc:5534
+#: cp/decl.cc:5544
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.cc:5538
+#: cp/decl.cc:5548
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.cc:5542
+#: cp/decl.cc:5552
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> 被忽略在中這個宣告"
 
-#: cp/decl.cc:5545 cp/decl.cc:5548 cp/decl.cc:5551
+#: cp/decl.cc:5555 cp/decl.cc:5558 cp/decl.cc:5561
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/decl.cc:5573
+#: cp/decl.cc:5583
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/decl.cc:5576
+#: cp/decl.cc:5586
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/decl.cc:5655
+#: cp/decl.cc:5665
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略屬性套用到類別型態 %qT 外側的定義"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5659
+#: cp/decl.cc:5669
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略屬性套用到附屬型態 %qT 而無需關聯的宣告"
 
-#: cp/decl.cc:5725 cp/decl2.cc:1021
+#: cp/decl.cc:5735 cp/decl2.cc:1021
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD 被初始化的 (使用 decltype 做為替代)"
 
-#: cp/decl.cc:5738
+#: cp/decl.cc:5748
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D 宣告有 %<extern%> 並被初始化"
 
-#: cp/decl.cc:5776
+#: cp/decl.cc:5786
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/decl.cc:5800
+#: cp/decl.cc:5810
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/decl.cc:5808
+#: cp/decl.cc:5818
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D 宣告為範本"
 
-#: cp/decl.cc:5809
+#: cp/decl.cc:5819
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/decl.cc:5821
+#: cp/decl.cc:5831
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允許將 %<%T::%D%> 定義為 %<%T::%D%>"
 
-#: cp/decl.cc:5833
+#: cp/decl.cc:5843
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允許成員 %qD 的初始化"
 
-#: cp/decl.cc:5883 cp/decl.cc:5887
+#: cp/decl.cc:5893 cp/decl.cc:5897
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.cc:5905
+#: cp/decl.cc:5915
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.cc:5941
+#: cp/decl.cc:5951
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:5947
+#: cp/decl.cc:5957
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:6012
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "變數 %q#D 有初始值設定，但是類型不完全"
 
-#: cp/decl.cc:6018 cp/decl.cc:7337
+#: cp/decl.cc:6028 cp/decl.cc:7347
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "陣列 %q#D 的元素類型不完全"
 
-#: cp/decl.cc:6028
+#: cp/decl.cc:6038
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合 %q#D 類型不完全，無法被定義"
 
-#: cp/decl.cc:6095
+#: cp/decl.cc:6105
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD 宣告為參照卻未被初始化"
 
-#: cp/decl.cc:6178
+#: cp/decl.cc:6188
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名稱已用於 GNU-style 指定的初始設定式用於陣列"
 
-#: cp/decl.cc:6184
+#: cp/decl.cc:6194
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名稱 %qD 用在 GNU 風格的陣列指定元素初始值設定中"
 
-#: cp/decl.cc:6203
+#: cp/decl.cc:6213
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值設定不受支援"
 
-#: cp/decl.cc:6207
+#: cp/decl.cc:6217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.cc:6268
+#: cp/decl.cc:6278
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值設定無法決定 %qD 的大小"
 
-#: cp/decl.cc:6275
+#: cp/decl.cc:6285
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD 缺少陣列大小"
 
-#: cp/decl.cc:6287
+#: cp/decl.cc:6297
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小為 0 的陣列 %qD"
 
-#: cp/decl.cc:6327
+#: cp/decl.cc:6337
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "貯藏大小的 %qD isn%'t 已知"
 
-#: cp/decl.cc:6352
+#: cp/decl.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "貯藏大小的 %qD isn%'t 常數"
 
-#: cp/decl.cc:6435
+#: cp/decl.cc:6445
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.cc:6439
+#: cp/decl.cc:6449
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.cc:6445
+#: cp/decl.cc:6455
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  您可以解決方法這個由移除初始設定式"
 
-#: cp/decl.cc:6487 rust/backend/rust-tree.cc:3230
+#: cp/decl.cc:6497 rust/backend/rust-tree.cc:3230
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常數 %qD"
 
-#: cp/decl.cc:6494 rust/backend/rust-tree.cc:3237
+#: cp/decl.cc:6504 rust/backend/rust-tree.cc:3237
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.cc:6503 rust/backend/rust-tree.cc:3246
+#: cp/decl.cc:6513 rust/backend/rust-tree.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.cc:6511
+#: cp/decl.cc:6521
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T 沒有任何 user-provided 預設建構函式"
 
-#: cp/decl.cc:6515
+#: cp/decl.cc:6525
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建構子未被 user-provided 因為它是明確的缺席在中類別本體"
 
-#: cp/decl.cc:6518
+#: cp/decl.cc:6528
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建構子不初始化 %q+#D"
 
-#: cp/decl.cc:6710
+#: cp/decl.cc:6720
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無效類型 %qT 做為類型為 %qT 的向量的初始化設定"
 
-#: cp/decl.cc:6782
+#: cp/decl.cc:6792
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT 的初始化設定必須在大括號內"
 
-#: cp/decl.cc:6826
+#: cp/decl.cc:6836
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E]=%>已用於 GNU-style 指定的初始設定式用於類別 %qT"
 
-#: cp/decl.cc:6839
+#: cp/decl.cc:6849
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/decl.cc:6863
+#: cp/decl.cc:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/decl.cc:6918
+#: cp/decl.cc:6928
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/decl.cc:6968
+#: cp/decl.cc:6978
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示項 %qE 外側彙總初始設定式"
 
-#: cp/decl.cc:7007 cp/decl.cc:7295 cp/typeck2.cc:1597 cp/typeck2.cc:1927
-#: cp/typeck2.cc:1975 cp/typeck2.cc:2022
+#: cp/decl.cc:7017 cp/decl.cc:7305 cp/typeck2.cc:1595 cp/typeck2.cc:1925
+#: cp/typeck2.cc:1973 cp/typeck2.cc:2020
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT 的初始值設定項太多"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7059
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.cc:7059
+#: cp/decl.cc:7069
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.cc:7192
+#: cp/decl.cc:7202
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: cp/decl.cc:7325
+#: cp/decl.cc:7335
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.cc:7339
+#: cp/decl.cc:7349
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "元件的陣列 %q#T 有不完整型態"
 
-#: cp/decl.cc:7352
+#: cp/decl.cc:7362
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "variable-sized 複合實字"
 
-#: cp/decl.cc:7408
+#: cp/decl.cc:7418
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D 有不完整型態"
 
-#: cp/decl.cc:7429
+#: cp/decl.cc:7439
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "純量物件 %qD 需求一個元件在中初始設定式"
 
-#: cp/decl.cc:7474
+#: cp/decl.cc:7484
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在中 C++98 %qD 必須被初始化的由建構子，無法由 %<{...}%>"
 
-#: cp/decl.cc:7617
+#: cp/decl.cc:7627
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "陣列 %qD 被有括號的字面字串 %qE 所初始化"
 
-#: cp/decl.cc:7656
+#: cp/decl.cc:7666
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "建構式中對靜態成員的初始化無效"
 
-#: cp/decl.cc:7658
+#: cp/decl.cc:7668
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.cc:7661
+#: cp/decl.cc:7671
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.cc:7666
+#: cp/decl.cc:7676
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一個類別外的初始化)"
 
-#: cp/decl.cc:7868
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/decl.cc:8125
+#: cp/decl.cc:8135
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.cc:8149
+#: cp/decl.cc:8159
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/decl.cc:8154
+#: cp/decl.cc:8164
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/decl.cc:8159
+#: cp/decl.cc:8169
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8164
+#: cp/decl.cc:8174
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8169
+#: cp/decl.cc:8179
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8219
+#: cp/decl.cc:8229
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/decl.cc:8240 cp/decl.cc:14789
+#: cp/decl.cc:8250 cp/decl.cc:14799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/decl.cc:8244 cp/decl.cc:14793
+#: cp/decl.cc:8254 cp/decl.cc:14803
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.cc:8289 cp/decl.cc:14756
+#: cp/decl.cc:8299 cp/decl.cc:14766
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "宣告的 %q#D 沒有任何初始設定式"
 
-#: cp/decl.cc:8325
+#: cp/decl.cc:8335
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "無效的使用的成員函式 (did 您忘記%<()%>?)"
 
-#: cp/decl.cc:8336
+#: cp/decl.cc:8346
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.cc:8466
+#: cp/decl.cc:8476
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.cc:8525
+#: cp/decl.cc:8535
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隱藏了早先的類型宣告 %q#D"
 
-#: cp/decl.cc:8568
+#: cp/decl.cc:8578
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 屬性只有套用到變數和函式"
 
-#: cp/decl.cc:8760
+#: cp/decl.cc:8770
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函式 %q#D 像變數一樣被初始化"
 
-#: cp/decl.cc:8871
+#: cp/decl.cc:8881
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  不能在 %q+D 使用過時的繫結，因為它有解構函式"
 
-#: cp/decl.cc:8874
+#: cp/decl.cc:8884
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:8881
+#: cp/decl.cc:8891
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT 是 %qT 不可存取的基礎類別"
 
-#: cp/decl.cc:8907
+#: cp/decl.cc:8917
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:8916
+#: cp/decl.cc:8926
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9126
+#: cp/decl.cc:9136
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.cc:9142
+#: cp/decl.cc:9152
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: cp/decl.cc:9151 cp/decl.cc:9230
+#: cp/decl.cc:9161 cp/decl.cc:9240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs 指定的用於結構欄位"
 
-#: cp/decl.cc:9155
+#: cp/decl.cc:9165
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9158
+#: cp/decl.cc:9168
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9199
+#: cp/decl.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.cc:9223
+#: cp/decl.cc:9233
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.cc:9232
+#: cp/decl.cc:9242
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9253
+#: cp/decl.cc:9263
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9259
+#: cp/decl.cc:9269
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.cc:9288
+#: cp/decl.cc:9298
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.cc:9293
+#: cp/decl.cc:9303
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/decl.cc:9298
+#: cp/decl.cc:9308
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "無法分解位址"
 
-#: cp/decl.cc:9304
+#: cp/decl.cc:9314
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "來源是的不完整類別型態"
 
-#: cp/decl.cc:9313
+#: cp/decl.cc:9323
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "無法套用 %<offsetof%> 到靜態資料成員 %qD"
 
-#: cp/decl.cc:9780
+#: cp/decl.cc:9790
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:9783
+#: cp/decl.cc:9793
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/decl.cc:9788
+#: cp/decl.cc:9798
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10007
+#: cp/decl.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始設定式失敗到決定大小的 %qT"
 
-#: cp/decl.cc:10011
+#: cp/decl.cc:10021
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "陣列大小缺少的在中 %qT"
 
-#: cp/decl.cc:10014
+#: cp/decl.cc:10024
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "zero-size 陣列 %qT"
 
-#: cp/decl.cc:10030
+#: cp/decl.cc:10040
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的解構函式不能做為成員"
 
-#: cp/decl.cc:10032
+#: cp/decl.cc:10042
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的建構式不能做為成員"
 
-#: cp/decl.cc:10058
+#: cp/decl.cc:10068
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD 宣告的做為 %<virtual%> 變數"
 
-#: cp/decl.cc:10060
+#: cp/decl.cc:10070
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中變數宣告"
 
-#: cp/decl.cc:10066
+#: cp/decl.cc:10076
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD 宣告的做為 %<virtual%> 參數"
 
-#: cp/decl.cc:10069
+#: cp/decl.cc:10079
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD 宣告的做為 %<inline%> 參數"
 
-#: cp/decl.cc:10071
+#: cp/decl.cc:10081
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中參數宣告"
 
-#: cp/decl.cc:10077
+#: cp/decl.cc:10087
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD 宣告的做為 %<virtual%> 型態"
 
-#: cp/decl.cc:10080
+#: cp/decl.cc:10090
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD 宣告的做為 %<inline%> 型態"
 
-#: cp/decl.cc:10082
+#: cp/decl.cc:10092
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中類型宣告"
 
-#: cp/decl.cc:10088
+#: cp/decl.cc:10098
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD 宣告的做為 %<virtual%> 欄位"
 
-#: cp/decl.cc:10091
+#: cp/decl.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD 宣告的做為 %<inline%> 欄位"
 
-#: cp/decl.cc:10093
+#: cp/decl.cc:10103
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中欄位宣告"
 
-#: cp/decl.cc:10100
+#: cp/decl.cc:10110
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.cc:10107
+#: cp/decl.cc:10117
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D 宣告時有異常指定"
 
-#: cp/decl.cc:10139
+#: cp/decl.cc:10149
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD 的定義不在包含 %qT 的命名空間中"
 
-#: cp/decl.cc:10179
+#: cp/decl.cc:10189
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "靜態成員函式 %q#D 的宣告帶有類型限定符"
 
-#: cp/decl.cc:10190
+#: cp/decl.cc:10200
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: cp/decl.cc:10197
+#: cp/decl.cc:10207
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.cc:10200
+#: cp/decl.cc:10210
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法 %qD 回傳非 Java 類型 %qT"
 
-#: cp/decl.cc:10276
+#: cp/decl.cc:10286
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/decl.cc:10305
+#: cp/decl.cc:10315
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.cc:10315
+#: cp/decl.cc:10325
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD 不是一個範本函式"
 
-#: cp/decl.cc:10360
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在夥伴宣告中定義明確特例化 %qD"
 
-#: cp/decl.cc:10371
+#: cp/decl.cc:10381
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本範本的宣告中對範本識別碼 %qD 的使用無效"
 
-#: cp/decl.cc:10389
+#: cp/decl.cc:10399
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "夥伴範本特例化 %qD 中不允許出現預設參數"
 
-#: cp/decl.cc:10398
+#: cp/decl.cc:10408
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> 不允許用於夥伴範本特例化 %qD 的宣告"
 
-#: cp/decl.cc:10415
+#: cp/decl.cc:10425
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.cc:10460
+#: cp/decl.cc:10470
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10473
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.cc:10466 cp/decl.cc:10469
+#: cp/decl.cc:10476 cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.cc:10471
+#: cp/decl.cc:10481
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.cc:10533
+#: cp/decl.cc:10543
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10534
+#: cp/decl.cc:10544
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10552
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10543
+#: cp/decl.cc:10553
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10555
+#: cp/decl.cc:10565
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.cc:10563
+#: cp/decl.cc:10573
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.cc:10569
+#: cp/decl.cc:10579
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.cc:10582
+#: cp/decl.cc:10592
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "實字運算子與 C 鏈結"
 
-#: cp/decl.cc:10592
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 有無效的引數清單"
 
-#: cp/decl.cc:10600
+#: cp/decl.cc:10610
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.cc:10606
+#: cp/decl.cc:10616
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "浮點數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.cc:10613
+#: cp/decl.cc:10623
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
 
-#: cp/decl.cc:10618
+#: cp/decl.cc:10628
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.cc:10704
+#: cp/decl.cc:10714
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> 必須回傳 %<int%>"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10754
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隱含宣告的 %qD 的定義"
 
-#: cp/decl.cc:10749
+#: cp/decl.cc:10759
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "定義的 explicitly-defaulted %q+D"
 
-#: cp/decl.cc:10751
+#: cp/decl.cc:10761
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D 明確的缺席在此"
 
-#: cp/decl.cc:10768
+#: cp/decl.cc:10778
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成員函式 %q#D 未在類別 %qT 中宣告"
 
-#: cp/decl.cc:10961
+#: cp/decl.cc:10971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.cc:10970
+#: cp/decl.cc:10980
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: cp/decl.cc:10976
+#: cp/decl.cc:10986
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.cc:10983
+#: cp/decl.cc:10993
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:10986
+#: cp/decl.cc:10996
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.cc:11108
+#: cp/decl.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的不完整型態"
 
-#: cp/decl.cc:11112
+#: cp/decl.cc:11122
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> 所需自 in-class 初始化的靜態資料成員 %q#D 的 non-integral 型態"
 
-#: cp/decl.cc:11116
+#: cp/decl.cc:11126
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的 non-literal 型態"
 
-#: cp/decl.cc:11127
+#: cp/decl.cc:11137
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "類別中對具有非整數類型 %qT 的靜態資料成員的初始化無效"
 
-#: cp/decl.cc:11132
+#: cp/decl.cc:11142
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允許在類別內初始化非常數靜態成員 %qD"
 
-#: cp/decl.cc:11137
+#: cp/decl.cc:11147
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允許初始化成員常數 %qD，因為它有非整數的類型 %qT"
 
-#: cp/decl.cc:11248
+#: cp/decl.cc:11258
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "陣列 %qD 的大小具有非整數類型 %qT"
 
-#: cp/decl.cc:11251
+#: cp/decl.cc:11261
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/decl.cc:11282 cp/decl.cc:11354
+#: cp/decl.cc:11292 cp/decl.cc:11364
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.cc:11286 cp/decl.cc:11357
+#: cp/decl.cc:11296 cp/decl.cc:11367
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.cc:11337
+#: cp/decl.cc:11347
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.cc:11340
+#: cp/decl.cc:11350
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允許大小為 0 的陣列"
 
-#: cp/decl.cc:11364
+#: cp/decl.cc:11374
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++禁止變數長度陣列 %qD"
 
-#: cp/decl.cc:11367
+#: cp/decl.cc:11377
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++禁止變數長度陣列"
 
-#: cp/decl.cc:11373
+#: cp/decl.cc:11383
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "變數長度陣列 %qD 被使用"
 
-#: cp/decl.cc:11376
+#: cp/decl.cc:11386
 #, fuzzy, gcc-internal-format
 msgid "variable length array is used"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.cc:11428
+#: cp/decl.cc:11438
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "陣列維數溢出"
 
-#: cp/decl.cc:11488
+#: cp/decl.cc:11498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.cc:11491
+#: cp/decl.cc:11501
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/decl.cc:11501
+#: cp/decl.cc:11511
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "宣告的 %qD 做為陣列的虛值"
 
-#: cp/decl.cc:11503
+#: cp/decl.cc:11513
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "建立陣列的虛值"
 
-#: cp/decl.cc:11508
+#: cp/decl.cc:11518
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "宣告的 %qD 做為陣列的函式"
 
-#: cp/decl.cc:11510
+#: cp/decl.cc:11520
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "建立陣列的函式"
 
-#: cp/decl.cc:11515
+#: cp/decl.cc:11525
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "宣告的 %qD 做為陣列的參考"
 
-#: cp/decl.cc:11517
+#: cp/decl.cc:11527
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "建立陣列的參考"
 
-#: cp/decl.cc:11522
+#: cp/decl.cc:11532
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "宣告的 %qD 做為陣列的函式成員"
 
-#: cp/decl.cc:11525
+#: cp/decl.cc:11535
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "建立陣列的函式成員"
 
-#: cp/decl.cc:11543
+#: cp/decl.cc:11553
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.cc:11547
+#: cp/decl.cc:11557
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "宣告多維陣列必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.cc:11561
+#: cp/decl.cc:11571
 #, fuzzy, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.cc:11637
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "為建構式指定回傳值無效"
 
-#: cp/decl.cc:11640
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11651
+#: cp/decl.cc:11661
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.cc:11654
+#: cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "為 %<operator %T%> 指定了回傳值"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11680
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11679
+#: cp/decl.cc:11689
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.cc:11682
+#: cp/decl.cc:11692
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11686
+#: cp/decl.cc:11696
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/decl.cc:11695
+#: cp/decl.cc:11705
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.cc:11716
+#: cp/decl.cc:11726
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名變數或欄位宣告為 void"
 
-#: cp/decl.cc:11724
+#: cp/decl.cc:11734
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "變數或欄位宣告為 void"
 
-#: cp/decl.cc:11739
+#: cp/decl.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.cc:11744
+#: cp/decl.cc:11754
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:11800
+#: cp/decl.cc:11810
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:11806
+#: cp/decl.cc:11816
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.cc:12022
+#: cp/decl.cc:12032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "無效的使用的限定名稱 %<::%D%>"
 
-#: cp/decl.cc:12025 cp/decl.cc:12047
+#: cp/decl.cc:12035 cp/decl.cc:12057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "無效的使用的限定名稱 %<%T::%D%>"
 
-#: cp/decl.cc:12028
+#: cp/decl.cc:12038
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "無效的使用的限定名稱 %<%D::%D%>"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12048
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/decl.cc:12062
+#: cp/decl.cc:12072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.cc:12069
+#: cp/decl.cc:12079
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "%qD 未宣告為成員"
 
-#: cp/decl.cc:12097
+#: cp/decl.cc:12107
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少宣告識別碼：使用了保留字 %qD"
 
-#: cp/decl.cc:12148
+#: cp/decl.cc:12158
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函式定義不宣告參數"
 
-#: cp/decl.cc:12156 cp/decl.cc:12165 cp/decl.cc:14023
+#: cp/decl.cc:12166 cp/decl.cc:12175 cp/decl.cc:14033
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.cc:12173
+#: cp/decl.cc:12183
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "宣告的 %qD 做為 %<typedef%>"
 
-#: cp/decl.cc:12178
+#: cp/decl.cc:12188
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "宣告的 %qD 做為參數"
 
-#: cp/decl.cc:12213
+#: cp/decl.cc:12223
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "未指定類別"
 
-#: cp/decl.cc:12220 cp/decl.cc:12227 cp/decl.cc:12234 cp/decl.cc:12241
+#: cp/decl.cc:12230 cp/decl.cc:12237 cp/decl.cc:12244 cp/decl.cc:12251
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.cc:12252
+#: cp/decl.cc:12262
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12262
+#: cp/decl.cc:12272
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs 的宣告指定了兩個以上的資料類型"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.cc:12365 cp/decl.cc:12369 cp/decl.cc:12372
+#: cp/decl.cc:12375 cp/decl.cc:12379 cp/decl.cc:12382
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允許宣告無類型的 %qs"
 
-#: cp/decl.cc:12389
+#: cp/decl.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%>未被支援由這個目標"
 
-#: cp/decl.cc:12397
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++不支援 %<__int128%>用於 %qs"
 
-#: cp/decl.cc:12451
+#: cp/decl.cc:12461
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> 和 %<unsigned%>指定的一起用於 %qs"
 
-#: cp/decl.cc:12457
+#: cp/decl.cc:12467
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> 和 %<short%>指定的一起用於 %qs"
 
-#: cp/decl.cc:12465
+#: cp/decl.cc:12475
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "%qs 沒有指定類別名"
 
-#: cp/decl.cc:12471
+#: cp/decl.cc:12481
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qD"
 msgstr "%qs 沒有指定類別名"
 
-#: cp/decl.cc:12483
+#: cp/decl.cc:12493
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/decl.cc:12485
+#: cp/decl.cc:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: cp/decl.cc:12552
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "對 %qs 而言無效的複數"
 
-#: cp/decl.cc:12596
+#: cp/decl.cc:12606
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12622
+#: cp/decl.cc:12632
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.cc:12631
+#: cp/decl.cc:12641
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.cc:12644
+#: cp/decl.cc:12654
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "參數宣告中出現的 typedef 宣告無效"
 
-#: cp/decl.cc:12651
+#: cp/decl.cc:12661
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "貯藏類別指定的用於模板參數 %qs"
 
-#: cp/decl.cc:12661 cp/decl.cc:12838
+#: cp/decl.cc:12671 cp/decl.cc:12848
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "為參數 %qs 指定了存儲類別"
 
-#: cp/decl.cc:12669 cp/decl.cc:12678 cp/decl.cc:12684 cp/decl.cc:12690
+#: cp/decl.cc:12679 cp/decl.cc:12688 cp/decl.cc:12694 cp/decl.cc:12700
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.cc:12700
+#: cp/decl.cc:12710
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.cc:12710 cp/decl.cc:12713 cp/decl.cc:12715 cp/decl.cc:12718
-#: cp/decl.cc:12728 cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12752
+#: cp/decl.cc:12720 cp/decl.cc:12723 cp/decl.cc:12725 cp/decl.cc:12728
+#: cp/decl.cc:12738 cp/decl.cc:12748 cp/decl.cc:12758 cp/decl.cc:12762
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:12722 cp/decl.cc:12744
+#: cp/decl.cc:12732 cp/decl.cc:12754
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:12732
+#: cp/decl.cc:12742
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "無效的輸入宣告"
 
-#: cp/decl.cc:12756
+#: cp/decl.cc:12766
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12768
+#: cp/decl.cc:12778
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:12771
+#: cp/decl.cc:12781
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:12779
+#: cp/decl.cc:12789
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:12810
+#: cp/decl.cc:12820
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.cc:12836
+#: cp/decl.cc:12846
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.cc:12850
+#: cp/decl.cc:12860
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: cp/decl.cc:12855
+#: cp/decl.cc:12865
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在頂層將 %qs 宣告為 %<auto%>"
 
-#: cp/decl.cc:12863
+#: cp/decl.cc:12873
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函式作用欄位的 %qs 隱含為 auto，卻被宣告為 %<__thread%>"
 
-#: cp/decl.cc:12877
+#: cp/decl.cc:12887
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "為夥伴函式宣告指定了無效的存儲類別"
 
-#: cp/decl.cc:12909 cp/decl.cc:14401 cp/parser.cc:14950 cp/parser.cc:20813
+#: cp/decl.cc:12919 cp/decl.cc:14411 cp/parser.cc:14950 cp/parser.cc:20813
 #: cp/parser.cc:27390
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: cp/decl.cc:12910
+#: cp/decl.cc:12920
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:12978
+#: cp/decl.cc:12988
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.cc:12984
+#: cp/decl.cc:12994
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "需要左圓括號"
 
-#: cp/decl.cc:13033
+#: cp/decl.cc:13043
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13053
+#: cp/decl.cc:13063
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs 函式使用 %<auto%> 型態說明符而無需尾隨傳回類型"
 
-#: cp/decl.cc:13057
+#: cp/decl.cc:13067
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.cc:13069
+#: cp/decl.cc:13079
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.cc:13078
+#: cp/decl.cc:13088
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.cc:13083
+#: cp/decl.cc:13093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "無效的使用的 %<auto%>"
 
-#: cp/decl.cc:13095
+#: cp/decl.cc:13105
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13114
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13117
+#: cp/decl.cc:13127
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13131
+#: cp/decl.cc:13141
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:13134
+#: cp/decl.cc:13144
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs 函式與尾隨傳回類型無法宣告的與 %<auto%> 型態說明符"
 
-#: cp/decl.cc:13141
+#: cp/decl.cc:13151
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs 函式無法有引數"
 
-#: cp/decl.cc:13167
+#: cp/decl.cc:13177
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13179
+#: cp/decl.cc:13189
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs 宣告為回傳一個函式的函式"
 
-#: cp/decl.cc:13185
+#: cp/decl.cc:13195
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs 宣告為回傳一個陣列的函式"
 
-#: cp/decl.cc:13192
+#: cp/decl.cc:13202
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> 函式回傳了一個非 void 的回傳值"
 
-#: cp/decl.cc:13225
+#: cp/decl.cc:13235
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/decl.cc:13227
+#: cp/decl.cc:13237
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.cc:13232
+#: cp/decl.cc:13242
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.cc:13233
+#: cp/decl.cc:13243
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.cc:13241
+#: cp/decl.cc:13251
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.cc:13242
+#: cp/decl.cc:13252
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.cc:13260
+#: cp/decl.cc:13270
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "建構式不能被宣告為虛函式"
 
-#: cp/decl.cc:13277
+#: cp/decl.cc:13287
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.cc:13282
+#: cp/decl.cc:13292
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.cc:13286
+#: cp/decl.cc:13296
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "can%'t 定義朋友函式 %qs 在中區域類別定義"
 
-#: cp/decl.cc:13296
+#: cp/decl.cc:13306
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13300
+#: cp/decl.cc:13310
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13338
+#: cp/decl.cc:13348
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "解構函式不能有參數"
 
-#: cp/decl.cc:13395
+#: cp/decl.cc:13405
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.cc:13408 cp/decl.cc:13415
+#: cp/decl.cc:13418 cp/decl.cc:13425
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/decl.cc:13417
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "無法宣告參照 %q#T 成員的指標"
 
-#: cp/decl.cc:13446
+#: cp/decl.cc:13456
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/decl.cc:13447
+#: cp/decl.cc:13457
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.cc:13520
+#: cp/decl.cc:13530
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "無法宣告參考到 %q#T, 該項並非 typedef 或模板型態引數"
 
-#: cp/decl.cc:13600
+#: cp/decl.cc:13610
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "範本識別碼 %qD 做為宣告"
 
-#: cp/decl.cc:13626
+#: cp/decl.cc:13636
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成員函式隱含地成為所屬類別的夥伴"
 
-#: cp/decl.cc:13631
+#: cp/decl.cc:13641
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多餘的限定 %<%T::%> 於成員 %qs 上"
 
-#: cp/decl.cc:13661
+#: cp/decl.cc:13671
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "無法定義成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.cc:13663
+#: cp/decl.cc:13673
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "無法宣告成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.cc:13671
+#: cp/decl.cc:13681
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "無法宣告成員 %<%T::%s%> 於 %qT 之內"
 
-#: cp/decl.cc:13711
+#: cp/decl.cc:13721
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "non-parameter %qs 無法參數包裝"
 
-#: cp/decl.cc:13720
+#: cp/decl.cc:13730
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "資料成員不能具有可變類型 %qT"
 
-#: cp/decl.cc:13723
+#: cp/decl.cc:13733
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/decl.cc:13734
+#: cp/decl.cc:13744
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.cc:13737
+#: cp/decl.cc:13747
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: cp/decl.cc:13740
+#: cp/decl.cc:13750
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/decl.cc:13750
+#: cp/decl.cc:13760
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:13757
+#: cp/decl.cc:13767
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非物件成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:13763
+#: cp/decl.cc:13773
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:13769
+#: cp/decl.cc:13779
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "靜態 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:13775
+#: cp/decl.cc:13785
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常數 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:13781
+#: cp/decl.cc:13791
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: cp/decl.cc:13797
+#: cp/decl.cc:13807
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.cc:13800
+#: cp/decl.cc:13810
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.cc:13826
+#: cp/decl.cc:13836
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.cc:13829
+#: cp/decl.cc:13839
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef 宣告 %<auto%>"
 
-#: cp/decl.cc:13834
+#: cp/decl.cc:13844
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13848
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/decl.cc:13864
+#: cp/decl.cc:13874
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允許嵌類別的類型 %qD 與其所屬的類別同名"
 
-#: cp/decl.cc:13953
+#: cp/decl.cc:13963
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "夥伴函式宣告中出現了 %<inline%>"
 
-#: cp/decl.cc:13961
+#: cp/decl.cc:13971
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "範本參數不能是夥伴"
 
-#: cp/decl.cc:13963
+#: cp/decl.cc:13973
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "夥伴宣告需要 class，即 %<friend class %T::%D%>"
 
-#: cp/decl.cc:13967
+#: cp/decl.cc:13977
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "夥伴宣告需要 class，即 %<friend %#T%>"
 
-#: cp/decl.cc:13980
+#: cp/decl.cc:13990
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "試圖讓 %qT 成為全域欄位的夥伴"
 
-#: cp/decl.cc:14000
+#: cp/decl.cc:14010
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成員函式類型上的限定符無效"
 
-#: cp/decl.cc:14004
+#: cp/decl.cc:14014
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14014
+#: cp/decl.cc:14024
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象宣告 %qT 做為宣告"
 
-#: cp/decl.cc:14029
+#: cp/decl.cc:14039
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.cc:14048
+#: cp/decl.cc:14058
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在參數宣告中使用 %<::%>"
 
-#: cp/decl.cc:14057 cp/parser.cc:20247
+#: cp/decl.cc:14067 cp/parser.cc:20247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能將參數 %q+D 宣告為具有抽象類型 %qT"
 
-#: cp/decl.cc:14064
+#: cp/decl.cc:14074
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14067
+#: cp/decl.cc:14077
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14073
+#: cp/decl.cc:14083
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.cc:14076
+#: cp/decl.cc:14086
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.cc:14127 cp/parser.cc:3561
+#: cp/decl.cc:14137 cp/parser.cc:3561
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用範本名 %qE 時不帶引數表無效"
 
-#: cp/decl.cc:14131
+#: cp/decl.cc:14141
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非靜態資料成員宣告 %<auto%>"
 
-#: cp/decl.cc:14152
+#: cp/decl.cc:14162
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14165
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14171
+#: cp/decl.cc:14181
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "錯誤地使用了 %<::%>"
 
-#: cp/decl.cc:14192
+#: cp/decl.cc:14202
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "宣告的函式 %qD 在中無效的語境"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.cc:14212
+#: cp/decl.cc:14222
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD 不能宣告為虛函式，因為它總是靜態的"
 
-#: cp/decl.cc:14226
+#: cp/decl.cc:14236
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在解構函式 %qD 中的夥伴宣告需要限定名"
 
-#: cp/decl.cc:14233
+#: cp/decl.cc:14243
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/decl.cc:14240 cp/decl.cc:14253
+#: cp/decl.cc:14250 cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14269
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "預期的限定名稱在中朋友宣告用於建構子 %qD"
 
-#: cp/decl.cc:14268
+#: cp/decl.cc:14278
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.cc:14274
+#: cp/decl.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.cc:14282 cp/decl.cc:14624
+#: cp/decl.cc:14292 cp/decl.cc:14634
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "無法開啟 %s"
 
-#: cp/decl.cc:14291
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/decl.cc:14294
+#: cp/decl.cc:14304
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "原來的型態宣告的在此"
 
-#: cp/decl.cc:14356
+#: cp/decl.cc:14366
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: cp/decl.cc:14361
+#: cp/decl.cc:14371
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名稱 %qT 類型不完全"
 
-#: cp/decl.cc:14381
+#: cp/decl.cc:14391
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.cc:14402 cp/parser.cc:20814 cp/parser.cc:27391
+#: cp/decl.cc:14412 cp/parser.cc:20814 cp/parser.cc:27391
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14443 cp/decl.cc:14454
+#: cp/decl.cc:14453 cp/decl.cc:14464
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.cc:14448
+#: cp/decl.cc:14458
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/decl.cc:14491 cp/decl.cc:14499 cp/decl.cc:14506 cp/decl.cc:14513
+#: cp/decl.cc:14501 cp/decl.cc:14509 cp/decl.cc:14516 cp/decl.cc:14523
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.cc:14565
+#: cp/decl.cc:14575
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<auto%> 無效"
 
-#: cp/decl.cc:14568
+#: cp/decl.cc:14578
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<register%> 無效"
 
-#: cp/decl.cc:14574
+#: cp/decl.cc:14584
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.cc:14578
+#: cp/decl.cc:14588
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.cc:14583
+#: cp/decl.cc:14593
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specifiers 在中 %qs 不允許外側類別定義"
 
-#: cp/decl.cc:14595
+#: cp/decl.cc:14605
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<static%> 無效"
 
-#: cp/decl.cc:14599
+#: cp/decl.cc:14609
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.cc:14607
+#: cp/decl.cc:14617
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虛函式 %qs 不是類別成員"
 
-#: cp/decl.cc:14614
+#: cp/decl.cc:14624
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs 定義的在中 non-class 範圍"
 
-#: cp/decl.cc:14615
+#: cp/decl.cc:14625
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs 宣告的在中 non-class 範圍"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14668
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能將成員函式 %qD 宣告為有靜態連結"
 
-#: cp/decl.cc:14667
+#: cp/decl.cc:14677
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一個函式中宣告一個靜態函式"
 
-#: cp/decl.cc:14708
+#: cp/decl.cc:14718
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "與宣告不同，定義靜態資料成員時不能使用 %<static%>"
 
-#: cp/decl.cc:14715
+#: cp/decl.cc:14725
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "靜態成員 %qD 宣告為 %<register%>"
 
-#: cp/decl.cc:14721
+#: cp/decl.cc:14731
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能明確地將成員 %q#D 宣告為有外部連結"
 
-#: cp/decl.cc:14729
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "宣告的 constexpr 變數 %qD 並非定義"
 
-#: cp/decl.cc:14736
+#: cp/decl.cc:14746
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.cc:14768
+#: cp/decl.cc:14778
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs 已初始化，卻又被宣告為 %<extern%>"
 
-#: cp/decl.cc:14773
+#: cp/decl.cc:14783
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs 既有 %<extern%> 又有初始值設定"
 
-#: cp/decl.cc:14970
+#: cp/decl.cc:14980
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "預設引數 %qE 使用 %qD"
 
-#: cp/decl.cc:14973
+#: cp/decl.cc:14983
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "預設引數 %qE 使用了局部變數 %qD"
 
-#: cp/decl.cc:15100
+#: cp/decl.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.cc:15104
+#: cp/decl.cc:15114
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.cc:15133
+#: cp/decl.cc:15143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "無效的參數類型 %qT"
 
-#: cp/decl.cc:15141
+#: cp/decl.cc:15151
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "參數 %qD 包含指標到陣列的不明約束 %qT"
 
-#: cp/decl.cc:15168
+#: cp/decl.cc:15178
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "參數 %qD 包含參考到陣列的不明約束 %qT"
 
-#: cp/decl.cc:15427
+#: cp/decl.cc:15437
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "無效的建構式：您要的可能是 %<%T (const %T&)%>"
 
-#: cp/decl.cc:15506
+#: cp/decl.cc:15516
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/decl.cc:15513
+#: cp/decl.cc:15523
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD 不能被宣告為靜態的"
 
-#: cp/decl.cc:15541
+#: cp/decl.cc:15551
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.cc:15549
+#: cp/decl.cc:15559
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.cc:15557
+#: cp/decl.cc:15567
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:15567
+#: cp/decl.cc:15577
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD 必須是一個非靜態成員函式或非成員函式"
 
-#: cp/decl.cc:15577
+#: cp/decl.cc:15587
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD 的引數必須有類別或列舉類型"
 
 #. 13.4.0.3
-#: cp/decl.cc:15608
+#: cp/decl.cc:15618
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允許多載 ?: 運算子"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: cp/decl.cc:15644
+#: cp/decl.cc:15654
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD 必須帶 0 或 1 個引數"
 
-#: cp/decl.cc:15645
+#: cp/decl.cc:15655
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD 必須帶 1 或 2 個引數"
 
-#: cp/decl.cc:15657
+#: cp/decl.cc:15667
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的參數"
 
-#: cp/decl.cc:15658
+#: cp/decl.cc:15668
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的第二個參數"
 
-#: cp/decl.cc:15669
+#: cp/decl.cc:15679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.cc:15670 cp/decl.cc:15680
+#: cp/decl.cc:15680 cp/decl.cc:15690
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD 帶且僅帶 1 個引數"
 
-#: cp/decl.cc:15681
+#: cp/decl.cc:15691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.cc:15696
+#: cp/decl.cc:15706
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD 不能有預設參數"
 
-#: cp/decl.cc:15720
+#: cp/decl.cc:15730
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "轉換到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.cc:15727
+#: cp/decl.cc:15737
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "轉換到參考到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.cc:15729
+#: cp/decl.cc:15739
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "轉換到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.cc:15738
+#: cp/decl.cc:15748
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "轉換到參考到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.cc:15740
+#: cp/decl.cc:15750
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "轉換到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.cc:15756
+#: cp/decl.cc:15766
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/decl.cc:15775
+#: cp/decl.cc:15785
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "字首 %qD 應當回傳 %qT"
 
-#: cp/decl.cc:15782
+#: cp/decl.cc:15792
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "字尾 %qD 應當回傳 %qT"
 
-#: cp/decl.cc:15794
+#: cp/decl.cc:15804
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD 應當回傳值而非參照"
 
-#: cp/decl.cc:15849
+#: cp/decl.cc:15859
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用範本類型參數 %qT，在 %qs 後"
 
-#: cp/decl.cc:15872
+#: cp/decl.cc:15882
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用別名模板特殊化 %qT 之後 %qs"
 
-#: cp/decl.cc:15875
+#: cp/decl.cc:15885
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名 %qD，在 %qs 後"
 
-#: cp/decl.cc:15877
+#: cp/decl.cc:15887
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD 有前一個宣告在此"
 
-#: cp/decl.cc:15885
+#: cp/decl.cc:15895
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: cp/decl.cc:15886 cp/decl.cc:15893
+#: cp/decl.cc:15896 cp/decl.cc:15903
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T 先前在此處有過宣告"
 
-#: cp/decl.cc:15892
+#: cp/decl.cc:15902
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT 做為列舉被參照"
@@ -57463,113 +57473,113 @@ msgstr "%qT 做為列舉被參照"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:15907
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> 需要範本參數"
 
-#: cp/decl.cc:15950 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
+#: cp/decl.cc:15960 cp/name-lookup.cc:5719 cp/name-lookup.cc:5851
 #: cp/parser.cc:7054 cp/parser.cc:31408
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/decl.cc:15959
+#: cp/decl.cc:15969
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/decl.cc:15981 cp/name-lookup.cc:5409
+#: cp/decl.cc:15991 cp/name-lookup.cc:5409
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.cc:16009 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
+#: cp/decl.cc:16019 cp/friend.cc:317 cp/parser.cc:3386 cp/parser.cc:6759
 #: cp/pt.cc:9836
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
 
-#: cp/decl.cc:16014
+#: cp/decl.cc:16024
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16129
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用列舉 %q#D 前沒有給出宣告"
 
-#: cp/decl.cc:16145
+#: cp/decl.cc:16155
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT 重宣告為非範本"
 
-#: cp/decl.cc:16156 cp/semantics.cc:3548
+#: cp/decl.cc:16166 cp/semantics.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "不能將 %qD 宣告為位元段類型"
 
-#: cp/decl.cc:16272
+#: cp/decl.cc:16282
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "衍生聯合 %qT 無效"
 
-#: cp/decl.cc:16279
+#: cp/decl.cc:16289
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16290
+#: cp/decl.cc:16300
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/decl.cc:16315
+#: cp/decl.cc:16325
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基礎類別型 %qT 不是結構或類別"
 
-#: cp/decl.cc:16345
+#: cp/decl.cc:16355
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "遞迴的類型 %qT 未定義"
 
-#: cp/decl.cc:16347
+#: cp/decl.cc:16357
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複的基礎類別型 %qT 無效"
 
-#: cp/decl.cc:16492
+#: cp/decl.cc:16502
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.cc:16495 cp/decl.cc:16503 cp/decl.cc:16513 cp/decl.cc:17112
+#: cp/decl.cc:16505 cp/decl.cc:16513 cp/decl.cc:16523 cp/decl.cc:17122
 #: cp/parser.cc:21163
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
 
-#: cp/decl.cc:16500
+#: cp/decl.cc:16510
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "下層的型態不匹配在中 enum %q#T"
 
-#: cp/decl.cc:16510
+#: cp/decl.cc:16520
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下層的輸入 enum %q#T"
 
-#: cp/decl.cc:16521
+#: cp/decl.cc:16531
 #, fuzzy, gcc-internal-format
 #| msgid "created and used with different endianness"
 msgid "cannot define %qD in different module"
 msgstr "建立和使用時使用了不同的高/低位位元組在前設定"
 
-#: cp/decl.cc:16596
+#: cp/decl.cc:16606
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
@@ -57578,83 +57588,83 @@ msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:16745
+#: cp/decl.cc:16755
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "沒有一個整數類型可以表示 %qT 的所有列舉值"
 
-#: cp/decl.cc:16920
+#: cp/decl.cc:16930
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.cc:16930
+#: cp/decl.cc:16940
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.cc:16979
+#: cp/decl.cc:16989
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.cc:16980
+#: cp/decl.cc:16990
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.cc:16991
+#: cp/decl.cc:17001
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD 處列舉值溢出"
 
-#: cp/decl.cc:17011
+#: cp/decl.cc:17021
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: cp/decl.cc:17110 cp/parser.cc:21161
+#: cp/decl.cc:17120 cp/parser.cc:21161
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/decl.cc:17184
+#: cp/decl.cc:17194
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.cc:17344 cp/typeck.cc:11114
+#: cp/decl.cc:17354 cp/typeck.cc:11114
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
 
-#: cp/decl.cc:18157
+#: cp/decl.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.cc:18159 cp/typeck.cc:10994
+#: cp/decl.cc:18169 cp/typeck.cc:10994
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: cp/decl.cc:18221
+#: cp/decl.cc:18231
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.cc:18414
+#: cp/decl.cc:18424
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD 已在類別 %qT 中定義過"
 
-#: cp/decl.cc:18802
+#: cp/decl.cc:18812
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "封閉任務"
 
-#: cp/decl.cc:18814
+#: cp/decl.cc:18824
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
@@ -58525,7 +58535,7 @@ msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 msgid "type %qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1359
+#: cp/init.cc:2028 cp/init.cc:4916 cp/typeck2.cc:1357
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
@@ -59614,7 +59624,7 @@ msgstr "在類別作用欄位使用非成員的 using 宣告"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/name-lookup.cc:5596 cp/pt.cc:18903
+#: cp/name-lookup.cc:5596 cp/pt.cc:18911
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE 並非類別、命名空間，或列舉類型"
@@ -60377,7 +60387,7 @@ msgstr "類型可能無法被定義在中 %<typeid%> 運算式"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: cp/parser.cc:7573 cp/pt.cc:21219
+#: cp/parser.cc:7573 cp/pt.cc:21227
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
@@ -61099,12 +61109,12 @@ msgstr "只有建構子需成員初始設定式"
 msgid "cannot expand initializer for member %qD"
 msgstr "無法展開初始設定式用於成員 %<%D%>"
 
-#: cp/parser.cc:16950 cp/pt.cc:27453
+#: cp/parser.cc:16950 cp/pt.cc:27456
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer 用於 %qD 追隨建構子 delegation"
 
-#: cp/parser.cc:16962 cp/pt.cc:27465
+#: cp/parser.cc:16962 cp/pt.cc:27468
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建構子 delegation 追隨 mem-initializer 用於 %qD"
@@ -61716,7 +61726,7 @@ msgstr "在中模板引數用於型態 %qT "
 msgid "%qT not permitted in template argument"
 msgstr "不匹配的引數"
 
-#: cp/parser.cc:24463 cp/typeck2.cc:340 cp/typeck2.cc:387 cp/typeck2.cc:2474
+#: cp/parser.cc:24463 cp/typeck2.cc:336 cp/typeck2.cc:383 cp/typeck2.cc:2472
 #: rust/backend/rust-tree.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -62589,7 +62599,7 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:43799 cp/pt.cc:18551
+#: cp/parser.cc:43799 cp/pt.cc:18559
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
@@ -63625,7 +63635,7 @@ msgstr "非範本類型 %qT 做為範本"
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.cc:9983 cp/pt.cc:22180
+#: cp/pt.cc:9983 cp/pt.cc:22188
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
@@ -63721,283 +63731,283 @@ msgstr "函式回傳了一個陣列"
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.cc:16362
+#: cp/pt.cc:16363
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.cc:16364
+#: cp/pt.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.cc:16366
+#: cp/pt.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.cc:16379
+#: cp/pt.cc:16380
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.cc:16382
+#: cp/pt.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.cc:16430
+#: cp/pt.cc:16431
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.cc:16436
+#: cp/pt.cc:16437
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.cc:16442
+#: cp/pt.cc:16443
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.cc:16508
+#: cp/pt.cc:16509
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
 
-#: cp/pt.cc:16545
+#: cp/pt.cc:16546
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16566
+#: cp/pt.cc:16567
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.cc:16599
+#: cp/pt.cc:16607
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.cc:16607
+#: cp/pt.cc:16615
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.cc:16720
+#: cp/pt.cc:16728
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.cc:17030
+#: cp/pt.cc:17038
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.cc:17045
+#: cp/pt.cc:17053
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.cc:17047
+#: cp/pt.cc:17055
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.cc:17140
+#: cp/pt.cc:17148
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17339
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.cc:17864 cp/pt.cc:19851
+#: cp/pt.cc:17872 cp/pt.cc:19859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.cc:17868 cp/pt.cc:19855
+#: cp/pt.cc:17876 cp/pt.cc:19863
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.cc:19992
+#: cp/pt.cc:20000
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++不允許初始設定式在中 lambda 運算式擷取清單"
 
-#: cp/pt.cc:21134
+#: cp/pt.cc:21142
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.cc:21169
+#: cp/pt.cc:21177
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.cc:21174
+#: cp/pt.cc:21182
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.cc:21177
+#: cp/pt.cc:21185
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.cc:21182
+#: cp/pt.cc:21190
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.cc:21233
+#: cp/pt.cc:21241
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "錯誤的引數數量到 %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21260
+#: cp/pt.cc:21268
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "錯誤的引數數量指定的用於 %qE 屬性"
 
-#: cp/pt.cc:21496
+#: cp/pt.cc:21504
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.cc:21499
+#: cp/pt.cc:21507
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.cc:21849
+#: cp/pt.cc:21857
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.cc:21851
+#: cp/pt.cc:21859
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.cc:21861
+#: cp/pt.cc:21869
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.cc:21876
+#: cp/pt.cc:21884
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.cc:21894
+#: cp/pt.cc:21902
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.cc:26132
+#: cp/pt.cc:26135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.cc:26134
+#: cp/pt.cc:26137
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.cc:26140
+#: cp/pt.cc:26143
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26164 cp/pt.cc:26259
+#: cp/pt.cc:26167 cp/pt.cc:26262
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.cc:26170
+#: cp/pt.cc:26173
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.cc:26172
+#: cp/pt.cc:26175
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.cc:26191
+#: cp/pt.cc:26194
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.cc:26197 cp/pt.cc:26254
+#: cp/pt.cc:26200 cp/pt.cc:26257
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.cc:26202
+#: cp/pt.cc:26205
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.cc:26210
+#: cp/pt.cc:26213
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.cc:26246
+#: cp/pt.cc:26249
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.cc:26269 cp/pt.cc:26336
+#: cp/pt.cc:26272 cp/pt.cc:26339
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.cc:26274 cp/pt.cc:26351
+#: cp/pt.cc:26277 cp/pt.cc:26354
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.cc:26308
+#: cp/pt.cc:26311
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.cc:26311
+#: cp/pt.cc:26314
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.cc:26320
+#: cp/pt.cc:26323
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26344
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.cc:26381
+#: cp/pt.cc:26384
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
 
-#: cp/pt.cc:26691
+#: cp/pt.cc:26694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -64010,173 +64020,173 @@ msgstr "在初次使用後明確特例化 %qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27183
+#: cp/pt.cc:27186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.cc:27230
+#: cp/pt.cc:27233
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.cc:27600
+#: cp/pt.cc:27603
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:27630
+#: cp/pt.cc:27633
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.cc:27639
+#: cp/pt.cc:27642
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:27647
+#: cp/pt.cc:27650
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.cc:27649
+#: cp/pt.cc:27652
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.cc:29077
+#: cp/pt.cc:29080
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/pt.cc:29367
+#: cp/pt.cc:29370
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/pt.cc:29376
+#: cp/pt.cc:29379
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT 不是一個命名空間"
 
-#: cp/pt.cc:29382
+#: cp/pt.cc:29385
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "在範本參數清單中定義了 %q#T"
 
-#: cp/pt.cc:29413
+#: cp/pt.cc:29416
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.cc:30561
+#: cp/pt.cc:30564
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/pt.cc:30573
+#: cp/pt.cc:30576
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:30579
+#: cp/pt.cc:30582
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qD directly instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.cc:30690
+#: cp/pt.cc:30693
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30697
+#: cp/pt.cc:30700
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.cc:30709
+#: cp/pt.cc:30712
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.cc:30712
+#: cp/pt.cc:30715
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考慮內聯函式"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30726
+#: cp/pt.cc:30729
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30730
+#: cp/pt.cc:30733
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "間接函式 %q+D 無法宣告的 weakref"
 
-#: cp/pt.cc:30744
+#: cp/pt.cc:30747
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.cc:30746
+#: cp/pt.cc:30749
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:30857
+#: cp/pt.cc:30860
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:30860
+#: cp/pt.cc:30863
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:30939
+#: cp/pt.cc:30942
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.cc:30942
+#: cp/pt.cc:30945
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.cc:31017
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31021
+#: cp/pt.cc:31024
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.cc:31025
+#: cp/pt.cc:31028
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.cc:31029
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.cc:31169
+#: cp/pt.cc:31172
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "無效的 non-type 模板引數"
@@ -64507,7 +64517,7 @@ msgstr "無效的基礎類別"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.cc:4002 cp/semantics.cc:12394
+#: cp/semantics.cc:4002 cp/semantics.cc:12399
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
@@ -64919,28 +64929,28 @@ msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12222
+#: cp/semantics.cc:12227
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qE 不是一個範本"
 
-#: cp/semantics.cc:12433
+#: cp/semantics.cc:12438
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/semantics.cc:12492
+#: cp/semantics.cc:12497
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/semantics.cc:12494
+#: cp/semantics.cc:12499
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:12512
+#: cp/semantics.cc:12517
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -64949,22 +64959,22 @@ msgstr "%<__builtin_return_address%> 的引數不受支援"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:12561
+#: cp/semantics.cc:12566
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:12567
+#: cp/semantics.cc:12572
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12594
+#: cp/semantics.cc:12599
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:12602
+#: cp/semantics.cc:12607
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -66253,229 +66263,229 @@ msgstr "前置宣告的 %q+#T"
 msgid "declaration of %q#T"
 msgstr "宣告的 %q+#T"
 
-#: cp/typeck2.cc:318
+#: cp/typeck2.cc:314
 #, fuzzy, gcc-internal-format
 msgid "%qD has incomplete type"
 msgstr "%q#D 有不完整型態"
 
-#: cp/typeck2.cc:332
+#: cp/typeck2.cc:328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of incomplete type %q#T"
 msgstr "無效的使用的不完整型態 %q#T"
 
-#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3888
+#: cp/typeck2.cc:365 rust/backend/rust-tree.cc:3888
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
 msgstr "無效的使用的成員函式 (did 您忘記%<()%>?)"
 
-#: cp/typeck2.cc:374 rust/backend/rust-tree.cc:3894
+#: cp/typeck2.cc:370 rust/backend/rust-tree.cc:3894
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
 msgstr "無效的使用的成員 (did 您忘記 %<&%>?)"
 
-#: cp/typeck2.cc:384
+#: cp/typeck2.cc:380
 #, fuzzy, gcc-internal-format
 msgid "invalid use of placeholder %qT"
 msgstr "無效的使用的 %qT"
 
-#: cp/typeck2.cc:391
+#: cp/typeck2.cc:387
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template type parameter %qT"
 msgstr "無效的使用的模板型態參數 %qT"
 
-#: cp/typeck2.cc:396
+#: cp/typeck2.cc:392
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template template parameter %qT"
 msgstr "無效的使用的模板模板參數 %qT"
 
-#: cp/typeck2.cc:402
+#: cp/typeck2.cc:398
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/typeck2.cc:408
+#: cp/typeck2.cc:404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of dependent type %qT"
 msgstr "無效的使用的附屬型態 %qT"
 
-#: cp/typeck2.cc:415 rust/backend/rust-tree.cc:3904
+#: cp/typeck2.cc:411 rust/backend/rust-tree.cc:3904
 #, fuzzy, gcc-internal-format
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "無效的使用的 brace-enclosed 初始設定式清單"
 
-#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3912
+#: cp/typeck2.cc:419 rust/backend/rust-tree.cc:3912
 #, fuzzy, gcc-internal-format
 msgid "address of overloaded function with no contextual type information"
 msgstr "位址的多載化函式不具任何語境的類型資訊"
 
-#: cp/typeck2.cc:427 rust/backend/rust-tree.cc:3917
+#: cp/typeck2.cc:423 rust/backend/rust-tree.cc:3917
 #, fuzzy, gcc-internal-format
 msgid "overloaded function with no contextual type information"
 msgstr "多載化函式不具任何語境的類型資訊"
 
-#: cp/typeck2.cc:430 rust/backend/rust-tree.cc:3921
+#: cp/typeck2.cc:426 rust/backend/rust-tree.cc:3921
 #, fuzzy, gcc-internal-format
 msgid "insufficient contextual information to determine type"
 msgstr "不足的語境的資訊到決定型態"
 
-#: cp/typeck2.cc:814
+#: cp/typeck2.cc:812
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "使用了建構式的語法，但沒有為類型 %qT 宣告建構式"
 
-#: cp/typeck2.cc:887
+#: cp/typeck2.cc:885
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/typeck2.cc:1066
+#: cp/typeck2.cc:1064
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {} 被不當形式的在中 C++11"
 
-#: cp/typeck2.cc:1078 cp/typeck2.cc:1092
+#: cp/typeck2.cc:1076 cp/typeck2.cc:1090
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {}"
 
-#: cp/typeck2.cc:1081
+#: cp/typeck2.cc:1079
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "運算式在中靜態假設不是整數常數運算式"
 
-#: cp/typeck2.cc:1256
+#: cp/typeck2.cc:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "用以初始化字元陣列的字串太長"
 
-#: cp/typeck2.cc:1319
+#: cp/typeck2.cc:1317
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1321
+#: cp/typeck2.cc:1319
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "標量初始化帶大括號"
 
-#: cp/typeck2.cc:1341
+#: cp/typeck2.cc:1339
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "不可使用複合原文初始化類型為 %qT 的聚集"
 
-#: cp/typeck2.cc:1825 cp/typeck2.cc:1855
+#: cp/typeck2.cc:1823 cp/typeck2.cc:1853
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/typeck2.cc:1832
+#: cp/typeck2.cc:1830
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.cc:1839
+#: cp/typeck2.cc:1837
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.cc:1924
+#: cp/typeck2.cc:1922
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: cp/typeck2.cc:1997
+#: cp/typeck2.cc:1995
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的聯合中找不到欄位 %qD"
 
-#: cp/typeck2.cc:2008
+#: cp/typeck2.cc:2006
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在聯合初始值設定中出現了索引值而不是欄位名"
 
-#: cp/typeck2.cc:2224
+#: cp/typeck2.cc:2222
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "偵測到循環指標代理"
 
-#: cp/typeck2.cc:2238
+#: cp/typeck2.cc:2236
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> 的基運算元具有非指標類型 %qT"
 
-#: cp/typeck2.cc:2268
+#: cp/typeck2.cc:2266
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> 的結果給出了非指標的結果"
 
-#: cp/typeck2.cc:2270
+#: cp/typeck2.cc:2268
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> 的左運算元不是一個指標"
 
-#: cp/typeck2.cc:2297
+#: cp/typeck2.cc:2295
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE 不能做為成員指標，因為它的類型為 %qT"
 
-#: cp/typeck2.cc:2306
+#: cp/typeck2.cc:2304
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "無法套用成員指標 %qE 到 %qE，該項是的 non-class 型態 %qT"
 
-#: cp/typeck2.cc:2328
+#: cp/typeck2.cc:2326
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: cp/typeck2.cc:2386
+#: cp/typeck2.cc:2384
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.cc:2397
+#: cp/typeck2.cc:2395
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.cc:2405
+#: cp/typeck2.cc:2403
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.cc:2446
+#: cp/typeck2.cc:2444
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "functional 演員陣容到陣列類型 %qT"
 
-#: cp/typeck2.cc:2463
+#: cp/typeck2.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/typeck2.cc:2468
+#: cp/typeck2.cc:2466
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/typeck2.cc:2493
+#: cp/typeck2.cc:2491
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: cp/typeck2.cc:2734
+#: cp/typeck2.cc:2732
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "呼叫的函式 %qD 會拋出不完全的類型 %q#T"
 
-#: cp/typeck2.cc:2737
+#: cp/typeck2.cc:2735
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "呼叫的函式會拋出不完全的類型 %q#T"
@@ -67457,7 +67467,7 @@ msgstr "non-parameter %qs 無法參數包裝"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "『我』於 %L 和『J』於 %L 無法兩者是 BOZ 實字常數"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11138
+#: fortran/check.cc:123 fortran/resolve.cc:11164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無效的 exponent-letter『q』在中 real-literal-constant 於 %C"
@@ -68598,12 +68608,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "初始化字串開始於 %L 被截短至符合變數 (%d/%d)"
 
-#: fortran/data.cc:188 fortran/resolve.cc:5219
+#: fortran/data.cc:188 fortran/resolve.cc:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L 處的子字串起始索引小於 1"
 
-#: fortran/data.cc:194 fortran/resolve.cc:5249
+#: fortran/data.cc:194 fortran/resolve.cc:5266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "子字串結束索引於 %L 超出字串長度"
@@ -68794,7 +68804,7 @@ msgstr "%C 處錯誤地指定 INTENT"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003:已推遲型態參數於 %C"
 
-#: fortran/decl.cc:1159 fortran/resolve.cc:12926
+#: fortran/decl.cc:1159 fortran/resolve.cc:12952
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -70859,7 +70869,7 @@ msgstr "transformational intrinsic『%s』於 %L 未被允許在中初始化運
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "延伸：求值的 nonstandard 初始化運算式於 %L"
 
-#: fortran/expr.cc:3001 fortran/resolve.cc:2816
+#: fortran/expr.cc:3001 fortran/resolve.cc:2833
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "函式『%s』在中初始化運算式於 %L 必須是內建函式"
@@ -71140,7 +71150,7 @@ msgstr "介面不匹配在中程序指標指派於 %L:%s"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2696
+#: fortran/expr.cc:4215 fortran/expr.cc:4230 fortran/resolve.cc:2713
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "NOPASS 或明確的介面必要項於 %C"
@@ -71258,7 +71268,7 @@ msgstr ""
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.cc:4621 fortran/resolve.cc:1535
+#: fortran/expr.cc:4621 fortran/resolve.cc:1552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "指標初始化目標於 %L 必須不是 ALLOCATABLE "
@@ -71268,7 +71278,7 @@ msgstr "指標初始化目標於 %L 必須不是 ALLOCATABLE "
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "指標初始化目標於 %C 必須有目標屬性"
 
-#: fortran/expr.cc:4642 fortran/resolve.cc:1541
+#: fortran/expr.cc:4642 fortran/resolve.cc:1558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "指標初始化目標於 %L 必須有儲存屬性"
@@ -71399,7 +71409,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1496
-#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8576
+#: fortran/trans-array.cc:6953 fortran/trans-array.cc:8588
 #: fortran/trans-intrinsic.cc:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -71620,12 +71630,12 @@ msgstr "第一個引數的定義的指派於 %L 必須是含義 (出) 或含義
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.cc:998 fortran/resolve.cc:17749
+#: fortran/interface.cc:998 fortran/resolve.cc:17775
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.cc:1005 fortran/resolve.cc:17767
+#: fortran/interface.cc:1005 fortran/resolve.cc:17793
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
@@ -71738,571 +71748,571 @@ msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和純量)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和 rank-%d)"
 
-#: fortran/interface.cc:2378
+#: fortran/interface.cc:2394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "無效的程序引數於 %L"
 
-#: fortran/interface.cc:2386 fortran/interface.cc:2413
+#: fortran/interface.cc:2402 fortran/interface.cc:2429
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "介面不匹配在中虛設程序『%s』於 %L:%s"
 
-#: fortran/interface.cc:2424
+#: fortran/interface.cc:2440
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "實際引數到 contiguous 指標虛設『%s』於 %L 必須是僅需 contigous"
 
-#: fortran/interface.cc:2447
+#: fortran/interface.cc:2463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "含義 (%s) 實際引數於 %L 也許 interfere 與實際引數於 %L。"
 
-#: fortran/interface.cc:2457
+#: fortran/interface.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "型態不匹配在中引數『%s』於 %L; 傳遞 %s 到 %s"
 
-#: fortran/interface.cc:2467
+#: fortran/interface.cc:2483
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/interface.cc:2481
+#: fortran/interface.cc:2497
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/interface.cc:2498
+#: fortran/interface.cc:2514
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/interface.cc:2508
+#: fortran/interface.cc:2524
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "實際引數到『%s』於 %L 必須有相同宣告的型態"
 
-#: fortran/interface.cc:2523
+#: fortran/interface.cc:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.cc:2539
+#: fortran/interface.cc:2555
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/interface.cc:2561
+#: fortran/interface.cc:2577
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Corank 不匹配在中引數『%s』於 %L (%d 和 %d)"
 
-#: fortran/interface.cc:2579
+#: fortran/interface.cc:2595
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "實際引數到『%s』於 %L 必須是僅需 contiguous"
 
-#: fortran/interface.cc:2594
+#: fortran/interface.cc:2610
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.cc:2609
+#: fortran/interface.cc:2625
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.cc:2628
+#: fortran/interface.cc:2644
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "虛引數『%s』必須是指標或 assumed-shape 陣列而無需 CONTIGUOUS 屬性 - 做為實際引數於 %L 不是僅需 contiguous 和兩者是非同步或易變的"
 
-#: fortran/interface.cc:2641
+#: fortran/interface.cc:2657
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "傳遞 coarray 於 %L 到 allocatable、noncoarray，含義 (出) 虛引數『%s』"
 
-#: fortran/interface.cc:2648
+#: fortran/interface.cc:2664
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "傳遞 coarray 於 %L 到 allocatable，noncoarray 虛引數『%s』，該項無效如果配額狀態被已修改"
 
-#: fortran/interface.cc:2734
+#: fortran/interface.cc:2750
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphic 純量傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.cc:2745
+#: fortran/interface.cc:2761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "元件的 assumed-shaped 或指標陣列傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.cc:2750
+#: fortran/interface.cc:2766
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "元件的 assumed-shaped 或指標陣列傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.cc:2763
+#: fortran/interface.cc:2779
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "延伸：純量 non-default-kind，non-C_CHAR-kind 字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.cc:2771
+#: fortran/interface.cc:2787
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003:純量字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.cc:3159
+#: fortran/interface.cc:3175
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.cc:3182
+#: fortran/interface.cc:3198
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.cc:3186
+#: fortran/interface.cc:3202
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.cc:3195
+#: fortran/interface.cc:3211
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "關鍵字引數『%s』於 %L 已經關聯的與另外的實際引數"
 
-#: fortran/interface.cc:3205
+#: fortran/interface.cc:3221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "更多實際的比形式引數在中程序呼叫於 %L"
 
-#: fortran/interface.cc:3218
+#: fortran/interface.cc:3234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "缺少交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.cc:3232
+#: fortran/interface.cc:3248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "未預期的交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.cc:3261
+#: fortran/interface.cc:3277
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/interface.cc:3264
+#: fortran/interface.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008:空指標於 %L 到 non-pointer 虛設『%s』"
 
-#: fortran/interface.cc:3290
+#: fortran/interface.cc:3306
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.cc:3316
+#: fortran/interface.cc:3332
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和指標或 allocatable 虛引數『%s』於 %L"
 
-#: fortran/interface.cc:3323
+#: fortran/interface.cc:3339
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和 assumed-shape 虛引數『%s』於 %L"
 
-#: fortran/interface.cc:3338
+#: fortran/interface.cc:3354
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "實際引數於 %L 到 allocatable 或指標虛引數『%s』必須有已推遲長度型態參數如果和只有如果虛設有一個"
 
-#: fortran/interface.cc:3357
+#: fortran/interface.cc:3373
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "字元長度的實際引數短於的虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.cc:3367 fortran/interface.cc:3372
+#: fortran/interface.cc:3383 fortran/interface.cc:3388
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "實際引數含有太少元件用於虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.cc:3393
+#: fortran/interface.cc:3409
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "預期的程序指標用於引數『%s』於 %L"
 
-#: fortran/interface.cc:3410
+#: fortran/interface.cc:3426
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "預期的程序用於引數『%s』於 %L"
 
-#: fortran/interface.cc:3475
+#: fortran/interface.cc:3491
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "實際引數用於『%s』無法 assumed-size 陣列於 %L"
 
-#: fortran/interface.cc:3504
+#: fortran/interface.cc:3520
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.cc:3519
+#: fortran/interface.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs at %L must be a pointer"
 msgstr "「%s」的引數在 %L 處必須是一個指標"
 
-#: fortran/interface.cc:3528
+#: fortran/interface.cc:3544
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008:Non-pointer 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.cc:3537
+#: fortran/interface.cc:3553
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
 msgstr ""
 
-#: fortran/interface.cc:3551
+#: fortran/interface.cc:3567
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Coindexed 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.cc:3565
+#: fortran/interface.cc:3581
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 到 allocatable 虛設『%s』需求含義 (在中)"
 
-#: fortran/interface.cc:3580
+#: fortran/interface.cc:3596
 #, fuzzy, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Coindexed 非同步或易變的實際引數於 %L 需求該虛設『%s』有 neither 非同步 nor 易變的"
 
-#: fortran/interface.cc:3595
+#: fortran/interface.cc:3611
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 與 allocatable ultimate 成分到虛設『%s』需求還是值或含義 (在中)"
 
-#: fortran/interface.cc:3608
+#: fortran/interface.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "實際的類別陣列引數用於『%s』必須是全部陣列於 %L"
 
-#: fortran/interface.cc:3619
+#: fortran/interface.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "實際引數用於『%s』必須是 ALLOCATABLE 於 %L"
 
-#: fortran/interface.cc:3656
+#: fortran/interface.cc:3672
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Array-section 實際引數與向量註標於 %L 是不相容的與含義 (出)，含義 (INOUT)，易變的或非同步屬性的虛引數『%s』"
 
-#: fortran/interface.cc:3676
+#: fortran/interface.cc:3692
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Assumed-shape 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.cc:3694
+#: fortran/interface.cc:3710
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Array-section 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.cc:3715
+#: fortran/interface.cc:3731
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pointer-array 實際引數於 %L 需求 assumed-shape 或 pointer-array 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.cc:3743
+#: fortran/interface.cc:3759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "缺少交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.cc:3756
+#: fortran/interface.cc:3772
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "參數「%s」在 %L 處缺少引數"
 
-#: fortran/interface.cc:3884
+#: fortran/interface.cc:3900
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.cc:3913
+#: fortran/interface.cc:3929
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3939
+#: fortran/interface.cc:3955
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.cc:3949
+#: fortran/interface.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "相同實際引數關聯的與含義 (%s) 引數『%s』和含義 (%s) 引數『%s』於 %L"
 
-#: fortran/interface.cc:3979
+#: fortran/interface.cc:3995
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.cc:3999
+#: fortran/interface.cc:4015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "程序引數於 %L 是本地到 PURE 程序和有指標屬性"
 
-#: fortran/interface.cc:4011
+#: fortran/interface.cc:4027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到含義 (%s) 引數"
 
-#: fortran/interface.cc:4021
+#: fortran/interface.cc:4037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到指標虛引數"
 
-#: fortran/interface.cc:4032
+#: fortran/interface.cc:4048
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Coindexed polymorphic 實際引數於 %L 被傳遞 polymorphic 虛引數『%s』"
 
-#: fortran/interface.cc:4074
+#: fortran/interface.cc:4090
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "程序『%s』called 於 %L 不是明確的宣告"
 
-#: fortran/interface.cc:4078 fortran/interface.cc:4088
+#: fortran/interface.cc:4094 fortran/interface.cc:4104
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "程序『%s』called 於 %L 不是明確的宣告"
 
-#: fortran/interface.cc:4084
+#: fortran/interface.cc:4100
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "呼叫程序「%s」帶隱含介面，位於 %L"
 
-#: fortran/interface.cc:4097
+#: fortran/interface.cc:4113
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "指標物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.cc:4105
+#: fortran/interface.cc:4121
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "allocatable 物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.cc:4113
+#: fortran/interface.cc:4129
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allocatable 函式『%s』於 %L 必須有明確的函式介面"
 
-#: fortran/interface.cc:4130
+#: fortran/interface.cc:4146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/interface.cc:4139
+#: fortran/interface.cc:4155
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.cc:4148
+#: fortran/interface.cc:4164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/interface.cc:4163
+#: fortran/interface.cc:4179
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "實際引數的 LOCK_TYPE 或與 LOCK_TYPE 成分於 %L 需求明確的介面用於程序『%s』"
 
-#: fortran/interface.cc:4178
+#: fortran/interface.cc:4194
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "實際引數的 LOCK_TYPE 或與 LOCK_TYPE 成分於 %L 需求明確的介面用於程序『%s』"
 
-#: fortran/interface.cc:4188
+#: fortran/interface.cc:4204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "鑄型引數到空值必要項於 %L"
 
-#: fortran/interface.cc:4196
+#: fortran/interface.cc:4212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/interface.cc:4206
+#: fortran/interface.cc:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.cc:4248
+#: fortran/interface.cc:4264
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "程序指標成分『%s』called 與隱含的介面於 %L"
 
-#: fortran/interface.cc:4259
+#: fortran/interface.cc:4275
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/interface.cc:4344
+#: fortran/interface.cc:4360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "鑄型=必要項在中空值() 引數於 %L:模稜兩可介於特定的函式 %s 和 %s"
 
-#: fortran/interface.cc:4414
+#: fortran/interface.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "%q+D 別名到未定義的符號 %qE"
 
-#: fortran/interface.cc:4787
+#: fortran/interface.cc:4803
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "實體『%s』於 %C 已經呈現在中介面"
 
-#: fortran/interface.cc:4904
+#: fortran/interface.cc:4920
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.cc:4998
+#: fortran/interface.cc:5014
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "無法覆寫通用『%s』於 %L"
 
-#: fortran/interface.cc:5010
+#: fortran/interface.cc:5026
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "『%s』於 %L 強制變更程序繫結宣告 NON_OVERRIDABLE"
 
-#: fortran/interface.cc:5018
+#: fortran/interface.cc:5034
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "『%s』於 %L 必須不是已推遲做為它強制變更 non-DEFERRED 繫結"
 
-#: fortran/interface.cc:5026
+#: fortran/interface.cc:5042
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "『%s』於 %L 強制變更 PURE 程序且須也是 PURE"
 
-#: fortran/interface.cc:5035
+#: fortran/interface.cc:5051
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "『%s』於 %L 強制變更 ELEMENTAL 程序且須也是 ELEMENTAL"
 
-#: fortran/interface.cc:5041
+#: fortran/interface.cc:5057
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "『%s』於 %L 強制變更 non-ELEMENTAL 程序且須無法是 ELEMENTAL，還是"
 
-#: fortran/interface.cc:5050
+#: fortran/interface.cc:5066
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "『%s』於 %L 強制變更副常式且須也是副常式"
 
-#: fortran/interface.cc:5061
+#: fortran/interface.cc:5077
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "『%s』於 %L 強制變更函式且須也是函式"
 
-#: fortran/interface.cc:5069
+#: fortran/interface.cc:5085
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.cc:5080
+#: fortran/interface.cc:5096
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "『%s』於 %L 強制變更公用的程序且須無法是私人的"
 
-#: fortran/interface.cc:5110
+#: fortran/interface.cc:5126
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "虛引數『%s』的『%s』於 %L 應該被具名的『%s』做為到匹配相應引數的 overridden 程序"
 
-#: fortran/interface.cc:5121
+#: fortran/interface.cc:5137
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.cc:5130
+#: fortran/interface.cc:5146
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "『%s』於 %L 必須有相同形式引數數量做為 overridden 程序"
 
-#: fortran/interface.cc:5139
+#: fortran/interface.cc:5155
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "『%s』於 %L 強制變更 NOPASS 繫結且須也是 NOPASS"
 
-#: fortran/interface.cc:5150
+#: fortran/interface.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "『%s』於 %L 強制變更繫結與回合且須也是回合"
 
-#: fortran/interface.cc:5157
+#: fortran/interface.cc:5173
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是於相同位置做為 passed-object 虛引數的 overridden 程序"
 
-#: fortran/interface.cc:5178
+#: fortran/interface.cc:5194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s 標記在 %L 處必須具有類型 %s"
 
-#: fortran/interface.cc:5185
+#: fortran/interface.cc:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/interface.cc:5192
+#: fortran/interface.cc:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/interface.cc:5196
+#: fortran/interface.cc:5212
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.cc:5200
+#: fortran/interface.cc:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Character-valued %s『%s』於 %L 必須不被假設長度"
 
-#: fortran/interface.cc:5204
+#: fortran/interface.cc:5220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "「%s」啞元引數在 %L 處不能是 INTENT(OUT)"
 
-#: fortran/interface.cc:5262 fortran/interface.cc:5308
+#: fortran/interface.cc:5278 fortran/interface.cc:5324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/interface.cc:5274
+#: fortran/interface.cc:5290
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "ELEMENTAL 程序『%s』於 %L 必須有明確的介面"
 
-#: fortran/interface.cc:5286
+#: fortran/interface.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "對「%s」的呼叫給出的參數太多，於 %L 處"
 
-#: fortran/interface.cc:5293
+#: fortran/interface.cc:5309
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -72495,7 +72505,7 @@ msgstr "從 %s 轉換到 %s，位於 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11113
+#: fortran/intrinsic.cc:5406 fortran/resolve.cc:11139
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -73056,7 +73066,7 @@ msgstr "名稱表列『%s』在中讀取敘述於 %L 含有符號『%s』該項
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
 
-#: fortran/io.cc:3431 fortran/resolve.cc:15597
+#: fortran/io.cc:3431 fortran/resolve.cc:15623
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
@@ -73641,7 +73651,7 @@ msgstr "停止編碼於 %L 必須是預設字元 KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "停止編碼於 %L 必須是預設整數 KIND=%d"
 
-#: fortran/match.cc:3208 fortran/resolve.cc:12252
+#: fortran/match.cc:3208 fortran/resolve.cc:12278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
@@ -75541,8 +75551,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "-frepo 必須與 -c 一起使用"
 
-#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10924
-#: fortran/resolve.cc:12480
+#: fortran/openmp.cc:6959 fortran/openmp.cc:6970 fortran/resolve.cc:10950
+#: fortran/resolve.cc:12506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "如果子句於 %L 需要純量邏輯的運算式"
@@ -77535,720 +77545,730 @@ msgstr "Character-valued %s『%s』於 %L 必須不被假設長度"
 msgid "Character-valued internal function %qs at %L must not be assumed length"
 msgstr "Character-valued %s『%s』於 %L 必須不被假設長度"
 
-#: fortran/resolve.cc:800
+#: fortran/resolve.cc:801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entries with mismatched array specifications"
 msgstr "函式 %s 於 %L 有條目與不匹配的陣列規格"
 
-#: fortran/resolve.cc:811
+#: fortran/resolve.cc:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L has entry %s with mismatched characteristics"
 msgstr "函式 %s 於 %L 有條目與不匹配的陣列規格"
 
-#: fortran/resolve.cc:826
+#: fortran/resolve.cc:827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
 msgstr "延伸：函式 %s 於 %L 與條目回傳變數的不同的字串長度"
 
-#: fortran/resolve.cc:853
+#: fortran/resolve.cc:859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
 msgstr "函數計算結果 %s 無法陣列在中函式 %s 於 %L"
 
-#: fortran/resolve.cc:857
+#: fortran/resolve.cc:863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
 msgstr "條目結果 %s 無法陣列在中函式 %s 於 %L"
 
-#: fortran/resolve.cc:864
+#: fortran/resolve.cc:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "函數計算結果 %s 無法指標在中函式 %s 於 %L"
 
-#: fortran/resolve.cc:868
+#: fortran/resolve.cc:874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
 msgstr "條目結果 %s 無法指標在中函式 %s 於 %L"
 
-#: fortran/resolve.cc:906
+#: fortran/resolve.cc:881
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "函數計算結果 %s 無法指標在中函式 %s 於 %L"
+
+#: fortran/resolve.cc:885
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr "條目結果 %s 無法指標在中函式 %s 於 %L"
+
+#: fortran/resolve.cc:923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "函數計算結果 %s 無法的型態 %s 在中函式 %s 於 %L"
 
-#: fortran/resolve.cc:911
+#: fortran/resolve.cc:928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
 msgstr "條目結果 %s 無法的型態 %s 在中函式 %s 於 %L"
 
-#: fortran/resolve.cc:958
+#: fortran/resolve.cc:975
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
 msgstr "符號『%s』於 %C 已經在中共同區塊"
 
-#: fortran/resolve.cc:962
+#: fortran/resolve.cc:979
 #, fuzzy, gcc-internal-format
 msgid "Global entity %qs at %L cannot appear in a COMMON block"
 msgstr "符號『%s』於 %C 已經在中共同區塊"
 
-#: fortran/resolve.cc:972
+#: fortran/resolve.cc:989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COMMON block at %L"
 msgstr "共同區塊/%s/找不到於 %C"
 
-#: fortran/resolve.cc:979
+#: fortran/resolve.cc:996
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
 msgstr "變數『%s』於 %L 是在中共同但是只有在中區塊資料初始化被允許"
 
-#: fortran/resolve.cc:983
+#: fortran/resolve.cc:1000
 #, fuzzy, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
 msgstr "初始化的變數『%s』於 %L 是在中空白共同但是初始化是只有允許的在中具名的共同區塊"
 
-#: fortran/resolve.cc:990
+#: fortran/resolve.cc:1007
 #, gcc-internal-format
 msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr ""
 
-#: fortran/resolve.cc:998
+#: fortran/resolve.cc:1015
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
 msgstr "衍生類型變數『%s』在中共同於 %L 有 neither 序列 nor 繫結©屬性"
 
-#: fortran/resolve.cc:1002
+#: fortran/resolve.cc:1019
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
 msgstr "衍生類型變數『%s』在中共同於 %L 有 ultimate 成分該是 allocatable"
 
-#: fortran/resolve.cc:1006
+#: fortran/resolve.cc:1023
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
 msgstr "衍生類型變數『%s』在中共同於 %L 可能無法有預設初始設定式"
 
-#: fortran/resolve.cc:1050
+#: fortran/resolve.cc:1067
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
 msgstr ""
 
-#: fortran/resolve.cc:1064
+#: fortran/resolve.cc:1081
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
 msgstr "共同區塊『%s』於 %L 被做為參數於 %L"
 
-#: fortran/resolve.cc:1072
+#: fortran/resolve.cc:1089
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1094
+#: fortran/resolve.cc:1111
 #, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:1115
+#: fortran/resolve.cc:1132
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
 msgstr "共同區塊『%s』於 %L 被做為參數於 %L"
 
-#: fortran/resolve.cc:1119
+#: fortran/resolve.cc:1136
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.cc:1123
+#: fortran/resolve.cc:1140
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
 msgstr "共同區塊『%s』於 %L 也是 intrinsic 程序"
 
-#: fortran/resolve.cc:1127
+#: fortran/resolve.cc:1144
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
 msgstr "Fortran 2003:共同區塊『%s』於 %L 該也是函數計算結果"
 
-#: fortran/resolve.cc:1132
+#: fortran/resolve.cc:1149
 #, fuzzy, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
 msgstr "Fortran 2003:共同區塊『%s』於 %L 該也是全域程序"
 
-#: fortran/resolve.cc:1199
+#: fortran/resolve.cc:1216
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
 msgstr ""
 
-#: fortran/resolve.cc:1339
+#: fortran/resolve.cc:1356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
 msgstr "分級的元件在中結構建構子於 %L 不匹配該的成分 (%d/%d)"
 
-#: fortran/resolve.cc:1360
+#: fortran/resolve.cc:1377
 #, fuzzy, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
 msgstr "元件在中結構建構子於 %L, 用於指標成分『%s』，是 %s 但是應該是 %s"
 
-#: fortran/resolve.cc:1392
+#: fortran/resolve.cc:1409
 #, fuzzy, gcc-internal-format
 msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
 msgstr "Unequal 字元長度 (%ld/%ld) 在中 %s 於 %L"
 
-#: fortran/resolve.cc:1437
+#: fortran/resolve.cc:1454
 #, fuzzy, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
 msgstr "空值在中結構建構子於 %L 正在被套用到成分『%s』，該項是 neither 指標 nor ALLOCATABLE"
 
-#: fortran/resolve.cc:1471
+#: fortran/resolve.cc:1488
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
 msgstr "介面不匹配用於 procedure-pointer 成分『%s』在中結構建構子於 %L:%s"
 
-#: fortran/resolve.cc:1490
+#: fortran/resolve.cc:1507
 #, fuzzy, gcc-internal-format
 msgid "Bad array spec of component %qs referenced in structure constructor at %L"
 msgstr "太多成分在中結構建構子於 %L！"
 
-#: fortran/resolve.cc:1503
+#: fortran/resolve.cc:1520
 #, fuzzy, gcc-internal-format
 msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
 msgstr "分級的元件在中結構建構子於 %L 不匹配該的成分 (%d/%d)"
 
-#: fortran/resolve.cc:1524
+#: fortran/resolve.cc:1541
 #, fuzzy, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
 msgstr "元件在中結構建構子於 %L, 用於指標成分『%s』應該是指標或目標"
 
-#: fortran/resolve.cc:1553
+#: fortran/resolve.cc:1570
 #, fuzzy, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
 msgstr "無效的運算式在中結構建構子用於指標成分『%s』於 %L 在中 PURE 程序"
 
-#: fortran/resolve.cc:1679
+#: fortran/resolve.cc:1696
 #, fuzzy, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
 msgstr "上限在中最後一筆尺寸必須出現在中參考到假設的大小陣列『%s』於 %L"
 
-#: fortran/resolve.cc:1741
+#: fortran/resolve.cc:1758
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is ambiguous"
 msgstr "『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.cc:1745
+#: fortran/resolve.cc:1762
 #, fuzzy, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "通用程序『%s』未被允許做為實際引數於 %L"
 
-#: fortran/resolve.cc:1866
+#: fortran/resolve.cc:1883
 #, fuzzy, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "型態指定的用於內建函式『%s』於 %L 被忽略"
 
-#: fortran/resolve.cc:1879
+#: fortran/resolve.cc:1896
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Intrinsic 副常式『%s』於 %L 不應該有型態說明符"
 
-#: fortran/resolve.cc:1890
+#: fortran/resolve.cc:1907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "『%s』宣告的 INTRINSIC 於 %L 不存在"
 
-#: fortran/resolve.cc:1903
+#: fortran/resolve.cc:1920
 #, fuzzy, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "intrinsic『%s』宣告的 INTRINSIC 於 %L 不是可用在中目前的標準設定值但是 %s。 使用適當 -std=* 選項或啟用 -fall-intrinsics 以便使用它。"
 
-#: fortran/resolve.cc:1939
+#: fortran/resolve.cc:1956
 #, fuzzy, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.cc:1997 fortran/resolve.cc:10433 fortran/resolve.cc:12407
+#: fortran/resolve.cc:2014 fortran/resolve.cc:10464 fortran/resolve.cc:12433
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "標籤 %d(參照自 %L)從未被定義"
 
-#: fortran/resolve.cc:2029
+#: fortran/resolve.cc:2046
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Fortran 2008:內部程序『%s』被做為實際引數於 %L"
 
-#: fortran/resolve.cc:2047
+#: fortran/resolve.cc:2064
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "敘述函式「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/resolve.cc:2055
+#: fortran/resolve.cc:2072
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsic『%s』於 %L 未被允許做為實際引數"
 
-#: fortran/resolve.cc:2062
+#: fortran/resolve.cc:2079
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Fortran 2008:內部程序『%s』被做為實際引數於 %L"
 
-#: fortran/resolve.cc:2070
+#: fortran/resolve.cc:2087
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL non-INTRINSIC 程序「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/resolve.cc:2097
+#: fortran/resolve.cc:2114
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "無法找到特定的 INTRINSIC 程序用於參考『%s』於 %L"
 
-#: fortran/resolve.cc:2119
+#: fortran/resolve.cc:2136
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "符號「%s」(位於 %L)有歧義"
 
-#: fortran/resolve.cc:2174
+#: fortran/resolve.cc:2191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "By-value 引數於 %L 不是的數字類型"
 
-#: fortran/resolve.cc:2181
+#: fortran/resolve.cc:2198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "By-value 引數於 %L 無法陣列或陣列區段"
 
-#: fortran/resolve.cc:2195
+#: fortran/resolve.cc:2212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: fortran/resolve.cc:2207
+#: fortran/resolve.cc:2224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "傳遞內部程序於 %L 依位置不允許"
 
-#: fortran/resolve.cc:2218
+#: fortran/resolve.cc:2235
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL non-INTRINSIC 程序「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/resolve.cc:2227
+#: fortran/resolve.cc:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Coindexed 實際引數於 %L 與 ultimate 指標成分"
 
-#: fortran/resolve.cc:2374
+#: fortran/resolve.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
 msgstr "『%s』於 %L 是陣列和可選的；如果它缺少，它無法實際引數的 ELEMENTAL 程序除非有 non-optional 引數與同級 (12.4.1.5)"
 
-#: fortran/resolve.cc:2413
+#: fortran/resolve.cc:2430
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "實際引數於 %L 用於含義 (%s) 虛設『%s』的 ELEMENTAL 副常式『%s』是純量，但是另外的實際引數是陣列"
 
-#: fortran/resolve.cc:2687
+#: fortran/resolve.cc:2704
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "傳回類型不匹配的函式『%s』於 %L (%s/%s)"
 
-#: fortran/resolve.cc:2714
+#: fortran/resolve.cc:2731
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "介面不匹配在中虛設程序『%s』於 %L:%s"
 
-#: fortran/resolve.cc:2820
+#: fortran/resolve.cc:2837
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "沒有任何特定的函式用於通用『%s』於 %L"
 
-#: fortran/resolve.cc:2840
+#: fortran/resolve.cc:2857
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "通用函式『%s』於 %L 不是一致的與特定的 intrinsic 介面"
 
-#: fortran/resolve.cc:2878
+#: fortran/resolve.cc:2895
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "函式『%s』於 %L 是 INTRINSIC 但是不是相容與 intrinsic"
 
-#: fortran/resolve.cc:2933
+#: fortran/resolve.cc:2950
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "無法解析特定的函式『%s』於 %L"
 
-#: fortran/resolve.cc:3010
+#: fortran/resolve.cc:3027
 #, gcc-internal-format
 msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:3042
+#: fortran/resolve.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.cc:3046 fortran/resolve.cc:17679
+#: fortran/resolve.cc:3063 fortran/resolve.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.cc:3170
+#: fortran/resolve.cc:3187
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部 FORALL %s"
 
-#: fortran/resolve.cc:3177
+#: fortran/resolve.cc:3194
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部做共時 %s"
 
-#: fortran/resolve.cc:3184
+#: fortran/resolve.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部 FORALL %s"
 
-#: fortran/resolve.cc:3251
+#: fortran/resolve.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "未預期的垃圾之後 NOWAIT 子句於 %C"
 
-#: fortran/resolve.cc:3262
+#: fortran/resolve.cc:3279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "『%s』於 %L 並非函式"
 
-#: fortran/resolve.cc:3270 fortran/resolve.cc:3785
+#: fortran/resolve.cc:3287 fortran/resolve.cc:3802
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "摘要介面『%s』必須不被引用於 %L"
 
-#: fortran/resolve.cc:3282
+#: fortran/resolve.cc:3299
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.cc:3325
+#: fortran/resolve.cc:3342
 #, fuzzy, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "函式『%s』被宣告字元 (*) 和無法使用的於 %L 自從它並非虛引數"
 
-#: fortran/resolve.cc:3359
+#: fortran/resolve.cc:3376
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "<unresolved overloaded function type>"
 
-#: fortran/resolve.cc:3373
+#: fortran/resolve.cc:3390
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.cc:3389
+#: fortran/resolve.cc:3406
 #, fuzzy, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "使用者自訂 non-ELEMENTAL 函式『%s』於 %L 不允許在中 WORKSHARE 建構"
 
-#: fortran/resolve.cc:3451
+#: fortran/resolve.cc:3468
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "條目『%s』於 %L 無法 called 遞迴，因為函式『%s』不是遞迴"
 
-#: fortran/resolve.cc:3455
+#: fortran/resolve.cc:3472
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "函式『%s』於 %L 無法 called 遞迴，因為它不是遞迴"
 
-#: fortran/resolve.cc:3513
+#: fortran/resolve.cc:3530
 #, fuzzy, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
 msgstr "%qE 被不宜用"
 
-#: fortran/resolve.cc:3529
+#: fortran/resolve.cc:3546
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中 FORALL 區塊於 %L 不是 PURE"
 
-#: fortran/resolve.cc:3535
+#: fortran/resolve.cc:3552
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中做共時區塊於 %L 不是 PURE"
 
-#: fortran/resolve.cc:3541
+#: fortran/resolve.cc:3558
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "副常式呼叫到『%s』於 %L 不是 PURE"
 
-#: fortran/resolve.cc:3609
+#: fortran/resolve.cc:3626
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "沒有任何特定的副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.cc:3618
+#: fortran/resolve.cc:3635
 #, fuzzy, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "通用副常式『%s』於 %L 不是一致的與 intrinsic 副常式介面"
 
-#: fortran/resolve.cc:3653
+#: fortran/resolve.cc:3670
 #, fuzzy, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "副常式『%s』於 %L 是 INTRINSIC 但是不是相容與 intrinsic"
 
-#: fortran/resolve.cc:3698
+#: fortran/resolve.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "無法解析特定的副常式『%s』於 %L"
 
-#: fortran/resolve.cc:3756
+#: fortran/resolve.cc:3773
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "『%s』於 %L 有型態，該項不是一致的與呼叫於 %L"
 
-#: fortran/resolve.cc:3795
+#: fortran/resolve.cc:3812
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "條目『%s』於 %L 無法 called 遞迴，因為副常式『%s』不是遞迴"
 
-#: fortran/resolve.cc:3799
+#: fortran/resolve.cc:3816
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "副常式『%s』於 %L 無法 called 遞迴，因為它不是遞迴"
 
-#: fortran/resolve.cc:3844
+#: fortran/resolve.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "<unresolved overloaded function type>"
 
-#: fortran/resolve.cc:3861
+#: fortran/resolve.cc:3878
 #, fuzzy, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
 msgstr "%qE 被不宜用"
 
-#: fortran/resolve.cc:3888
+#: fortran/resolve.cc:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L 和 %L 處的運算元外形不相容"
 
-#: fortran/resolve.cc:3940
+#: fortran/resolve.cc:3957
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4043
+#: fortran/resolve.cc:4060
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.cc:4047
+#: fortran/resolve.cc:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "alwaysinline 函式也許無法是 inlinable(_I)"
 
-#: fortran/resolve.cc:4124
+#: fortran/resolve.cc:4141
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "By-value 引數於 %L 無法陣列或陣列區段"
 
-#: fortran/resolve.cc:4148
+#: fortran/resolve.cc:4165
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.cc:4322 fortran/resolve.cc:4337
+#: fortran/resolve.cc:4339 fortran/resolve.cc:4354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "By-value 引數於 %L 無法陣列或陣列區段"
 
-#: fortran/resolve.cc:4376
+#: fortran/resolve.cc:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.cc:4378
+#: fortran/resolve.cc:4395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.cc:4438
+#: fortran/resolve.cc:4455
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.cc:4724
+#: fortran/resolve.cc:4741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.cc:4729
+#: fortran/resolve.cc:4746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中 codimension %d"
 
-#: fortran/resolve.cc:4739
+#: fortran/resolve.cc:4756
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.cc:4744
+#: fortran/resolve.cc:4761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中 codimension %d"
 
-#: fortran/resolve.cc:4765
+#: fortran/resolve.cc:4782
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零間隔無效"
 
-#: fortran/resolve.cc:4782
+#: fortran/resolve.cc:4799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.cc:4790
+#: fortran/resolve.cc:4807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.cc:4806
+#: fortran/resolve.cc:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.cc:4815
+#: fortran/resolve.cc:4832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.cc:4831
+#: fortran/resolve.cc:4848
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "陣列參照缺少下標"
 
-#: fortran/resolve.cc:4854
+#: fortran/resolve.cc:4871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rightmost 上限的假設的大小陣列區段尚未指定於 %L"
 
-#: fortran/resolve.cc:4864
+#: fortran/resolve.cc:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L 處陣列參照中秩不匹配(%d/%d)"
 
-#: fortran/resolve.cc:4872
+#: fortran/resolve.cc:4889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Coindex 分級不匹配在中陣列參照於 %L (%d/%d)"
 
-#: fortran/resolve.cc:4888
+#: fortran/resolve.cc:4905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Coindex 的 codimension %d 必須是純量於 %L"
 
-#: fortran/resolve.cc:4916
+#: fortran/resolve.cc:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L 處陣列索引必須是標量"
 
-#: fortran/resolve.cc:4922
+#: fortran/resolve.cc:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "陣列索引於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/resolve.cc:4928
+#: fortran/resolve.cc:4945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "擴充：%L 處的 REAL 陣列索引"
 
-#: fortran/resolve.cc:4967
+#: fortran/resolve.cc:4984
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/resolve.cc:4974
+#: fortran/resolve.cc:4991
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/resolve.cc:5034
+#: fortran/resolve.cc:5051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of array reference at %C"
 msgid "Invalid array reference of a non-array entity at %L"
 msgstr "%C 處陣列參照形式無效"
 
-#: fortran/resolve.cc:5048
+#: fortran/resolve.cc:5065
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.cc:5060
+#: fortran/resolve.cc:5077
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.cc:5105
+#: fortran/resolve.cc:5122
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L 處陣列索引是一個秩為 %d 的陣列"
 
-#: fortran/resolve.cc:5203
+#: fortran/resolve.cc:5220
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L 處的子字串起始索引類型必須為 INTEGER"
 
-#: fortran/resolve.cc:5210
+#: fortran/resolve.cc:5227
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L 處的子字串起始索引必須是標量"
 
-#: fortran/resolve.cc:5232
+#: fortran/resolve.cc:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L 處的子字串終止索引類型必須為 INTEGER"
 
-#: fortran/resolve.cc:5239
+#: fortran/resolve.cc:5256
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L 處的子字串終止索引必須是標量"
 
-#: fortran/resolve.cc:5259
+#: fortran/resolve.cc:5276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "子字串結束索引於 %L 太大"
 
-#: fortran/resolve.cc:5450
+#: fortran/resolve.cc:5467
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/resolve.cc:5464
+#: fortran/resolve.cc:5481
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有指標屬性於 %L"
 
-#: fortran/resolve.cc:5474
+#: fortran/resolve.cc:5491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有 ALLOCATABLE 屬性於 %L"
 
-#: fortran/resolve.cc:5520
+#: fortran/resolve.cc:5537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "兩個以上部分參考與非零值分級必須不被指定的於 %L"
 
-#: fortran/resolve.cc:5612
+#: fortran/resolve.cc:5629
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.cc:5694
+#: fortran/resolve.cc:5711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.cc:5704
+#: fortran/resolve.cc:5721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -78257,12 +78277,12 @@ msgstr "假定外形的陣列在 %L 處必須是啞引數"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5714
+#: fortran/resolve.cc:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5733
+#: fortran/resolve.cc:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -78271,294 +78291,294 @@ msgstr "假定外形的陣列在 %L 處必須是啞引數"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.cc:5743
+#: fortran/resolve.cc:5760
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.cc:5754
+#: fortran/resolve.cc:5771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.cc:5763
+#: fortran/resolve.cc:5780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.cc:5779
+#: fortran/resolve.cc:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.cc:5961
+#: fortran/resolve.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』，已用於規格運算式，被引用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.cc:5966
+#: fortran/resolve.cc:5983
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』被使用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.cc:6036
+#: fortran/resolve.cc:6053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphic 子物件的 coindexed 物件於 %L"
 
-#: fortran/resolve.cc:6049
+#: fortran/resolve.cc:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 物件與 polymorphic allocatable subcomponent 於 %L"
 
-#: fortran/resolve.cc:6065
+#: fortran/resolve.cc:6082
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE 被不宜用"
 
-#: fortran/resolve.cc:6155
+#: fortran/resolve.cc:6172
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6333 fortran/resolve.cc:6485
+#: fortran/resolve.cc:6350 fortran/resolve.cc:6502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "在中 type-spec 於 %L 時發生錯誤"
 
-#: fortran/resolve.cc:6449
+#: fortran/resolve.cc:6466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Passed-object 於 %L 必須是純量"
 
-#: fortran/resolve.cc:6456
+#: fortran/resolve.cc:6473
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 procedure-pointer 成分呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.cc:6495
+#: fortran/resolve.cc:6512
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 type-bound 程序呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.cc:6504
+#: fortran/resolve.cc:6521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "基底物件用於 NOPASS type-bound 程序呼叫於 %L 必須是純量"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6692
+#: fortran/resolve.cc:6709
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "找到沒有匹配特定的繫結用於呼叫到通用『%s』於 %L"
 
-#: fortran/resolve.cc:6726
+#: fortran/resolve.cc:6743
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "『%s』於 %L 應該是副常式"
 
-#: fortran/resolve.cc:6778
+#: fortran/resolve.cc:6795
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "『%s』於 %L 應該是函式"
 
-#: fortran/resolve.cc:7313
+#: fortran/resolve.cc:7330
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要運算式類型"
 
-#: fortran/resolve.cc:7346
+#: fortran/resolve.cc:7363
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L 處)必須是一個標量"
 
-#: fortran/resolve.cc:7356
+#: fortran/resolve.cc:7373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: fortran/resolve.cc:7360 fortran/resolve.cc:7367
+#: fortran/resolve.cc:7377 fortran/resolve.cc:7384
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L 處)必須是 INTEGER"
 
-#: fortran/resolve.cc:7422
+#: fortran/resolve.cc:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "步進敘述於 %L 處的 DO 迴圈中不可為零"
 
-#: fortran/resolve.cc:7445
+#: fortran/resolve.cc:7462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "做迴圈於 %L 將被執行零次"
 
-#: fortran/resolve.cc:7462
+#: fortran/resolve.cc:7479
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7468
+#: fortran/resolve.cc:7485
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7529
+#: fortran/resolve.cc:7546
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:7534
+#: fortran/resolve.cc:7551
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 啟始敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:7541
+#: fortran/resolve.cc:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 結束敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:7549
+#: fortran/resolve.cc:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L 處的 FORALL 步幅敘述必須是 %s 標量"
 
-#: fortran/resolve.cc:7554
+#: fortran/resolve.cc:7571
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L 處的 FORALL 步幅敘述不能為零"
 
-#: fortran/resolve.cc:7567
+#: fortran/resolve.cc:7584
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引『%s』可能無法出現在中 triplet 規格於 %L"
 
-#: fortran/resolve.cc:7672 fortran/resolve.cc:7970
+#: fortran/resolve.cc:7689 fortran/resolve.cc:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object 於 %L 必須是 ALLOCATABLE 或指標"
 
-#: fortran/resolve.cc:7680 fortran/resolve.cc:7933
+#: fortran/resolve.cc:7697 fortran/resolve.cc:7950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.cc:7790
+#: fortran/resolve.cc:7807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr 於 %L 必須是純量或有同級做為 allocate-object 於 %L"
 
-#: fortran/resolve.cc:7821
+#: fortran/resolve.cc:7838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr 於 %L 和 allocate-object 於 %L 必須有相同形狀"
 
-#: fortran/resolve.cc:7981
+#: fortran/resolve.cc:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "型態的實體於 %L 是型態不相容的與 source-expr 於 %L"
 
-#: fortran/resolve.cc:7993
+#: fortran/resolve.cc:8010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "allocate-object 於 %L 和 source-expr 於 %L 應該有相同 kind 型態參數"
 
-#: fortran/resolve.cc:8007
+#: fortran/resolve.cc:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.cc:8022
+#: fortran/resolve.cc:8039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.cc:8035
+#: fortran/resolve.cc:8052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "配置 %s 的摘要基底類型於 %L 需要 type-spec 或 source-expr"
 
-#: fortran/resolve.cc:8053
+#: fortran/resolve.cc:8070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 於 %L 與 type-spec 需求相同 character-length 參數做為在中宣告"
 
-#: fortran/resolve.cc:8134 fortran/resolve.cc:8149
+#: fortran/resolve.cc:8154 fortran/resolve.cc:8169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8141
+#: fortran/resolve.cc:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8166
+#: fortran/resolve.cc:8186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Coarray 規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8176 fortran/resolve.cc:8278
+#: fortran/resolve.cc:8196 fortran/resolve.cc:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "不當的 coarray 規格在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8182
+#: fortran/resolve.cc:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8194
+#: fortran/resolve.cc:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8205 fortran/resolve.cc:8233
+#: fortran/resolve.cc:8225 fortran/resolve.cc:8253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "不當的陣列規格在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8252
+#: fortran/resolve.cc:8272
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "『%s』必須不出現在中陣列規格於 %L 在中相同配置敘述位置它是它自己配置"
 
-#: fortran/resolve.cc:8267
+#: fortran/resolve.cc:8287
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "預期『*』在中 coindex 規格在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8309
+#: fortran/resolve.cc:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable 於 %L 必須是純量整數變數"
 
-#: fortran/resolve.cc:8338
+#: fortran/resolve.cc:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.cc:8351
+#: fortran/resolve.cc:8371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG 於 %L 是無用的而無需 STAT 標籤"
 
-#: fortran/resolve.cc:8365
+#: fortran/resolve.cc:8385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.cc:8394
+#: fortran/resolve.cc:8414
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.cc:8426
+#: fortran/resolve.cc:8446
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object 於 %L 也出現於 %L"
 
-#: fortran/resolve.cc:8432 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8452 fortran/resolve.cc:8458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
@@ -78567,285 +78587,285 @@ msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8666
+#: fortran/resolve.cc:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.cc:8717
+#: fortran/resolve.cc:8737
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L 處 CASE 敘述中的運算式必須具有 %s 類型"
 
-#: fortran/resolve.cc:8728
+#: fortran/resolve.cc:8748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "運算式在中條件敘述於 %L 必須是的 kind %d"
 
-#: fortran/resolve.cc:8741
+#: fortran/resolve.cc:8761
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/resolve.cc:8787
+#: fortran/resolve.cc:8807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "選擇運算式在中計算的前往敘述於 %L 必須是純量整數運算式"
 
-#: fortran/resolve.cc:8806
+#: fortran/resolve.cc:8826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.cc:8816
+#: fortran/resolve.cc:8836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.cc:8834 fortran/resolve.cc:8842
+#: fortran/resolve.cc:8854 fortran/resolve.cc:8862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "運算式在中條件敘述於 %L 不是在中範圍的 %s"
 
-#: fortran/resolve.cc:8904 fortran/resolve.cc:9561
+#: fortran/resolve.cc:8924 fortran/resolve.cc:9592
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "預設大小寫於 %L 無法在之後秒預設大小寫於 %L"
 
-#: fortran/resolve.cc:8930
+#: fortran/resolve.cc:8950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
 
-#: fortran/resolve.cc:8943
+#: fortran/resolve.cc:8963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "常數邏輯的值在中條件敘述被重複於 %L"
 
-#: fortran/resolve.cc:8958
+#: fortran/resolve.cc:8978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "範圍規格於 %L 可以永不被匹配"
 
-#: fortran/resolve.cc:9061
+#: fortran/resolve.cc:9081
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "邏輯的選取大小寫區塊於 %L 有更多該兩大小寫"
 
-#: fortran/resolve.cc:9112
+#: fortran/resolve.cc:9143
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/resolve.cc:9121
+#: fortran/resolve.cc:9152
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名稱「%s」在 %C 處不能做為已定義的運算子"
 
-#: fortran/resolve.cc:9138
+#: fortran/resolve.cc:9169
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.cc:9154
+#: fortran/resolve.cc:9185
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9161
+#: fortran/resolve.cc:9192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.cc:9166
+#: fortran/resolve.cc:9197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.cc:9188
+#: fortran/resolve.cc:9220
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.cc:9199
+#: fortran/resolve.cc:9230
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9431
+#: fortran/resolve.cc:9462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "選擇器應該是 polymorphic 在中選取型態敘述於 %L"
 
-#: fortran/resolve.cc:9469 fortran/resolve.cc:9481
+#: fortran/resolve.cc:9500 fortran/resolve.cc:9512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.cc:9510
+#: fortran/resolve.cc:9541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.cc:9523
+#: fortran/resolve.cc:9554
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.cc:9536
+#: fortran/resolve.cc:9567
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "衍生類型『%s』於 %L 必須是延伸的『%s』"
 
-#: fortran/resolve.cc:9539
+#: fortran/resolve.cc:9570
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/resolve.cc:9549
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/resolve.cc:9796
+#: fortran/resolve.cc:9827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "雙倍類別是區塊在中選取型態敘述於 %L"
 
-#: fortran/resolve.cc:9930
+#: fortran/resolve.cc:9961
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9939
+#: fortran/resolve.cc:9970
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9942
+#: fortran/resolve.cc:9973
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9952 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9983 fortran/resolve.cc:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10066
+#: fortran/resolve.cc:10097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.cc:10120
+#: fortran/resolve.cc:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/resolve.cc:10130
+#: fortran/resolve.cc:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法 polymorphic 除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10143
+#: fortran/resolve.cc:10174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10152
+#: fortran/resolve.cc:10183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.cc:10159
+#: fortran/resolve.cc:10190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有 ALLOCATABLE 成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10170
+#: fortran/resolve.cc:10201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "資料轉移元件於 %L 無法有私人的成分"
 
-#: fortran/resolve.cc:10176
+#: fortran/resolve.cc:10207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10194
+#: fortran/resolve.cc:10225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "資料轉移元件於 %L 無法全部參考到 assumed-size 陣列"
 
-#: fortran/resolve.cc:10251
+#: fortran/resolve.cc:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.cc:10261
+#: fortran/resolve.cc:10292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.cc:10265
+#: fortran/resolve.cc:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.cc:10268
+#: fortran/resolve.cc:10299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.cc:10275 fortran/resolve.cc:10397
+#: fortran/resolve.cc:10306 fortran/resolve.cc:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.cc:10287 fortran/resolve.cc:10409
+#: fortran/resolve.cc:10318 fortran/resolve.cc:10440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.cc:10299
+#: fortran/resolve.cc:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=引數於 %L 必須是純量邏輯的變數"
 
-#: fortran/resolve.cc:10312
+#: fortran/resolve.cc:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.cc:10373
+#: fortran/resolve.cc:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.cc:10377 fortran/resolve.cc:10387
+#: fortran/resolve.cc:10408 fortran/resolve.cc:10418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset 引數於 %L 必須介於 1 和 numimages()(_I)"
 
-#: fortran/resolve.cc:10440
+#: fortran/resolve.cc:10471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "敘述於 %L 並非有效分支目標敘述用於分支敘述於 %L"
 
-#: fortran/resolve.cc:10450
+#: fortran/resolve.cc:10481
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "分支於 %L 也許會導致無窮迴圈"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10467 fortran/resolve.cc:10490
+#: fortran/resolve.cc:10498 fortran/resolve.cc:10521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往敘述於 %L 樹葉重要建構用於標貼於 %L"
 
-#: fortran/resolve.cc:10471 fortran/resolve.cc:10496
+#: fortran/resolve.cc:10502 fortran/resolve.cc:10527
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
@@ -78853,213 +78873,213 @@ msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10511
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "標貼於 %L 不是在中相同區塊做為前往敘述於 %L"
 
-#: fortran/resolve.cc:10583
+#: fortran/resolve.cc:10614
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "位置遮罩於 %L 有不一致形狀"
 
-#: fortran/resolve.cc:10599
+#: fortran/resolve.cc:10630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "位置指派目標於 %L 有不一致形狀"
 
-#: fortran/resolve.cc:10612 fortran/resolve.cc:10704
+#: fortran/resolve.cc:10643 fortran/resolve.cc:10735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL 使用者定義的指派在中位置於 %L"
 
-#: fortran/resolve.cc:10622 fortran/resolve.cc:10714
+#: fortran/resolve.cc:10653 fortran/resolve.cc:10745
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L 處在 WHERE 內不支援的敘述"
 
-#: fortran/resolve.cc:10653
+#: fortran/resolve.cc:10684
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.cc:10662
+#: fortran/resolve.cc:10693
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL 與索引『%s』未被使用左側的側邊的指派於 %L 和因而也許造成多重指派到這個物件"
 
-#: fortran/resolve.cc:10819
+#: fortran/resolve.cc:10850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008:區塊建構於 %C"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:10850
+#: fortran/resolve.cc:10881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "外 FORALL 建構已經有索引與這個名稱 %L"
 
-#: fortran/resolve.cc:10932
+#: fortran/resolve.cc:10958
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L 處的 WHERE/ELSEWHERE 子句需要一個 LOGICAL 陣列"
 
-#: fortran/resolve.cc:11048
+#: fortran/resolve.cc:11074
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11161
+#: fortran/resolve.cc:11187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/resolve.cc:11193
+#: fortran/resolve.cc:11219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Coindexed 運算式於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11199
+#: fortran/resolve.cc:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11211
+#: fortran/resolve.cc:11237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "指派到 coindexed 變數於 %L 在中 PURE 程序"
 
-#: fortran/resolve.cc:11243
+#: fortran/resolve.cc:11269
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11247
+#: fortran/resolve.cc:11273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.cc:11252
+#: fortran/resolve.cc:11278
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11259
+#: fortran/resolve.cc:11285
 #, fuzzy, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "變數必須不是 polymorphic 在中 intrinsic 指派於 %L - 檢查該有匹配特定的副常式用於『=』運算子"
 
-#: fortran/resolve.cc:11270
+#: fortran/resolve.cc:11296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Coindexed 變數必須不是有 allocatable ultimate 成分在中指派於 %L"
 
-#: fortran/resolve.cc:11693
+#: fortran/resolve.cc:11719
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:11997
+#: fortran/resolve.cc:12023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/resolve.cc:12009
+#: fortran/resolve.cc:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/resolve.cc:12094
+#: fortran/resolve.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.cc:12285
+#: fortran/resolve.cc:12311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.cc:12321
+#: fortran/resolve.cc:12347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "指派的前往敘述於 %L 需求整數變數"
 
-#: fortran/resolve.cc:12325
+#: fortran/resolve.cc:12351
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/resolve.cc:12336
+#: fortran/resolve.cc:12362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "交替回傳敘述於 %L 需要 SCALAR-INTEGER 回傳說明符"
 
-#: fortran/resolve.cc:12374
+#: fortran/resolve.cc:12400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "%C 處 CASE 中需要初始化運算式"
 
-#: fortran/resolve.cc:12416
+#: fortran/resolve.cc:12442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "指派敘述於 %L 需要純量預設整數變數"
 
-#: fortran/resolve.cc:12463
+#: fortran/resolve.cc:12489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.cc:12467
+#: fortran/resolve.cc:12493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "算術如果敘述於 %L 需要數值運算式"
 
-#: fortran/resolve.cc:12528
+#: fortran/resolve.cc:12554
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12533
+#: fortran/resolve.cc:12559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "離開條件的做當迴圈於 %L 必須是純量邏輯的運算式"
 
-#: fortran/resolve.cc:12617
+#: fortran/resolve.cc:12643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL 遮罩子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12745
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/resolve.cc:12740
+#: fortran/resolve.cc:12766
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "未使用的參數『%s』宣告的於 %L"
 
-#: fortran/resolve.cc:12834
+#: fortran/resolve.cc:12860
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:12848
+#: fortran/resolve.cc:12874
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -79067,1001 +79087,1001 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:12867
+#: fortran/resolve.cc:12893
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
-#: fortran/resolve.cc:12953
+#: fortran/resolve.cc:12979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "字串長度於 %L 太大"
 
-#: fortran/resolve.cc:13188
+#: fortran/resolve.cc:13214
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可指派的陣列「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.cc:13192
+#: fortran/resolve.cc:13218
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "純量物件『%s』於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.cc:13200
+#: fortran/resolve.cc:13226
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "陣列指標「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.cc:13211
+#: fortran/resolve.cc:13237
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "陣列「%s」在 %L 處不能有延遲的外形"
 
-#: fortran/resolve.cc:13228
+#: fortran/resolve.cc:13254
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "型態『%s』的類別變數『%s』於 %L 不是 extensible"
 
-#: fortran/resolve.cc:13240
+#: fortran/resolve.cc:13266
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "類別變數『%s』於 %L 必須是虛設，allocatable 或指標"
 
-#: fortran/resolve.cc:13273
+#: fortran/resolve.cc:13299
 #, fuzzy, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "型態『%s』無法主機關聯的於 %L 因為它被阻斷由不相容的物件的同名宣告的於 %L"
 
-#: fortran/resolve.cc:13295
+#: fortran/resolve.cc:13321
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008:意味著的儲存用於模組變數『%s』於 %L, 所需的由於預設初始化"
 
-#: fortran/resolve.cc:13328
+#: fortran/resolve.cc:13354
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13364
+#: fortran/resolve.cc:13390
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "模組或主程式陣列「%s」在 %L 處必須有常態的外形"
 
-#: fortran/resolve.cc:13389
+#: fortran/resolve.cc:13415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "實體與假設的字元長度於 %L 必須是虛引數或參數"
 
-#: fortran/resolve.cc:13410
+#: fortran/resolve.cc:13436
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "『%s』於 %L 必須有常數字元長度在中這個語境"
 
-#: fortran/resolve.cc:13417
+#: fortran/resolve.cc:13443
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.cc:13464
+#: fortran/resolve.cc:13490
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可指派的「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13467
+#: fortran/resolve.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13470
+#: fortran/resolve.cc:13496
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13473
+#: fortran/resolve.cc:13499
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "內建函式「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13476
+#: fortran/resolve.cc:13502
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函式結果「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13479
+#: fortran/resolve.cc:13505
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自動陣列「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13521
+#: fortran/resolve.cc:13547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，於 %s:%d"
 
-#: fortran/resolve.cc:13553
+#: fortran/resolve.cc:13579
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Character-valued 敘述函式『%s』於 %L 必須有常數長度"
 
-#: fortran/resolve.cc:13576
+#: fortran/resolve.cc:13602
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:『%s』是的私人的型態和無法虛引數的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.cc:13598
+#: fortran/resolve.cc:13624
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003:程序『%s』在中公用的介面『%s』於 %L 需虛引數的『%s』該項是私人的"
 
-#: fortran/resolve.cc:13616
+#: fortran/resolve.cc:13642
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: fortran/resolve.cc:13628
+#: fortran/resolve.cc:13654
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部物件「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13638
+#: fortran/resolve.cc:13664
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL 函式『%s』於 %L 必須有純量結果"
 
-#: fortran/resolve.cc:13648
+#: fortran/resolve.cc:13674
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "敘述函式『%s』於 %L 可能無法有指標或 allocatable 屬性"
 
-#: fortran/resolve.cc:13667
+#: fortran/resolve.cc:13693
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以陣列賦值"
 
-#: fortran/resolve.cc:13671
+#: fortran/resolve.cc:13697
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.cc:13675
+#: fortran/resolve.cc:13701
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.cc:13679
+#: fortran/resolve.cc:13705
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "字元 (*) 函式『%s』於 %L 無法遞迴"
 
-#: fortran/resolve.cc:13692
+#: fortran/resolve.cc:13718
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.cc:13703
+#: fortran/resolve.cc:13729
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/resolve.cc:13709
+#: fortran/resolve.cc:13735
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "虛設程序『%s』於 %C 無法有通用介面"
 
-#: fortran/resolve.cc:13729
+#: fortran/resolve.cc:13755
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.cc:13786
+#: fortran/resolve.cc:13812
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "程序屬性衝突與儲存屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:13792
+#: fortran/resolve.cc:13818
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "程序屬性衝突與含義屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:13798
+#: fortran/resolve.cc:13824
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "程序屬性衝突與結果屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:13806
+#: fortran/resolve.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "外部屬性衝突與函式屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:13812
+#: fortran/resolve.cc:13838
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "程序指標結果『%s』於 %L 缺少指標屬性"
 
-#: fortran/resolve.cc:13855
+#: fortran/resolve.cc:13881
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13863
+#: fortran/resolve.cc:13889
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13871
+#: fortran/resolve.cc:13897
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:13880
+#: fortran/resolve.cc:13906
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:13904
+#: fortran/resolve.cc:13930
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "介面『%s』的程序『%s』於 %L 必須是明確的"
 
-#: fortran/resolve.cc:13974
+#: fortran/resolve.cc:14000
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "最後的程序『%s』於 %L 並非副常式"
 
-#: fortran/resolve.cc:13983
+#: fortran/resolve.cc:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "最後的程序於 %L 必須有精確的一個引數"
 
-#: fortran/resolve.cc:13991 fortran/resolve.cc:14008
+#: fortran/resolve.cc:14017 fortran/resolve.cc:14034
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "引數的最後的程序於 %L 必須是的型態『%s』"
 
-#: fortran/resolve.cc:13999
+#: fortran/resolve.cc:14025
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14016
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "引數的最後的程序於 %L 必須不是指標"
 
-#: fortran/resolve.cc:14022
+#: fortran/resolve.cc:14048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "引數的最後的程序於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.cc:14028
+#: fortran/resolve.cc:14054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "引數的最後的程序於 %L 必須不是可選的"
 
-#: fortran/resolve.cc:14036
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "引數的最後的程序於 %L 必須不是含義 (出)"
 
-#: fortran/resolve.cc:14045
+#: fortran/resolve.cc:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Non-scalar 最後的程序於 %L 應該已假設形狀引數"
 
-#: fortran/resolve.cc:14067
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "最後的程序『%s』宣告的於 %L 有同級 (%d) 做為『%s』"
 
-#: fortran/resolve.cc:14104
+#: fortran/resolve.cc:14130
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "只有陣列最後的程序宣告的用於衍生類型『%s』定義的於 %L, 建議也純量一個"
 
-#: fortran/resolve.cc:14145
+#: fortran/resolve.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "『%s』和『%s』無法混合的函式/副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.cc:14181
+#: fortran/resolve.cc:14207
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "『%s』和『%s』用於通用『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.cc:14240
+#: fortran/resolve.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定義的特定的繫結『%s』做為目標的通用『%s』於 %L"
 
-#: fortran/resolve.cc:14252
+#: fortran/resolve.cc:14278
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "通用『%s』於 %L 必須目標特定的繫結，『%s』是通用，太"
 
-#: fortran/resolve.cc:14280
+#: fortran/resolve.cc:14306
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "通用『%s』於 %L 無法覆寫特定的繫結與同名"
 
-#: fortran/resolve.cc:14336
+#: fortran/resolve.cc:14362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound 運算子於 %L 無法 NOPASS"
 
-#: fortran/resolve.cc:14548
+#: fortran/resolve.cc:14574
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "『%s』必須是模組程序或外部程序與明確的介面於 %L"
 
-#: fortran/resolve.cc:14591
+#: fortran/resolve.cc:14617
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.cc:14605
+#: fortran/resolve.cc:14631
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.cc:14619 fortran/resolve.cc:15107
+#: fortran/resolve.cc:14645 fortran/resolve.cc:15133
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Non-polymorphic passed-object 虛引數的『%s』於 %L"
 
-#: fortran/resolve.cc:14627
+#: fortran/resolve.cc:14653
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.cc:14636
+#: fortran/resolve.cc:14662
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是純量"
 
-#: fortran/resolve.cc:14642
+#: fortran/resolve.cc:14668
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.cc:14648
+#: fortran/resolve.cc:14674
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是指標"
 
-#: fortran/resolve.cc:14677
+#: fortran/resolve.cc:14703
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "程序『%s』於 %L 有同名做為成分的『%s』"
 
-#: fortran/resolve.cc:14687
+#: fortran/resolve.cc:14713
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "程序『%s』於 %L 有同名做為繼承的成分的『%s』"
 
-#: fortran/resolve.cc:14782
+#: fortran/resolve.cc:14808
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "衍生類型『%s』宣告的於 %L 必須是摘要因為『%s』是已推遲和無法 overridden"
 
-#: fortran/resolve.cc:14887
+#: fortran/resolve.cc:14913
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Coarray 成分『%s』於 %L 必須是 allocatable 與已推遲形狀"
 
-#: fortran/resolve.cc:14896
+#: fortran/resolve.cc:14922
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.cc:14906
+#: fortran/resolve.cc:14932
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.cc:14931
+#: fortran/resolve.cc:14957
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/resolve.cc:14942
+#: fortran/resolve.cc:14968
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L 處 ICHAR 的參數長度必須為 1"
 
-#: fortran/resolve.cc:15040
+#: fortran/resolve.cc:15066
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序指標成分『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.cc:15054
+#: fortran/resolve.cc:15080
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "程序指標成分『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.cc:15070
+#: fortran/resolve.cc:15096
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.cc:15080
+#: fortran/resolve.cc:15106
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是純量"
 
-#: fortran/resolve.cc:15089
+#: fortran/resolve.cc:15115
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法有指標屬性"
 
-#: fortran/resolve.cc:15098
+#: fortran/resolve.cc:15124
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.cc:15140
+#: fortran/resolve.cc:15166
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "成分『%s』的『%s』於 %L 有同名做為繼承 type-bound 程序"
 
-#: fortran/resolve.cc:15153
+#: fortran/resolve.cc:15179
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "字元長度的成分『%s』需要是常數規格運算式於 %L"
 
-#: fortran/resolve.cc:15164
+#: fortran/resolve.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "運算式於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/resolve.cc:15177
+#: fortran/resolve.cc:15203
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字元成分『%s』的『%s』於 %L 與已推遲長度必須是指標或 ALLOCATABLE"
 
-#: fortran/resolve.cc:15210
+#: fortran/resolve.cc:15236
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:成分『%s』是私人的型態和無法成分的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.cc:15218
+#: fortran/resolve.cc:15244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 於 %L 在中序列或繫結©型態 %s"
 
-#: fortran/resolve.cc:15227
+#: fortran/resolve.cc:15253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "成分 %s 的序列型態宣告的於 %L 沒有序列屬性"
 
-#: fortran/resolve.cc:15313
+#: fortran/resolve.cc:15339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "衝突在中屬性的函式引數於 %C"
 
-#: fortran/resolve.cc:15358
+#: fortran/resolve.cc:15384
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "做為延伸型態『%s』於 %L 有 coarray 成分，親代型態『%s』應該也有一個"
 
-#: fortran/resolve.cc:15371
+#: fortran/resolve.cc:15397
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Non-extensible 衍生類型『%s』於 %L 必須不是摘要"
 
-#: fortran/resolve.cc:15435
+#: fortran/resolve.cc:15461
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15468
+#: fortran/resolve.cc:15494
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.cc:15482
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.cc:15550
+#: fortran/resolve.cc:15576
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.cc:15556
+#: fortran/resolve.cc:15582
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:15562
+#: fortran/resolve.cc:15588
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:15570
+#: fortran/resolve.cc:15596
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:15587
+#: fortran/resolve.cc:15613
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:15609
+#: fortran/resolve.cc:15635
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:15620
+#: fortran/resolve.cc:15646
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:15647
+#: fortran/resolve.cc:15673
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:15666
+#: fortran/resolve.cc:15692
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.cc:15682
+#: fortran/resolve.cc:15708
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.cc:15693
+#: fortran/resolve.cc:15719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.cc:15701
+#: fortran/resolve.cc:15727
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.cc:15752
+#: fortran/resolve.cc:15778
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
-#: fortran/resolve.cc:15763
+#: fortran/resolve.cc:15789
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:15770
+#: fortran/resolve.cc:15796
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:15810
+#: fortran/resolve.cc:15836
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:15823
+#: fortran/resolve.cc:15849
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:15881
+#: fortran/resolve.cc:15907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.cc:15884
+#: fortran/resolve.cc:15910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.cc:15984
+#: fortran/resolve.cc:16010
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.cc:16005
+#: fortran/resolve.cc:16031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "不當的規格用於假設的大小陣列於 %C"
 
-#: fortran/resolve.cc:16018
+#: fortran/resolve.cc:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16047
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.cc:16031
+#: fortran/resolve.cc:16057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.cc:16038
+#: fortran/resolve.cc:16064
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16051
+#: fortran/resolve.cc:16077
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.cc:16057
+#: fortran/resolve.cc:16083
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.cc:16067
+#: fortran/resolve.cc:16093
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.cc:16076
+#: fortran/resolve.cc:16102
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.cc:16089 fortran/resolve.cc:16266
+#: fortran/resolve.cc:16115 fortran/resolve.cc:16292
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.cc:16103
+#: fortran/resolve.cc:16129
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16112
+#: fortran/resolve.cc:16138
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16121
+#: fortran/resolve.cc:16147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.cc:16129
+#: fortran/resolve.cc:16155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.cc:16136
+#: fortran/resolve.cc:16162
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16156
+#: fortran/resolve.cc:16182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.cc:16163
+#: fortran/resolve.cc:16189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.cc:16170
+#: fortran/resolve.cc:16196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.cc:16177
+#: fortran/resolve.cc:16203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.cc:16203
+#: fortran/resolve.cc:16229
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.cc:16213
+#: fortran/resolve.cc:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "%s 的參數(位於 %L)長度必須為 1"
 
-#: fortran/resolve.cc:16292
+#: fortran/resolve.cc:16318
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.cc:16307
+#: fortran/resolve.cc:16333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.cc:16320
+#: fortran/resolve.cc:16346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.cc:16338
+#: fortran/resolve.cc:16364
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.cc:16350
+#: fortran/resolve.cc:16376
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.cc:16359
+#: fortran/resolve.cc:16385
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.cc:16372
+#: fortran/resolve.cc:16398
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.cc:16381
+#: fortran/resolve.cc:16407
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.cc:16394
+#: fortran/resolve.cc:16420
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.cc:16410
+#: fortran/resolve.cc:16436
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.cc:16418
+#: fortran/resolve.cc:16444
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.cc:16425
+#: fortran/resolve.cc:16451
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.cc:16438
+#: fortran/resolve.cc:16464
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.cc:16447
+#: fortran/resolve.cc:16473
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.cc:16463
+#: fortran/resolve.cc:16489
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.cc:16469
+#: fortran/resolve.cc:16495
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.cc:16494
+#: fortran/resolve.cc:16520
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/resolve.cc:16565
+#: fortran/resolve.cc:16591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.cc:16577
+#: fortran/resolve.cc:16603
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:16693
+#: fortran/resolve.cc:16719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/resolve.cc:16701
+#: fortran/resolve.cc:16727
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.cc:16708
+#: fortran/resolve.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.cc:16715
+#: fortran/resolve.cc:16741
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.cc:16731
+#: fortran/resolve.cc:16757
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.cc:16738
+#: fortran/resolve.cc:16764
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:16747
+#: fortran/resolve.cc:16773
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "引數『%s』的 elemental 程序於 %L 無法有 ALLOCATABLE 屬性"
 
-#: fortran/resolve.cc:16793
+#: fortran/resolve.cc:16819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.cc:16806
+#: fortran/resolve.cc:16832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.cc:16905
+#: fortran/resolve.cc:16931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:16913
+#: fortran/resolve.cc:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:16921
+#: fortran/resolve.cc:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:16928
+#: fortran/resolve.cc:16954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:17053
+#: fortran/resolve.cc:17079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.cc:17219
+#: fortran/resolve.cc:17245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.cc:17225
+#: fortran/resolve.cc:17251
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.cc:17309
+#: fortran/resolve.cc:17335
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.cc:17318
+#: fortran/resolve.cc:17344
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.cc:17326
+#: fortran/resolve.cc:17352
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.cc:17342
+#: fortran/resolve.cc:17368
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.cc:17445
+#: fortran/resolve.cc:17471
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.cc:17460
+#: fortran/resolve.cc:17486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.cc:17485
+#: fortran/resolve.cc:17511
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.cc:17494
+#: fortran/resolve.cc:17520
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.cc:17569
+#: fortran/resolve.cc:17595
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.cc:17580
+#: fortran/resolve.cc:17606
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.cc:17591
+#: fortran/resolve.cc:17617
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.cc:17622
+#: fortran/resolve.cc:17648
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C 處指定字元長度時語法錯誤"
 
-#: fortran/resolve.cc:17689
+#: fortran/resolve.cc:17715
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.cc:17702
+#: fortran/resolve.cc:17728
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.cc:17724
+#: fortran/resolve.cc:17750
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.cc:17734
+#: fortran/resolve.cc:17760
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.cc:17742
+#: fortran/resolve.cc:17768
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.cc:17756
+#: fortran/resolve.cc:17782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.cc:17774
+#: fortran/resolve.cc:17800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.cc:17781
+#: fortran/resolve.cc:17807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.cc:17860
+#: fortran/resolve.cc:17886
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -80982,7 +81002,7 @@ msgstr "重疊 unequal 初始設定式在中等價於 %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "重疊 unequal 初始設定式在中等價於 %L"
 
-#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9462
+#: fortran/trans-array.cc:2318 fortran/trans-expr.cc:9505
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
@@ -80994,12 +81014,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "元件號碼的在中陣列建構子於 %L 需求增加的允許 %d 上限。  參看 -fmax-array-constructor 選項"
 
-#: fortran/trans-array.cc:8572
+#: fortran/trans-array.cc:8584
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "建立陣列暫時的於 %L 用於引數『%s』"
 
-#: fortran/trans-array.cc:11864
+#: fortran/trans-array.cc:11887
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "不當的運算式型態在的期間遍歷 (%d)"
@@ -81092,82 +81112,87 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr ""
 
 #: fortran/trans-decl.cc:1795
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s at %C has no default type"
+msgstr "符號「%s」(位於 %L)沒有 IMPLICIT 類型"
+
+#: fortran/trans-decl.cc:1798
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "內建函式變數不是一個程序"
 
-#: fortran/trans-decl.cc:4545 fortran/trans-decl.cc:7789
+#: fortran/trans-decl.cc:4548 fortran/trans-decl.cc:7793
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "傳回值的函式『%s』於 %L 無法設定"
 
-#: fortran/trans-decl.cc:5037
+#: fortran/trans-decl.cc:5040
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "已推遲型態參數尚未支援"
 
-#: fortran/trans-decl.cc:5270
+#: fortran/trans-decl.cc:5273
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "模組變數 %s 的後端程式宣告已存在"
 
-#: fortran/trans-decl.cc:5283
+#: fortran/trans-decl.cc:5286
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "未使用的變數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.cc:5905
+#: fortran/trans-decl.cc:5908
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/trans-decl.cc:5908
+#: fortran/trans-decl.cc:5911
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/trans-decl.cc:5923
+#: fortran/trans-decl.cc:5926
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "虛引數『%s』於 %L 被宣告含義 (出) 但是不是設定"
 
-#: fortran/trans-decl.cc:5929
+#: fortran/trans-decl.cc:5932
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "衍生類型虛引數『%s』於 %L 被宣告含義 (出) 但是不是設定和沒有預設初始設定式"
 
-#: fortran/trans-decl.cc:5940 fortran/trans-decl.cc:6091
+#: fortran/trans-decl.cc:5943 fortran/trans-decl.cc:6094
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "未使用的虛引數『%s』於 %L"
 
-#: fortran/trans-decl.cc:5956
+#: fortran/trans-decl.cc:5959
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "未使用的模組變數『%s』該項已被明確的匯入的於 %L"
 
-#: fortran/trans-decl.cc:5975
+#: fortran/trans-decl.cc:5978
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "未使用的變數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.cc:6024
+#: fortran/trans-decl.cc:6027
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "未使用的參數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.cc:6028
+#: fortran/trans-decl.cc:6031
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "未使用的參數『%s』該項已被明確的匯入的於 %L"
 
-#: fortran/trans-decl.cc:6058
+#: fortran/trans-decl.cc:6061
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "傳回值『%s』的函式『%s』宣告的於 %L 無法設定"
 
-#: fortran/trans-decl.cc:6655
+#: fortran/trans-decl.cc:6658
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -81182,27 +81207,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2202
+#: fortran/trans-expr.cc:2207
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2211
+#: fortran/trans-expr.cc:2216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "無限制的多型於 %C 尚未支援"
 
-#: fortran/trans-expr.cc:3887
+#: fortran/trans-expr.cc:3895
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "不明的內建作業"
 
-#: fortran/trans-expr.cc:5405
+#: fortran/trans-expr.cc:5413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "不明引數清單函式於 %L"
 
-#: fortran/trans-expr.cc:10034
+#: fortran/trans-expr.cc:10077
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -83067,6 +83092,10 @@ msgstr "未使用的參數 %q+D"
 #~ msgid "PIC register isn't set up"
 #~ msgstr "尚未設定好 PIC 暫存器"
 
+#, fuzzy
+#~ msgid "invalid operand size for operand code 'Z'"
+#~ msgstr "無效的運算元大小用於運算元編碼『%c』"
+
 #, fuzzy
 #~ msgid "operand is not a condition code, invalid operand code 'I'"
 #~ msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"

commit 45b94986b1640f914eeefd876f30987144b65f18
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Apr 28 03:11:38 2023

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index faac45ae8d2..dd82014ea01 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20230427
+20230428
diff --git a/gcc/c/ChangeLog b/gcc/c/ChangeLog
index 2f8b8d7b0e8..70f4e11ec73 100644
--- a/gcc/c/ChangeLog
+++ b/gcc/c/ChangeLog
@@ -1,3 +1,23 @@
+2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/109409
+	* c-parser.cc (c_parser_initializer): Move diagnostics about
+	initialization of variable sized object with non-empty initializer
+	after c_parser_expr_no_commas call and ret.set_error (); after it.
+
+2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/107682
+	PR c/109412
+	* c-typeck.cc (pop_init_level): If constructor_type is FUNCTION_TYPE,
+	reject empty initializer as invalid.
+
 2023-04-26  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 2a5c36b1583..ae0e0ce5d33 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,9 @@
+2023-04-27  Joseph Myers  <joseph@codesourcery.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+
 2023-04-26  Release Manager
 
 	* GCC 13.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 4f603cb8f3f..88b714f849d 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,20 @@
+2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/109409
+	* gcc.dg/pr109409.c: New test.
+
+2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2023-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/107682
+	PR c/109412
+	* gcc.dg/pr109412.c: New test.
+
 2023-04-26  Andrew Stubbs  <ams@codesourcery.com>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 84d62c13f51..3bd827021b5 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,31 @@
+2023-04-27  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2023-04-27  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/mofunc_impl.h: Fix typo in doxygen comment.
+	* include/std/format: Likewise.
+
+2023-04-27  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2023-04-27  Jonathan Wakely  <jwakely@redhat.com>
+
+	* doc/doxygen/user.cfg.in (SOURCE_BROWSER): Only set to YES for
+	HTML docs.
+	* include/bits/gslice_array.h (_DEFINE_VALARRAY_OPERATOR): Omit
+	from doxygen docs.
+	* include/bits/indirect_array.h (_DEFINE_VALARRAY_OPERATOR):
+	Likewise.
+	* include/bits/mask_array.h (_DEFINE_VALARRAY_OPERATOR):
+	Likewise.
+	* include/bits/slice_array.h (_DEFINE_VALARRAY_OPERATOR):
+	Likewise.
+	* include/std/valarray (_DEFINE_VALARRAY_UNARY_OPERATOR)
+	(_DEFINE_VALARRAY_AUGMENTED_ASSIGNMENT)
+	(_DEFINE_VALARRAY_EXPR_AUGMENTED_ASSIGNMENT)
+	(_DEFINE_BINARY_OPERATOR): Likewise.
+
 2023-04-26  Release Manager
 
 	* GCC 13.1.0 released.

commit ffc6b225c955a3d8478de1beba5ad08a7396648c
Author: Andrew Stubbs <ams@codesourcery.com>
Date:   Wed Apr 26 16:23:48 2023

    amdgcn: Fix addsub bug
    
    The vec_fmsubadd instuction actually had add twice, by mistake.
    
    Also improve code-gen for all the complex patterns by using properly
    undefined values.  Mostly this just prevents the compiler reserving space
    in the stack frame.
    
    gcc/ChangeLog:
    
            * config/gcn/gcn-valu.md (cmul<conj_op><mode>3): Use gcn_gen_undef.
            (cml<addsub_as><mode>4): Likewise.
            (vec_addsub<mode>3): Likewise.
            (cadd<rot><mode>3): Likewise.
            (vec_fmaddsub<mode>4): Likewise.
            (vec_fmsubadd<mode>4): Likewise, and use sub for the odd lanes.
    
    (cherry picked from commit b17c57b06d90f2ca12ea0395046c4ea7d439065f)

diff --git a/gcc/config/gcn/gcn-valu.md b/gcc/config/gcn/gcn-valu.md
index 44c48468dd6..7290cdc2fd0 100644
--- a/gcc/config/gcn/gcn-valu.md
+++ b/gcc/config/gcn/gcn-valu.md
@@ -2323,8 +2323,9 @@
     rtx even = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (even, get_exec (0x5555555555555555UL));
     rtx dest = operands[0];
-    emit_insn (gen_<cmul_subadd><mode>3_exec (dest, t1, t1_perm, dest, even));
-                                                             // a*c-b*d 0
+    emit_insn (gen_<cmul_subadd><mode>3_exec (dest, t1, t1_perm,
+                                              gcn_gen_undef (<MODE>mode),
+                                              even));            // a*c-b*d 0
 
     rtx t2_perm = gen_reg_rtx (<MODE>mode);
     emit_insn (gen_dpp_swap_pairs<mode> (t2_perm, t2));          // b*c a*d
@@ -2368,7 +2369,8 @@
     rtx even = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (even, get_exec (0x5555555555555555UL));
     rtx dest = operands[0];
-    emit_insn (gen_sub<mode>3_exec (dest, t1, t2_perm, dest, even));
+    emit_insn (gen_sub<mode>3_exec (dest, t1, t2_perm,
+                                    gcn_gen_undef (<MODE>mode), even));
 
     rtx odd = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (odd, get_exec (0xaaaaaaaaaaaaaaaaUL));
@@ -2392,7 +2394,8 @@
     rtx dest = operands[0];
     rtx x = operands[1];
     rtx y = operands[2];
-    emit_insn (gen_sub<mode>3_exec (dest, x, y, dest, even));
+    emit_insn (gen_sub<mode>3_exec (dest, x, y, gcn_gen_undef (<MODE>mode),
+                                    even));
     rtx odd = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (odd, get_exec (0xaaaaaaaaaaaaaaaaUL));
     emit_insn (gen_add<mode>3_exec (dest, x, y, dest, odd));
@@ -2419,7 +2422,9 @@
 
     rtx even = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (even, get_exec (0x5555555555555555UL));
-    emit_insn (gen_<cadd_subadd><mode>3_exec (dest, x, y, dest, even));
+    emit_insn (gen_<cadd_subadd><mode>3_exec (dest, x, y,
+                                              gcn_gen_undef (<MODE>mode),
+                                              even));
     rtx odd = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (odd, get_exec (0xaaaaaaaaaaaaaaaaUL));
     emit_insn (gen_<cadd_addsub><mode>3_exec (dest, x, y, dest, odd));
@@ -2439,7 +2444,8 @@
     rtx even = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (even, get_exec (0x5555555555555555UL));
     rtx dest = operands[0];
-    emit_insn (gen_sub<mode>3_exec (dest, t1, operands[3], dest, even));
+    emit_insn (gen_sub<mode>3_exec (dest, t1, operands[3],
+                                    gcn_gen_undef (<MODE>mode), even));
     rtx odd = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (odd, get_exec (0xaaaaaaaaaaaaaaaaUL));
     emit_insn (gen_add<mode>3_exec (dest, t1, operands[3], dest, odd));
@@ -2459,10 +2465,11 @@
     rtx even = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (even, get_exec (0x5555555555555555UL));
     rtx dest = operands[0];
-    emit_insn (gen_add<mode>3_exec (dest, t1, operands[3], dest, even));
+    emit_insn (gen_add<mode>3_exec (dest, t1, operands[3],
+                                    gcn_gen_undef (<MODE>mode), even));
     rtx odd = gen_rtx_REG (DImode, EXEC_REG);
     emit_move_insn (odd, get_exec (0xaaaaaaaaaaaaaaaaUL));
-    emit_insn (gen_add<mode>3_exec (dest, t1, operands[3], dest, odd));
+    emit_insn (gen_sub<mode>3_exec (dest, t1, operands[3], dest, odd));
 
     DONE;
   })
